define(function(require, exports, module){

	var channelType = require("./channelType");

	var requestByNative = require("./requestByNative");
	var requestByAjax = require("./requestByAjax");
	var requestByMock = require("./requestByMock");

	var request;
	if(config.base.mock_server) request = requestByMock;
	else if(ENABLE_PHONEGAP) request = requestByNative;
	else request = requestByAjax;


	var HttpRequester = module.exports = function(){
		this.storage = new CustomStorage();
		this.requestList = [];
	};

	_.extend(HttpRequester.prototype, Backbone.Events, {

		request: function(urlKey, options){
			options = options || {};
			var self = this;

			var deferred = $.Deferred();
			deferred.completeCallbacks = $.Callbacks("once memory");
			deferred.complete = deferred.completeCallbacks.add;

			if(options.success) deferred.done(options.success);
			if(options.error) deferred.fail(options.error);
			if(options.complete) deferred.completeCallbacks.add(options.complete);

			var settings = _.defaults({}, options, {
				url: this.getUrl(urlKey),
				type: "POST",
				dataType: "JSON",
				urlKey: urlKey,
				cancelWhenRouting: true
			});

			settings.success = undefined;
			settings.error = undefined;
			settings.complete = undefined;
			settings.tokenKey = this.getInterceptLossRoute(settings.urlKey);
			if(settings.tokenKey){
				this.getToken(settings.tokenKey.key).progress(_.bind(function(tokenValue){
					settings.data = this.attachTokenAdditionalData(settings.data, tokenValue);

					var cachedData = this.storage.get(urlKey);
					if(cachedData){
						deferred.resolve(cachedData, "success");
						deferred.completeCallbacks.fireWith(null, cachedData, "success");
						return deferred;
					}

					this.trigger("before:request", settings);

					var process = request(settings, function(status, data){
						self.onRequestComplete(status, data, process, deferred, settings);
						self.trigger("after:request", settings);
					});
					process.settings = settings;

					this.requestList.push(process);

					return deferred;
				},this));
			}else{
				settings.data = this.attachAdditionalData(settings.data);

				var cachedData = this.storage.get(urlKey);
				if(cachedData){
					deferred.resolve(cachedData, "success");
					deferred.completeCallbacks.fireWith(null, cachedData, "success");
					return deferred;
				}

				this.trigger("before:request", settings);

				var process = request(settings, function(status, data){
					self.onRequestComplete(status, data, process, deferred, settings);
					self.trigger("after:request", settings);
				});
				process.settings = settings;

				this.requestList.push(process);

				return deferred;
			}
		},

		onRequestComplete: function(status, data, process, deferred, settings){
			this.requestList = _.without(this.requestList, process);

			if(status == "canceled") return;

			// session timeout
			if(status == "success" && data && (data.code == "400" || data.code == "100" || data.code == "402")) {
				this.handleSessionTimeout(data.code);
				_(this.requestList.splice(0)).forEach(function(process){
					if(process && process.cancel) process.cancel();
				});
				return;
			}

			var err;
			if(status === "parseerror") err = { message: "响应数据格式异常" };
			if(status === "timeout") err = { message: "请求超时，请重试" };
			if(status === "offline") err = { message: "网络连接失败，请检查你的网络设置" };
			if(data && !data.success) err = data;
			if(status != "success" && !err) err = { message: "数据请求失败，请重试" };
			if(data && data.code == "600") err = {message : data.message};
			if(err && status == "success") status = "error";

			try {
				if (err) {
					deferred.reject(err, status);
				} else {
					deferred.resolve(data, status);
					if (settings.cache == true) {
						this.storage.set(settings.urlKey, data);
					}
					if (App.storage.get("isToaFLoginIn") && App.storage.get("isUserLoggedIn") && settings.url != config.urls.get('bankToaMaintainLogin')) {
						utils.native.setToaFHearBeat();
					}
				}
				deferred.completeCallbacks.fire(err, data, status);

			}catch(e){ console.log(e); }
		},

		getUrl:function(urlKey){
			return config.urls.get(urlKey) || urlKey;
		},

		attachAdditionalData: function(data){
			return _.defaults({}, data, { channelType: channelType });
		},

		attachTokenAdditionalData: function(data, tokenValue){
			return _.defaults({}, data, { channelType: channelType, tokenValue: tokenValue });
		},

		handleSessionTimeout: function(code){
			var msg ="登录超时，请重新登录";
			if(code == "402"){
				msg = "用户已在别处重新登录，强制下线! ";
			}
			utils.dialog.alert(msg, function(){
				//超时情况下隐藏密码弹框以及密码键盘
				nativeBroadcast.trigger("keyboard:click:left:right:cancel:keyboard:button");
				App.commands.execute("logout", true);
			})
		},

		getInterceptLossRoute: function(url){
			var requestURL = [
				{'url':'currentToFixedTransferConfirm','key':'tokenFixedIn'},   //定活通转入
				{'url':'profitTransferInto','key':'tokenPAYIn'},                //平安盈转入
				{'url':'toBuyFinanceConfirm','key':'tokenFinanceIn'},           //理财转入
				{'url':'goldAcctBuyOrRedeemGold','key':'tokenGoldInOrOut'},     //黄金转入转出
				{'url':'fundBuy','key':'tokenFundIn'},                          //基金转入
				{'url':'fundEntrustRevoke','key':'tokenCommision4PAY'},         //基金委托撤销
				{'url':'toBuyPensionConfirm','key':'tokenPensionIn'},           //直通专属养老保障产品转入
				{'url':'fixedToCurrentTransferConfirm','key':'tokenFixedOut'},  //定活通转出
				{'url':'profitTransferExport','key':'tokenPAYOut'},             //平安盈转出
				{'url':'profitTransferExportAddOne','key':'tokenPAYAddOneOut'}, //平安盈转出T+1
				{'url':'fundRedeem','key':'tokenFundOut'},                      //基金转出
				{'url':'pensionEntrustRevocation','key':'tokenRevokeBuyTrust'}, //理财、养老产品委托撤销
				{'url':'vToken','key':'tokenSendOtp'},
				{'url':'toBuyPapiaoConfirm','key':'tokenPapiaoIn'},                  //快E盈 购买
				{'url':'appToBuyGoldConfirm','key':'tokenGoldFinanceIn'},            //app购买黄金宝
				{'url':'updateAccountGXInfo','key':'tokenCSRFInfoModify'},           //个人信息修改
				{'url':'updateAccountContactInfo','key':'tokenContactInfoModify'},   //联系信息
				{'url':'pingAnPRevocation','key':'tokenRevokeBuyPapTrust'},          //快E盈委托撤销
				{'url':'fundFix','key':'tokenFundFixIn'},                            //基金定投
				{'url':'toRevokeEntrustGold','key':'tokenRevokeEntrustGoldTrust'},   //黄金宝赎回委托撤销
				{'url':'goldTreasureRedempSubmit','key':'tokenGoldFinanceOut'},      //黄金宝预约赎回提交
				{'url':'financialEntrustRevocation','key':'tokenRevokeRedeemTrust'}, //理财产品赎回委托撤销
				{'url':'financialRedemption','key':'tokenFinanceRedeemOut'},         //理财产品赎回
				{'url':'buyBillConfirm','key':'tokenBillIn'},                        //小票购买
				{'url':'addNewDream','key':'tokenAddDream'},              //添加梦想
				{'url':'dreamSpeech','key':'tokenManageDream'},           //梦想感言
				{'url':'qryOrderForBuying','key':'tokenPushPurchase'},    //购买抢购产品
				{'url':'buyFundStrong','key':'tokenFundStrongBuy'},       //每日盈购买
				{'url':'fundStrongRedeem','key':'tokenFundStrongRedeem'},  //每日盈赎回
				{'url':'sameBankEnterConfirm','key':'tokenSBankTransferIn'},			// 本贷本转入
				{'url':'borrowMoney','key':'tokenBorrowMoney'}			// 橙易贷提款
			];
			return _.find(requestURL,function(r){
				return r.url == url;
			});
		},

		getToken: function(key){
			var dfd = $.Deferred();
			var tokenValue = "";
			App.request("defineRepeatSubmit",{
				data : { defineTypeName: key},
				success : function(resp){
					tokenValue = resp.object.tokenValue;
					dfd.notify(tokenValue);
				},
				error   : function(resp){
					console.log(resp.message);
					dfd.notify(tokenValue);
				}
			});
			return dfd;
		}
	});
});