/*
 * @author ex-zhengzongyi001
 * @modify ex-wangqiang001
 * @description 对iScroll进行了封装，实现下拉刷新和上拉加载更多
 */
define(["vendor/iscroll"], function(iScroll){

    function BaseClass(){}
    BaseClass.prototype = iScroll.prototype;

    var html_pull_down = '<div class="pullDown"></div>';
    var html_pull_down_to_refresh = '<div class="pullTxt"><span class="pullDownIcon"></span>&nbsp;&nbsp;<span class="pullDownLabel">下拉刷新...</span></div>';
    var html_release_to_refresh =  '<div class="pullTxt"><span class="pullDownIcon"></span>&nbsp;&nbsp;<span class="pullDownLabel">松开立即刷新...</span></div>';
    //var html_refreshing = '<div class="pullTxt">正在刷新...</div>';
    var html_refreshing = '<div class="pullTxt"><span class="pullLoading"></span>&nbsp;正在刷新...</div>';

    var html_pull_up = '<div class="pullUp"></div>';
    var html_pull_up_to_load_more = '<div class="pullTxt"><span class="pullUpIcon"></span>&nbsp;&nbsp;<span class="pullUpLabel">上拉加载更多...</span></div>';
    var html_release_to_load_more = '<div class="pullTxt"><span class="pullUpIcon"></span>&nbsp;&nbsp;<span class="pullUpLabel">松开立即加载...</span></div>';
    //var html_loading = '<div class="pullTxt">正在加载...</div>';
    var html_loading = '<div class="pullTxt"><span class="pullLoading"></span>&nbsp;正在加载...</div>';

    function PTRScroll(el, options){
        options = _.extend({}, PTRScroll.defaultOptions, options);

        iScroll.call(this, el, options);
        this._initializeDOMStructure();
        this._status = {};

        // 2015-07-03 wuyongsheng560 滑动时边界检测
        // 针对 ios8 当UIWebview非全屏时 手指滑出 UIWebview
        // 无法 触发 touchend || touchcancel 事件 iscroll
        // 不能返回初始状态, 具体原因未找到。
        // ============================================
        var isIos8 = (/iphone|ipad/gi).test(navigator.appVersion) && parseInt(navigator.appVersion.match(/OS (\d+)_(\d+)_?(\d+)?/)[1]) > 7;
        this.threshold = isIos8 && options.threshold !== false;
        var clientRect = this.wrapper.getBoundingClientRect();
        this.thresholdY = options.thresholdY ? options.thresholdY : [clientRect.top, clientRect.bottom];

        this.options.topOffset = this._pullDownOffset();
        this.refresh();
        this.scrollTo(0, -this.options.topOffset, 0);
    }

    PTRScroll.prototype = _.extend(new BaseClass, {
        constructor: PTRScroll,

        _setMinScrollY: function(minScrollY){
            this.minScrollY = minScrollY;
            this.scrollerW = Math.round(this.scroller.offsetWidth * this.scale);
            this.scrollerH = Math.round((this.scroller.offsetHeight + this.minScrollY) * this.scale);
            this.maxScrollX = this.wrapperW - this.scrollerW;
            this.maxScrollY = this.wrapperH - this.scrollerH + this.minScrollY;
       },

       _pullDownOffset: function(recalculate){
            if(!this.options.pullDownToRefresh) return 0;
            if(!this.pullDownEl) return 0;
            // hard code 28px, for that
            // offsetHeight is 0 if entire scroller is hidden
            return this.pullDownEl.outerHeight(true) || 34;
        },

        _initializeDOMStructure: function(){
            this.pullDownEl = $(html_pull_down).prependTo(this.scroller);
            this._renderComponentByStatus("pulldown to refresh");

            this.pullUpEl = $(html_pull_up).appendTo(this.scroller);
            this._renderComponentByStatus("pullup to load more");
        },

        //启用下拉刷新
        enablePullDownToRefresh: function(){
            this.options.pullDownToRefresh = true;
            this._status.toRefresh = this._status.refreshing = false;
            this._renderComponentByStatus("pulldown to refresh");
            this.refresh();
        },

        //禁止下拉刷新
        disablePullDownToRefresh: function(){
            this.options.pullDownToRefresh = false;
            this.options.topOffset = this._pullDownOffset();
            this.refresh();
        },

        //启用上拉加载
        enablePullUpToLoadMore: function(){
            this.options.pullUpToLoadMore = true;
            this._status.toLoad = this._status.loading = false;
            this._renderComponentByStatus("pullup to load more");
            this.refresh();
        },

        //禁止上拉加载
        disablePullUpToLoadMore: function(){
            this.options.pullUpToLoadMore = false;
            this.refresh();
        },

        disabledPullUpToLoadMore: function(){
            if(console){console.log("*Deprecated*, rename to disablePullUpToLoadMore");}
            return this.disablePullUpToLoadMore.apply(this, arguments);
        },

        refresh: function(){
            this.pullDownEl && this.pullDownEl.toggle(this.options.pullDownToRefresh);
            this.pullUpEl && this.pullUpEl.toggle(this.options.pullUpToLoadMore);

            this.options.topOffset = this._pullDownOffset();
            return iScroll.prototype.refresh.apply(this, arguments);
        },

        destroy: function(){
            this.pullDownEl.remove();
            this.pullUpEl.remove();
            return iScroll.prototype.destroy.apply(this, arguments);
        },

        _renderComponentByStatus: function(keyword){
            if(keyword === "pulldown to refresh")//下拉刷新
                return this.pullDownEl && this.pullDownEl.html(html_pull_down_to_refresh);
                //return this.pullDownEl && this.pullDownEl.find(".pullDownLabel").html("下拉刷新...");
            if(keyword === "release to refresh")//下拉松开立即刷新
                //return this.pullDownEl && this.pullDownEl.html(html_release_to_refresh);
                return this.pullDownEl && this.pullDownEl.find(".pullDownLabel").html("松开立即刷新...");
            if(keyword === "refreshing")//下拉刷新，正在刷新
                //return this.pullDownEl && this.pullDownEl.html(html_refreshing);
                return this.pullDownEl && this.pullDownEl.find(".pullDownIcon").removeClass("pullDownIcon").addClass("pullLoading") && this.pullDownEl.find(".pullDownLabel").html("正在刷新...");
            if(keyword === "pullup to load more")//上拉加载更多
                return this.pullUpEl && this.pullUpEl.html(html_pull_up_to_load_more);
                //return this.pullUpEl && this.pullUpEl.find(".pullUpLabel").html("上拉加载更多...");
            if(keyword === "release to load more")//松开立即加载
                //return this.pullUpEl && this.pullUpEl.html(html_release_to_load_more);
                return this.pullUpEl && this.pullUpEl.find(".pullUpLabel").html("松开立即加载...");
            if(keyword === "loading")//正在加载
                //return this.pullUpEl && this.pullUpEl.html(html_loading);
                return this.pullUpEl && this.pullUpEl.find(".pullUpIcon").removeClass("pullUpIcon").addClass("pullLoading") && this.pullUpEl.find(".pullUpLabel").html("正在加载...");

            //为了动画不修改只修改label下的字符
            if(keyword === "pulldown to refresh animation")//下拉刷新
                return this.pullDownEl && this.pullDownEl.find(".pullDownLabel").html("下拉刷新...");
            if(keyword === "pullup to load more animation")//上拉加载更多
                return this.pullUpEl && this.pullUpEl.find(".pullUpLabel").html("上拉加载更多...");

        }

    });

    PTRScroll.defaultOptions = {
        // hide scrollbar default
        hScrollbar: false,
        vScrollbar: true,

        refreshContent: function(){},
        loadMoreContent: function(){},

        pullDownToRefresh: true,
        pullUpToLoadMore: true,

        onScrollMove: function(e){
            var status = this._status;

            if(this.options.pullDownToRefresh){
                //下拉距离>20并
                if(!status.toRefresh && this.y > 20){
                    status.toRefresh = true;
                    this._renderComponentByStatus("release to refresh");
                    this.pullDownEl.addClass("flip");
                    this._setMinScrollY(0);
                }

                if(status.toRefresh && this.y <= 20){
                    status.toRefresh = false;
                    this._renderComponentByStatus("pulldown to refresh animation");
                    this.pullDownEl.removeClass("flip");
                    this._setMinScrollY(-this._pullDownOffset());
                }
            }

            if(this.options.pullUpToLoadMore){
                //上拉距离
                if(!status.toLoad && this.y < Math.min(this.maxScrollY, this.minScrollY) - 20){
                    status.toLoad = true;
                    this._renderComponentByStatus("release to load more");
                    this.pullUpEl.addClass("flip");
                }

                if(status.toLoad && this.y >= Math.min(this.maxScrollY, this.minScrollY) - 20){
                    status.toLoad = false;
                    this._renderComponentByStatus("pullup to load more animation");
                    this.pullUpEl.removeClass("flip");
                }
            }

            if (this.threshold) {
                if ((this.pointY < this.thresholdY[0] && this.y < this.maxScrollY) || (this.pointY > this.thresholdY[1] && (this.y >= this.minScrollY || this.maxScrollY > 0))) {

                    this._resetPos(400);
                }
            }
        },

        onScrollEnd: function(){
            var that = this;
            var status = this._status;

            if(status.toRefresh){
                this._renderComponentByStatus("pulldown to refresh");
                this.pullDownEl.removeClass("flip");
            }
            if(status.toLoad){
                this._renderComponentByStatus("pullup to load more");
                this.pullUpEl.removeClass("flip");
            }

            if(this.options.pullDownToRefresh && status.toRefresh && !status.refreshing){
                status.refreshing = true;
                this._renderComponentByStatus("refreshing");
                this.options.refreshContent.call(this, function(){
                    _.defer(function(){
                        status.refreshing = status.toRefresh = false;
                        that._renderComponentByStatus("pulldown to refresh");
                        that.refresh();
                    });
                });
            }

            if(this.options.pullUpToLoadMore && status.toLoad && !status.loading){
                status.loading = true;
                this._renderComponentByStatus("loading");
                this.options.loadMoreContent.call(this, function(){
                    _.defer(function(){
                        status.loading = status.toLoad = false;
                        that._renderComponentByStatus("pullup to load more");

                        // hold current minScrollY after refresh
                        var topOffset = that.options.topOffset;
                        if(status.refreshing) that.options.topOffset = that.minScrollY;
                        that.refresh();
                        if(status.refreshing) that.options.topOffset = topOffset;
                    });
                });
            }

        }

    };

    return PTRScroll;
});