/**
 * ex-huangzit 首页 登陆视图
 */
define(function (require, exports, module) {
    var IdentityModel = require('mod/verifyAccount/model/identityModel');
    var transModel = require('mod/me/model/transferModel');

    module.exports = {
        _userInfo: function () {
            return App.storage.get('UserInfo').toJSON() || {};
        },

        newBindFlag: function () {
            var userInfo = this._userInfo(), //用户信息
                cardState = userInfo.cardState;
            if (
                userInfo.bindCardFlag === '1' &&
                (
                    cardState == '0' || cardState == '2' ||
                    (cardState == '1' && userInfo.activeState == '0')
                    )
                ) {
                return true;
            }

            return false;
        },

        /**
         * 新激活注册流程开关，开：来帐关闭，弹框展示；关：来帐开启，弹框隐藏
         */
        activeSwitch: function (options) {
            var self = this;
            options = options || {};
            if (options.constructor.name === "Boolean") options = {back: options};
            self.back = options.back || false;
            App.storage.set('bindCardFlag_first', true);

            if (options.susFlag) {
                var suspitions = App.storage.get('suspitions');
                if (suspitions === void 0 || !suspitions) {
                    IdentityModel.checkAccountSuspicious({
                        url: "checkAccountSuspicious",
                        data: {},
                        callback: function (res) {
                            var isSuspicious = res.object && res.object.isSuspicious;
                            App.storage.set('suspitions', isSuspicious === 'N');
                            if (isSuspicious === 'N') { //非可疑用户
                                self.queryUserState();
                            } else {
                                utils.dialog.alert('由于您的账户存在风险，如需进行交易，请联系电话中心95511-3，客服将告知具体操作流程。', function () {
                                    self._back();
                                });
                            }
                        },
                        errorCallback: function (error) {
                            utils.dialog.alert(error.message, function () {
                                self._back();
                            });
                        }
                    });
                    return;
                }
            }
            //判断是否冻结用户：是则跳到提示页面
            this.queryUserState();
        },

        /**
         * 未激活情况下弹框提示用户：
         * 0:非一账通用户，需要完善一账通信息;
         * 1:没有绑定的一账通用户，需要用户名、密码校验;
         * 2:绑定的一账通用户，未设置交易密码，需设置(关联开户);
         * 3:绑定的一账通用户，已设置交易密码，直接进入绑定借记卡
         */
        queryUserState: function () {
            var cradLossStatus = App.storage.get("cradLossStatus");
            if (cradLossStatus) {
                App.storage.set('backUrl', 'index/indexLogined/index');
                App.navigate('common/accountInfoCon/accountLoss', true);
                return;
            }

            var self = this;
            IdentityModel.validateUserInfo({
                callback: function (res) {
                    var userFlag = res.object.userFlag;
                    var userInfoOption = {
                        mobile: res.object.mobile,
                        email: res.object.email,
                        userFlag: userFlag,
                        birthDate: res.object.birthDate
                    };
                    App.storage.set("verifyAccount/userInfoOption", userInfoOption);
                    switch (userFlag) {
                        case "0":
                            self.yztInfoTip("verifyAccount/main/accountInfoSet");
                            break;
                        case "1":
                            self.yztInfoTip("verifyAccount/main/verifyYZT");
                            break;
                        case "2":
                            self.yztInfoTip("verifyAccount/main/accountInfoImprove");
                            break;
                        case "3":
                            self.queryBindList(); //先弹框，在跳转到绑卡
                            break;
                        default:
                            utils.dialog.alert("橙子账号状态不正常，请联系橙子客服，谢谢！");
                            break;
                    }
                },
                errorCallback: function (res) {
                    utils.dialog.alert(res.message);
                }
            });
        },

        //查询当前绑定的账户
        queryBindList: function () {
            var self = this;
            transModel.qryBindAccount({
                "url": "qryBindAccount",
                "callback": function (response) {
                    if (!response.object.list || !response.object.list.length) {
                        self.bindAccountTip();
                    }
                },
                "errorCallback": function (response) {
                    utils.dialog.alert(response.message);
                }
            });
        },

        //绑卡提示
        bindAccountTip: function () {
            var self = this;
            var message = "尊敬的客户，您还未绑定借记卡，建议您马上去绑卡。";
            var addMain = App.storage.remove("addBindCard/addMain"); //判断从‘我-银行卡管理’入口进入，不需要弹绑定提示框
            if(addMain){
                App.navigate('verifyAccount/bindCard/inputBindCard', true);
            }else{
                utils.dialog.confirm(message, {
                    title: "提示",
                    okButtonText: "马上绑卡",
                    cancelButtonText: "下次再说"
                },function (ok) {
                        if (ok) { //跳到绑卡页面
                            App.navigate('verifyAccount/bindCard/inputBindCard', true);
                        } else {
                            self._back();
                        }
                    }
                );
            }
        },

        //完善一账通信息提示
        yztInfoTip: function (url) {
            var self = this;
            var message = "尊敬的客户，您还未设置安全信息及绑定借记卡，建议您马上设置并完成绑卡。";
            utils.dialog.confirm(message, {
                title: "提示",
                okButtonText: "马上设置",
                cancelButtonText: "下次再说"
            },
                function (ok) {
                    if (ok) {
                        App.navigate(url, true);
                    } else {
                        self._back();
                    }
                }
                );
        },

        _back: function () {
            if (!this.back || !this.fragment || !this.prev) return;
            this.back = false;

            if (this.fragment === this.prev) {
                App.back();
            } else {
                if (!~this.prev.indexOf('login/login')) {
                    App.navigate(this.prev, true);
                } else {
                    App.navigate('me/logined/index', true);
                }
            }
        }
    };
});
