define(function (require, exports, module) {

	var IS_ANDROID = ENABLE_PHONEGAP && IS_RUN_ON_ANDROID;
	var IS_IDEVICE = ENABLE_PHONEGAP && IS_RUN_ON_IDEVICE;


	// KEYBOARD TYPES:
	// - decimal
	// - number
	// - ascii
	// - password-number
	// - password-ascii

	// CUSTOMINPUT CLASS DEFINITION
	// ============================

	var CustomInput = function(element, options){
		this.options = this.getOptions(options);
		this.$element = $(element);
		this.$input = this.createInput();

		this.insertInput();
		this.render();
	};

	CustomInput.prototype.getOptions = function(options){
		return $.extend({
			type: "decimal",
			className: "",
			placeholder: "",
			maxLength: 524288
		}, options);
	};

	CustomInput.prototype.isMoneyInput = function(){
		return /decimal/i.test(this.options.type);
	};

	CustomInput.prototype.isSupportPlaceholderText = function(){
		return this.$input.prop("type") != "button";
	};

	CustomInput.prototype.isCustomKeyboard = function(){
		var type = this.options.type;
		if(IS_IDEVICE)
			return true;

		if(IS_ANDROID) return true;

		return false;
		//return IS_ANDROID || (IS_IDEVICE && this.options.type === "password-ascii");
	};

	CustomInput.prototype.render = function(){
		this.$element.addClass("customInput");

        if(this.isMoneyInput()){
            this.$input.addClass("customInput-input spaninput tal");
        }else{
            this.$input.addClass("customInput-input spaninput2 tal");
        }

		this.$input.addClass(this.options.className);
		this.$input.prop("maxLength", this.options.maxLength);
		this.$input.prop("placeholder", this.options.placeholder);

        if(this.isCustomKeyboard()) this.$input.val(this.options.placeholder);

	};

	CustomInput.prototype.createInput = function(){
		var input = $("<input />");
		var type = this.options.type;
		var inputType = "text";

		if(IS_ANDROID || IS_IDEVICE) inputType = "button";
		else if(!this.isMoneyInput()) inputType = "password";
		input.prop("type", inputType);

		return input;
	};

	CustomInput.prototype.insertInput = function(){
		var placeholderElement = this.$element.find("");
		var inputContainer = $("<div class='flex1 customInput-input-container'><i class='twinkling'></i></div>");
		inputContainer.prepend(this.$input);
		if(placeholderElement.length) placeholderElement.replaceWith(this.$input);
		else this.$element.append(inputContainer);

	};


	CustomInput.prototype.value = function(newValue){
		if(newValue == undefined)
			return this.getValue();
		this.setValue(newValue);
	};

	CustomInput.prototype.getValue = function(){
		if(this.isCustomKeyboard()) {
			var value = this.$element.data("customInput.value");

			// 在IOS平台下，有的时候文本域获得焦点了，但是自定义键盘并没有弹出，此时出现的是系统键盘（例如苹果审核
			// 应用的时候有可能是用实体键盘输入的）。这种情况下从$.data取不到值，以input.value值取代
			if(IS_IDEVICE && !value && this.isSupportPlaceholderText()){
				value = this.$input.val();
			}

			return value || "";
		}

		return this.$input.val() || "";
	};

	CustomInput.prototype.setValue = function(newValue){
		if(typeof newValue === "function"){
			newValue = newValue.call(this, this.value());
		}

		if(this.isCustomKeyboard()){
			this.$element.data("customInput.value", newValue);
			this.renderText(newValue);
			return;
		}

		this.$input.val(newValue);
	};

	CustomInput.prototype.renderText = function(value){
		var text = value || "";

		if(!this.isMoneyInput())
			text = text.replace(/./g, "*");

		this.$input.val(text);
		// this.$input.toggleClass("", isEmpty);
	};


	CustomInput.prototype.hideKeyboard = function(){
		if(this.isCustomKeyboard()){
			utils.native.hideSafeKeyboard();
		}
	};

	CustomInput.prototype.showKeyboard = function(){
		if(this.isCustomKeyboard()){
			var rect = this.$input[0].getClientRects()[0];
			window.setTimeout(_.bind(function(){
			    utils.native.showSafeKeyboard({
                    currentYPos: rect.top + rect.height,
                    inputType: this.options.type
                });
			},this),100);

		}

	};

	CustomInput.prototype.format = function(){
		if(this.options.type === "decimal"){
			this.value(function(oldValue){
				oldValue = oldValue.replace(/[^.\d]/g, "");
				return utils.string.numberFormat(oldValue, 2);
			});
		}
	};

	CustomInput.prototype.stripFormat = function(){
		if(this.options.type === "decimal"){
			this.value(function(oldValue){
				var o = oldValue.replace(/[^.\d]/g, "");
				// 如果小数点后是0就删掉，否则如果最后一位是0也删掉
				// by 7iang
				if(o.indexOf(".") != -1){
					var num = o.split(".");
					if(num[1] == 0){
						return num[0];
					}else if(num[1].substr(1,1) == 0){
						return num[0]+"."+num[1].substr(0,1);
					}else{
						return o;
					}
				}
			});
		}
	};

	CustomInput.prototype.focus = function(){
	    if(this.isCustomKeyboard()){
	        if(this.getValue().length==0){
                this.$input.val("");
            }
            this.$input.addClass("on");
            this.$input.next().css({"display":"inline-block"});
            this.$input.focus();
            this.$input.closest("li").prev().find("input").blur();
	    }
		this.$input.trigger("customInputFocusIn");
		this.stripFormat();
		this.showKeyboard();
		nativeBroadcast.off("keyboard:input");
		nativeBroadcast.on("keyboard:input", function(character){
			if(CustomInput.activeInput){
				CustomInput.activeInput.handlePressCustomKeyboard(character);
			}
		});
	};

	CustomInput.prototype.blur = function(){
	    if(this.isCustomKeyboard()){
	        if(this.getValue().length==0){
	            this.$input.removeClass("on");
                this.$input.val(this.options.placeholder);
            }
            this.$input.next().css({"display":"none"});
	    }
	    if(this.getValue().length!=0){
	        this.format();
	    }
		this.$input.trigger("customInputFocusOut");
		if(App.isShowKeyborad) return;
		window.setTimeout(_.bind(function(){
		    this.hideKeyboard();
		},this),10);

	};

	CustomInput.prototype.handlePressCustomKeyboard = function(character){
        if(character!="del" && this.options.type == "password-number"){
            if(isNaN(character)) return;
        }
		var maxLength = this.options.maxLength;
		var isBackspace = character == "del";
		var originalValue = this.value();

		if(!isBackspace && originalValue.length >= maxLength)
			return;

		if(character === "." && (originalValue === "" || originalValue.indexOf(".") != -1))
			return;

		// 金额框只能输入两位小数
		// by 7iang
		if(this.options.type === "decimal"){
			if(originalValue.indexOf(".") != -1){
				var o = originalValue.split(".");
				if(o[1].length>1 && !isBackspace)return;
			}
		}

		if(isBackspace) this.value(originalValue.replace(/.$/, ""));
		else this.value(originalValue + character);


		this.$input.trigger("customInputKeyup");
	};




	// CUSTOMINPUT PLUGIN DEFINITION
	// =============================

	$.fn.customInput = function(options){
		var returnValue, method, args;

		if(typeof options == "string"){
			method = options;
			args = $.makeArray(arguments).slice(1);
			options = {};
		}

		this.each(function(){
			var $element = $(this);
			var instance = $element.data("customInput");
			var val;

			if(!instance) $element.data("customInput", (instance = new CustomInput(this, options)));
			if(method) val = instance[method].apply(instance, args);
			if(returnValue == undefined && val != undefined) returnValue = val;
		});

		return returnValue == undefined ? this : returnValue;
	};


	nativeBroadcast.on("click:header:left:button click:header:right:button", function(){
		if(CustomInput.activeInput){
			CustomInput.activeInput.blur();
			CustomInput.activeInput = null;
		}
	});


	function activateCustomInput(event){
		var customInput = $(event.target).closest(".customInput").data("customInput");

		if(CustomInput.activeInput) CustomInput.activeInput.blur();
		if(customInput) customInput.focus();

		CustomInput.activeInput = customInput;
	}



	$(document).on("tap", activateCustomInput);


	// 从系统键盘(IME)直接切换到自定义键盘（安全键盘），此时计算input的clientRect可能有错，
	// 因为系统键盘还未完全收起。
	// 这里用的解决方案是，android端会在系统键盘(IME)完全关闭时，触发一个事件，并阻止自
	// 定义键盘的显示，由JS端重新发起一个显示自定义键盘的请求
	nativeBroadcast.on("os:softkeyboard:close", function(){
		if(CustomInput.activeInput){
			CustomInput.activeInput.showKeyboard();
		}
	});
	App.isShowKeyborad = false;

});