/**
 * 2015-12-18 wuyongsheng560 人脸识别新流程
 * 依赖壳方法(开发许海鹏):
 *     native.livenessDetection(callback(data: obj)):
 *     data:{
 *         ‘image’:’base64Image’, //图片数据，格式:base64
 *         ‘width’:’200’,         //图片宽度
 *         ‘height’:’200’,        //图片高度
 *
 *         ‘x’:’1’,        //图片中人脸的X坐标
 *         ‘y’:’1’,        //图片中人脸的Y坐标
 *         ‘w’:’1’,        //图片中人脸的宽度
 *         ‘h’:’1’         //图片中人脸的高度
 *     }
 *
 * 依赖后台接口(开发张强):
 *     /rest/account/timeStampEncrypt //加签
 *     /rest/portal/uploadpic/facePhotoUploadToServer //上传人脸图片
 *     /rest/account/faceCompareByPhotoGetResemblance //获得相似度
 */
define(function(require, exports, module) {
    var _noop = function() {};
    var _log = function(msg) {
        console.log(msg);
    };
    /**
     * @param  {Function} callback [error，isSamePeople]
     */
    module.exports = function(callback, options) {
        callback = callback || _noop;
        options = options || {};
        if (!IS_RUN_ON_DEVICE) {
            utils.dialog.alert('人脸识别需在手机端调用!');
            return;
        }

        var log = options.debug ? _log : _noop;
        // 图片压缩选项：0,不压缩, 1, 压缩
        var comflag = options.comflag || '0';
        // 场景号编码规则： B001代表绑卡，A002账户激活  (以功能的字母开头+第几个场景编号)
        var sceneNum = options.sceneNum;
        if (!sceneNum) {
            utils.dialog.alert('人脸识别需要场景号进行统计， B001代表绑卡，A002账户激活。');
            return;
        }

        log('STEP 1 =====>>> 调用获取手机版本信息方法: versionInformation');
        utils.native.versionInformation(function(vd) {
            vd = vd || {};
            var version = vd.version;
            var iModel = vd.model;
            //urlFlag为调用新老接口标记, 0是老接口, 1是新接口
            var urlFlag = 0;
            if (IS_RUN_ON_IDEVICE && iModel) {
                if (5 > (String(iModel).split(',')[0].slice(-1) | 0)) {
                    utils.dialog.alert('IOS版本过低, 不支持此功能!');
                    return;
                }
            }
            if (!version) {
                utils.dialog.alert('获取客户端版本信息异常!');
                return;
            }
            if (209 > (String(version).split('.').join('') | 0)) {
                utils.dialog.alert('客户端版本过低，请升级到新版本。');
                return;
            }
            //如果版本小于或者等于2.1.1 , 那么调用老接口
//            if (211 >= (String(version).split('.').join('') | 0)) {
//                log('调用人脸识别老接口');
//                 urlFlag = 0;
//            }

            log('STEP 2 =====>>> 调用后端加签接口: timeStampEncrypt');
            App.request('timeStampEncrypt').done(function(results) {
                var timeStr = (results.object || {}).timeStr;
                var signInfo = (results.object || {}).signInfo;
                if (!timeStr || !signInfo) {
                    return callback(new Error('加签接口异常!'));
                }

                log('STEP 3 =====>>> 调用人脸识别方法: livenessDetection');
                utils.native.livenessDetection(function(data) {
                    data = data || {};
                    if (!data.image) {
                        return callback(new Error('人脸识别方法异常!'));
                    }
                    data.image = 'data:image/jpeg;base64,' + data.image.replace(/^.+base64,/, '');

                    log('STEP 4 =====>>> 调用后端上传图片接口: facePhotoUploadToServer');
                    App.request('facePhotoUploadToServer', {
                        'data': {
                            'timeStr': timeStr,
                            'signInfo': signInfo,
                            'imageUrl': data.image,
                            'flag': comflag,
                            'width': data.width,
                            'height': data.height
                        }
                    }).done(function(result) {
                        var url = (result.object || {}).imageUrl;
                        var timeStr = (result.object || {}).timeStr;
                        var signInfo = (result.object || {}).signInfo;
                        if (!url || !timeStr || !signInfo) {
                            return callback(new Error('上传图片接口异常!'));
                        }

                        log('STEP 5 =====>>> 调用后端获得相似度接口: faceCompareByPhotoGetResemblance');
                        App.request('faceCompareByPhotoGetResemblance', {
                            'data': {
                                'responsePictureUrl': url,          //图片路径
                                'signInfo': signInfo,               //加签串
                                'timeStr': timeStr,                 //时间戳
                                'urlFlag': urlFlag,                 //访问新旧地址标志，1访问新的URL，0访问旧的URL
                                'sceneNum': sceneNum,               //场景号：B001绑卡，A002账户激活，L003橙易贷
                                'xCoordinate': String(data.x | 0),  //X轴
                                'yCoordinate': String(data.y | 0),  //Y轴
                                'faceWidth': String(data.w | 0),    //人脸图片宽
                                'faceHeight': String(data.h | 0),   //人脸图片高
                                'userAgent': data.userAgent ,  //终端应用是浏览器
                                'terminalType': data.terminalType,  //终端设备类型
                                'terminalSystem': data.terminalSystem,//终端设备使用的软件系统
                                'blurMotion': data.blurMotion,//运动模糊
                                'brightness': data.brightness,//明暗度
                                'deflectionH':data.deflectionH,//水平偏角
                                'deflectionV': data.deflectionV,//上下偏角
                                'contentType': data.contentType//图片格式
                            }
                        }).done(function(res) {
                            //返回是否是同一个人true/false
                            var isSamePeople = !!((res.object || {}).isSamePeople | 0);

                            callback(null, isSamePeople);
                        }).fail(function(error) {
                            callback(error);
                        });

                    }).fail(function(error) {
                        callback(error);
                    });
                });

            }).fail(function(error) {
                callback(error);
            });

        });

    };
});
