define(function (require, exports, module) {

    var componentFactory = require("./formControl/componentFactory");
    var componentQuery = require("./formControl/componentQuery");

    var Form = module.exports = Layout.extend({


        constructor: function(){
            Form.__super__.constructor.apply(this, arguments);
            this._childComponents = [];
        },

        render: function(){
            Form.__super__.render.apply(this, arguments);
            this._destroyComponents();
            this._initializeComponents();
        },

        remove: function(){
            this._destroyComponents();
            Form.__super__.remove.apply(this, arguments);
        },

        find: function(selector){
            return componentQuery.find(selector, this.el);
        },

        findAll: function(selector){
            return componentQuery.findAll(selector, this.el);
        },

        checkValidity: function(){
            return this._check_or_report_validity("checkValidity");
        },

        reportValidity: function(){
            return this._check_or_report_validity("reportValidity")
        },

        _check_or_report_validity: function(method){
            var elements = this._childComponents, elem, i;
            for(i = 0; elem = elements[i]; ++i) {
                if (elem[method] && (elem[method]() == false)) {
                    return false;
                }
            }
            return true;
        },

        _initializeComponents: function(){
            this.triggerMethod("before:init:component");

            this._createComponents();
            this._associateComponents();
            this._setDefaultErrorMessages();

            this.triggerMethod("init:component");
        },

        _createComponents: function(){
            var form = this;
            this.$el.find("[data-component]").each(function(idx, htmlElement){
                var component = componentFactory.createComponent(htmlElement, form);
                form._childComponents.push(component);
            });
        },

        _associateComponents: function(){
            var form = this;
            var properties = {};

            _.each(this._childComponents, function(component){
                _.each(["id", "name"], function(key){
                    if(!(key = component[key])) return;
                    if(!properties[key]) properties[key] = [];
                    properties[key].push(component);
                });
            });

            _.each(properties, function(value, name){
                value = _.unique(value);
                if(value.length === 1) value = value[0];
                form[name] = value;
            });
        },

        _destroyComponents: function(){
            while(this._childComponents.length) {
                this._childComponents.shift().destroy();
            }
        },

        _setDefaultErrorMessages: function(){
            var form = this, messages = form.errorMessages;
            _.each(_.keys(messages), function(selector){
                _.each(form._childComponents, function(component){
                    if(component.$el.is(selector) && component.setErrorMessages)
                        component.setErrorMessages(messages[selector]);
                });
            });
        }
    });
});