define(function (require, exports, module) {
    var Component = require("./component");

    function isNumeric(charValue) {
        return /^\d$/.test(charValue);
    }

    function formatCardNumber(rawText, keepRightWhitespace) {
        var text = rawText.replace(/\D/g, "").replace(/(....)(?!$)/g, "$1 ");
        if (keepRightWhitespace && /\s+$/.test(rawText)) text += " ";
        return text;
    }

    function formatDataNumber(rawText, index) {//ex_huangzit 2016-03-08
        if (rawText.length <= index) return rawText;
        var phoneArr = [];
        phoneArr.push(rawText.substring(0, index));
        var phoneEnd = rawText.substring(index);
        var spaceCount = Math.ceil(phoneEnd.length / 4);
        for (var i = 0; i < spaceCount; i++) {// 每4位数添加进数组
            var fourNumbers = phoneEnd.substr(i * 4, 4);
            phoneArr.push(fourNumbers);
        }
        return phoneArr.join(" ");
    }

    function getCaretPosition(input) {
        if (input.selectionStart != null) return input.selectionStart;

        try {
            var sel = document.selection.createRange();
            sel.moveStart('character', -input.value.length);
            return sel.text.length;
        } catch (e) {
            return this.el.value.length;
        }
    }

    function setCaretPosition(input, position) {
        if (input.setSelectionRange)
            return input.setSelectionRange(position, position);

        try {
            var range = input.createTextRange();
            range.collapse(true);
            range.moveEnd('character', position);
            range.moveStart('character', position);
            range.select();
        } catch (e) { }
    }

    var Input = module.exports = Component.extend({
        componentName: "input",
        constructor: function () {
            Input.__super__.constructor.apply(this, arguments);
            this.$el.on("focus", _.bind(this._focus, this));
            this.$el.on("blur", _.bind(this._blur, this));
            this.$el.on("keypress", _.bind(this._keypress, this));
            this.$el.on("keyup", _.bind(this._keyup, this));
        },
        _focus: function () {
            var el = this.$el,
                rule_format = el.attr("data-format");
            this._hasSpan();
            if (el.next().hasClass("js-error-icon")) {
                el.next().remove();
            }
            el.after($('<i class="iconA54 js-clear-input"></i>'));
            el.removeClass("error").addClass("focus");
            if (rule_format == "money" && el.val()) {
                var amount = (el.val().replace(/,/g, "")) * 1;
                el.val(amount);
            } else if (!!~_.indexOf(["cardnum", "phoneno", "idnumber"], rule_format) && this._value) {
                var tempData = this._value.replace(/\s/g, "");
                el.val(tempData);
            }

            $(".js-clear-input").on("touchstart", function (e) {
                e.stopPropagation(); e.preventDefault();
                el.val("");
                el.trigger("jsClearIconHandler");
            });
        },
        _value: "",
        _blur: function (e) {
            var el = this.$el,
                rule_format = el.attr("data-format");
            $(".js-clear-input").remove();
            this.$el.removeClass("focus");
            if (el.attr("data-format") == "money" && el.val()) {
                var amount = utils.string.formatMoneyNumber(el.val());
                el.val(amount);
            } else if (!!~_.indexOf(["cardnum", "phoneno", "idnumber"], rule_format)) {//ex_huangzit 2016-03-08
                this._value = el.val();
                if (el.val()) this._formatNumber(e, rule_format);
            }

            if (this._getValue() === "") {
                this.$el.after(this.$el._span);
            }
        },

        _keypress: function (e) {
            //2015-06-25 wuyongsheng560 增加 maxlength number 过滤；
            var EL = this.$el,
                value = EL.val(),
                rule_maxlength = EL.attr("data-maxlength"),
                rule_format = EL.attr("data-format");
            if (rule_maxlength && (value.length > rule_maxlength - 1)) {
                e.preventDefault();
            }

            if (rule_format == 'alpha' && !/[a-zA-Z0-9]/.test(String.fromCharCode(e.which))) {
                e.preventDefault();
            }

            if (!!~_.indexOf(["cardno", "number", "phoneno", "cardnum"], rule_format)) {//ex_huangzit 2016-03-08
                this._preventNonNumeric(e);
            }
        },
        _keyup: function (e) {
            if (this.$el.attr("data-format") == "cardno") {
                this._formatCardNumber(e);
            }
        },

        _hasSpan: function () {
            var el = this.$el;
            if (el.next().is("span")) {
                el._span = el.next();
                el.next().remove();
            }
        },
        _getValue: function () {
            return this.$el.val();
        },

        getValue: function () {
            if ("value" in this.el) return this.$el.val();
            else return this.$el.attr("data-value");
        },

        setCustomValidity: function (message) {
            var el = this.$el;
            this._hasSpan();
            if (!el.next().hasClass("js-error-icon")) {
                el.after($('<i class="iconA54 m_r10 js-error-icon"></i>'));
            }
            el.addClass("error");
            if (message !== "") {
                utils.dialog.toast(message);
            }
        },
        _preventNonNumeric: function (e) {
            //《Javascript 权威指南》 p475
            if (e.which < 32 || e.charCode == 0 || e.ctrlKey || e.altKey)
                return;

            if (!isNumeric(String.fromCharCode(e.which)))
                e.preventDefault();
        },
        
        //格式化卡号
        _formatCardNumber: function (e) {
            var rawText = this.$el.val();
            var formatted = formatCardNumber(rawText);
            if (rawText == formatted) return;

            var caretPos = getCaretPosition(this.el);
            var leftText = formatCardNumber(rawText.substring(0, caretPos), true);

            this.$el.val(formatted);
            setCaretPosition(this.el, leftText.length);
        },
        
        //格式化数据 ex_huangzit 2016-03-08
        _formatNumber: function (e, type) {
            var options = { "cardnum": "4", "phoneno": "3", "idnumber": "6" }; //6:格式化身份证, 3:格式化手机号, 4:格式化卡号
            var value = options[type];
            var rawText = this.$el.val().replace(/\s/g, "");
            var formatted = formatDataNumber(rawText, value);
            this.$el.val(formatted);
        }
    });
});
