define(function (require, exports, module) {

    var broadcast = require("./broadcast");
    var Input = require("./input");

    var MoneyInput = module.exports = Input.extend({

        constructor: function(options){
            MoneyInput.__super__.constructor.apply(this, arguments);

            this.$el.on("focusout", _.bind(this._onMoneyInputFocusout, this));
            this.$el.on("focusin", _.bind(this._onMoneyInputFocusin, this));
            this.$el.on("keyup", _.bind(this._onMoneyInputKeyUp, this));
        },

        getValue: function(){
            return this._stripFormat(this.$el.val());
        },

        setValue: function(value){
            if(value != "") value = utils.string.numberFormat(value, 2)

            this.$el.val(value);
            broadcast.trigger("moneyinput:valueChange", this);
        },

        _onMoneyInputFocusout: function(){
            this.$el.val(function(_, oldValue){
                oldValue = $.trim(oldValue);
                if(oldValue != "" && isNaN(oldValue)) return oldValue;
                oldValue = utils.string.numberFormat(oldValue, 2);
                return oldValue;
            });
        },

        _onMoneyInputFocusin: function(){
            var oldValue = this.$el.val();
            this.$el.val(this._stripFormat(oldValue));
        },

        _onMoneyInputKeyUp: function(e){
             var amount = this.$el.val();
            //先把非数字都替换掉除了数字和.
            amount = amount.replace(/[^\d.]/g,"");
            //必须保证第数字而.
            amount = amount.replace(/^\./g,"");
            //保证只有出现.而没有多.
            amount = amount.replace(/\.{2,}/g,".");
            //只能输入小数点后两位
            amount = amount.replace(/\.\d{2,}$/,amount.substr(amount.indexOf("."),3));
            
            amount = amount.substr(0,16);
            
            
            this.$el.val(amount);

            broadcast.trigger("moneyinput:valueChange", this);
        },
        
        _stripFormat: function(text){
            var ret = text.replace(/,/g, "");
            if(isNaN(ret)) return text;
            return ret.replace(/\.0*$/, "");
        }

    });

});