define(function (require, exports, module) {

    var ValidityState = require("./validityState");

    var Validator = module.exports = function(){
        this.defaultErrorMessages = _.clone(Validator.defaultErrorMessages);

        this._validations = [
            this._validateRequired,
            this._validateNumber,
            this._validateMoney
        ];
    };

    _.extend(Validator.prototype, {

        validate: function(input, value){
            var validations = this._validations,
                validate, state;

            // validate requirement
            state = validations[0].apply(this, arguments);
            if(state) return state;
            if(this._isBlank(value)) return;

            for(var i = 1; validate = this._validations[i]; i++){
                if(state = validate.apply(this, arguments))
                    return state;
            }
        },

        addValidation: function(validate){
            this._validations.push(validate);
        },

        _validateRequired: function(input, value){
            if(input.getAttribute("required") == null) return;
            if(this._isBlank(value)) return new ValidityState("valueMissing", this.defaultErrorMessages.valueMissing);
        },

        _validateNumber: function(input, value){
            if(input.getAttribute("type") != "number") return;
            if(!this._isNumber(value)) return new ValidityState("typingMismatch", this.defaultErrorMessages.typingMismatch);
        },

        _validateMoney: function(input, value){
            if(input.getAttribute("component") != "moneyinput") return;
            if(!this._isNumber(value)) return new ValidityState("typingMismatch", this.defaultErrorMessages.typingMismatch);
            if(value <= 0) return new ValidityState("moneyTooLittle", this.defaultErrorMessages.moneyTooLittle);
        },

        _isBlank: function(str){
            if (str == null) str = '';
            return (/^\s*$/).test(str);
        },

        _isNumber: function(str){
            return !(this._isBlank(str) || isNaN(str));
        }
    });


    Validator.defaultErrorMessages = {
        "valueMissing": "请填写此字段。",
        "typingMismatch": "请填写一个格式正确的值。",
        "moneyTooLittle": "金额应大于零。"
    };

    Validator.extend = Backbone.Model.extend;
});