define(function(require,exports,module) {

    var OtpView=require("./otp");

    var BaseOtpHelper = function(options){
        this.otpService = options.otpService || null;
        //低级网银不需要发送OTP，则在用户提交的时候不验证OTP是否为空
        this.isValidateOtp = true;
    };
    BaseOtpHelper.prototype.validateOtpInput = function(otp){
        // 用OTP父容器精准定位元素（主要用于区分一个页面使用多个OTP组件的场景）
        var thisOtpTpl = $(this.otpService.otpParentId);
        if(!thisOtpTpl || thisOtpTpl.length == 0){
            thisOtpTpl = document;
        }

        // 清除错误提示信息和输入框的错误样式
        $("#otp_passWord",thisOtpTpl).parent().removeClass("inputText1Error");
        $("#passWordOutTime_ErrorTip",thisOtpTpl).hide();

        //如果需要效验otp
        if(this.isValidateOtp){

            //发送请求到OTP校验接口（通过后台接口校验OTP）
            if(this.otpService.isNeedSendOtpValidate){
                this.otpService.sendOtpValidate(otp)
                return false;
            }

        }
        return true;
    };
    BaseOtpHelper.prototype.onOtpResendListener = function(){
            if(this.otpView.isSendedOTP()){
                return;
            }
            var thisOtpTpl = $(this.otpParentId);
            if(!thisOtpTpl || thisOtpTpl.length == 0){
                thisOtpTpl = document;
            }

            $("#otp_passWord",thisOtpTpl).parent().removeClass("inputText1Error");
            $("#passWordOutTime_ErrorTip",thisOtpTpl).hide();

            //手机号码
            var phone = this.otpView.phone;
            if(phone!=null&&$.trim(phone)!=""){
                //如果手机号码已存在，则发送OTP到手机
                this.sendSmsOTP();
            }else{
                //如果手机号码不存在，则获取手机号码
                this.qryOtpMobile();
            }
    };

    BaseOtpHelper.prototype.setValidateOtp = function(isValidateOtp){
            this.isValidateOtp = isValidateOtp;
    };
    BaseOtpHelper.lang = {
        otpEmptyError : "请输入动态密码",
        otpTimeOutError : "请点击重新获取动态密码。",
        otpCheckError : "动态密码错误，未通过校验",
        qryOtpErrpr : "获取动态密码失败"
    }

    var OtpService = function(options) {
        this.otpParentId = options.otpParentId;


        this.otpView = null;
        // 手机动态密码输入框
        this.phoneCodeField = options.phoneCodeField || null;
        //提交确认按钮
        this.submitField = options.submitField || null;
        // 重新发送按钮
        this.resendField = options.resendField || null;
        // 倒计时标签
        this.countdownLabel = options.countdownLabel || null;
        // OTP输入界面的容器，当为普通网银时，整行不可见
        this.otpInputContainer = options.otpInputContainer || null;
        // OTP label界面容器，当为普通网银时，整行不可见
        this.otpLabelContainer = options.otpLabelContainer || null;


        if(options.isNeedSendOtpValidate == false){
            this.isNeedSendOtpValidate = false;
        }
        else if(options.isNeedSendOtpValidate == true){
            this.isNeedSendOtpValidate = true;
        }else{
            this.isNeedSendOtpValidate = null;
        }
        this.isOtpSended = options.isOtpSended || false;
        //失败回调
        this.callbackError = options.callbackError || null;
        //效验回调
        this.callbackValidate = options.callbackValidate || null;
        //提交回调
        this.callbackSubmit = options.callbackSubmit || null;

        //用户输入手机号码获取动态密码时，”立即获取“按钮的绑定函数
        this.resendBtnHandler = options.resendBtnHandler || null;

        //是否是登陆区外的逻辑
        this.isOutLogin=options.isOutLogin||false;

        this.cat=options.cat;

        if(options.values){
            this.values = options.values;
        }

        //otp helper
        this.baseOtpHelper = null;
        //是否初始化错误，如果初始化错误，则无法使用此otp服务
        this.isInitError = false;
        this.phoneNum=options.phone;
        if(this.phoneCodeField==null  ||
            this.resendField==null || this.countdownLabel==null){
            console.log("请设置必要的控件，如：验证码框框，提交按钮，重新发送按钮，");
            this.isInitError = true;
        }
        if(!this.isOutLogin&&(this.callbackError==null||
            this.callbackSubmit==null) ){
            console.log("请设置必要的回调,如：成功，错误，提交");
            this.isInitError = true;
        }
        if(this.isNeedSendOtpValidate == null){
            console.log("请设置是否需要发送otp效验请求");
            this.isInitError = true;
        }

    };
    OtpService.prototype.initOtp = function(isQryOtpPhoneNo,otpEnable,isMobilePhoneByUser) {
        //如果初始化错误 ，不做任何处理
        if(!this.isInitError){
            //初始化otp帮助类
            this.baseOtpHelper = new BaseOtpHelper({otpService : this});
            //初始化otpView控制工具，倒计时等逻辑都在这个里面
            this.otpView = new OtpView({
                phoneCodeField : this.phoneCodeField,
                resendField : this.resendField,
                countdownLabel : this.countdownLabel,
                isMobilePhoneByUser:isMobilePhoneByUser,
                phone:this.phoneNum
            });
            //是否发送‘获取手机号码‘请求，默认为true，即默认需要获取手机号码
            if(isQryOtpPhoneNo==null){
                isQryOtpPhoneNo = true;
            }
            if(isMobilePhoneByUser==null){
                isMobilePhoneByUser = false;
            }
            //提交监听
            //如果手机号码不是靠用户自己输入的  则我们绑定事件
            if(!isMobilePhoneByUser){
                 //重新发送OTP监听
                this.resendField.bind('click', _.bind(this.baseOtpHelper.onOtpResendListener,this));
            }

            //用户输入手机号码获取动态密码时，”立即获取“按钮的绑定函数
            if(isMobilePhoneByUser){
                if(this.resendBtnHandler){
                    this.otpLabelContainer.parent().hide();
                    this.resendField.bind('click', _.bind(this.resendBtnHandler,this));
                }else {
                    console.log('用户输入手机号码时，必须设置动态密码发送按钮的绑定函数');
                }
            }

                //开启提交前otp页面校验功能
                this.baseOtpHelper.setValidateOtp(true);
                //获取手机号码
                if(isQryOtpPhoneNo){
                    this.qryOtpMobile();
                }

                if (this.otpInputContainer != null) {
                    this.otpInputContainer.show();
                }

                if (this.otpLabelContainer != null) {
                    this.otpLabelContainer.parent().css({"display":"-webkit-box"});
                }

        }

    };
    OtpService.prototype.qryOtpMobile = function(){
        var otpService = this;

        /**2013.8.22    start*/
        var userInfo = App.storage.get("UserInfo");
        //获取手机号码
        var phoneNum = this.phoneNum||userInfo.get("telephoneNum");
        if(phoneNum && $.trim(phoneNum) != ""){
            otpService.otpView.setPhone(phoneNum);
            // 如果需要手动请求OTP则发送OTP请求
            if(!otpService.isOtpSended){
                otpService.sendSmsOTP();
            }
            // 不需要手动请求OTP接口，部分务接口会自动发送OTP
            else{
                otpService.otpView.ready();
            }
            return;
        }
        /**2013.8.22    end*/
    };
    OtpService.prototype.submit=function(){
        var otp = this.phoneCodeField.val();
        //效验取款密码和OTP
        if(this.baseOtpHelper.validateOtpInput(otp)){
            this.callbackSubmit(otp);
        }
    };
    OtpService.prototype.sendSmsOTP = function(urlName,parameter){
        var otpService = this;
        if(otpService.otpView.isSendedOTP()){
            return;
        }
        console.log("发送otp给手机");
        otpService.otpView.phoneCodeField.val('');

        // 增加回调函数
        var successCallback = function() {}, errorCallback = function() {};
        if ( parameter && ('function' == typeof(parameter.successFunction)) ) {
            successCallback = parameter.successFunction;
            delete parameter.successFunction;
        }
        if ( parameter && ('function' == typeof(parameter.errorFunction)) ) {
            errorCallback = parameter.errorFunction;
            delete parameter.errorFunction;
        }

        //成功回调
        var successFunction = function(response) {
                otpService.otpView.ready();
                otpService.otpLabelContainer.parent().css({"display":"-webkit-box"});

                successCallback()
        };

        //失败回调
        var errorFunction = function(response){
           console.log("发送otp给手机 出错 by error");
            otpService.otpView.resendShow(OtpView.lang.resend);
            // “重新发送”按钮可用
            // otpService.otpView.resendField.attr("class","dongtai_btn dstc add");
            otpService.otpView.resendField.parent().removeClass("disable");
           if($(".ui-dialog").length>0){
               var dialog=App.storage.get("activeDialog");
               dialog.toast({
                   message:response.message
                   });
           }else{
               utils.dialog.alert(response.message);
           }

           errorCallback()
        };

        //如果是登录外的逻辑....  (手机号码是用户输入的)
        if(urlName!=null&&parameter!=null){
            var mobileNo = parameter.mobileNo;
            var cat=parameter.cat;
            if(mobileNo != ""&&this.isOutLogin){
                otpService.otpView.setPhone(mobileNo.replace( /^(\d{3}).*(\d{3})$/, "$1*****$2"));

                // if(!ENABLE_PHONEGAP) {
                    // // var browserName = navigator.userAgent.toLowerCase();
                    // // if(browserName.indexOf("mozilla/") == "0" && (browserName.indexOf("iphone") != -1 || browserName.indexOf("ipad") != -1) &&
                    // // browserName.indexOf("mobile/") != -1 && browserName.indexOf("safari/") != -1) {
                        // var sessionId = App.storage.get("register_sessionId");
                        // urlName = config.urls.get("sendSMJson")+";JSESSIONID="+sessionId;
                    // // }
                // }

                App.request(urlName, {
                    data : parameter,
                    silent:true,
                    success: successFunction,
                    error: errorFunction
                });
            }else if(mobileNo != ""&&cat){
                var url=config.urls.get(urlName)+"/"+cat;
                otpService.otpView.setPhone(mobileNo.replace( /^(\d{3}).*(\d{3})$/, "$1*****$2"));
                App.request(url, {
                    type:"POST",
                    mockURL:"sendSmsOTP",
                    data : parameter,
                    silent:true,
                    success: successFunction,
                    error: errorFunction
                });
            }else{
                console.log("手机号码获取失败");
            }
        }
        //如果是登录区内的逻辑....
        else{
            var url=config.urls.get("sendSmsOTP")+"/"+this.cat;
            var data={};
            if(this.values){
                url = config.urls.get("sendSmsOTP")+"/template/"+this.cat;
                data = {"values":this.values};
            }
            App.request(url, {
                mockURL:"sendSmsOTP",
                data:data,
                 silent:true,
                success: successFunction,
                error: errorFunction
            });
        }

    };
    OtpService.prototype.sendOtpValidate = function(otp){
        var otpService = this;

        console.log("发送otp效验");

        var requestData = {
                    'password' : otp
                };
            var otpCode=$("#otp_passWord").val();
            var url=config.urls.get("verifyOTP")+"/"+otpCode+"/"+this.cat;
            App.request(url, {
                mockURL:"verifyOTP",
                // type:"GET",
                data : requestData,
                success: function(response) {
                    otpService.callbackSubmit(otp);
                },

                error: function(response){
                    console.log("发送otp效验  出错  otp效验不通过");
                    otpService.otpView.phoneCodeField.val('');

                       response.message="动态密码校验失败！"
                       otpService.callbackError(response);
                }
            });

       };
    OtpService.prototype.stopService = function(){
        this.otpView.stop();
    };

    OtpService.prototype.isSendedOTP=function(){
        return this.otpView.isSendedOTP();
    };
        return OtpService;

});

