define(function() {

    /**
     * OTP相关公共类
     */
    var OTP = function(options) {
        // 倒计时(秒)
        this.countdown = 120;
        // 计时器句柄
        this.interval = null;

        // 手机号码
        this.phone = options.phone || '';
        // 手机动态密码输入框
        this.phoneCodeField = options.phoneCodeField || null;
        // 重新发送按钮
        this.resendField = options.resendField || null;
        // 倒计时标签
        this.countdownLabel = options.countdownLabel || null;

        this.isMobilePhoneByUser=options.isMobilePhoneByUser||null;
        this.init();
    };
    OTP.lang = {
        awaitInput : '动态码已经发送到<span class="c_f60">{phone}</span>，请在<span class="c_f60">{second}</span>秒内输入',
        timeout : '动态码已失效，请重新获取',
        resendForTime : '<span class="c_999"><span class="c_999">({second})</span>秒后<br>可重新获取</span>',
        buttonSend : '<span>获取动态码</span>',
        btnSending : '<span>正在发送动态码</span>',
        resend : '<span class="c_f60">获取动态码</span>',

        phoneCodeInput : '请输入动态码',
        phoneCodeReput : '重发后再输入'
    };
    /**
     * 定义外部接口
     * ===========================================================
     */
    // 开始计时或重新计时
    OTP.prototype.ready = function() {
        clearInterval(this.interval);
        this.phoneCodeField.removeAttr("disabled");
        this.resendField.parent().css("background","");
        this.interval = null;
        this.isSended=false;
        this.countdown = 120;
        this.timeLabel();

        // this.resendField.attr("class","dongtai_btn2");
        this.resendField.parent().addClass("disable");

        this.resendShow('<span class="c_999"><span class="c_999">(60)</span>秒后<br>可重新获取</span>');
        this.interval = setInterval(_.bind(this.timeLabel, this), 1000);
    };
    // 停止计时
    OTP.prototype.stop = function() {
        clearInterval(this.interval);
        this.interval = null;
        this.countdownLabel.html(OTP.lang.timeout);
        this.resendShow(OTP.lang.resend);
        this.isSended=false;
        this.phoneCodeField.val("");
        // this.resendField.attr("class","dongtai_btn");
        this.resendField.parent().removeClass("disable");
    };
    // 设置手机号码
    OTP.prototype.setPhone = function(phone) {
        this.phone = phone.replace( /^(\d{3}).*(\d{4})$/, "$1****$2");;
    };
    // 显示重新发送按钮
    OTP.prototype.resendShow = function(text) {
        this.resendField.html(text || '');
    };
    // 隐藏重新发送按钮
    OTP.prototype.resendHide = function() {
        this.resendField.hide();
    };
    // 重置到动态密码失效
    OTP.prototype.resetStatus = function() {
    	this.phoneCodeField.val('');
        this.phoneCodeField.attr("disabled","true");
        this.countdown = 0;
        this.stop();

        // this.resendField.attr("class","dongtai_btn");
        this.resendField.parent().removeClass("disable");

        this.resendShow(OTP.lang.resend);
        this.countdownLabel.html(OTP.lang.timeout);
    };
    // 是否处在倒计时阶段
    OTP.prototype.isTimeout = function() {
        return !!this.interval;
    };
    OTP.prototype.isSendedOTP=function(){
        return this.isSended;
    };
    /**
     * 显示正在发送中的计时文本
     */
    OTP.prototype.timeLabel = function() {
        var lang = OTP.lang, countdown = this.countdown;

        if (countdown == 60) {
            this.isSended=false;
            // this.resendField.attr("class","dongtai_btn");
            this.resendField.parent().removeClass("disable");

            this.resendShow(lang.resend);
        } else if (countdown <= 0) {
            this.isSended=false;
            this.stop();
            this.countdownLabel.html(lang.timeout);
            this.resendShow(lang.resend);
            this.phoneCodeField.attr("disabled","true");

            return false;
        }

        var text = lang.awaitInput;
        var resendText = lang.resendForTime;
        text = text.replace('{phone}', this.phone);
        text = text.replace('{second}', this.countdown);
        if(this.countdown>60){
            this.isSended=true;
        	var resetCount = ""+(this.countdown-60);
            if(resetCount.length==1){
                resetCount = "0"+resetCount;
            }
            resendText = resendText.replace('{second}', resetCount);
            this.resendShow(resendText);
        }
        this.countdownLabel.html(text);
        this.countdown--;
    };
    /**
     * 初始化获取元素
     */
    OTP.prototype.init = function() {
        this.bind();
        this.phoneCodeField.attr('placeholder', OTP.lang.phoneCodeInput);
    };
    /**
     * 绑定元素事件
     */
    OTP.prototype.bind = function() {
        var lang = OTP.lang;
        if(!this.isMobilePhoneByUser){
            // this.resendField.parent().css("background","#ccc");
            this.resendShow(lang.btnSending);
            return;
        }
        this.resendShow(lang.buttonSend);
    };



    return OTP;
});
