define(function (require, exports, module) {

    var CheckToaPwdInput = function (options) {
        this.options = _.extend({
            titleText: '校验登录密码',
            pwdLabel: '登录密码：',
            okButtonText: '确定',
            cancelButtonText: '取消',
            minlength: 6,
            maxlength: 16,
            callback: function (flag) {
            }
        }, options);
        this._init();
    };

    CheckToaPwdInput.prototype = {
        _init: function () {
            var body = $('body');
            body.find('#checkToaPwdComponent').remove();

            this.$el = $(_.template(require('text!./checkToaPwdInput.html'), this.options));
            this.$pwdInput = this.$el.find('#toa-password-input');
            this.$confirmBtn = this.$el.find('#confirm-button');
            this.$cancelBtn = this.$el.find('#cancel-button');
            this.isFlag = false;
            this.isRequesting = false;
            this.pwd = '';
            this.top = 0;
            body.append(this.$el);

            this._loadEvent();

            if (!this._isCustomKeyboard()) return;
            this.$pwdInput.prop('type', 'button');
            this.$pwdInput.removeClass('input1 flex1').addClass('spaninput2 on');
            nativeBroadcast.off('keyboard:input');
            nativeBroadcast.on('keyboard:input', _.bind(this._handlePressCustomKeyboard, this));
            nativeBroadcast.off('keyboard:click:left:right:cancel:keyboard:button');
            nativeBroadcast.on('keyboard:click:left:right:cancel:keyboard:button', _.bind(this._hideSafeKeyboard, this));
        },

        _loadEvent: function () {
            this.$confirmBtn.on('tap', _.bind(function () {
                if (!this.isFlag) {
                    utils.dialog.alert('请输入最少' + this.options.minlength + '位密码');
                    return;
                }

                this._checkToaPwd();
            }, this));

            this.$cancelBtn.on('tap', _.bind(function () {
                if (this.isRequesting) return;
                var self = this;
                window.setTimeout(function () {
                    self._destoryCustom();
                    self.options.callback.call(self, 'cancel');
                }, 320);

            }, this));


            if (this._isCustomKeyboard()) {
                this.$el.on('tap', _.bind(function (event) {
                    this._getCustomHeight();
                    var pwdInput = $(event.target).closest('.toa-password-input');
                    if (pwdInput.length > 0) {
                        this.$pwdInput.next().css({
                            'display': 'inline-block'
                        });
                        this._showSafeKeyboard();
                    }

                }, this));
                return;
            }

            this.$pwdInput.on('keyup.pwdInput', _.bind(function () {
                var keyCode = event.which || event.keyCode;
                if ((keyCode < 48 && keyCode !== 8) || (222 < keyCode)) {
                    return false;
                }

                this.pwd = this.$pwdInput.val();
                if (this.pwd.length >= this.options.minlength) {
                    this.isFlag = true;
                    this.$confirmBtn.removeClass('disable');
                } else {
                    this.isFlag = false;
                    this.$confirmBtn.addClass('disable');
                }

            }, this));

        },

        _checkToaPwd: function () {
            if (this.isRequesting) return;
            this.isRequesting = true;

            var pwd = utils.crypto.RSAKey.encrypt(this.pwd, config.base.rsa_public_key);
            var sm2Pwd = utils.sm2.SM2Key.encrypt(this.pwd, config.base.sm2_public_key);
            var data = {
                pwd: pwd,
                sm2Pwd: sm2Pwd
            };

            var successFunction = _.bind(function (res) {
                this.isRequesting = false;
                if ('000' == res.code) {
                    this._hideSafeKeyboard();
                    this.$el.remove();
                    this.options.callback.call(this, 'ok');
                } else {
                    utils.dialog.alert(res.message || '密码校验失败');
                }
            }, this);

            var errorFunction = _.bind(function (error) {
                this.isRequesting = false;
                utils.dialog.alert(error.message);
            }, this);

            App.request('checkToaPwd', {
                data: data,
                success: successFunction,
                error: errorFunction
            });
        },

        _getCustomHeight: function () {
            var rect = this.$el.find('.pop_pay')[0].getClientRects()[0];
            var height = rect.height;
            var keyboardHeight = 0;
            if (IS_RUN_ON_ANDROID) {
                keyboardHeight = 315 + height;
            } else if (IS_RUN_ON_IDEVICE) {
                var temp = parseInt(App.locStorage.get('webviewHeight'), 10) < 380 ? 320 : 380;
                keyboardHeight = temp + height;
            }
            if (this.top === 0) {
                this.top = rect.bottom - keyboardHeight;
            }
        },

        _setValue: function (value) {
            this.$pwdInput.data('pwdInput.value', value);
            this.$pwdInput.val(value.replace(/./g, '*'));
            this.pwd = value;
        },

        _getValue: function () {
            return this.$pwdInput.data('pwdInput.value') || '';
        },

        _isCustomKeyboard: function () {
            if (IS_RUN_ON_DEVICE) return true;
            else return false;
        },

        _destoryCustom: function () {
            this._hideSafeKeyboard();
            this.$el.remove();
        },

        _showSafeKeyboard: function () {
            this.$el.find('.pop_pay').css({
                'margin-top': this.top + 'px'
            });
            utils.native.showSafeKeyboard({
                currentYPos: 0,
                inputType: 'password-ascii'
            });
        },

        _hideSafeKeyboard: function () {
            this.$el.find('.pop_pay').css({
                'margin-top': '0px'
            });
            utils.native.hideSafeKeyboard();
        },

        _handlePressCustomKeyboard: function (character) {
            var tempStr = this._getValue();

            if (this.pwd.length > this.options.maxlength && character != 'del') {
                return;
            }

            if (character == 'del') tempStr = tempStr.substr(0, tempStr.length - 1);
            else tempStr = tempStr + character;

            this._setValue(tempStr);

            if (this.pwd.length >= this.options.minlength) {
                this.isFlag = true;
                this.$confirmBtn.removeClass('disable');
            } else {
                this.isFlag = false;
                if (!this.$confirmBtn.hasClass('disable')) this.$confirmBtn.addClass('disable');
            }
        }

    };

    module.exports = CheckToaPwdInput;
});
