define(function (require, exports, module) {
    var CustomPwdInput = function (callback, options) {
        this.callback = callback;
        this.options = {
            titleText: "请输入交易密码",
            contentText: "",
            okButtonText: "确定",
            cancelButtonText: "取消"
        };
        this.options = options ? _.extend(this.options, options) : this.options;

        if (!_.isFunction(this.callback)) {
            this.callback = function () {
            };
        } else {
            this.callback = function (pwd) {
                App.requester.storage.remove("loginedAccountInfo");
                callback(pwd);
            }
        }

        this._init();
    };

    CustomPwdInput.prototype = {
        _init: function () {
            this.$el = $(_.template(require("text!./customPwdInput.html"), this.options));
            this.$confirmBtn = this.$el.find("#confirmBtn");
            this.$cancelBtn = this.$el.find("#cancelBtn");
            this.isFlag = false;
            $("body").append(this.$el);
            this._loadEvent();

            if (!this._isCustomKeyboard()) return;

            var rect = this.$el.find(".pop_pay")[0].getClientRects()[0];
            var tempHeight = rect.height;
            var keyboardHeight = 0;
            var isFlag = parseInt(App.locStorage.get('webviewHeight')) < 380 ? true : false;//判断是否为3.5寸或以下的手机
            if (IS_RUN_ON_ANDROID) {
                keyboardHeight = 315 + tempHeight;
            } else if (IS_RUN_ON_IDEVICE) {
                var temp = isFlag ? 320 : 380;
                keyboardHeight = temp + tempHeight;
            }
            //如果是3.5寸或以下的手机，密码框的margin-top值为-191
            var top = isFlag ? -191 : rect.bottom - keyboardHeight;
            this.$el.find(".pop_pay").css({"margin-top": top > 20 ? 0 + "px" : top + "px"});
            App.isShowKeyborad = true;
            this._showSafeKeyboard();
        },

        _isCustomKeyboard: function () {
            if (IS_RUN_ON_DEVICE) return true;
            else return false;
        },

        _loadEvent: function () {

            $(document).on("keydown.custom", function () {
                if (window.event.keyCode == 8) {
                    window.event.keyCode = 0;
                    window.event.returnValue = false;
                    return false;
                }
                return true;

            });


            $(document).on("keyup.custom", _.bind(function (event) {
                var str = this._getValue(), tempStr = "", keyCode = event.which || event.keyCode;

                if (keyCode == 8) {
                    if (str.length <= 0) return;
                    tempStr = str.substr(0, str.length - 1);
                } else if (keyCode >= 48 && keyCode <= 57) {
                    if (str.length >= 6) return;
                    tempStr = str + String.fromCharCode(keyCode);
                } else {
                    return;
                }

                if (tempStr.length == 6) {
                    this.isFlag = true;
                    this.$confirmBtn.removeClass("disable");
                } else {
                    this.isFlag = false;
                    if (!this.$confirmBtn.hasClass("disable")) this.$confirmBtn.addClass("disable");

                }

                this._setValue(tempStr);
                this._setClass(tempStr);

            }, this));

            this.$confirmBtn.on("tap", _.bind(function () {
                if (!this.isFlag) return;
                this.callback(this._getValue());
                this._destoryEvent();
            }, this));

            this.$cancelBtn.on("tap", _.bind(function () {
                window.setTimeout(this._destoryEvent(), 320);
            }, this));

            if (!this._isCustomKeyboard()) return;

            nativeBroadcast.off("keyboard:input");
            nativeBroadcast.on("keyboard:input", _.bind(this._handlePressCustomKeyboard, this));
            nativeBroadcast.on("keyboard:click:left:right:cancel:keyboard:button", _.bind(this._destoryEvent, this));
            nativeBroadcast.on("os:softkeyboard:close", _.bind(function () {
                this._showSafeKeyboard();
            }, this));
        },

        _destoryEvent: function () {
            App.isShowKeyborad = false;
            $(document).off("keydown.custom");
            $(document).off("keyup.custom");
            this.$el.remove();

            if (!this._isCustomKeyboard()) return;
            nativeBroadcast.off("keyboard:click:left:right:cancel:keyboard:button");
            utils.native.hideSafeKeyboard();
        },

        _setClass: function (value) {
            this.$el.find("i").addClass("del");
            for (var i = 0; i < value.length; i++) {
                this.$el.find("i").eq(i).removeClass("del");
            }
        },

        _setValue: function (value) {

            this.$el.find("i").each(function (i, ele) {
                if (value.charAt(i)) {
                    $(ele).data("pwd", value.charAt(i));
                } else {
                    $(ele).data("pwd", "");
                }
            });

            this._setClass(value);
        },

        _getValue: function () {
            var str = "";
            this.$el.find("i").each(function (i, ev) {
                if (!$(ev).data("pwd")) return false;
                str += $(ev).data("pwd");
            });
            return str;
        },

        _showSafeKeyboard: function () {
            utils.native.showSafeKeyboard({
                currentYPos: 0,
                inputType: "password-number"
            });
        },

        _hideSafeKeyboard: function () {
            utils.native.hideSafeKeyboard();
        },

        _handlePressCustomKeyboard: function (character) {
            var tempStr = this._getValue();

            if (tempStr.length >= 6 && character != "del") {
                return;
            }

            if (character == "del") tempStr = tempStr.substr(0, tempStr.length - 1);
            else tempStr = tempStr + character;

            if (tempStr.length == 6) {
                this.isFlag = true;
                this.$confirmBtn.removeClass("disable");
            } else {
                this.isFlag = false;
                if (!this.$confirmBtn.hasClass("disable")) this.$confirmBtn.addClass("disable");

            }

            this._setValue(tempStr);
        }
    };

    exports.customPwdInput = function (callback, options) {
        var fn1 = new CustomPwdInput(callback, options);
    };
});
