define(function (require, exports, module) {

    var IS_ANDROID = ENABLE_PHONEGAP && IS_RUN_ON_ANDROID;
    var IS_IDEVICE = ENABLE_PHONEGAP && IS_RUN_ON_IDEVICE;

    var CustomPwdOtpInput = function (options) {
        this.options = _.extend({
            isNeedSendOtpValidate: true,
            titleText: "输入密码",
            okButtonText: "确定",
            cancelButtonText: "取消"
        }, options);
        this._init();
    };

    CustomPwdOtpInput.lang = {
        timeout: '动态密码已失效，请重新获取',
        resendForTime: '<span class="c_999"><span>({second})</span>秒后<br>可重新获取</span>',
        buttonSend: '<span>立即发送动态密码</span>',
        btnSending: '<span>正在发送动态密码</span>',
        resend: '<span>获取动态密码</span>',
        phoneCodeInput: '请输入动态密码',
        phoneCodeReput: '重发后再输入'
    };

    CustomPwdOtpInput.prototype = {
        _init: function () {
            this.$el = $(_.template(require("text!./customPwdOtpInput.html"), this.options));
            this.$pwdInput = this.$el.find("#trading-password-input");
            this.$otpInput = this.$el.find("#otp-password-input");
            this.$sendBtn = this.$el.find("#send-button");
            this.$confirmBtn = this.$el.find("#confirm-button");
            this.$cancelBtn = this.$el.find("#cancel-button");
            this.isFlag = false;
            this.pwd = "";
            this.otp = "";
            this.top = 0;
            $("body").append(this.$el);

            this._loadEvent();
            this._sendSmsOTP();


            if (!this._isCustomKeyboard()) return;
            this.$pwdInput.prop("type", "button");
            this.$otpInput.prop("type", "button");
            this.$pwdInput.removeClass("input1 flex1").addClass("spaninput2 on");
            this.$otpInput.removeClass("input1 flex1").addClass("spaninput2 on");
            nativeBroadcast.off("keyboard:input");
            nativeBroadcast.on("keyboard:input", _.bind(this._handlePressCustomKeyboard, this));
            nativeBroadcast.off("keyboard:click:left:right:cancel:keyboard:button");
            nativeBroadcast.on("keyboard:click:left:right:cancel:keyboard:button", _.bind(this._destoryCustom, this));
        },

        _getCustomHeight: function () {
            var rect = this.$el.find(".pop_pay")[0].getClientRects()[0];
            var height = rect.height;
            var keyboardHeight = 0;
            if (IS_RUN_ON_ANDROID) {
                keyboardHeight = 315 + height;
            } else if (IS_RUN_ON_IDEVICE) {
                var temp = parseInt(App.locStorage.get('webviewHeight')) < 380 ? 320 : 380;
                keyboardHeight = temp + height;
            }
            if (this.top == 0) {
                this.top = rect.bottom - keyboardHeight;
            }

        },

        _loadEvent: function () {


            this.$sendBtn.on("tap", _.bind(function () {
                this._sendSmsOTP();
            }, this));

            this.$confirmBtn.on("tap", _.bind(function () {

                if (!this.isFlag) return;

                if (this.options.isNeedSendOtpValidate) {
                    this._sendOtpValidate(this.otp);
                } else {
                    this.$el.remove();
                    window.clearInterval(this.intervalId);
                    this._hideSafeKeyboard();
                    App.requester.storage.remove("loginedAccountInfo"); //删除我的橙子页面资产接口缓存
                    this.options.callback(this.pwd, this.otp);
                }

            }, this));

            this.$cancelBtn.on("tap", _.bind(function () {

                window.setTimeout(this._destoryCustom(), 320);

            }, this));


            if (this._isCustomKeyboard()) {
                this.$el.on("tap", _.bind(function (event) {
                    this._getCustomHeight();
                    var pwdInput = $(event.target).closest(".trading-password-input");
                    var otpInput = $(event.target).closest(".otp-password-input");

                    if (pwdInput.length > 0) {
                        this.$pwdInput.next().css({"display": "inline-block"});
                        this.$otpInput.next().css({"display": "none"});
                        this._showSafeKeyboard();
                        this.isPwdInput = true;
                        this.isOtpInput = false;
                    } else if (otpInput.length > 0) {
                        this.$pwdInput.next().css({"display": "none"});
                        this.$otpInput.next().css({"display": "inline-block"});
                        this._showSafeKeyboard();
                        this.isPwdInput = false;
                        this.isOtpInput = true;
                    }

                }, this));
                return;
            }

            this.$pwdInput.on("keyup.pwdInput", _.bind(function () {
                var keyCode = event.which || event.keyCode;
                if ((keyCode < 48 || keyCode > 57) && keyCode != 8) {
                    return false;
                }

                this.pwd = this.$pwdInput.val();
                this.otp = this.$otpInput.val();
                if (this.pwd.length == 6 && this.otp.length >= 6) {
                    this.isFlag = true;
                    this.$confirmBtn.removeClass("disable");
                } else {
                    this.isFlag = false;
                    this.$confirmBtn.addClass("disable");
                }

            }, this));

            this.$otpInput.on("keyup.otpInput", _.bind(function (event) {
                var keyCode = event.which || event.keyCode;
                if ((keyCode < 48 || keyCode > 57) && keyCode != 8) {
                    return false;
                }

                this.pwd = this.$pwdInput.val();
                this.otp = this.$otpInput.val();
                if (this.pwd.length == 6 && this.otp.length >= 6) {
                    this.isFlag = true;
                    this.$confirmBtn.removeClass("disable");
                } else {
                    this.isFlag = false;
                    this.$confirmBtn.addClass("disable");
                }

            }, this));

        },

        _sendSmsOTP: function () {
            var url = config.urls.get("sendSmsOTP") + "/" + this.options.cat;
            var data = {};
            if (this.options.values) {
                url = config.urls.get("sendSmsOTP") + "/template/" + this.options.cat;
                data = {"values": this.options.values};
            }

            var successFunction = _.bind(function () {
                if (this.isSend) return;
                this.isSend = true;
                this.second = 59;
                this.$sendBtn.html(CustomPwdOtpInput.lang.resendForTime.replace("{second}", "60"));
                this.intervalId = window.setInterval(_.bind(function () {
                    this.$sendBtn.html(CustomPwdOtpInput.lang.resendForTime.replace("{second}", this.second));
                    if (this.second <= 0) {
                        this.$sendBtn.html("重新获取");
                        this.isSend = false;
                        window.clearInterval(this.intervalId);
                    }
                    this.second--;
                }, this), 1000);
            }, this);

            var errorFunction = _.bind(function (error) {
                utils.dialog.alert(error.message);
            }, this);

            if (this.options.isSendOtp) {
                successFunction();
                this.options.isSendOtp = false;
                return;
            }


            App.request(url, {
                mockURL: "sendSmsOTP",
                data: data,
                silent: true,
                success: successFunction,
                error: errorFunction
            });
        },

        _sendOtpValidate: function (otp) {
            var url = config.urls.get("verifyOTP") + "/" + otp + "/" + this.options.cat;
            App.request(url, {
                mockURL: "verifyOTP",
                data: {"password": otp},
                success: _.bind(function (response) {
                    this._destoryCustom();
                    this.options.callback(this.pwd);
                }, this),

                error: _.bind(function (response) {
                    this._destoryCustom();
                    utils.dialog.alert("动态密码校验失败！");
                }, this)
            });

        },

        _clearInterval: function () {
            window.clearInterval(this.intervalId);
        },

        _setValue: function (value) {
            if (this.isPwdInput) {
                this.$pwdInput.data("pwdInput.value", value);
                this.$pwdInput.val(value.replace(/./g, "*"));
                this.pwd = value;
            }

            if (this.isOtpInput) {
                this.$otpInput.data("otpInput.value", value);
                this.$otpInput.val(value);
                this.otp = value;
            }

        },

        _getValue: function () {
            var str = "";
            if (this.isPwdInput) {
                str = this.$pwdInput.data("pwdInput.value") || "";
            }

            if (this.isOtpInput) {
                str = this.$otpInput.data("otpInput.value") || "";
            }
            return str;
        },

        _isCustomKeyboard: function () {
            if (IS_RUN_ON_DEVICE) return true;
            else return false;
        },

        _showSafeKeyboard: function () {
            this.$el.find(".pop_pay").css({"margin-top": this.top + "px"});
            utils.native.showSafeKeyboard({
                currentYPos: 0,
                inputType: "password-number"
            });
        },

        _destoryCustom: function () {
            this._hideSafeKeyboard();
            if (arguments && $.makeArray(arguments).slice(0, 1) == "safeKeyboardDidHide") {
                this.$el.find(".pop_pay").css({"margin-top": "0px"});
                return;
            }
            window.clearInterval(this.intervalId);
            this.$el.remove();
        },

        _hideSafeKeyboard: function () {
            utils.native.hideSafeKeyboard();
        },

        _handlePressCustomKeyboard: function (character) {
            if (character != "del" && isNaN(character)) return;
            var tempStr = this._getValue();

            if (this.pwd.length >= 6 && this.isPwdInput && character != "del") {
                return;
            }

            if (this.otp.length >= 7 && this.isOtpInput && character != "del") {
                return;
            }


            if (character == "del") tempStr = tempStr.substr(0, tempStr.length - 1);
            else tempStr = tempStr + character;

            this._setValue(tempStr);


            if (this.pwd.length >= 6 && this.otp.length >= 6) {
                this.isFlag = true;
                this.$confirmBtn.removeClass("disable");
            } else {
                this.isFlag = false;
                if (!this.$confirmBtn.hasClass("disable")) this.$confirmBtn.addClass("disable");

            }


        }

    };

    exports.customPwdOtpInput = function (options) {
        var fn1 = new CustomPwdOtpInput(options);
    }
});
