define(function(require, exports, module){

    var iScroll = require("vendor/iscroll");
    var template = require("text!./template.html");

    var SwipeRefreshView = module.exports = Layout.extend({

        className: "swipeRefreshLayout-container",
        template: template,
        topBarHeight: 40,

        regions: {
            contentRegion: ".swipeRefreshLayout-content"
        },

        start: function(){
            this.status = "normal";
            this.renderTopBar();
            this.$(".swipeRefreshLayout-topBar").show();

            this.scroller = new iScroll(this.el, {
                useTransition: true,
                topOffset: this.topBarHeight,
                onScrollMove: _.bind(this._onScrollMove, this),
                onScrollEnd: _.bind(this._onScrollEnd, this)
            });

            this.scroller.scrollTo(0, -this.topBarHeight, 0);
        },

        remove: function(){
            this.scroller.destroy();
            SwipeRefreshView.__super__.remove.apply(this, arguments);
        },

        renderTopBar: function(){
            this.$(".swipeRefreshLayout-topBar-normal").toggle(this.status == "normal");
            this.$(".swipeRefreshLayout-topBar-beforeRefresh").toggle(this.status == "beforeRefresh");
            this.$(".swipeRefreshLayout-topBar-refreshing").toggle(this.status == "refreshing");
        },

        clearRefreshing: function(){
            this.status = "normal";
            this.renderTopBar();
            this.scroller.refresh();
        },

        _onScrollMove: function(){
            if(this.scroller.y > 10 && this.status == "normal") {
                this.status = "beforeRefresh";
                this._setMinScrollY(0);
                this.renderTopBar();
            }

            if(this.scroller.y <= 10 && this.status == "beforeRefresh"){
                this.status = "normal";
                this._setMinScrollY(-this.topBarHeight);
                this.renderTopBar();
            }

            this.trigger("scroll", this.scroller);
            if(this.scroller.y <= this.scroller.maxScrollY) this.trigger("scrollAtBottom");
        },

        _onScrollEnd: function(){
            if(this.status == "beforeRefresh"){
                this.status = "refreshing";
                this.renderTopBar();
                this.trigger("refresh");
            }

            this.trigger("scroll", this.scroller);
            if(this.scroller.y <= this.scroller.maxScrollY) this.trigger("scrollAtBottom");
        },

        _setMinScrollY: function (minScrollY) {
            var scroller = this.scroller;

            scroller.minScrollY = minScrollY;
            scroller.scrollerW = Math.round(scroller.scroller.offsetWidth * scroller.scale);
            scroller.scrollerH = Math.round((scroller.scroller.offsetHeight + scroller.minScrollY) * scroller.scale);
            scroller.maxScrollX = scroller.wrapperW - scroller.scrollerW;
            scroller.maxScrollY = scroller.wrapperH - scroller.scrollerH + scroller.minScrollY;
        }
    });

});