/**
 * wuyongsheng560 localStorage简单封装 API与storage 一致
 */
define(function(require, exports, module){

	var LocalStorage = module.exports = function(prefix){
		this.prefix = prefix || 'CZ__';
		this._init();
	};

	_.extend(LocalStorage.prototype, {
		_init : function () {
			var testKey = '__test__';

			if ('localStorage' in window && window['localStorage']) {
				this.storage = window['localStorage'];
			}else{
				throw new Error('localStorage not supported!');
			}

			this.storage.setItem(testKey, testKey);
			if (this.storage.getItem(testKey) != testKey) console.log('localStorage is disabled!');
			this.storage.removeItem(testKey);
		},

		set : function(key, val) {
			if (!key) return;

			key = this.prefix + key;

			if (val == void 0) { return this.remove(key); }
			this.storage.setItem(key, this.serialize(val));

			return val;
		},

		get : function(key, defaultVal) {
			if (!key) return;

			key = this.prefix + key;

			var val = this.deserialize(this.storage.getItem(key));

			return (val == void 0 ? defaultVal : val);
		},

		getAll : function() {
			var ret = {};

			this._forEach(function(key, val) {
				ret[key] = val;
			});

			return ret;
		},

		has : function(key) {
			return this.get(key) != void 0;
		},

		remove : function(key) {
			if (!key) return;

			var val = this.get(key);
			key = this.prefix + key;
			this.storage.removeItem(key);

			return val;
		},

		clear : function() {
			var collection = this.getAll();

			for(var key in collection){
				this.remove(key);
			}
		},

		_forEach : function(callback) {
			var i, key,
				prefix = this.prefix;
				n = this.storage.length;

			for (i = 0; i < n; i++) {
				key = this.storage.key(i);

				if (key && !key.indexOf(prefix)) {
					key = key.substr(prefix.length);

					callback(key, this.get(key));
				}

			}
		},

		serialize : function(value) {
			return JSON.stringify(value);
		},

		deserialize : function(value) {
			if (typeof value != 'string') { return null; }

			try { return JSON.parse(value);}
			catch(e) { return value || null; }
		}

	});

});