/**
 * wuyongsheng560 产品收益计算
 */
define(function(require, exports, module) {
    var safeKeyBoardHelper = require('component/customInput.helper');
    var caculatorTpl = require('text!./template/caculator.html');

    module.exports = function(view, options) {
        options = options || {};
        if (!(view instanceof Backbone.View) || !view.model || !view.model.get('planRate')) return;
        var dayEdited = (options.dayEdited === void 0) ? false : Boolean(options.dayEdited);
        var normal = (options.normal === void 0) ? true : Boolean(options.normal);
        view._planRate = parseFloat(options.planRate || view.model.get('planRate'));
        view._cycleDays = dayEdited ? 7 : parseInt(view.model.get('cycleDays'), 10);
        view._yearDays = 365;

        view.on('render', function() {
            view.$el.append(caculatorTpl);
            view._caculator = view.$('#caculatorLayout').hide();

            var cTips = normal ? '预期年化收益率：' : '业绩比较基准：';
            cTips += '<strong class="c_666 f15" id="planRate">' + view._planRate + '</strong><strong class="f2">%</strong>&nbsp;&nbsp;&nbsp;投资期限：<strong class="c_666 f15" id="cycleDays">' + view._cycleDays + '</strong>天';
            view.$('#cTips').html(cTips);

            view.$('#caculatorInput').customInput({
                type: 'decimal',
                placeholder: '请输入投资金额',
                maxLength: 10
            });
            if (dayEdited) {
                view.$('#caculatorDInput').removeAttr('style')
                    .customInput({
                        type: 'decimal',
                        placeholder: '请输入投资期限',
                        maxLength: 4
                    });
            }

            if (!IS_RUN_ON_DEVICE) return;
            nativeBroadcast.off('keyboard:click:left:right:cancel:keyboard:button');
            nativeBroadcast.on('keyboard:click:left:right:cancel:keyboard:button', function() {
                view._rePosCaculator();
            });
        });

        view.on('close', function() {
            if (!IS_RUN_ON_DEVICE) return;
            nativeBroadcast.off('keyboard:click:left:right:cancel:keyboard:button');
        });

        var throttleFn = _.throttle(function() {
            var input = view.$('#caculatorInput').customInput('value').replace(/,/g, '');
            input = parseFloat(input) || 0;

            var cycleDays = view._cycleDays;
            if (dayEdited) {
                var dinput = view.$('#caculatorDInput').customInput('value').replace(/,/g, '');
                dinput = parseInt(dinput, 10);
                if (!dinput) dinput = 7;
                cycleDays = dinput;

                view.$('#cycleDays').text(cycleDays);
            }

            var incomeResult = input * ((100 * view._planRate * (cycleDays / view._yearDays)) / 10000);
            view.$('#incomeResult').text(utils.string.numberFormat(incomeResult));
        }, 100);

        var adjustPos = _.throttle(function(focusIn) {
            var ds, top,
                wHeight = $(window).height(),
                caluconMain = view.$('.caluconMain').eq(0);
            if (caluconMain.length < 1) return;
            ds = focusIn ? 230 : 0;
            top = (wHeight - caluconMain.height() - ds) / 2;
            caluconMain.css('top', top);
            if (focusIn) {
                view.focusIn = true;
            } else {
                view.focusIn = false;
            }

        }, 100);

        var eve = {
            _clearResult: function(e) {
                view.$('#incomeResult').text('0.00');
            },

            _focusIn: function(e) {
                safeKeyBoardHelper.focusIn({
                    id: 'caculatorInput'
                });

                adjustPos(true);
            },

            _focusOut: function(e) {
                safeKeyBoardHelper.focusOut({
                    id: 'caculatorInput'
                });
            },

            _keyup: function() {
                throttleFn();
            },

            _rePosCaculator: function() {
                adjustPos(false);
            },

            openCaculator: function() {
                if (view._caculator) {
                    view._caculator.show();
                    adjustPos(false);
                }
            },

            hideCaculator: function() {
                if (view._caculator) {
                    view.focusIn = false;
                    view._caculator.hide();
                }
            }
        };

        var eva = dayEdited ? {
            _focusInDay: function(e) {
                safeKeyBoardHelper.focusIn({
                    id: 'caculatorDInput'
                });

                adjustPos(true);
            },

            _focusOutDay: function(e) {
                safeKeyBoardHelper.focusOut({
                    id: 'caculatorDInput'
                });
            }
        } : {};

        _.extend(view, eve, eva);

        var nEvents = {
            'tap .caluconTitle': 'hideCaculator',
            'customInputFocusIn #caculatorInput': '_focusIn',
            'customInputFocusOut #caculatorInput': '_focusOut',
            'customInputKeyup #caculatorInput': '_keyup',
            'jsClearIconHandler #caculatorInput': '_clearResult'
        };
        if (dayEdited) {
            nEvents['customInputFocusIn #caculatorDInput'] = '_focusInDay';
            nEvents['customInputFocusOut #caculatorDInput'] = '_focusOutDay';
            nEvents['customInputKeyup #caculatorDInput'] = '_keyup';
            nEvents['jsClearIconHandler #caculatorDInput'] = '_clearResult';
        }

        view.events = _.extend({}, view.events, nEvents);
    };

});
