/**
 * wuyongsheng560 hightchart 形状绘制
 */
define(function(require, exports, module) {
    require('highcharts');

    module.exports.ratioCircle = function(ratioremarkEl) {
        if (ratioremarkEl.length < 1) return;
        ratioremarkEl.each(function(i, el) {
            var style, html,
                ratioremark = $(el).data('ratioremark');
            switch (ratioremark) {
                case 'start':
                    ratioremark = 0;
                    html = '<span style="">预发布</span>';
                    style = {
                        left: '-5px',
                        top: '6px',
                        fontSize: '12px'
                    };
                    break;
                case 'panicStart':
                    ratioremark = parseFloat(100);
                    html = '剩余<br/><span style="color:#f60;">100%</span>';
                    style = {
                        left: '0%',
                        top: '0%',
                        fontSize: '12px'
                    };
                    break;
                case 'end':
                    ratioremark = 0;
                    html = '<span style="">已售完</span>';
                    style = {
                        left: '-5px',
                        top: '6px',
                        fontSize: '12px'
                    };
                    break;
                case 'panicEnd':
                    ratioremark = 0;
                    html = '<span style="">售罄</span>';
                    style = {
                        left: '1px',
                        top: '6px',
                        fontSize: '12px'
                    };
                    break; 
                default:
                    ratioremark = parseFloat(ratioremark);
                    html = '剩余<br/><span style="color:#f60;">' + ratioremark + '%</span>';
                    style = {
                        left: '0%',
                        top: '0%',
                        fontSize: '12px'
                    };
                    break;
            }

            new Highcharts.Chart({
                chart: {
                    renderTo: el,
                    height: 50,
                    width: 50,
                    style: {
                        left: '-5px',
                        top: '-3px'
                    }
                },
                title: {
                    text: ''
                },
                tooltip: {
                    enabled: false
                },
                colors: ['#f60', '#aaa'],
                plotOptions: {
                    pie: {
                        states: {
                            hover: {
                                enabled: false
                            }
                        },
                        borderWidth: 0,
                        dataLabels: {
                            enabled: false
                        },
                        size: 45,
                        innerSize: 40,
                        startAngle: 45,
                        center: [-7, -7]
                    }
                },
                labels: {
                    items: [{
                        html: html,
                        style: style
                    }]

                },
                series: [{
                    type: 'pie',
                    data: [ratioremark, 100 - ratioremark]
                }]
            });
        });
    };

    module.exports.ratioLCircle = function(ratioremarkEl, options) {
        if (ratioremarkEl.length < 1) return;
        options || (options = {});

        var ratioremark = parseFloat(ratioremarkEl.data('ratioremark')) || 0;
        return new Highcharts.Chart({
            chart: {
                renderTo: ratioremarkEl[0],
                height: 175,
                width: 175,
                style: {
                    left: '0px',
                    top: '0px'
                }
            },
            title: {
                text: ''
            },
            tooltip: {
                enabled: false
            },
            colors: ['#f60', '#aaa'],
            plotOptions: {
                pie: {
                    states: {
                        hover: {
                            enabled: false
                        }
                    },
                    borderWidth: 0,
                    dataLabels: {
                        enabled: false
                    },
                    size: 172,
                    innerSize: 162,
                    startAngle: 45,
                    center: ['50%', '53%']
                },
                series: {
                    animation: {
                        duration: 2000,
                    }
                }
            },
            series: [{
                type: 'pie',
                data: [ratioremark, 100 - ratioremark]
            }]
        });
    };

    module.exports.AreaChartView = ItemView.extend({
        template: _.template('<div id="chartsContainer" style="width:95%; height:180px;"></div>'),
        initialize: function(options) {
            this.view = options.view;
            this.series = options.series || [];
        },
        onRender: function() {
            var series = this.series;
            var categories = [];
            var data = [];
            var tempD;
            for (var i = 0, len = series.length; i < len; i++) {
                tempD = series[i];
                var nav = tempD.nav;
                if(tempD.prdAttr == '4'){
                    nav = (tempD.sevenIncomeRate * 100).toFixed(2);
                }
                categories.push(this._getCategorieLabel(tempD.issDate));
                data.push({
                    name: this._getYearMonthDayLabel(tempD.issDate),
                    y: Number(nav || 0.000)
                });
            }
            this._drawChart(categories, data);
        },

        _getCategorieLabel: function(mStr) {
            if (!mStr) return '';
            return mStr.substring(4, 6) + '-' + mStr.substring(6, 8);
        },

        _getYearMonthDayLabel: function(mStr) {
            if (!mStr) return '';
            mStr = String(mStr);
            return mStr.substring(0, 4) + '年' + mStr.substring(4, 6) + '月' + Number(mStr.substring(6, 8)) + '日';
        },

        _queryMinMax: function(data) {
            var arr = [],
                maxData, minData;
            if (!data.length) return {
                max: 0,
                min: 0
            };

            for (var i = 0; i < data.length; i++) {
                arr.push(data[i].y);
            }

            maxData = Math.max.apply(null, arr);
            minData = Math.min.apply(null, arr);
            return {
                max: maxData,
                min: minData
            };
        },

        _drawChart: function(categories, data) {
            var minMax = this._queryMinMax(data),
                min = minMax.min,
                max = minMax.max,
                chartEl = this.$('#chartsContainer');
            if (!chartEl.length) return;
            if (min === max && min !== 0) min = 0;

            chartEl.highcharts({
                chart: {
                    type: 'area'
                },
                title: {
                    text: ''
                },
                legend: {
                    enabled: false
                },
                xAxis: {
                    gridLineWidth: 1,
                    gridLineColor: '#ffdf7f',
                    lineWidth: 0, //
                    tickWidth: 0, //刻度宽度
                    offset: 5,
                    // tickmarkPlacement: 'on', // label对齐tick
                    categories: categories,
                    title: {
                        enabled: false
                    }
                },
                yAxis: {
                    max: max,
                    min: min,
                    gridLineWidth: 1,
                    gridLineColor: '#ffdf7f',
                    tickInterval: max / 5,
                    title: {
                        enabled: false
                    },
                    labels: {
                        enabled: true,
                        formatter: function() {
                            return this.value.toFixed(4);
                        }
                    }
                },
                plotOptions: {
                    area: {
                        lineWidth: 2,
                        lineColor: '#FE6601',
                        color: '#FE6601',
                        fillOpacity: 0.2,
                        marker: {
                            radius: 5,
                            fillColor: '#FE6601',
                            lineWidth: 3,
                            lineColor: '#FFFFFF'
                        }
                    },
                    series: {
                        marker: {
                            states: {
                                hover: {
                                    lineWidth: 3,
                                    radius: 8
                                }
                            }
                        }
                    }
                },
                tooltip: {
                    enabled: true,
                    shared: false,
                    useHTML: true,
                    headerFormat: '',
                    footerFormat: '',
                    backgroundColor: '#FE6601',
                    pointFormat: '<div style="font-size:14px;">{point.y:.4f}</div>'
                },
                series: [{
                    data: data
                }]
            });
        }
    });

});
