/* global App */
/* global utils */
/* global IS_RUN_ON_DEVICE */
/* global Collection */
/* global ItemView */
define(function(require, exports, module) {
	var initPTRScroll = require('mod/common/widget/initPTRScroll');

	var dreamModel = require("../model/dream");
	var dreamWallHtml = require("text!../template/dreamWall.html");
	var dreamListHtml = require("text!../template/dreamList.html");
	var dreamListItemHtml = require("text!../template/dreamListItem.html");

	module.exports = ItemView.extend({
		template : _.template(dreamWallHtml),

		events : {
			"tap #myDream" : "myDream",
			"tap #addDream" : "addDream",
			"tap .dreamQ" : "dreamDetails", //梦想墙详情
			"tap .praiseReport" : "praiseReport" //点赞,举报
		},

		initialize : function(options) {
			this.respListName = 'allDreamsList';
			this.collection = new Collection([]);
			this.margin = '5';

			//查询参数
			this.param = {
				'pageIndex' : 1,
				'pageSize' : 20
			};
			//历史数据
			this.clist = [];
		},

		onShow : function() {
			this.listRegion = this.$('#transRecordListContainer');
			this.listRegion.parent().css('margin', this.margin + 'px');

			this.initPTRScroll();

			this.scrollerLoadData();
		},
		// //初始化上下拉
		initPTRScroll : function() {
			var self = this, gap = 40;
			if (IS_RUN_ON_DEVICE)
				gap = 15;
			initPTRScroll.call(this, {
				gap : gap,
				pullDownToRefresh : true,
				refreshContent : function(refresh) {
					self._refresher = refresh;
					self.scrollerLoadData();
				},
				loadMoreContent : function(refresh) {
					self._refresher = refresh;
					self.scrollerLoadData(false);
				}
			});
		},
		_refresherFun : function() {
			var self = this;
			clearTimeout(self._refreshTimer);
			self._refreshTimer = setTimeout(function() {
				if (self._refresher) {
					self._refresher();
				} else {
					self.scroller && self.scroller.refresh();
				}
			}, 500);
		},
		_renderData : function(list, pulldown) {
			if (!this.listRegion.length)
				return;
			(Array.isArray(list) && list.length) || ( list = []);

			var self = this;
			var listA = [], listB = [], idx = 0;

			if (list.length) {
				list = _.map(list, function(item, index) {
					!!(index % 2) ? listB.push(item) : listA.push(item);
					return item;
				});
			}

			strA = _.template(dreamListItemHtml, {
				'items' : listA
			});
			strB = _.template(dreamListItemHtml, {
				'items' : listB
			});

			if (pulldown) {
				this.clist = list;
				var empty = !(this.clist.length);
				var str = _.template(dreamListHtml, {
					'empty' : empty,
					'margin' : this.margin
				});
				this.listRegion.html(str);
				this.columnA = this.listRegion.find('#dreamFlexItemA');
				this.columnB = this.listRegion.find('#dreamFlexItemB');

				this.columnA.length && this.columnA.html(strA);
				this.columnB.length && this.columnB.html(strB);
			} else {
				this.clist = this.clist.concat(list);
				this.columnA.length && this.columnA.append(strA);
				this.columnB.length && this.columnB.append(strB);
			}

			// 防止图片加载慢，刷新过早后部分子节点没显示全
			this._refresherFun();
			var imgArr = $(strA + strB).find('img');
			imgArr.length && imgArr.load(function() {
				self._refresherFun();
			});
		},
		//上下拉时加载数据
		scrollerLoadData : function(pulldown) {
			pulldown = (
			void 0 === pulldown) ? true : Boolean(pulldown);
			var self = this, pageIndex = this.param.pageIndex;
			var dreamWallListData = App.storage.remove("dreamWallListData");
			if(dreamWallListData){
			    self.param = dreamWallListData.param;
			}
			var more = function() {
				var totalPage = Math.ceil(self.param.totalNum / self.param.pageSize);
				if (totalPage && ((self.param.pageIndex + 1) <= totalPage))
					return true;
				return false;
			};
			// 防重复提交
			if (this.submitFlag)
				return;
			this.submitFlag = true;

			if (pulldown) {
			    if(dreamWallListData){
                    this.param.pageIndex = dreamWallListData.param.pageIndex;
                }else{
                    this.param.pageIndex = 1;
                }
			} else {
				if (!more())
					return;
				this.param.pageIndex++;
			}
			dreamModel.qryDreamWall({
				param : self.param,
				callback : function(response) {
					var result = response.object;
					self.param.totalNum = result && result.totalNum;
					if (self.scroller && more()) {
						self.scroller.enablePullUpToLoadMore();
					} else {
						self.scroller.disablePullUpToLoadMore();
					}
                    if(dreamWallListData){
                        self._renderData(dreamWallListData.myDreamList, pulldown);
                        if(self.scroller){
                            self.scroller._pos(0, dreamWallListData.scrollY);
                        }
                    }else{
    					self._renderData(result[self.respListName], pulldown);
                    }
				},
				errorCallback : function(err) {
					self.param.pageIndex = pageIndex;
					utils.dialog.alert(err.message);
				},
				complete : function() {
					self.submitFlag = false;
				}
			});
		},

		dreamDetails : function(e) {
			e.preventDefault();
			var curr = $(e.currentTarget).closest('.dreamColumn2');
			var id = curr && curr.data('dreamid');
			if (id ==
				void 0)
				return;
			//存储iscroll滚动高度，以及当前页数
			var dreamWallListData = {};
			dreamWallListData.param = this.param;
			dreamWallListData.myDreamList = this.clist;
			if(this.scroller){
    			dreamWallListData.scrollY = this.scroller.y;
			}
            App.storage.set("dreamWallListData",dreamWallListData);
			App.storage.set("dreamDetailId", id);
			App.storage.set("dreamDisplayList", 0);
			App.storage.set('myDream', this.clist);
			App.navigate("dream/dream/dreamDetails", true);
		},

		//点赞, 举报 flag 0-举报,1-点赞
		//2015-11-26 自己发布的梦想不能点赞举报规则
		praiseReport : function(event) {
			event.preventDefault();
			event.stopPropagation();

			var curr = $(event.currentTarget);
			var id = curr.index();
			var dreamid = curr && curr.closest('.dreamColumn2').data('dreamid').toString();
			if (!curr.length || !dreamid)
				return;
			//2015-12-02 acctNo	改为是否为自己的梦想标志
			// var clickModel = _.findWhere(this.clist, { 'dreamId': dreamid });
			// var isMy = clickModel && !(parseInt(clickModel['acctNo']));
			// if (isMy) {
			//     var msg = !!id ? '不能举报自己' : '不能点赞自己';
			//     utils.dialog.toast(msg);
			//     return;
			// };

			var self = this;
			var data = {};
			data.dreamId = dreamid;
			data.flag = !!id ? 0 : 1;

			dreamModel.praiseOrReport({
				data : data,
				callback : function(res) {
					App.storage.remove("myDreames");

					var ii = curr.find('i').eq(0), hasOn = ii.hasClass('on'), next = ii.next('i'), num = Number(next.text().replace(',', ''));
                    var flag;
                    
					if (hasOn) {
						ii.removeClass('on');
						num -= 1;
						flag = 0;
					} else {
						ii.addClass('on');
						num += 1;
						flag = 1;
					}
					next.text(num);

					var msg, type, clickModel, clickType;
					if (!!id) {
						msg = '举报';
						type = 'reportAmt';
						clickType = 'reportFlag';
					} else {
						msg = '点赞';
						type = 'praiseAmt';
						clickType = 'praiseFlag';
					}

					clickModel = _.findWhere(self.clist, {
						'dreamId' : dreamid
					});
					clickModel[type] = num;
					clickModel[clickType] = flag;
					msg += hasOn ? '已取消' : '成功!';
					utils.dialog.toast(msg);
				},
				errorCallback : function(err) {
					utils.dialog.toast(err.message);
				}
			});
		},

		//底部菜单-我的梦想
		myDream : function() {
			App.navigate("dream/dream/myDream", true);
		},
		//底部菜单-添加梦想
		addDream : function() {
			//禁言(0未禁言,1禁言)与频次(0合理,1不合理)
			var promise = $.when(dreamModel.isOrNotForbidden(), dreamModel.dreamFrequencyControl());
			promise.done(function(arg1, arg2) {
				var arg1 = arg1[0].object;
				var arg2 = arg2[0].object;
				if (arg1.chkFlag == 1) {
					utils.dialog.alert("因您多次发表违禁内容，已被禁言，不能发表梦想！");
				} else if (arg2.chkFlag == 1) {
					utils.dialog.alert("您发布梦想的频率过高，请稍候再添加");
				} else {
					App.storage.set("addDreamFromPage", "dream/dream/dreamWall");
					App.navigate("dream/dream/addDream", true);
				}
			});
			promise.fail(function(err) {
				utils.dialog.toast(err.message);
			});
		}
	});
}); 