/**
 * @author zhoushiwen
 * @ date ${date}
 * @company 中国平安
 */
define(function (require, exports, module) {
	var Form = require("component/form");
	var safeKeyBoardHelper = require("component/customInput.helper");
	var InputTpl = require("text!../../template/buy/buys.html");
	var CustomPwdInput = require("component/password/customPwdInput");
	var BuyModel = require("../../model/buy");
	var InputView = module.exports = Form.extend({
		template: _.template(InputTpl),
		ui: {
			"checkbox": "#checkbox",
			"booksLink": "#booksLink a"
		},
		events: {
			"tap #submitBtn": "submit",
			"tap #setting": "setting",
			"click @ui.checkbox": "toggleCheckbox",
			"click @ui.booksLink": "openBookLink",
			"tap #selPaymentMethod": "selPaymentMethod",
			"customInputKeyup  #amountInput": "_onCustomInputFocusSelAmount"
		},
		templateHelpers : {
			evalMarkup : function (val) {
				var monthMarkup = Number(val);
				if( -1 == monthMarkup || !monthMarkup ){
					monthMarkup = '---';
				}else{
					monthMarkup = ((monthMarkup - 1)*100).toFixed(2);
				}
				return monthMarkup;
			}
		},

		initialize: function (options) {
			this.FundsData   = options.model.get("FundsData");
			this.balance     = options.model.get("balance");
			this.accountList = options.model.get("accountList");
			this.submitFlag  = false;
			this.prdCode     = this.FundsData.prdCode;
			this.firstAmt    = this.FundsData.firstAmt;
			this.appAmt      = this.FundsData.appAmt;
		},

		onRender: function () {
			var self = this;

			//创建输入购买金额框
			//firstAmt 起购金额
			this.$("#amountInput").customInput({
				type: "decimal",
				placeholder: " " + parseInt(self.FundsData.firstAmt) + "元起购",
				className: "safeKeyBoard",
				maxLength: "10"
			});

			var selPayBeforeData = App.storage.get("selPayBeforeData");
			if (selPayBeforeData) {
				if (selPayBeforeData.amountInput != 0) {
					this.$("#amountInput").customInput("value", utils.string.numberFormat(selPayBeforeData.amountInput)); //输入金额
				}
				//选择支付方式
				if (selPayBeforeData.payMentMethod == 1) {
					this.$("#selPaymentMethod p:last").text(utils.string.numberFormat(selPayBeforeData.balance));
				} else if (selPayBeforeData.payMentMethod == 2) {
					this.$("#selPaymentMethod p:last").text(utils.string.numberFormat(selPayBeforeData.dhBalance));
				} else {
					this.$("#selPaymentMethod p:last").text(utils.string.numberFormat(selPayBeforeData.totalBalance) + "=" + utils.string.numberFormat(selPayBeforeData.balance) + "+" + utils.string.numberFormat(selPayBeforeData.dhBalance));
				}
				this.$("#selPaymentMethod").attr("payMethodAttr", selPayBeforeData.payMentMethod);
			}
		},

		//短信设置
		setting: function () {
			App.navigate("fund/buy/setting", true);
		},
		submit: function (event) {
			event.stopPropagation();
			var self = this;
			var check = this;
			var FundsData = {};

			var amount = this.$("#amountInput").customInput("value").replace(/,/g, "");
			var prdCode = this.prdCode

			if (!this.validate(amount)) {
				return;
			}
			CustomPwdInput.customPwdInput(function (password) {
				FundsData.amt = amount;      //购买金额
				FundsData.prdCode = prdCode; //基金代码
				FundsData.password = utils.crypto.RSAKey.encrypt(password, config.base.rsa_public_key);//密码加密
				FundsData.sm2Pwd = utils.sm2.SM2Key.encrypt(password, config.base.sm2_public_key);
				FundsData.paymentType = self.$("#selPaymentMethod").attr("payMethodAttr");  //选择支付方式
				var params = FundsData;

				BuyModel.fundBuy({
					"params": params,
					"callback": function (response) {
						App.storage.set("FundsData", response.object);
						App.storage.remove("selPayBeforeData");   //删除选择支付方式缓存信息
						App.requester.storage.remove("lcProductMoneyQry");
						App.requester.storage.remove("currentToFixedTransferBalance");
						App.requester.storage.remove("loginedAccountInfo");
						App.navigate("fund/buy/finish", true);
					},
					"errorCallback": _.bind(function (response) {
						utils.dialog.alert(response.message);
					}, this)
				});
			});
		},

		/*amount  用户输入的金额
		 password  用户输入的密码
		 balance  用户余额
		 firstAmt 购买起点
		 * */
		validate: function (amount, password) {
			var balance = this.balance;
			if (amount == "") {
				safeKeyBoardHelper.setCustomValidity({
					id: "amountInput",
					message: "请输入金额",
					maxLength: 9
				});
				return false;
			}
			if (parseFloat(amount) > parseFloat(this.model.get("totalBalance"))) {
				safeKeyBoardHelper.setCustomValidity({
					id: "amountInput",
					message: "账户余额不足"
				});
				return false;
			}
			if (parseFloat(amount) < this.firstAmt) {
				safeKeyBoardHelper.setCustomValidity({
					id: "amountInput",
					message: "此产品投资起点为" + this.firstAmt + "元,请输入足够的金额"
				});
				return false;
			}
			return true;
		},

		/**
		 * wuwenjun059
		 * 智能选择支付方式
		 *
		 */
		_onCustomInputFocusSelAmount: function () {
			var num = parseFloat(this.$("#amountInput").customInput("value"));
			var dhBalance = parseFloat(this.model.get("dhBalance")); //平安盈（大华）
			var totalBalance = parseFloat(this.model.get("totalBalance")); //活期余额+平安盈（大华）
			if (num <= parseFloat(this.balance)) {
				this.$("#selPaymentMethod").attr("payMethodAttr", "1");
				this.$("#selPaymentMethod p:first").text("活期余额");
				this.$("#selPaymentMethod p:last").text(utils.string.numberFormat(this.balance));
			} else {
				this.$("#selPaymentMethod").attr("payMethodAttr", "3");
				this.$("#selPaymentMethod p:first").text("活期余额+平安盈(大华)");
				this.$("#selPaymentMethod p:last").text(utils.string.numberFormat(totalBalance) + "=" + utils.string.numberFormat(this.balance) + "+" + utils.string.numberFormat(dhBalance));
			}
		},

		/**
		 * wuwenjun059
		 * 选择支付方式
		 *
		 */
		selPaymentMethod: function () {
			this.formInputData();
			App.navigate("common/selPaymentMethod/selPaymentMethod", true);
		},

		/**
		 * wuwenjun059
		 * 缓存页面数据
		 *
		 */
		formInputData: function () {
			var data = {};
			data.amountInput = this.$("#amountInput").customInput("value").replace(/,/g, '') * 1; //购买金额;
			data.payMentMethod = this.$("#selPaymentMethod").attr("payMethodAttr"); //支付方式
			data.balance = this.model.get("balance");  //余额
			data.dhBalance = this.model.get("dhBalance"); //平安盈（大华）
			data.totalBalance = this.model.get("totalBalance"); //活期余额+平安盈（大华）
			data.selPayBackUrl = "fund/buy/inputs";
			App.storage.set("selPayBeforeData", data);
		}
	});
});
