define(function(require, exports, module){
    var PaymentWayTpl = require("text!../../template/fixedInvestment/paymentWay.html");
    var safeKeyBoardHelper = require("component/customInput.helper");
    var Form = require("component/form");
    var PaymentWayView = module.exports = Form.extend({
        template:_.template(PaymentWayTpl),
        
        events : {
            "customInputFocusIn #fixedAmtInput":"_onCustomInputFocusInAmount",
            "customInputFocusOut #fixedAmtInput":"_onCustomInputFocusOutAmount",
            "customInputFocusIn #reductRateInput":"_onCustomInputFocusInAmount",
            "customInputFocusOut #reductRateInput":"_onCustomInputFocusOutAmount",
            "customInputFocusIn #increaseAmtInput":"_onCustomInputFocusInAmount",
            "customInputFocusOut #increaseAmtInput":"_onCustomInputFocusOutAmount",
            "tap .payment_way_choose" : "paymentWayChoose",
            "tap #submitBtn" : "submit"
            
        },
        
        initialize : function(options){
            this.fundFixedInvestment = options.model;
        },
        
        onRender : function(){
            this.$("#fixedAmtInput").customInput({
                type: "decimal",
                placeholder: "请输入金额(元)",
                maxLength: 11
            });
            
            this.$("#reductRateInput").customInput({
                type: "decimal",
                placeholder: "请输入比例(%)",
                maxLength: 11
            });
            
            this.$("#increaseAmtInput").customInput({
                type: "decimal",
                placeholder: "请输入金额(元)",
                maxLength: 11
            });

        },
        
        reduceWay : "0",
        
        reduceWayText : ["按固定金额扣款","按余额比例扣款","按递增金额扣款"],
        
        reduceWayValue : "",
        
        submit : function(){
            if(!this.validate()) return;
            
            this.fundFixedInvestment.set("reduceWay",this.reduceWay);
            this.fundFixedInvestment.set("reduceWayValue",this.reduceWayValue);
            this.fundFixedInvestment.set("reduceWayText",this.reduceWayText[this.reduceWay]);
            
            App.storage.set("myInvestment/commendProducts/curProObj",this.fundFixedInvestment);
            
            App.navigate("fund/fundFixedInvestment/index/1",true);
            
        },
        
        paymentWayChoose : function(event){
            this.$(".payment_way_choose").find("i").removeClass("iconA59");
            this.$(".payment_way_choose").next().hide();
            var event = this.$(event.currentTarget);
            this.reduceWay = event.attr("paymentWayValue");
            event.find("i").addClass("iconA59");
            if(event.find("i").hasClass("iconA59")) event.next().show();
            else event.next().hide();
        },
        
        validate : function(){
            if(this.reduceWay == "0"){
                this.reduceWayValue = this.$("#fixedAmtInput").customInput("value").replace(/,/g,"");
                if(!this.reduceWayValue || this.reduceWayValue<=0){
                    utils.dialog.toast("请输入定投金额");
                    return false;
                }
                if(isNaN(this.reduceWayValue)){
                    utils.dialog.toast("定投金额输入有误");
                    return false;
                }
                
                if(this.reduceWayValue <this.fundFixedInvestment.get("minInvestAmt")){
                    utils.dialog.toast("定投金额不能少于最低定投金额");
                    return false;
                }
                
            }else if(this.reduceWay == "1"){
                this.reduceWayValue = this.$("#reductRateInput").customInput("value").replace(/,/g,"");
                if(!this.reduceWayValue){
                    utils.dialog.toast("请输入余额比例");
                    return false;
                }
                if(isNaN(this.reduceWayValue)){
                    utils.dialog.toast("余额比例输入有误");
                    return false;
                }
                if(this.reduceWayValue>100 || this.reduceWayValue<=0){
                    utils.dialog.toast("余额比例输入有误");
                    return false;
                }
            }else{
                this.reduceWayValue = this.$("#increaseAmtInput").customInput("value").replace(/,/g,"");
                if(!this.reduceWayValue){
                    utils.dialog.toast("请输入递增金额");
                    return false;
                }
                if(isNaN(this.reduceWayValue) || this.reduceWayValue<=0){
                    utils.dialog.toast("递增金额输入有误");
                    return false;
                }
            }
            
            return true;
        },
        
        _onCustomInputFocusInAmount: function(){
            safeKeyBoardHelper.focusIn({ id:"fixedAmtInput" });
            safeKeyBoardHelper.focusIn({ id:"reductRateInput" });
            safeKeyBoardHelper.focusIn({ id:"increaseAmtInput" });
        },
        
        _onCustomInputFocusOutAmount: function(){
            safeKeyBoardHelper.focusOut({ id:"fixedAmtInput" });
            safeKeyBoardHelper.focusOut({ id:"reductRateInput" }); 
            safeKeyBoardHelper.focusOut({ id:"increaseAmtInput" }); 
        }
        
        
    });
});
