/*
 * @Author: WANGQIANG873
 * @Date:   2016-04-16 16:25:11
 * @Last Modified by:   WANGQIANG873
 * @Last Modified time: 2016-04-25 16:49:45
 */

define(function (require, exports, module) {
    var Tpl = require("text!../template/buy.html");
    var safeKeyBoardHelper = require("component/customInput.helper");
    var CustomPwdInput = require("component/password/customPwdInput");
    var fundStrongModel = require("../model/model");
    var tools = require("../common/tools");
    var lang = require("../common/lang");

    var indexView = module.exports = ItemView.extend({
        template: _.template(Tpl),
        events: {
            "tap #buyBtn": "buySubmit",
            "customInputFocusIn #buyAmount": "customInputFocusInAmount",
            "customInputFocusOut #buyAmount": "customInputFocusOutAmount",
            "customInputKeyup #buyAmount": "smartChoice",
            "input #buyAmount": "smartChoice",
            "tap #openBookLink": "openBookLink",
            "tap #book": "toggleCheckbox",
            "tap #selPaymentMethod": "selPaymentMethod",
            "tap #pactLink": "openLink"
        },
        initialize: function () {
            this.submitFlag = false;
        },
        onShow: function () {
            this.showSafeKeyBoardAmount();
            $("#arrivalTime").html(tools.incomeArrivalTime());

            var selPayBeforeData = App.storage.get("selPayBeforeData");
            if (selPayBeforeData) {
                if (selPayBeforeData.amountInput != 0) {
                    this.$("#buyAmount").customInput("value", utils.string.numberFormat(selPayBeforeData.amountInput));//输入金额
                }
                //协议
                if (selPayBeforeData.checkbox) {
                    this.$("#book").toggleClass("on");
                }

                if (selPayBeforeData.amountInput != 0 && selPayBeforeData.checkbox) {
                    this.$("#buyBtn").removeClass('btn_disable').addClass("btn_orange");
                }
            }
        },

        showSafeKeyBoardAmount: function () {
            this.$("#buyAmount").customInput({
                type: "decimal",
                placeholder: this.model.get("minAmt") + "元起购",
                maxLength: 12,
                className: "safeKeyBoard"
            });
        },

        customInputFocusInAmount: function () {
            safeKeyBoardHelper.focusIn({
                id: "buyAmount"
            });
        },
        customInputFocusOutAmount: function () {
            safeKeyBoardHelper.focusOut({
                id: "buyAmount"
            });
        },

        buySubmit: function (e) {
            if ($(e.target).hasClass('btn_disable')) {
                return;
            }
            if (this.submitFlag) {
                return;
            }
            var self = this;
            var data = this.formData();
            if (this.validate(data)) {
                CustomPwdInput.customPwdInput(function (password) {
                    self.submitFlag = true;
                    fundStrongModel.any({
                        "url": "buyFundStrong",
                        "data": {
                            "password": utils.crypto.RSAKey.encrypt(password, config.base.rsa_public_key),
                            "sm2Pwd": utils.sm2.SM2Key.encrypt(password, config.base.sm2_public_key),
                            "amt": data.amountInput,
                            "paymentType": data.payMentMethod
                        },
                        "callback": function (res) {
                            App.storage.remove("selPayBeforeData"); //删除支付方式
                            App.storage.set("fundStrong_buy_success_data", res);
                            App.navigate('fundStrong/fundStrongLogin/buySuccess', true);
                        },
                        "errorCallback": function (res) {
                            self.submitFlag = false;
                            if (res.code == 601) {
                                utils.dialog.confirm(res.message, {"okButtonText": "立即测评", "cancelButtonText": "暂不测评"}, function (ok) {
                                    if (ok) {
                                        App.navigate("riskExam/riskExam/riskExam/7", true);
                                    }
                                });
                            } else if (res.code == 602) { //密码错误
                                utils.dialog.alert(res.message);
                            } else {
                                App.storage.remove("selPayBeforeData"); //删除支付方式
                                App.storage.set("fundStrong_buy_fail_data", res.message);
                                App.navigate('fundStrong/fundStrongLogin/buyFail', true);
                            }
                        }
                    });
                });
            }
        },

        smartChoice: function () {
            var amt = this.$("#buyAmount").customInput("value").replace(/,/g, '') * 1;
            var balance = parseFloat(this.model.get("balance"));
            var dhBalance = parseFloat(this.model.get("dhBalance")); //平安盈(大华)
            var totalBalance = parseFloat(this.model.get("totalBalance"));
            if (amt > 0 && this.$("#book").hasClass('on')) {
                this.$("#buyBtn").removeClass('btn_disable').addClass("btn_orange");
            } else {
                this.$("#buyBtn").addClass('btn_disable').removeClass("btn_orange");
            }
            if (amt <= balance) {
                this.$("#selPaymentMethod").attr("payMethodAttr", "1");
                this.$("#selPaymentMethod p:first").text("活期余额");
                this.$("#selPaymentMethod p:last").text(utils.string.numberFormat(balance));
            } else {
                this.$("#selPaymentMethod").attr("payMethodAttr", "3");
                this.$("#selPaymentMethod p:first").text("活期余额+平安盈(大华)");
                this.$("#selPaymentMethod p:last").text(utils.string.numberFormat(totalBalance) + "=" + utils.string.numberFormat(balance) + "+" + utils.string.numberFormat(dhBalance));
            }
        },
        selPaymentMethod: function () {
            this.formData();
            App.navigate("common/selPaymentMethod/selPaymentMethod", true);
        },

        validate: function (data) {
            if (data.amountInput == "") {
                safeKeyBoardHelper.setCustomValidity({
                    id: "buyAmount",
                    message: lang("please_enter_the_purchase_amount")//"请输入购买金额"
                });
                return false;
            }
            if (isNaN(data.amountInput)) {
                safeKeyBoardHelper.setCustomValidity({
                    id: "amountInput",
                    message: lang("enter_the_amount_is_not_legitimate") //"购买金额输入不合法"
                });
                return false;
            }

            if (parseFloat(data.amountInput) > parseFloat(this.model.get("totalBalance"))) {
                safeKeyBoardHelper.setCustomValidity({
                    id: "amountInput",
                    message: lang("account_balance_is_insufficient") //"账户余额不足"
                });
                return false;
            }

            if (parseFloat(data.amountInput) < this.model.get("minAmt")) {
                safeKeyBoardHelper.setCustomValidity({
                    id: "amountInput",
                    message: lang("purchase_amount_not_less") + this.model.get("minAmt") + "元。" //"购买金额不能低于1000元。"
                });
                return false;
            }

            if (!data.checkbox) {
                utils.dialog.toast(lang("please_read_and_agree_to"));
                return false;
            }
            return true;
        },

        formData: function () {
            var data = {
                amountInput: this.$("#buyAmount").customInput("value").replace(/,/g, '') * 1, //购买金额
                payMentMethod: this.$("#selPaymentMethod").attr("payMethodAttr"), //支付方式
                balance: this.model.get("balance"), //余额
                dhBalance: this.model.get("dhBalance"), //平安盈（大华）
                totalBalance: this.model.get("totalBalance"), //活期余额+平安盈（大华）
                checkbox: this.$("#book").hasClass("on"), //是否同意协议
                selPayBackUrl: "fundStrong/fundStrongLogin/buy"
            };
            App.storage.set("selPayBeforeData", data);
            return data;
        },

        toggleCheckbox: function (e) {
            $(e.currentTarget).toggleClass("on");
            var amt = this.$("#buyAmount").customInput("value").replace(/,/g, '') * 1;
            if ($(e.currentTarget).hasClass('on') && amt > 0) {
                this.$("#buyBtn").removeClass('btn_disable').addClass("btn_orange");
            } else {
                this.$("#buyBtn").addClass('btn_disable').removeClass("btn_orange");
            }
        },
        openBookLink: function (e) {
            e.stopPropagation();
            var t = $(e.target);
            this.$("#pact").show();
            utils.native.hideSafeKeyboard();
            setTimeout(function () {
                $("#pactLink").css({"bottom": "0px"});
            }, 200);
        },
        openLink: function (e) {
            e.stopPropagation();
            var t = $(e.target);

            if (t.attr("data-url") == "cancel") {
                this.$("#pactLink").css({"bottom": "-" + $("#pactLink").height() + "px"});
                setTimeout(function () {
                    $("#pact").hide();
                }, 200);
                return;
            }
            utils.window.open({
                title: t.text(),
                url: t.attr('data-url')
            });
        }
    });
});