/*
 * @Author: WANGQIANG873
 * @Date:   2016-04-16 16:25:11
 * @Last Modified by:   WANGQIANG873
 * @Last Modified time: 2016-04-26 11:31:05
 */

define(function (require, exports, module) {
    var Tpl = require("text!../template/redeem.html");
    var safeKeyBoardHelper = require("component/customInput.helper");
    var CustomPwdInput = require("component/password/customPwdInput");
    var fundStrongModel = require("../model/model");
    var tools = require("../common/tools");
    var lang = require("../common/lang");

    var redeemView = module.exports = ItemView.extend({
        template: _.template(Tpl),
        events: {
            "tap #redeemBtn": "redeemSubmit",
            "customInputFocusIn #redeemAmount": "customInputFocusInAmount",
            "customInputFocusOut #redeemAmount": "customInputFocusOutAmount",
            "customInputKeyup #redeemAmount": "smartChoice",
            "input #redeemAmount": "smartChoice",
            "change #redeemAmount": "smartChoice",
            "tap #allAmount": "allAmount"

        },
        initialize: function () {
            this.submitFlag = false;
            this.model = new Model(App.storage.get("fundStrong_income_and_assets"));
        },
        onShow: function () {
            this.showSafeKeyBoardAmount();
            this.$("#redeemAmount").append("<span class='c_f60 m_r10 dsb fcyCoTp' id='allAmount'>全部赎回</span>");
            if (this.model.get("availLot") == 0) {
                this.$("#allAmount").hide();
            }
            $("#arrivalTime").html(tools.ransomArrivalTime());
        },

        showSafeKeyBoardAmount: function () {
            this.$("#redeemAmount").customInput({
                type: "decimal",
                placeholder: "最多可赎回" + utils.string.formatMoneyNumber(this.model.get("availLot")),
                maxLength: 12,
                className: "safeKeyBoard"
            });
        },

        customInputFocusInAmount: function () {
            safeKeyBoardHelper.focusIn({id: "redeemAmount"});
        },
        customInputFocusOutAmount: function () {
            safeKeyBoardHelper.focusOut({id: "redeemAmount"});
        },

        redeemSubmit: function (e) {
            if ($(e.target).hasClass('btn_disable')) {
                return;
            }
            if (this.submitFlag) {
                return;
            }
            var self = this;
            if (this.validate()) {
                CustomPwdInput.customPwdInput(function (password) {
                    self.submitFlag = true;
                    fundStrongModel.any({
                        "url": "fundStrongRedeem",
                        "data": {
                            "password": utils.crypto.RSAKey.encrypt(password, config.base.rsa_public_key),
                            "sm2Pwd": utils.sm2.SM2Key.encrypt(password, config.base.sm2_public_key),
                            "redeemAmt": self.$("#redeemAmount").customInput("value").replace(/,/g, '') * 1
                        },
                        "callback": function (res) {
                            App.storage.set("fundStrong_redeem_success_data", res);
                            App.navigate('fundStrong/fundStrongLogin/redeemSuccess', true);
                        },
                        "errorCallback": function (res) {
                            self.submitFlag = false;
                            if (res.code == 602) { //密码错误
                                utils.dialog.alert(res.message);
                            } else {
                                App.storage.set("fundStrong_redeem_fail_data", res.message);
                                App.navigate('fundStrong/fundStrongLogin/redeemFail', true);
                            }
                        }
                    });
                });
            }
        },
        allAmount: function (e) {
            e.stopPropagation();
            e.preventDefault();
            this.$("#redeemAmount").customInput("value", utils.string.formatMoneyNumber(this.model.get("availLot")));
            this.smartChoice();
        },
        smartChoice: function () {
            var amount = this.$("#redeemAmount").customInput("value").replace(/,/g, '') * 1;
            if (amount > 0) {
                this.$("#redeemBtn").removeClass('btn_disable').addClass("btn_orange");
            } else {
                this.$("#redeemBtn").addClass('btn_disable').removeClass("btn_orange");
            }
        },

        validate: function () {
            var amount = $("#redeemAmount").customInput("value").replace(/,/g, '') * 1;
            if (amount == "") {
                safeKeyBoardHelper.setCustomValidity({
                    id: "redeemAmount",
                    message: lang("please_enter_the_redemption_amount")//"请输入赎回金额"
                });
                return false;
            }
            if (isNaN(amount)) {
                safeKeyBoardHelper.setCustomValidity({
                    id: "redeemAmount",
                    message: lang("enter_the_redeem_amount_is_not_legitimate")//"赎回金额输入不合法"
                });
                return false;
            }

            if (this.model.get("availLot") == 0) {
                safeKeyBoardHelper.setCustomValidity({
                    id: "redeemAmount",
                    message: lang("callable_balance_is_0")//"可赎回余额为0元！"
                });
                return false;
            }

            if (parseFloat(amount) > parseFloat(this.model.get("availLot"))) {
                safeKeyBoardHelper.setCustomValidity({
                    id: "redeemAmount",
                    message: lang("redeem_amount_greater_than_the_balance") //"赎回金额不能大于产品余额！"
                });
                return false;
            }
            return true;
        }
    });
});