define(function(require, exports, module) {
	var IndexQryModel = module.exports = Model.extend({}, {
		getBannerList: function() {
			return utils.native.readConfigAsXMLDoc().then(function(xml) {
				var banners = $(xml).find('bannerList banner').map(function(idx, item) {
					var $item = $(item);

					return {
						url: $item.attr('url'),
						img: $item.attr('img'),
						title: $item.attr('title')
					};
				});

				return banners.get();
			});
		},
		getBannerTmp: function(options) {
			var data = options || {};
			return App.request('ADimg', {
				silent: true,
				data: data
			});
		},
		queryProduct: function(options) {
			var data = options || {};
			return App.request('qryFistPageProductList', {
				data: data,
				isSave: true
			}).pipe(function(result) {
				App.storage.set('indexPrdLastRefresh', Date.now());
				return IndexQryModel._processQryPrdList(result);
			});
		},

		// 2015-10-09 增加 黄金单价查询
		queryGoldPrice: function(options) {
			var data = options || {};
			return App.request('goldAcctQryGoldPrice', {
				data: data
			}).pipe(function(result) {
				return result.object;
			});
		},
		// 2015-10-30 登录后显示总资产
		queryAccountInfo: function(options) {
			options || (options = {});
			return App.request('loginedAccountInfo', {
				data: options.data,
				silent: options.silent || true,
				cache: options.cache || true
			}).pipe(function(result) {
				return result.object || {};
			});
		},

		queryNativeProduct: function(options) {
			var data = options || {};
			var CFG = _.extend({
				key: 'qryFistPageProductList'
			}, data);
			return utils.native.HTTPRequestCache(CFG).pipe(function(result) {
				return IndexQryModel._processQryPrdList(result);
			});
		},

		_processQryPrdList: function(result) {
			var res = {
				productList: [],
				params: {}
			};
			try {
				res = IndexQryModel._processQryResult(result);
			} catch (e) {}

			// 防止再次请求回来的 空数据覆盖缓存
			// if( res.productList.length > 0 && refresh) {
			//     res.params.lastRefresh = Date.now();
			//     //IndexQryModel._getSetCachePrdList(res);
			// }

			return res;
		},

		queryYesterdayEarning: function(options) {
			options || (options = {});
			return App.request('qryYesterdayIncome', {
				data: options.data,
				silent: options.silent || true,
				cache: options.cache || true
			}).pipe(function(result) {
				return result.object || {};
			});
		},

		_getSetCachePrdList: function() {
			if (arguments.length > 0) {
				App.locStorage.set('modIndexPrdCache', arguments[0]);
			}
			return App.locStorage.get('modIndexPrdCache');
		},

		/**
		 * 处理接口数据
		 * 产品数组list分离，其余非数组字段作为view 参数
		 * 根据返回数据键，增加值 type 属性
		 * type = 'pay' 表示平安盈 'fund' 表示基金产品 'finance' 表示理财产品 ‘currentYing’每日盈
		 *
		 */
		_processQryResult: function(result) {
			//2015-10-29 增加稳E盈基金产品wenEyingPrdList
			//2015-09-24 增加黄金宝理财产品goldPrdList
			var productListArr = [
				'paYingList', 'fundList', 'financingPrdList',
				'pensionPrdList', 'papiaoPrdList', 'goldPrdList',
				'wenEyingPrdList','fundStrongPrdList'
			];
			var prdList = _.pick(result.object, productListArr);
			var productParam = _.omit(result.object, productListArr);
			prdList = _.reduce(prdList, function(memo, value, key) {
				if (value) memo[key] = value;
				return memo;
			}, {});

			//2015-09-07 暂时屏蔽 货币型， 这期不上
			if (Array.isArray(prdList.fundList) && prdList.fundList.length) {
				prdList.fundList = _.filter(prdList.fundList, function(item) {
					return item.prdAttr && ('4' !== item.prdAttr);
				});
			}
			if (Array.isArray(prdList.wenEyingPrdList) && prdList.wenEyingPrdList.length) {
				prdList.wenEyingPrdList = _.filter(prdList.wenEyingPrdList, function(item) {
					return item.prdAttr && ('4' !== item.prdAttr);
				});
			}

			['financingPrdList', 'pensionPrdList',
				'papiaoPrdList'
			].forEach(function(listType) {
				if (Array.isArray(prdList[listType]) && prdList[listType].length) {
					prdList[listType] = IndexQryModel._processFinaceProductList(
						prdList[listType], productParam.currentTime);
				}
			});

			// 2015-06-13 计算平安盈 7日年化收益率 与 活期利率 倍数
			if (prdList.paYingList) {
				_.each(prdList.paYingList, function(v, k) {
					//后台所返回的活期利率为百分比,这里需要(sevenIncomeRate)乘以100
					var mRate = Math.round(v.sevenIncomeRate * 100 / productParam.currentRate);
					if (_.isNaN(mRate) || !_.isFinite(mRate)) {
						v.mRate = 'x';
					} else {
						v.mRate = mRate;
					}
				});
			}

			//计算每日盈 7日年化收益率 与 活期利率 倍数
			if(prdList.fundStrongPrdList){
				_.each(prdList.fundStrongPrdList,function(v,k){
					var mRate = Math.round(v.sevenIncomeRate / productParam.currentRate);
					if (_.isNaN(mRate) || !_.isFinite(mRate)) {
						v.mRate = 'x';
					} else {
						v.mRate = mRate;
					}
				})
			}

			prdList = _.chain(prdList)
				.map(function(value, key) {
					switch (key) {
						case 'paYingList':
							return IndexQryModel._setValue(value, 'paY');
						case 'fundList':
							return IndexQryModel._setValue(value, 'fund');
						case 'wenEyingPrdList':
							IndexQryModel._setValue(value, 'subtype', 'wenEyingPrdList');
							return IndexQryModel._setValue(value, 'fund');
						case 'financingPrdList':
							return IndexQryModel._setValue(value, 'finance');
						case 'pensionPrdList':
							return IndexQryModel._setValue(value, 'pension');
						case 'papiaoPrdList':
							return IndexQryModel._setValue(value, 'pap');
						case 'goldPrdList':
							return IndexQryModel._setValue(value, 'goldbao');
						case 'fundStrongPrdList':
							return IndexQryModel._setValue(value,'fundStrong');
					}
				})
				.flatten(true)
				.sortBy(function(value, id) { //以index键 排序
					return parseInt(value.index, 10);
				})
				.value();

			return {
				productList: prdList,
				params: productParam
			};
		},

		_setValue: function(obj, key) {
			var tkey, val;
			if (arguments.length > 2) {
				tkey = key;
				val = arguments[2];
			} else {
				tkey = 'type';
				val = key;
			}
			if (_.isArray(obj)) {
				_.each(obj, function(v, k) {
					v[tkey] = val;
				});
			} else {
				obj[tkey] = val;
			}
			return obj;
		},

		/**
		 * 处理理财产品信息
		 * 增加 flag 0 表示预发布 1 表示正在发售 2 表示 已售完或者过期
		 * 增加 countdown (秒) 倒计时时间 当 flag = 0 || 1
		 * 增加 ratioRemark = balanceRemark / totalAmt
		 * 2015/05/26 更改为
		 * 增加 ratioRemark = remainQuota0799 / totalAmt
		 *
		 * 全开放式（日添利型）、收益类：CycleMode=40，TypeId=310，NavMode=1；
		 * 全开放式（按天计收益型）、收益类：CycleMode=41，TypeId=311，NavMode=1；
		 * 全开放式（真净值型）、净值类：CycleMode=50，TypeId=51开头（暂仅510），NavMode=0；
		 * 2015/12/09 根据产品字段prdCode增加理财产品中的日添利，净值产品标志:
		 * fnType : '1' 日添利， '2' 净值
		 */
		_processFinaceProductList: function(list, currentTime) {
			if (!list || !_.isArray(list)) return;
			currentTime = new Date(currentTime).getTime() || new Date().getTime();
			return _.map(list, function(item, id) {
				var tempDate = item.saleStartDate1 + ' ' + item.saleStartTime.substr(0, 2) + ':' + item.saleStartTime.substr(2, 2);
				var startDate = new Date(tempDate.replace(/-/g, '/')).getTime();
				tempDate = item.saleEndDate1 + ' ' + item.saleEndTime.substr(0, 2) + ':' + item.saleEndTime.substr(2, 2);
				var endDate = new Date(tempDate.replace(/-/g, '/')).getTime();
				if (startDate > endDate) return;

				var flag = 2,
					ratio;
				if (currentTime < startDate) {
					flag = 0;
				} else if (currentTime < endDate && parseFloat(item.minAmount) < parseFloat(item.remainQuota0799)) {
					flag = 1;
				}
				item.flag = flag;
				if (flag === 1 || flag === 0) {
					item.countdown = parseInt((endDate - currentTime) / 1000, 10);
					//if (flag == 1) {
					ratio = (parseFloat(item.remainQuota0799) / parseFloat(item.totalAmt)) * 100;
					if (_.isFinite(ratio)) {
						ratio = ratio >= 1 ? parseInt(ratio, 10) : (ratio < 0.1 ? 0.1 : ratio.toFixed(1));
					} else {
						ratio = 99;
					}
					item.ratioRemark = ratio;
					//}
				}

				if (flag === 2) {
					item.balanceRemark = '0';
				}

				if (/^310/.test(item.prdCode)) {
					item.fnType = '1'
				} else if (/^510/.test(item.prdCode)) {
					item.fnType = '2'
				}

				return item;
			});
		},

		/**
		 * ex-wuwenjun001
		 * 抢购开关
		 */
		qryIsRuPurchase : function(options){
			if(App.storage.get("isUserLoggedIn")){
				return App.request("qryIsRuPurchase", {data : options});
			}else{
				return App.request("qryIsRuPurchaseOutside", {data : options});

			}
		},
		
		/**
		 * ex-chenfuhua001
		 * 夺宝奇兵开关
		 */
		chestSwitch: function(options){
			App.request(options.url,{
				success: function(res){
					options.callback(res);
				},
				error: function(err){
					options.errorCallback(err);
				}
			});
		}
	});
});
