/**
 * ex-wuyongsheng001 产品列表视图
 */
define(function(require, exports, module) {
    var shapeRender = require('mod/common/widget/shapeRender');
    var paYTpl = _.template(require('text!../template/paYProduct.html'));
    var fundTpl = _.template(require('text!../template/fundProduct.html'));
    var financeTpl = _.template(require('text!../template/financeProduct.html'));
    var wenEyingTpl = _.template(require('text!../template/wenEyingProduct.html'));
    var FundStrongTpl = _.template(require('text!../template/fundStrong.html'));

    var ProductView = ItemView.extend({
        className: 'productItem',
        triggers: {
            'tap': 'tap' //跳转产品详情页
        },
        templateHelpers: {
            minAmountFmt: function(minAmount) {
                if ('goldbao' === this.type) {
                    return '<span class="f24">' + minAmount + '克<i class="f12 lh12">黄金份额</i></span>';
                }

                if (minAmount >= 10000) {
                    return Math.floor(minAmount / 10000) + '<i class="f15 lh12">万元</i>';
                } else {
                    return utils.string.numberFormat(minAmount, 0) + '<i class="f15 lh12">元</i>';
                }
            },
            evalMarkup: function(val, normal) {
                var monthMarkup = Number(val);
                if (-1 === monthMarkup || !monthMarkup) {
                    monthMarkup = '---';
                } else {
                    monthMarkup = this.splitStr(((monthMarkup - 1) * 100).toFixed(2));
                    if (normal) {
                        monthMarkup += '%';
                    } else {
                        monthMarkup += '<i class="f15 lh12">'+  this.splitStr(((monthMarkup - 1) * 100).toFixed(2), 1) +'%</i>';
                    }
                }
                return monthMarkup;
            },

            otherMarkup: function(val) {
                var monthMarkup = Number(val);
                if( -1 === monthMarkup || !val){
                    monthMarkup = '---';
                }else{
                    monthMarkup = this.splitStr(monthMarkup.toFixed(3)) + '<i class="f15 lh12">'+ this.splitStr(monthMarkup.toFixed(3), 1) +'%</i>';
                }
                return monthMarkup;
            },

            rateTpl : function (val){
                var cls = 'c_f60';
                val = Number(val);
                if( -1 === val || !val ){
                    val = '---';
                }else{
                    if (val < 0) cls = 'c_3eb';
                    val = this.splitStr(((val - 1)*100).toFixed(2)) + '<i class="f15 lh12">'+ this.splitStr(((val - 1)*100).toFixed(2), 1) +'%</i>';
                }
                return '<p class="f28 '+cls+'">'+val+'</p>';
            },

            splitStr : function(val, index) {
                if(typeof val !== "string" && typeof val !== "number") return val;
                if(typeof val === "number") val = String(val);
                index = index == null ? 0 : index;
                var strArr = val.split('.'), sStr = strArr[1] ? ('.') + strArr[1] : '.00';
                strArr.splice(1, 1, sStr);
                return strArr[index];
            },

            rPrdAttrName: function(name) {
                return name && name.replace(/^\s*\u57FA\u91D1/, '');
            },
            /**
             * 1 股票型 2 混合型 3 基金债券型 4 基金货币型 5 基金保本型 6 基金QDII 7 基金其他
             */
            rPrdAttrCls: function(prdAttr) {
                var cls = {
                    '1': 'Stock',
                    '2': 'Mix',
                    '3': 'Bond',
                    '4': 'Monetary',
                    '5': 'Guaranteed',
                    '6': 'QDII',
                    '7': 'Other'
                };

                prdAttr = (prdAttr + '').trim();
                return cls[prdAttr] || 'Other';
            }
        },
        getTemplate: function() {
            var productType, productSubType;
            productType = this.model.get('type');
            productSubType = this.model.get('subtype');
            //2015-10-29 增加稳E盈基金产品wenEyingPrdList
            if ('fund' === productType && 'wenEyingPrdList' === productSubType) {
                return wenEyingTpl;
            }

            switch (productType) {
                case 'paY':
                    return paYTpl;
                case 'fund':
                    return fundTpl;
                case 'goldbao':
                case 'finance':
                case 'pension':
                case 'pap':
                    return financeTpl;
                case 'fundStrong':
                    return FundStrongTpl;
            }
        }

    });

    module.exports = CollectionView.extend({
        className: 'listProducts',
        itemView: ProductView,

        onRender: function() {
            this.lastRefresh = App.storage.get('indexPrdLastRefresh') || Date.now();
            this._renderCountDown();

            var ratios = this.$('[data-ratioremark]');
            if (ratios.length) shapeRender.ratioCircle(ratios);
        },

        onItemviewTap: function(itemView, args) {
            var _this = this;
            var model = args.model;
            var isLogin = App.storage.get('isUserLoggedIn');

            model.set('lastRefresh', _this.lastRefresh);
            model.set('fromPage', 'index');

            switch (model.get('type')) {
                case 'finance':
                case 'pension':
                case 'pap':
                    App.storage.set('products/detail/finace', model);
                    App.navigate('products/detail/finace', true);
                    break;
                case 'fund':
                    App.storage.set('products/detail/fund', model);
                    App.navigate('products/detail/fund', true);
                    break;
                    //2015-09-24 增加黄金宝理财产品
                case 'goldbao':
                    App.storage.set('products/detail/goldbao', model);
                    App.navigate('products/detail/goldbao', true);
                    break;
                case 'paY':
                    if (!isLogin) {
                        App.storage.set('pinganying/payIndexLogin/index', model);
                        App.navigate('pinganying/payIndexLogin/index', true);
                    } else {
                        App.storage.set('pinganying/payIndex/index', model);
                        App.navigate('pinganying/payIndex/index', true);
                    }
                    break;
                case 'fundStrong':
                    if (!isLogin) {
                        App.storage.set('fundStrong/fundStrong/index', model);
                        App.navigate('fundStrong/fundStrong/index', true);
                    } else {
                        App.storage.set('fundStrong/fundStrongLogin/index', model);
                        App.navigate('fundStrong/fundStrongLogin/index', true);
                    }
                    break;
            }

        },

        /**
         * 渲染倒计时
         */
        _renderCountDown: function() {
            var countdownEl = this.$('[data-countdown]');
            var lastRefreshEllipsis = parseInt((Date.now() - this.lastRefresh) / 1000, 10);
            if (countdownEl.length < 1) return;

            countdownEl.each(function(i, el) {
                el = $(el);
                var day = el.find('.day')[0],
                    hour = el.find('.hour')[0],
                    minute = el.find('.minute')[0],
                    second = el.find('.second')[0];
                var countdown = el.data('countdown');
                if (!countdown) return;
                el.show();

                countdown = countdown - lastRefreshEllipsis;
                utils.date.countDown(countdown, {
                    day: day,
                    hour: hour,
                    min: minute,
                    sec: second
                });
            });
        }

    });

});
