define(function (require, exports, module) {
	var payBackTpl = require("text!../../template/creditCard/payBack.html");
	var CustomPwdInput = require("component/password/customPwdInput");
	var CreditPaymentModel = require("../../model/creditCard");
	var safeKeyBoardHelper = require("component/customInput.helper");
	var RedPacket          = require("component/redPacket/redPacket");
	module.exports = ItemView.extend({
		template : _.template(payBackTpl),
		events : {
			"tap #selectCreditCard"            : "selectCreditCard",
			"tap #allPayBack"                  : "selectpayBackType",
			"tap #leastPayBack"                : "selectpayBackType",
			"tap #selfPayBack"                 : "selectpayBackType",
			"tap #modifyPayBacklimit"          : "_modifyPayBacklimit",
			"tap #determinePay"                : "_determinePay",
			"tap .creditCardList ul li"        : "creditCardListHandler",
			"customInputFocusOut #amountInput" : "selfPayBackAmt"
		},

		initialize: function(){
			this.submitFlag = false;  // 提交接口防重复
			this.payBackType = 0 ;    //还款类型 0 全额 1最低 2自定义
		},

		onShow : function() {
			//可用余额
			var creditCardInfo = this.model.get("creditCardInfo");
			var amt = $("#payBackAmt").html();
			var balance = parseFloat(creditCardInfo.accBalance || 0) + parseFloat(creditCardInfo.nfBalance || 0) + parseFloat(creditCardInfo.dhBalance || 0);
			this.$("#balance").html(utils.string.formatMoneyNumber(balance) + "元");
			this.$("#amountInput").customInput({
				type : "decimal",
				placeholder : "请输入还款金额",
				className : "",
				maxLength : "10"
			});
			this.redPacket = new RedPacket({
				amt:amt,
				title:"信用卡还款红包<span class='f12'>(返等值万里通积分)</span>",
				className : "h50 lh12",
				text:"信用卡还款红包",
				textClassName : "c_000 f16",
				selectionBox:"checkbox",
				redPacketCategoryCode:"01",
				redPacketStatusCode:"0|1",
				callback:function(){}
			});
			this.$("#redPacketSelect").empty();
			this.$("#redPacketSelect").append($(this.redPacket.$el[0]));
		},

		//输入金额后匹配红包
		selfPayBackAmt: function(){
			var amt=this.$("#amountInput").customInput('value');
			this.redPacket.reload({amt: amt});
		},

		//选择信用卡
		selectCreditCard: function (events) {
			this.$(".creditCardList").slideToggle(300);
		},

		creditCardListHandler: function (event) {
			this.$(".creditCardList").find("i").remove();
			this.$(event.target).append("<i class='iconA59'>");
			this.$(".creditCardList").slideUp(300, _.bind(function () {
				var cardNum = this.$(event.target).attr("data-acct");
				this.$("#cardNum").attr("data-acct", cardNum).text(utils.string.dealTheAccNo(cardNum));
			}, this));
		},

		//选择还款类型
		selectpayBackType: function (event) {
		    var self = this;
            var $current = this.$(event.currentTarget);
            if ($current.find("i").hasClass("iconA107")){
            	return;
            }
            this.$("#payBackType").find("i").removeClass("iconA107");
            $current.find("i").addClass("iconA107");
            this.payBackType = $current.data("type");
            if (this.payBackType == "0") {
                var amt = utils.string.formatMoneyNumber(this.model.get("creditCardInfo").cnyRemainDutAmt);
                this.$("#payBackAmt").text(amt);
                this.$("#systemDutAmt").show();
                this.$("#amountInput").hide();
            } else if (this.payBackType == "1") {
                var amt = utils.string.formatMoneyNumber(this.model.get("creditCardInfo").cnyRemainMinDutAmt);
                this.$("#payBackAmt").text(amt);
                this.$("#systemDutAmt").show();
                this.$("#amountInput").hide();
            } else if (this.payBackType == "2") {
                var amt = utils.string.formatMoneyNumber(this.$("#amountInput").customInput('value'));
                this.$("#amountInput").show();
                this.$("#systemDutAmt").hide();
            }
            this.redPacket.reload({amt: amt});
		},

		//输入密码组件
		customPsdComponet: function () {
			utils.native.talkingDataTrackEvent("2.0信用卡还款验密");
			CustomPwdInput.customPwdInput(function (pwd) {
				var transToken = App.storage.get("creditPayment_Input_Data").transToken;
				var params = {
					"password": utils.crypto.RSAKey.encrypt(pwd, config.base.rsa_public_key),
					"sm2Pwd": utils.sm2.SM2Key.encrypt(pwd, config.base.sm2_public_key),
					"transToken": transToken
				};
				App.storage.remove("creditPayment_Input_Data");
				CreditPaymentModel.creditCardRepayConfirm(params, function (res) {
					App.storage.set("totalRedPacketAmt",res.object.totalRedPacketAmt);
					App.navigate("me/creditCard/payBackResult", true);
				});
			});
		},

		//确定还款
		_determinePay: function () {
			var self = this;
			if (!this.validate()) {
				return;
			}
			if(this.submitFlag){
                return;
            }
            this.submitFlag = true;
			var repayAmt = 0;
			if (this.payBackType == 0 || this.payBackType == 1) {
				repayAmt = this.$("#payBackAmt").text().replace(/,/g, "");
			} else {
				repayAmt = this.$("#amountInput").customInput("value").replace(/,/g, "");
			}
			// 封装信用卡还款数据
			var repayData = {
				"fromAccountNumber" : this.model.get("creditCardInfo").fromAccountNumber,
				"toAccountNumber" : this.$("#cardNum").attr("data-acct"),
				"transferAmount" : repayAmt,
				"userRemark" : this.$("#payBackRemark").val(),
				"redPacketIds" : this.redPacket.getType()
			};
			CreditPaymentModel.creditCardRepayInput({
				params:repayData,
				callback: function(res){
				repayData.transToken = res.object.transToken;
				App.storage.set("creditPayment_Input_Data", repayData);
				App.storage.set("sucTypeAmount", repayAmt);
				self.customPsdComponet();
					self.submitFlag = false;
				},
				errorCallback: function(res){
					self.submitFlag = false;
					utils.dialog.alert(res.message);
				}
			});
		},

		//验证是否要还款
		validate: function () {
			var repayAmt = 0;
			if (this.payBackType == 0 || this.payBackType == 1) {
				repayAmt = this.$("#payBackAmt").text().replace(/,/g, "");
			} else {
				repayAmt = this.$("#amountInput").customInput("value").replace(/,/g, "");
			}
			var creditCardInfo = this.model.get("creditCardInfo");
			var transferLimit = this.model.get("transferLimit");
			var repayType = this.payBackType + 1;
			//还款类型

			// 是否设置转账限额
			var inUseFlag = transferLimit.inUseFlag;
			// 日累计限额减去当日已使用金额
			var dailyRemain = parseFloat(transferLimit.dailyLimit) - parseFloat(transferLimit.dailySum);

			if (repayAmt == 0) {
				// 还款金额不能为0
				if (repayType == 1) {
					utils.dialog.toast("你本期剩余应还款额为0，暂无需还款。");
				} else if (repayType == 2) {
					utils.dialog.toast("本期最低还款额为0，请选择其它还款类型。");
				} else if (repayType == 3) {
					utils.dialog.toast("还款金额不能为0，请重新输入！");
				}
				return false;
			}

			if (inUseFlag == 1) {
				if (repayAmt > dailyRemain) {
					//utils.dialog.alert("还款金额大于交易限额！");
					// 转账金额大于当日可用额度
					utils.dialog.confirm("还款金额大于交易限额！你的信用卡还款每日限额是" + utils.string.formatMoneyNumber(transferLimit.dailyLimit) + "，其中当前可用额度为" + utils.string.formatMoneyNumber(dailyRemain), {
						okButtonText: "修改还款限额",
						cancelButtonText: "更改还款方式"
					}, function (ok) {
						if (ok) {
							App.storage.set("me/accoutAndSecurity/transferLimit/fromPage", "me/creditCard/payBack");
							App.navigate("me/accoutAndSecurity/transferLimit", true);
						}else{
							App.navigate("me/autoReply/index");
						}
					});
					return false;
				}
			} else {
				// 没有开通转账限额，直接提示用户先进行限额设置
				utils.dialog.confirm("你还未设置交易限额", {
					okButtonText: "立即设置",
					cancelButtonText: "取消"
				}, function (ok) {
					if (ok) {
						App.storage.set("me/accoutAndSecurity/transferLimit/fromPage", "me/creditCard/payBack");
						App.navigate("me/accoutAndSecurity/transferLimit", true);
					}
				});
				return false;
			}

			var sumBalance = 0;

			if (this.model.get("creditCardInfo").accBalance) {
				sumBalance += parseFloat(this.model.get("creditCardInfo").accBalance)
			}
			if (this.model.get("creditCardInfo").nfBalance) {
				sumBalance += parseFloat(this.model.get("creditCardInfo").nfBalance);
			}
			if (this.model.get("creditCardInfo").dhBalance) {
				sumBalance += parseFloat(this.model.get("creditCardInfo").dhBalance);
			}

			// 判断还款额是否大于可用余额
			if (repayAmt > sumBalance) {
				// 余额不足
				utils.dialog.toast("你的账户可用余额不足！");
				return false;
			}

			var payBackRemark = this.$("#payBackRemark").val();
			// 备注是否含有特殊字符
			if (!utils.validate.specialCharacter(payBackRemark)) {
				utils.dialog.toast("你输入的备注不符合规范！");
				return false;
			}
			return true;
		}
	});
});
