/**
 * EX-WUWENJUN
 * 重置手机号码第三步
 *
 */

define(function (require, exports, module) {
    var FormComponent = require("component/form");
    var OtpView = require("component/otp/OtpView");
    var Temp = require("text!../../template/meInfo/resetIphoneStep3.html");
    var meInfoModel = require('../../model/meInfo');

    module.exports = FormComponent.extend({

        template: _.template(Temp),

        events: {
            "tap #nextBtn": "goNext",
            "input #phoneInput,#otp_passWord": "changeBtn",
            "customInputKeyup #passInput": "changeBtn"
        },

        onShow: function () {
            this._initPasswordInputKeyBoard();
            var options = {
                isOtpSended: true,
                isNeedSendOtpValidate: false,
                isQryOtpPhoneNo: false,
                isMobilePhoneByUser: true,
                callbackError: _.bind(this.callbackError, this),
                callbackSubmit: _.bind(this.callbackSubmit, this),
                resendBtnHandler: _.bind(this.resendBtnHandler, this),
                cat: config.values.mobileResetOtpCat
            };
            this.otpView = new OtpView();
            this.otpView.initOtp(options);

            this.$("#otp_input_container").html($(this.otpView.$el[0]));
        },

        _initPasswordInputKeyBoard: function () {
            this.$("#passInput").customInput({
                type: "password-number",
                placeholder: "请输入您的交易密码",
                maxLength: 6,
                className: "safeKeyBoard"
            });
        },

        callbackSubmit: function () {
            this._goNext();
        },
        callbackError: function () {
            this.otpView.setCustomValidity("动态密码校验失败！");
        },

        /**
         *点击“立即获取”按钮调用方法
         */
        resendBtnHandler: function () {
            var phoneInput = this.phoneInput.getValue();

            if (phoneInput == '') {
                this.phoneInput.setCustomValidity("请输入手机号码");
                return false;
            } else if (!utils.validate.phone(phoneInput)) {
                this.phoneInput.setCustomValidity("手机号码错误");
                return false;
            }

            if (this.submitFlag === "1") return;
            this.submitFlag = "1";

            meInfoModel.checkUniqeMobile({
                params: {
                    "mobile": phoneInput
                },
                success: _.bind(function () {
                    this.sentOtp(phoneInput);
                    this.submitFlag = "0";
                }, this),
                error: _.bind(function (response) {

                    utils.dialog.alert(response.message);
                    this.submitFlag = "0";
                }, this)
            });

        },

        /**
         *发送otp
         */
        sentOtp: function (mobile) {
            var param = {
                "mobileNo": mobile,
                "cat": config.values.mobileResetOtpCat
            };
            this.otpView.sendSmsOTP('sendByPhoneNo', param, true);
        },

        goNext: function () {
            var self = this;
            if (self.$("#nextBtn").hasClass("btn_disable")) {
                return;
            }
            var formData = this.formData();
            if (this.validate(formData)) {
                meInfoModel.verifyByPhoneNo({
                    params: {
                        mobileNo: formData.phoneInput,
                        code: self.otpView.getValue(),
                        cat: config.values.mobileResetOtpCat
                    },
                    success: function () {
                        self._goNext();
                    },
                    error: function () {
                        self.otpView.setCustomValidity("动态密码校验失败！");
                    }
                });
            }
        },

        _goNext: function () {
            var formData = this.formData();
            this.resetMobSubmit(formData, _.bind(function () {
                $("#personal_phoneNum").text(formData.phoneInput);
                App.storage.get("UserInfo").set("telephoneNum", formData.phoneInput);
            }, this));
        },

        resetMobSubmit: function (formData, callback) {
            var thisView = this;
            var params = {
                "password": formData.password,
                "sm2Pwd": formData.sm2Pwd,
                "newMobile": formData.phoneInput,
                "mobileCode": this.otpView.getValue()
            };

            if (this.submitFlag === "1") return;
            this.submitFlag = "1";

            meInfoModel.resetMobSubmit({
                params: params,
                success: function () {
                    callback();
                    App.navigate("me/meInfo/resetIphoneStep4", true);
                    thisView.submitFlag = "0";
                },
                error: function (response) {
                    utils.dialog.alert(response.message);
                    thisView.submitFlag = "0";
                }
            });
        },

        formData: function () {
            var passInput = this.$("#passInput").customInput("value");
            var data = {};
            data.password = utils.crypto.RSAKey.encrypt(passInput, config.base.rsa_public_key);
            data.sm2Pwd = utils.sm2.SM2Key.encrypt(passInput, config.base.sm2_public_key);
            data.phoneInput = this.phoneInput.getValue();
            data.ckcodeInput = this.$("#otp_passWord").val();
            return data;
        },

        validate: function (formData) {
            if (formData.password == '') {
                this.phoneInput.setCustomValidity("请输入交易密码");
                return false;
            }

            if (formData.phoneInput == '') {
                this.phoneInput.setCustomValidity("请输入手机号码");
                return false;
            } else if (!utils.validate.phone(formData.phoneInput)) {
                this.phoneInput.setCustomValidity("你输入的手机号不符合规范");
                return false;
            }

            if (!this.otpView.isSendedOTP() && $("#btn_resend").text() != "重新获取") {
                this.otpView.setCustomValidity("请点击获取动态密码");
                return false;
            } else if (!this.otpView.isSendedOTP() && $("#otp_passWord").attr("disabled") == "disabled") {
                this.otpView.setCustomValidity("请点击获取动态密码");
                return false;
            } else if (!formData.ckcodeInput) {
                this.otpView.setCustomValidity("请输入动态密码");
                return false;
            }

            return true;
        },

        changeBtn: function () {
            var passInput = this.$("#passInput").customInput("value");
            var phoneInput = this.$("#phoneInput").val();
            var otp_passWord = this.$("#otp_passWord").val();
            if (passInput != "" && phoneInput != "" && otp_passWord != "") {
                this.$("#nextBtn").removeClass("btn_disable").addClass("btn_orange");
            } else {
                this.$("#nextBtn").removeClass("btn_orange").addClass("btn_disable");
            }
        }

    });
});
