/**
 * @ex_huangzit
 * 无卡取现
 */
define(function (require, exports, module) {
    var transferInTpl = require("text!../../template/noCardCash/noCardCashIndex.html");
    var transModel = require("../../model/transferModel");
    var safeKeyBoardHelper = require("component/customInput.helper");
    var CustomPwdInput = require("component/password/customPwdInput");

    var transferInView = module.exports = ItemView.extend({
        template: _.template(transferInTpl),

        events: {
            "customInputFocusIn #noCardCashAmt": "_onCustomInputFocusInAmount",
            "customInputFocusOut #noCardCashAmt": "_onCustomInputFocusOutAmount",
            "tap #noCardCashBtn": "_queryEntrustList",
            "customInputKeyup #noCardCashAmt": "_noCardCashAmtKp",
            "jsClearIconHandler #noCardCashAmt": "_noCardCashAmtKp"
        },
        onRender: function () {
            var self = this;
            App.header.reset({
                title: "无卡取现",
                leftButtonContent: "@back",
                leftButtonHandler: function () {
                    App.navigate("me/logined/index", true);
                },
                rightButtonContent: "取现记录",
                rightButtonHandler: function () {
                    self._toNoCardCashTransList();
                }
            });

            this._initAmountKeyboard();
            this._showDetial();
        },

        initialize: function () {
            this.monthLimit = "1000";
            this.dayLimit = "500";
            this.singleLimit = "500";
            this.isSubmited = false;
        },

        _showDetial: function () {
            this._qryCashBalance();
            this._bookingNocardCashBalance();
        },

        //初始化交易金额空间
        _initAmountKeyboard: function () {
            this.$("#noCardCashAmt").customInput({
                type: "decimal",
                placeholder: "金额为100的整数倍",
                className: "safeKeyBoard",
                maxLength: "10"
            });
        },

        _onCustomInputFocusInAmount: function () {
            safeKeyBoardHelper.focusIn({ id: "noCardCashAmt"});
        },

        _onCustomInputFocusOutAmount: function () {
            safeKeyBoardHelper.focusOut({ id: "noCardCashAmt"});
        },

        //监听金额输入框
        _noCardCashAmtKp: function () {
            this._validateAmtAndPayWay();
        },

        //判断输入金额及支付方式是否已选择输入
        _validateAmtAndPayWay: function () {
            if (this.$("#noCardCashAmt").customInput("value")) {
                //this.$("#noCardCashBtn").attr("disabled", false);
                if (this.$("#noCardCashBtn").hasClass("btn_disable")) this.$("#noCardCashBtn").addClass("btn_orange").removeClass("btn_disable");
            } else {
                //this.$("#noCardCashBtn").attr("disabled", true);
                this.$("#noCardCashBtn").addClass("btn_disable");
                if (this.$("#noCardCashBtn").hasClass("btn_orange")) this.$("#noCardCashBtn").addClass("btn_disable").removeClass("btn_orange");
            }
        },

        //查询余额、可取现金额
        _qryCashBalance: function () {
            var self = this;
            transModel.queryAccountInfo({
                url: "currentToFixedTransferBalance",
                data: {},
                callback: function (resp) {
                    var accountBalance = self.accountBalance = resp.object.balance;
                    self.$("#accountBalance").html(utils.string.formatMoneyNumber(accountBalance));
                    self.$("#accountBalance").addClass("m_l10");
                },
                errorCallback: function (resp) {
                    utils.dialog.alert(resp.message);
                }
            });
        },

        //无卡取现预约限额查询
        _bookingNocardCashBalance: function () {
            //无卡取现要添加一个token

            var self = this;
            transModel.bookingNocardCashBalance({
                url: "bookingNocardCashBalance",
                data: {},
                callback: function (resp) {
                    var monthlyAmount = self.monthlyAmount = ((resp.object.monthLimit - resp.object.monthlyAmount - 1000)).toFixed(2);
                    var dayLimit = self.dayLimit = resp.object.dayLimit;
                    var dayAmount = self.dayAmount = (dayLimit - resp.object.dailyAmount).toFixed(2);

                    var monthLimit = self.monthLimit = (resp.object.monthLimit - 1000).toFixed(2);
                    var singleLimit = self.singleLimit = resp.object.singleLimit;

                    self.$("#monthlyAmount").html(utils.string.formatMoneyNumber(monthlyAmount));
                    self.$("#monthlyAmount").addClass("m_l10");
                    self.$("#dayLimit").html(utils.string.formatMoneyNumber(dayLimit));
                    self.$("#monthsLimit").html(utils.string.formatMoneyNumber(monthLimit));

                },
                errorCallback: function (resp) {
                    utils.dialog.alert(resp.message);
                }
            });
        },

        //校验数据
        _validate: function () {

            /**取现金额规则：
             1.每户每月取现的额度为1000，
             2.单日取现的额度为500，
             3.取现的金额为100的整数倍，
             4.取现的金额不能大于可取现的额度
             */
            var amount = (this.$("#noCardCashAmt").customInput("value").replace(/,/g, "")) * 1;
            var lowLimit = 100;
            //为空判断
            if (amount === "" || amount === 0) {
                safeKeyBoardHelper.setCustomValidity({ id: "noCardCashAmt", message: "请输入取现金额" });
                return false;
            }

            //不能大于活期余额
            if (amount % lowLimit != 0) {
                safeKeyBoardHelper.setCustomValidity({ id: "noCardCashAmt", message: "金额为100的整数倍" });
                return false;
            }

            //取现的额度超出了本日可用额度
            if (amount > this.dayAmount.replace(/,/g, '')) {
                safeKeyBoardHelper.setCustomValidity({ id: "noCardCashAmt", message: "你取现的额度超出了单日可用额度" });
                return false;
            }

            //取现的额度超出了本月可用额度
            if (amount > this.monthlyAmount.replace(/,/g, '')) {
                safeKeyBoardHelper.setCustomValidity({ id: "noCardCashAmt", message: "你取现的额度超出了单月可用额度" });
                return false;
            }

            //取款金額大於余额
            if (amount > this.accountBalance.replace(/,/g, '')) {
                safeKeyBoardHelper.setCustomValidity({ id: "noCardCashAmt", message: "取现的金额大于活期额度" });
                return false;
            }


            //取现的额度超出了本月取现额度
            if (amount > this.monthLimit.replace(/,/g, '')) {
                safeKeyBoardHelper.setCustomValidity({ id: "noCardCashAmt", message: "你取现的额度超出了本月取现额度" });
                return false;
            }

            //取现的额度超出了单日取现额度
            if (amount > this.singleLimit.replace(/,/g, '')) {
                safeKeyBoardHelper.setCustomValidity({ id: "noCardCashAmt", message: "你取现的额度超出了单笔额度" });
                return false;
            }

            //取现的额度超出了单日取现额度
            if (amount > this.dayLimit.replace(/,/g, '')) {
                safeKeyBoardHelper.setCustomValidity({ id: "noCardCashAmt", message: "你取现的额度超出了单日取现额度" });
                return false;
            }
            //校验银行信息
            return true;
        },

        //转入提交
        _noCardCashSmt: function () {
            var self = this;
            if (this.isSubmited) {
                return false;
            }
            if (this._validate()) {
                var data = {
                    payAmt: this.$("#noCardCashAmt").customInput("value").replace(/,/g, "") * 1
                };
                this.isSubmited = true;
                utils.native.talkingDataTrackEvent("2.0-我-无卡取现验密");
                CustomPwdInput.customPwdInput(function (pwd) {
                    data.password = utils.crypto.RSAKey.encrypt(pwd, config.base.rsa_public_key);
                    data.sm2Pwd = utils.sm2.SM2Key.encrypt(pwd, config.base.sm2_public_key);
                    transModel.bookingNocardCash({
                        url: "bookingNocardCash",
                        data: data,
                        callback: function (resp) {
                            self.isSubmited = false;
                            var mobile = resp.object.mobile;
                            var cashDate = resp.object.endTime;
                            var options = {
                                mobile: mobile,
                                cashDate: cashDate
                            };
                            App.storage.set("noCardCashOptions", options);
                            App.navigate("me/transferIn/toNoCardCashSucc", true);
                        },
                        errorCallback: function (resp) {
                            self.isSubmited = false;
                            utils.dialog.alert(resp.message);
                        }
                    });
                });

            }
        },


        //提交可撤销记录
        _queryEntrustList: function () {
            var self = this;
            if ($("#noCardCashBtn").hasClass('btn_disable')) {
                return;
            }
            var currentDate = new Date(App.storage.get("Login_SysTime") || new Date());
            var endDate = utils.date.diffDateAdd(currentDate, 0, 'd').format("yyyyMMdd");
            var startDate = utils.date.diffDateAdd(currentDate, -1, 'd').format("yyyyMMdd");
            if (self._validate()) {
                var options = {
                    startDate: startDate,
                    endDate: endDate,
                    pageIndex: 1,
                    pageSize: 20,
                    status: 0
                }
                self.isSubmited = true;
                transModel.qryBookingNocardRecordList({
                    url: "qryBookingNocardRecordList",
                    data: options,
                    callback: function (resp) {
                        self.isSubmited = false;
                        var resultList = resp.object.resultList;
                        //判断返回列表是否为空，空则
                        if (resultList.length == 0) {
                            self._noCardCashSmt();
                        } else {
                            var noCardCashMoney = utils.string.formatMoneyNumber(resultList[0].payAmt);
                            var message = "您已经成功预约了一笔金额为" + noCardCashMoney + "元的无卡取现业务。如果重新预约之前的将被替换，是否继续？"
                            var title = "温馨提示";
                            utils.dialog.confirm(message, {title: title}, _.bind(self._callBackEntrust, self));
                        }
                    },
                    errorCallback: function (resp) {
                        self.isSubmited = false;
                        utils.dialog.alert(resp.message);
                    }
                });
            }
        },

        _callBackEntrust: function (param) {
            if (param) this._noCardCashSmt();
        },

        //跳转到无卡取现交易记录
        _toNoCardCashTransList: function () {
            var currentDate = new Date(App.storage.get("Login_SysTime") || new Date());
            var endDate = utils.date.diffDateAdd(currentDate, 0, 'd').format("yyyy-MM-dd");
            var startDate = utils.date.diffDateAdd(currentDate, -7, 'd').format("yyyy-MM-dd");
            App.storage.set("noCardCashDateOption", {
                startDate: startDate,
                endDate: endDate
            });
            App.navigate('me/tradeRecords/index/' + config.values.nocardcash_code + "?" + Date.parse(new Date()), {
                trigger: true,
                replace: true
            });
        }
    });
});