/**
 * @author zhoushiwen
 * @ date ${date}
 * @company 中国平安
 * @type   修改密码验证页面
 */
define(function (require, exports, module) {
	var FormComponent = require("component/form");
	var OtpView = require("component/otp/OtpView");
	var SafeKeyBoardHelper = require("component/customInput.helper");
	var temp = require("text!../../template/passmanagement/passmanagement.html");
	var SecuritySetModel = require("../../model/securitySet");

	module.exports = FormComponent.extend({
		template: _.template(temp),

		events: {
			"tap #submit": "submit"
		},

		initialize: function () {
			this.param = {};
		},

		onRender: function () {
			this._showSafeKeyBoard();
			this._initOtp();
		},

		_showSafeKeyBoard : function () {
			this.$("#old-pwd-input").customInput({
				type: "password-number",
				placeholder: "原交易密码",
				maxLength: 6,
				className: "safeKeyBoard"
			});

			this.$("#new-pwd-input").customInput({
				type: "password-number",
				placeholder: "新交易密码",
				maxLength: 6,
				className: "safeKeyBoard"
			});

			this.$("#confirm-pwd-input").customInput({
				type: "password-number",
				placeholder: "确认新交易密码",
				maxLength: 6,
				className: "safeKeyBoard"
			});
		},

		_initOtp: function () {
			var options = {
				isOtpSended: false,
				isNeedSendOtpValidate: false,
				isQryOtpPhoneNo: true,
				otpEnable: null,
				isMobilePhoneByUser: false,
				callbackError: _.bind(this._callbackError, this),
				callbackSubmit: _.bind(this._callbackSubmit, this),
				cat: config.values.otp_cat_modify_password
			};
			this.otpView = new OtpView();
			this.otpView.initOtp(options);
			this.$("#otp-container").empty();
			this.$("#otp-container").append($(this.otpView.$el[0]));
		},
		_callbackSubmit: function () {
			this._formSubmit();
		},

		_callbackError: function () {
			this.otpView.setCustomValidity("动态密码错误！");
		},

		_formSubmit: function () {
			if (this.submitFlag)
				return;
			this.submitFlag = true;

			var self = this;
			SecuritySetModel.modifyTransferPwd({
				"params": this._formData(),
				"errorCallback": function (res) {
					utils.dialog.alert(res.message);
					self.submitFlag = false;
				},
				"callback": function (res) {
					App.navigate("me/passmanagement/tradeSuccess", true);
					self.submitFlag = false;
				}
			});
		},

		topass: function () {
			SecuritySetModel.modifyTransferPwd(this._formData(), function (res) {
				App.navigate("me/passmanagement/tradeSuccess", true);
			});
		},

		submit: function () {
			if (this._validateForm()) {
				this.otpView.submit();
			}
		},

		_formData: function () {
			var oldPwd = this.$("#old-pwd-input").customInput("value");
			var newPwd = this.$("#new-pwd-input").customInput("value");
			var otp = this.otpView.getValue();

			return {
				oldPwd: utils.crypto.RSAKey.encrypt(oldPwd, config.base.rsa_public_key),
				oldSm2Pwd: utils.sm2.SM2Key.encrypt(oldPwd, config.base.sm2_public_key),
				newPwd: utils.crypto.RSAKey.encrypt(newPwd, config.base.rsa_public_key),
				newSm2Pwd: utils.sm2.SM2Key.encrypt(newPwd, config.base.sm2_public_key),
				otp: otp
			};
		},

		_validateForm: function () {
			var oldPwd = this.$("#old-pwd-input").customInput("value");
			if (oldPwd === "") {
				SafeKeyBoardHelper.setCustomValidity({
					id: "old-pwd-input",
					message: "请输入原交易密码"
				});
				return false;
			}

			var newPwd = this.$("#new-pwd-input").customInput("value");
			if (newPwd === "") {
				SafeKeyBoardHelper.setCustomValidity({
					id: "new-pwd-input",
					message: "请输入新交易密码"
				});
				return false;
			}

			var confirmPwd = this.$("#confirm-pwd-input").customInput("value");
			if (confirmPwd === "") {
				SafeKeyBoardHelper.setCustomValidity({
					id: "confirm-pwd-input",
					message: "请再次输入新交易密码"
				});
				return false;
			}

			if (oldPwd === newPwd) {
				SafeKeyBoardHelper.setCustomValidity({
					id: "new-pwd-input",
					message: "新旧密码不能相同"
				});
				return false;
			}

			if (newPwd !== confirmPwd) {
				SafeKeyBoardHelper.setCustomValidity({
					id: "confirm-pwd-input",
					message: "新密码不一致"
				});
				return false;
			}

			if (!this.otpView.getValue()) {
				this.otpView.setCustomValidity("请输入动态密码！");
				return false;
			}

			return true;
		}
	});
});