/**
 *注册模块帮助类
 */
define(function(require, exports, module){
    var registerLang = require("./registerLang");

    var registerTools = module.exports = {
        /**
         * 用户名校验方法
         * @param {Object} name 用户名
         */
        isValidateUserName : function(name){
            var tempFlag_f = false;
            if( name.length==0 )
                return registerLang("registerUserNameEmpty");
            // 4-30位
            if(name.length<4) return registerLang("userNameNoLessFour");
            else if(name.length>30) return registerLang("userNameMaxThirty");

            // 添加11位数字控制
            var isNumberAddFlag = true;
            var numberCount = 0;
            var strLength = name.length;

            for (var i=0; i<strLength; i++)
            {
                var curChar_f = name.charAt(i);

                // 首字节不能是下滑线
                if( i==0 && (curChar_f=='_' || curChar_f=='-') ){
                    return registerLang("userNameFormatError3");
                }

                if( (curChar_f>='0' && curChar_f<='9') ||
                    (curChar_f>='a' && curChar_f<='z') ||
                   (curChar_f>='A' && curChar_f<='Z')  ||
                    curChar_f=='_' ||
                    curChar_f=='-' )
                {
                    if( isNumberAddFlag==true )
                    {
                        if( curChar_f>='0' && curChar_f<='9' )
                        {
                            numberCount ++;
                            if( numberCount>11 && i==strLength-1 )
                            {
                                return registerLang("userNameFormatError1");
                            }
                        }
                        else
                        {
                            isNumberAddFlag = false;
                            numberCount = 0;
                        }
                    }
                    else
                    {
                        numberCount = 0;
                    }

                    tempFlag_f = true;
                    continue;
                }

                return registerLang("userNameFormatError2");
            }
            return tempFlag_f;
        },

       /**
        * 登录密码的校验规则
        * @param {Object} options
        *       value       需要校验的密码
         *      uid         用户名
         *      mobile      手机号码
         *      birthday    出生年月日 yyyyMMdd
         *      idcard      身份证号码
        */
        isValidatePassword : function(options){
            var value = options.value||"";
            var uid = options.uid||"";
            var mobile = options.mobile||"";
            var birthday = options.birthday||"";
            var idcard = options.idcard||"";

            var regex1 = /^[a-zA-Z0-9]{8,16}$/;
            var regex2 = /^[a-zA-Z]{8,16}$/;
            var regex5 = /^[0-9]{8,16}$/;

            //var flag = false;
            //格式错误（小于8位）
            if (value.length<8 ) {
                return registerLang("logPwdNoLessSix");
            }
            //格式错误（大于16位）
            if (value.length>16 ) {
                return registerLang("logPwdMaxSixteen");
            }
            //密码不能含有特殊符号和空格
            if (!regex1.test(value)) {
                return registerLang("logPwdNoContainSignAndSpace");
            }
            //格式错误（登录密码为纯字母）
            if (regex2.test(value)) {
                return registerLang("logPwdPureLetter");
            }
            
            //ex_huangzit(20150625) 格式错误（登录密码不能为纯数字）
            if (regex5.test(value)) {
                return registerLang("logPwdPureNumber");
            }
            //密码不能和用户名相同
            if ( uid && uid.length!=0 && (value.toLocaleLowerCase()==uid.toLocaleLowerCase()) ) {
                return "请不要将自己的账号作为密码，请你重新设置。";
            }

            // if ( regex5.test(value) ) {
                // flag = true;
            // }
            //格式错误（密码中同一数字不能出现连续3次重复）
            if (/(\d)\1\1/.test(value) ) {
                return registerLang("logPwdNoRepeatThreeAboutSameNumber");
            }
            //格式错误（密码中不能出现连续4位数字升、降序排列）
            if (this.digitCheck(value)) {
                return registerLang("logPwdNoRepeatLifting");
            }
            //格式错误（密码中不能出现2个数字连续3次重复）
            if (/(\d\d)\1\1/.test(value)) {
                return registerLang("logPwdNoRepeatThreeTime");
            }
            //格式错误（密码中不能出现3个数字连续2次重复）
            if (/(\d\d\d)\1/.test(value)) {
                return registerLang("logPwdNoRepeatTwoTime");
            }
            //格式错误（密码中不能包含出生日期）
            if (birthday && birthday.length == 8) {
                var format1 = birthday.substring(0, 4)+ birthday.substring(4, 6) + birthday.substring(6, 8);
                 var format2 = birthday.substring(0, 4)+ birthday.substring(6, 8) + birthday.substring(4, 6);
                 var format3 = birthday.substring(4, 6) + birthday.substring(6, 8)+ birthday.substring(0, 4);
                 var format4 = birthday.substring(6, 8) + birthday.substring(4, 6) + birthday.substring(0, 4);
                 var format5 = birthday.substring(4, 6) + birthday.substring(0, 4) + birthday.substring(6, 8);
                 var format6 = birthday.substring(6, 8) + birthday.substring(0, 4) + birthday.substring(4, 6);

                 var format7 = birthday.substring(2, 4)+ birthday.substring(4, 6) + birthday.substring(6, 8);
                 var format8 = birthday.substring(2, 4)+ birthday.substring(6, 8) + birthday.substring(4, 6);
                 var format9 = birthday.substring(4, 6) + birthday.substring(6, 8)+ birthday.substring(2, 4);
                 var format10 = birthday.substring(6, 8) + birthday.substring(4, 6) + birthday.substring(2, 4);
                 var format11 = birthday.substring(4, 6) + birthday.substring(2, 4) + birthday.substring(6, 8);
                 var format12 = birthday.substring(6, 8) + birthday.substring(2, 4) + birthday.substring(4, 6);

                if (value.indexOf(format1)!=-1 || value.indexOf(format2)!=-1 ||
                    value.indexOf(format3)!=-1 ||  value.indexOf(format4)!=-1 ||
                    value.indexOf(format5)!=-1 ||  value.indexOf(format6)!=-1 ||
                    value.indexOf(format7)!=-1 ||  value.indexOf(format8)!=-1 ||
                    value.indexOf(format9)!=-1 ||  value.indexOf(format10)!=-1 ||
                    value.indexOf(format11)!=-1 ||  value.indexOf(format12)!=-1 ) {
                    return registerLang("logPwdNoContainBirthday");
                }
            }

            //格式错误（密码中不能包含电话号码前、后6位）
            if (mobile && mobile.length > 7) {
                var pre = mobile.substring(0,6);
                var suf = mobile.substring(mobile.length-6,mobile.length);
                if ( value.indexOf(pre)!=-1 ||
                     value.indexOf(suf)!=-1) {
                    return registerLang("logPwdFormatErrorAboutPhone");
                }
            }
            return true;
        },

        /**
         * 检查 密码出现连续4位及以上数字升、降序排列
         * @param {Object} value E账户密码
         */
        digitCheck : function(value) {
            var flag = false;
            var c1, c2, c3, c4;

            for (var i=0;(i+4)<=value.length; i++) {
                c1 = parseInt(value.charAt(i));
                c2 = parseInt(value.charAt(i+1));
                c3 = parseInt(value.charAt(i+2));
                c4 = parseInt(value.charAt(i+3));
                if ( (c1==c2+1&&c2==c3+1&&c3==c4+1)||
                     (c1==c2-1&&c2==c3-1&&c3==c4-1) ) {
                        flag = true;
                        break;
                    }
            }

            return flag;
        },

        /*
         * 验证身份证号码合理性
         *
         * 入参：
         *    num: 身份证号码
         *
         * 返回：无
         */
        isIdCardNo : function(num) {
            var len = num.length, re;
            if (len == 18){
                re = new RegExp(/^(\d{6})()?(\d{4})(\d{2})(\d{2})(\d{3})([\dX])$/);
            }
            else {
                return false;
            }
            var a = num.match(re);
            if (a != null)
            {
                if (len==18)
                {
                    var D = new Date(a[3]+"/"+a[4]+"/"+a[5]);
                    var B = D.getFullYear()==a[3]&&(D.getMonth()+1)==a[4]&&D.getDate()==a[5];
                }
                if (!B) {
                    return false;
                }
            }else{
                return false;
            }

            return true;
        },

        /**
         *省份列表
         */
        getProvinceInfo:[
             {"key":"11","name":"北京","cityPy":"BJ"},
             {"key":"12","name":"天津","cityPy":"TJ"},
             {"key":"13","name":"河北","cityPy":"HB"},
             {"key":"14","name":"山西","cityPy":"SX"},
             {"key":"15","name":"内蒙","cityPy":"NMG"},
             {"key":"21","name":"辽宁","cityPy":"LN"},
             {"key":"22","name":"吉林","cityPy":"JL"},
             {"key":"23","name":"黑龙江","cityPy":"HLJ"},
             {"key":"31","name":"上海","cityPy":"SH"},
             {"key":"32","name":"江苏","cityPy":"JS"},
             {"key":"33","name":"浙江","cityPy":"ZJ"},
             {"key":"34","name":"安徽","cityPy":"AH"},
             {"key":"35","name":"福建","cityPy":"FJ"},
             {"key":"36","name":"江西","cityPy":"JX"},
             {"key":"37","name":"山东","cityPy":"SD"},
             {"key":"41","name":"河南","cityPy":"HN"},
             {"key":"42","name":"湖北","cityPy":"HB"},
             {"key":"43","name":"湖南","cityPy":"HN"},
             {"key":"44","name":"广东","cityPy":"GD"},
             {"key":"45","name":"广西","cityPy":"GX"},
             {"key":"46","name":"海南","cityPy":"HN"},
             {"key":"51","name":"四川","cityPy":"SC"},
             {"key":"52","name":"贵州","cityPy":"GZ"},
             {"key":"53","name":"云南","cityPy":"YN"},
             {"key":"54","name":"西藏","cityPy":"XZ"},
             {"key":"55","name":"重庆","cityPy":"CQ"},
             {"key":"61","name":"陕西","cityPy":"SX"},
             {"key":"62","name":"甘肃","cityPy":"GS"},
             {"key":"63","name":"青海","cityPy":"QH"},
             {"key":"64","name":"宁夏","cityPy":"NX"},
             {"key":"65","name":"新疆","cityPy":"XJ"}
      ],

      /**
       *对城市列表分组并排序
       */
      assCityData : function(data) {
            //省份根据首字母归类
            var myFliterList = [];
            var proList = data;
            for(var i = 0; i < proList.length; i++) {
                var newProList = [];
                var tempObj = {};

                var frist = proList[i].cityPy.substring(0,1);
                if(i == "0") {
                    newProList.push(proList[i]);
                    tempObj.Ab = frist;
                    tempObj.lists = newProList;
                    myFliterList.push(tempObj);
                }else {
                    for (var j=0; j < myFliterList.length; j++) {
                        if(frist == myFliterList[j].Ab) {
                            myFliterList[j].lists.push(proList[i]);
                            break;
                        }else{
                            if(j+1 == myFliterList.length) {
                                newProList.push(proList[i]);
                                tempObj.Ab = frist;
                                tempObj.lists = newProList;
                                myFliterList.push(tempObj);
                                break;
                            }
                        }
                    }
                }

            };
            //根据首字母排序
            myFliterList.sort(function(a,b){
               return a.Ab > b.Ab ? 1 : -1
            });
            //console.log(myFliterList);
            return myFliterList;
        },

       /**
         * 登录密码强度设置，提示密码强度
         * 密码强度规则：强：大于等于2分，中：1分，弱：0分
         * 加分规则：1.长度超过10位，+1分，2.包含数字和英文字母（全大写或全小写），+1分，3.包含数字、大小写英文字母，+2分
         */
        getPassComplex: function(pwd) {
            var tempPsw = pwd;
            // 判断登录密码强度
            var passComplex = 0;
            if(tempPsw.length>10){
                passComplex = passComplex+1;
            }

            //数字和小写英文字母
            if(/^(?!(\d+|[a-z]+)$)[0-9a-z]+$/.test(tempPsw)){
                passComplex = passComplex+1;
            }

            //数字和大写英文字母
            if(/^(?!(\d+|[A-Z]+)$)[0-9A-Z]+$/.test(tempPsw)){
                passComplex = passComplex+1;
            }

            //数字和大小写字母
            if(/\d+/.test(tempPsw)&&/[a-z]+/.test(tempPsw)&&/[A-Z]+/.test(tempPsw)){
                passComplex = passComplex+2;
            }

            //密码包含特殊符号和空格
            if(!/^[a-zA-Z0-9]+$/.test(tempPsw)){
                passComplex = -1;
            }
            return passComplex;
        },

        /**
         *显示报错信息
         * @param {Object} id 报错的文本框
         * @param {Object} errText 报错提示信息
         */
        showError : function(id,errText) {
           $(id).attr("class","error");
           $(id).nextAll().filter("i").attr("class","iconA06").show();
           utils.dialog.toast(errText);
        },

        /**
         *是否safari浏览器
         */
        isInSafari : function() {
            var isSafariFlag = false;
            var browserName=navigator.userAgent.toLowerCase();
            if(browserName.indexOf("mozilla/") == "0" && (browserName.indexOf("iphone") != -1 || browserName.indexOf("ipad") != -1) &&
            browserName.indexOf("mobile/") != -1 && browserName.indexOf("safari/") != -1) {
                isSafariFlag = true;
            }
            return isSafariFlag;
        },

        getSource : function(){
            var out = App.storage.get("outerSourceObject")||{};
            if(out.source || out.outerSource){
                return out;
            }
            var search = location.search.replace("?","");
            var array  = search.split("&");
            var obj    = {};
            _.each(array,function(data,index){
                var params = data.split("=");
                obj[params[0]] = params[1];
            });
            return obj;
        }
    };

});

