/**
 * ex-wuyongsheng001 一账通 开户第一步 视图
 */
define(function (require, exports, module) {
    var FormLayout = require("component/form");
    var OtpView = require("component/otp/OtpView");

    var registerModel = require("../model/registerModel");
    var registerLang = require("../common/registerLang");
    var registerTools = require("../common/registerTools");
    var Tpl = _.template(require("text!../template/openMain.html"));

    module.exports = FormLayout.extend({
        template: Tpl,
        events: {
            //进入第二步
            'tap #nextStepBtn': 'toNextStep',
            //打开ORC扫描
            'tap #ORCScanner': '_openIDCardScanner',
            "tap #agreeBtn": '_setAgree',
            "tap #agreement": 'showAgreement'
        },
        onShow: function () {
            var _this = this;
            var options = {
                isOtpSended: true,
                isNeedSendOtpValidate: false,
                isQryOtpPhoneNo: false, //不调用接口查询手机号码
                otpEnable: null,

                isMobilePhoneByUser: true, //手机号码是用户输入的
                resendBtnHandler: _.debounce(_.bind(_this.resendBtnHandler, _this), 300),  //点击“立即获取”按钮调用方法
                isOutLogin: true
            };
            this.otpView = new OtpView();
            this.otpView.initOtp(options);
            this.$('#otpWrap').empty().append(this.otpView.$el);
            this.processOtpInput();

            //轮询表单必填字段
            this._fullFillTimer = setInterval(function () {
                _this._setFullFill();
            }, 300);
        },
        processOtpInput: function () {
            var input = this.$('#otp_passWord'), value = input.val(),
                rule_maxlength = input.attr('maxlength'),
                rule_format = /[^0-9]/g;
            if (input.length < 1) return;

            input.on('input keypress keyup', _.debounce(function (e) {
                value = input.val();
                if (rule_maxlength && (value.length > rule_maxlength)) {
                    value = value.substr(0, rule_maxlength);
                }
                if (rule_format.test(value)) {
                    value = value.replace(rule_format, '');
                }

                input.val(value);
            }, 100));
        },

        onClose: function () {
            var _this = this;
            _this.$('#otp_passWord').off('input keypress keyup');

            clearInterval(_this._fullFillTimer);
        },

        resendBtnHandler: function () {
            var _this = this;
            var formData = {
                trueName: this.$("#trueName").val().trim(),
                IDNumber: this.$("#IDNumber").val().replace(/\s/g, "").toUpperCase(),
                mobile: this.$("#mobile").val().replace(/\s/g, "")
            };

            if (_this._validMobile(formData)) {
                if (_this._submitFlag != 0) return;
                _this.otpView.sendSmsOTP('vToken', {
                    mobileNo: formData.mobile,
                    cat: config.values.register,
                    successFunction: _.bind(_this.successFunction, _this),
                    errorFunction: _.bind(_this.errorFunction, _this)
                }, _this);
            }
        },

        successFunction: function () {
            this.$('#Columns').addClass('m_t30');
            this.$('#otp_passWord').prop('disabled', false);
        },

        errorFunction: function () {
            if (this.$('#otp_label').text().indexOf('动态密码') < 0) {
                this.$('#Columns').removeClass('m_t30');
            }
        },

        _validMobile: function (formData) {
            //真实姓名
            if (!formData.trueName) {
                this.trueName.setCustomValidity(registerLang("registerRealNameEmpty"));
                return false;
            }
            //1.中英文不能混输
            //2.中文（2~25），英文（4~50）,英文大于等于4位,最多输入50位。
            //3.不可以输入特殊字符,‘.()-/
            //4.不能输入全角英文
            //5.中文中间不允许有空格，英文中间可以有空格
            //6.在系统的后台，把姓名的头部和尾部出现的空格去除。
            //身份证校验
            if (!(/^([\u4e00-\u9fa5]{1,12}(?:\u2022|\u00B7)?[\u4e00-\u9fa5]{1,12}$|[A-Za-z\s]{4,50})$/.test(formData.trueName))) {
                this.trueName.setCustomValidity(registerLang("registerRealNameError"));
                return false;
            }

            //校验身份证号
            if (!formData.IDNumber) {
                this.IDNumber.setCustomValidity(registerLang("registerTypeNoEmpty"));
                return false;
            }
            var cardNumberValid = registerTools.isIdCardNo(formData.IDNumber);
            if (!cardNumberValid) {
                this.IDNumber.setCustomValidity(registerLang("registerTypeNoError"));
                return false;
            }

            //校验手机号码
            if (!formData.mobile) {
                this.mobile.setCustomValidity(registerLang("registerPhoneEmpty"));
                return false;
            }
            if (formData.mobile && !utils.validate.phone(formData.mobile)) {
                this.mobile.setCustomValidity(registerLang("registerPhoneError"));
                return false;
            }

            this.$("#mobile").val(utils.string.formatMobile(formData.mobile));

            return true;
        },

        /**
         * 标识表单状态
         */
        _submitFlag: 0,    // 表单提交状态
        _agree: true,      // 是否同意
        _fullFill: false,  // 是否必填项完成
        _fullFillTimer: 0, // 轮询handler
        _setFullFill: function () {
            this._fullFill = false;
            this.$('#nextStepBtn').addClass('btn_disable');
            var agree = this._agree,
                _submitFlag = this._submitFlag == 0,
                trueName = this.$("#trueName").val().trim(),
                IDNumber = this.$("#IDNumber").val().trim(),
                otp_passWord = this.$('#otp_passWord').val().trim(),
                mobile = this.$("#mobile").val().trim();

            if (agree && trueName && IDNumber && mobile && otp_passWord && _submitFlag) {
                this._fullFill = true;
                this.$('#nextStepBtn').removeClass('btn_disable');
            }
        },
        _setAgree: function (e) {
            this._agree = !this._agree;
            if (this._agree) {
                this.$('#agreeBtn i').addClass('on');
            } else {
                this.$('#agreeBtn i').removeClass('on');
            }
        },
        showAgreement: function (e) {
            e.stopPropagation(); e.preventDefault();
            utils.window.open({
                title: "《平安直通银行服务协议》",
                url: "https://ssl.pingan.com/bank/xieyi/zt-zhuche.html"
            });
        },

        _openIDCardScanner: function (e) {
            var _this = this;
            var ocrSwitch = App.ocrSwitch;
            if (ocrSwitch) {
                utils.native.idCardScan(function (data) {
                    var IDCardInfo = _this.IDCardInfo = JSON.parse(data);

                    _this.$("#trueName").val(IDCardInfo.name);
                    _this.$("#IDNumber").val(IDCardInfo.cardno);

                    _this.IDCardInfo.VALID_PERIOD = _this.IDCardInfo.VALID_PERIOD || "";

                    var effectDate = _this.IDCardInfo.VALID_PERIOD.substr(0, 10).replace(/\./g, '') || (_this.IDCardInfo.effectDate || '').replace(/\-/g, '');

                    var expireDate = _this.IDCardInfo.VALID_PERIOD.substr(11, 10).replace(/\./g, '') || (_this.IDCardInfo.expireDate || '').replace(/\-/g, '');

                    var birthday = (_this.IDCardInfo.cardno || _this.IDCardInfo.cardNumber || '').substr(6, 8);

                    //是否符合公安机关对证件有效期的规则
                    if (!!effectDate && !!expireDate && !!birthday) {
                        if (!_this._IDCardValidity(effectDate, expireDate, birthday)) {

                            utils.dialog.confirm('不符合公安机关证件有效期规则，是否重新扫描身份证？', function (flag) {
                                if (flag) {
                                    _this._openIDCardScanner();
                                } else {
                                    _this.$("#trueName").val('');
                                    _this.$("#IDNumber").val('');
                                }
                            });

                        } else {
                            //身份证ocr识别
                            App.idCardScan = "1";
                        }
                    }
                });
            }
        },

        /*
         * 计算身份证的有效期
         *
         * 检查规则：
         * 十六周岁以上公民的居民身份证的有效期为十年、二十年、长期。
         * 十六周岁至二十五周岁的，发给有效期十年的居民身份证；
         * 二十六周岁至四十五周岁的，发给有效期二十年的居民身份证；
         * 四十六周岁以上的，发给长期有效的居民身份证。
         * 未满十六周岁的公民，自愿申请领取居民身份证的，发给有效期五年的居民身份证。
         */
        _IDCardValidity: function (effectDate, expireDate, birthday) {
            if (!effectDate || !expireDate || !birthday) return;
            var age = utils.date.diffDate(birthday, effectDate) / 365;        //领证年龄

            if (expireDate == "长期") {
                if (46 <= age) {
                    return true;
                } else {
                    return false;
                }
            }

            var idValidity = utils.date.diffDate(effectDate, expireDate) / 365;
            var validity;
            switch (true) {
                case age < 16:
                    validity = 5;
                    break;
                case 16 <= age && age <= 25:
                    validity = 10;
                    break;
                case 26 <= age && age <= 45:
                    validity = 20;
                    break;
            }
            if (parseInt(idValidity) == validity || Math.round(idValidity)) {
                return true;
            } else {
                return false;
            }
        },

        _validInput: function (formData) {
            var _this = this;
            var trueName = formData.trueName,
                IDNumber = formData.idNo,
                recCode = formData.umCode,
                mobile = formData.mobileNo,
                otp_passWord = formData.code;

            if (!otp_passWord) {
                this.$('#otp_passWord').setCustomValidity(registerLang("registerVerityOTPEmpty"));
                return false;
            }

            //真实姓名
            if (!trueName) {
                this.trueName.setCustomValidity(registerLang("registerRealNameEmpty"));
                return false;
            }
            //1.中英文不能混输
            //2.中文（2~25），英文（4~50）,英文大于等于4位,最多输入50位。
            //3.不可以输入特殊字符,‘.()-/
            //4.不能输入全角英文
            //5.中文中间不允许有空格，英文中间可以有空格
            //6.在系统的后台，把姓名的头部和尾部出现的空格去除。
            //身份证校验
            if (!(/^([\u4e00-\u9fa5]{1,12}(?:\u2022|\u00B7)?[\u4e00-\u9fa5]{1,12}$|[A-Za-z\s]{4,50})$/.test(trueName))) {
                this.trueName.setCustomValidity(registerLang("registerRealNameError"));
                return false;
            }
            if (!IDNumber) {
                this.IDNumber.setCustomValidity(registerLang("registerTypeNoEmpty"));
                return false;
            }
            var cardNumberValid = registerTools.isIdCardNo(IDNumber);
            if (!cardNumberValid) {
                this.IDNumber.setCustomValidity(registerLang("registerTypeNoError"));
                return false;
            }

            //手机号码
            if (mobile && !utils.validate.phone(mobile)) {
                this.mobile.setCustomValidity(registerLang("registerPhoneError"));
                return false;
            }

            //recCode校验
            if (recCode && !(/^[A-Za-z\d\-\_]{1,50}$/.test(recCode))) {
                this.recCode.setCustomValidity(registerLang("registerUmCodeError"));
                return false;
            }

            return true;
        },

        toNextStep: function () {
            if (!this._agree || !this._fullFill || (this._submitFlag != 0)) return;
            var source = registerTools.getSource();
            var formData = {
                source: source.source,
                outerSource: source.outerSource,
                // 必填真实姓名，身份证号
                trueName: this.$("#trueName").val().trim(),
                idNo: this.$("#IDNumber").val().replace(/\s/g, "").toUpperCase(),
                // 后台otp校验需要参数
                mobileNo: this.$("#mobile").val().replace(/\s/g, "").trim(),
                cat: config.values.register,
                code: this.$('#otp_passWord').val().trim(),

                umCode: this.$("#recCode").val().trim()
            };

            if (this._validInput(formData)) {
                this._submit(formData);
            }
        },

        _submit: function (formData) {
            if (this._submitFlag != 0) return;
            var _this = this;
            _this._submitFlag = 1;
            //是否绑定一账通 resp.isToaLogin = '1'
            //是否手机号码不变 resp.isMobileLogin = '1'
            //是否财富e用户 resp.isRich = '1'
            //是否财富e迁移信息 resp.isMoveMap = '{...}'
            //卡号 resp.cardNo = '430603198201020021'
            registerModel.registerOfLowThreshold({
                formData: formData,
                callback: function (resp) {
                    _this._submitFlag = 0;
                    resp.formData = formData;
                    App.storage.set("openAccount/main/openMain", resp);
                    _this._redirect(resp);
                },
                errorCallback: function (resp) {
                    _this._submitFlag = 0;
                    utils.dialog.toast(resp.message);
                }
            });
        },

        /**
         * 橙子2.0， 开户 流程
         *
         * 根据接口返回信息处理转跳
         * -------------------------------------------------------
         *
         * 是否橙子用户 -> 否 -> 是否财富e用户  -> 是 -> 验证一账通 -> 验证OTP -> 开户成功
         *                                      -> 否 -> 开户成功
         *              -> 是 -> 是否绑定一账通 -> 是 -> 提示已是橙子用户用一账通用户名登录
         *                                      -> 否 -> 是否同一手机号码 -> 是 -> 提示已是橙子用户用手机号登录
         *                                                                -> 否 -> 更新手机号并开户成功
         * -------------------------------------------------------
         */
        _redirect: function (resp) {
            var message;
            // isRich为0不是财富E，isRich为1是财富E
            // isMoveFlag为0可迁移,isMoveFlag为1不可迁移
            if (resp.isRich == "1") {
                if (resp.isMoveMap.isMoveFlag == "1") {
                    return this._getNotMoveMap(resp.isMoveMap);
                } else {
                    App.navigate("openAccount/main/upgrade", true);
                }
                return;
            }

            // 是否绑定一账通 resp.isToaLogin = '1';
            if (resp.isToaLogin == '1') {
                message = '你已是橙子用户请用一账通用户名登录。';
                utils.dialog.alert(message, function () {
                    App.navigate("login/login/toaIndex", true);
                });
                return;
            }

            /**
             * 你已是平安橙子用户，请用手机137****1234直接登录平安橙子。
             */
            if (resp.isMobileLogin == '1') {
                message = '你已是平安橙子用户，请用手机' + utils.string._maskPhoneNumber(resp.formData.mobileNo) + '直接登录平安橙子。';
                utils.dialog.alert(message, function () {
                    App.navigate("login/login/mobileIndex", true);
                });
                return;
            }

            //免登
            registerModel.autoMobileLogin({
                mobile: resp.formData.mobileNo
            }).done(function (response) {
                //设置是否已登录（true：是，false：否);
                var errorCode = response.object.errorCode;
                if (errorCode != 100 && errorCode != 101 && errorCode != 102) {
                    App.storage.set("isUserLoggedIn", true);
                }
                App.storage.set("register/bindCardFlag", resp.bindCardFlag);
                registerModel.validateUserInfo().done(function (res) {
                    var userInfoOption = {
                        mobile: res.object.mobile,
                        email: res.object.email,
                        userFlag: res.object.userFlag,
                        birthDate: res.object.birthDate
                    };

                    App.storage.set("verifyAccount/userInfoOption", userInfoOption);
                    if (res.object.userFlag == "0") {//新用户，跳转至安全信息设置页面
                        App.navigate("openAccount/main/securitySet", true);
                    } else if (res.object.userFlag == "1") {//一账通用户，跳转至一账通绑定页面
                        App.navigate("openAccount/main/bindToa", true);
                    } else {//跳转至注册成功页面
                        App.navigate("openAccount/main/openSuccess", true);
                    }
                }).fail(function () {
                    App.navigate("openAccount/main/openSuccess", true);
                });


            }).fail(function () {
                App.navigate("openAccount/main/openSuccess", true);
            });




        },

        _getNotMoveMap: function (map) {
            var content = [];
            if (map.isFixed == "1") content.push("定期存款");
            if (map.isNotice == "1") content.push("通知存款");
            if (map.isIntelligent == "1") content.push("智能存款");
            if (map.isRTL == "1") content.push("日添利");
            if (map.isGDCP == "1") content.push("滚动型理财产品");
            if (map.isAPIShare == "1") content.push("基金/基金组合");
            if (map.isAPIPro == "1") content.push("智能定投");
            if (map.isYCB == "1") content.push("溢财宝");
            if (map.isGoldPro == "1") content.push("黄金定投");
            utils.dialog.alert("你已经是财富e用户，并且目前持有/签约了:\n\n" + content.join("、\n") + "，\n\n需用电脑登录网银完成赎回或解约，即可成功升级。");
        }

    });
});
