/**
 * ex-wuwenjun001
 * 抢购专区购买
 *
 */
define(function (require, exports, module) {
    var Form = require("component/form");
    var safeKeyBoardHelper = require("component/customInput.helper");
    var InputTpl = require("text!../../template/buy/input.html");
    var CustomPwdInput = require("component/password/customPwdInput");
    var BuyModel = require("../../model/buy");
    var dreamModel = require("../../../dream/model/dream");
    var paymentMothodView = require("mod/common/selPaymentMethod/paymentMothodView");

    var InputView = module.exports = Form.extend({
        template: _.template(InputTpl),
        ui: {
            "checkbox": "#checkbox",
            "booksLink": "#booksLink a"
        },
        events: {
            "tap #submitBtn": "submit",
            "click @ui.checkbox": "toggleCheckbox",
            "click @ui.booksLink": "openBookLink",
            "customInputKeyup  #amountInput": "_onCustomInputFocusSelAmount"
            //"keyup  #amountInput" : "_onCustomInputFocusSelAmount"
        },

        initialize: function (options) {
            this.financeProductData = options.model.get("panicBuySelData");
            this.balance = options.model.get("balance");
            this.accountList = options.model.get("accountList");
            this.submitFlag = false;
        },

        onShow: function () {
            this.$("#amountInput").customInput({
                type: "decimal",
                placeholder: "请输入购买金额",
                className: "",
                maxLength: "10"
            });

            //页面缓存信息
            var formData = App.storage.get("formData");
            if (formData) {
                if (formData.amountInput != 0) {
                    //输入金额
                    this.$("#amountInput").customInput("value", utils.string.numberFormat(formData.amountInput));
                }
                //预期收益
                this.$("#interest").text(formData.interest);
                //购买协议协议
                if (formData.checkbox) {
                    this.toggleCheckbox();
                }
            }
            //添加选择支付方式
            this.paymentMothodView = new paymentMothodView();
            this.$("#addPaymentMethod").empty();
            this.$("#addPaymentMethod").append($(this.paymentMothodView.$el[0]));
        },

        //购买提交
        submit: function (event) {
            event.stopPropagation();
            var self = this;
            var check = this;
            var financeProductData = {};

            var amount = this.$("#amountInput").customInput("value").replace(/,/g, "");

            var account = this.accountList[0];
            if (!this.validate(amount)) {
                return;
            }
            if (this.submitFlag) {
                return;
            }
            utils.native.talkingDataTrackEvent("2.0抢购产品购买验密");
            CustomPwdInput.customPwdInput(function (password) {
                self.submitFlag = true;
                //金额
                financeProductData.sourceAmount = amount;
                //密码
                financeProductData.password = utils.crypto.RSAKey.encrypt(password, config.base.rsa_public_key);
                financeProductData.sm2Pwd = utils.sm2.SM2Key.encrypt(password, config.base.sm2_public_key);
                //产品编号
                financeProductData.productId = self.financeProductData.productId;
                //支付方式
                financeProductData.paymentType = self.paymentMothodView.getPayMethod();
                BuyModel.toBuyForm({
                    "params": financeProductData,
                    "callback": function (response) {
                        App.storage.remove("formData");   //清除页面缓存信息
                        App.navigate("panicBuy/buy/finish", true);
                    },
                    "errorCallback": _.bind(function (response) {
                        self.submitFlag = false;
                        utils.dialog.alert(response.message);
                    }, this)
                });
            });

        },

        _onCustomInputFocusSelAmount: function () {
            var num = this.$("#amountInput").customInput("value");
            num = num.replace(/\D/gi, "");
            var num = this.$("#amountInput").customInput("value", num);
            var num = this.$("#amountInput").customInput("value");
            var interestBaseDays = (this.$("#interestBaseDays").val() || '').replace(/,/g, "");
            var planRate = this.financeProductData.planRate;
            var PlanRateRemark = this.financeProductData.planRateRemark;

            //年化收益率
            var plan = planRate * 0.01;
            var PlanRateRemarks = PlanRateRemark * 0.01;
            var year = 365;
            var interest = utils.string.numberFormat(num * plan / year * interestBaseDays);
            if (amountInput == "") {
                this.$("#interest").text("");
            }
            //预期收益
            this.$("#interest").text(interest + "(元)");
            //智能选择支付方式
            this.paymentMothodView.intelligentSelect(num);
            //缓存数据
            this.formData();
        },

        //验证信息
        validate: function (amount) {
            var balance = this.balance, unitAmount = this.financeProductData.unitAmount, maxAmount = this.financeProductData.maxAmount, minAmount = this.financeProductData.minAmount;
            var totalBalance = this.paymentMothodView.getPayAmt();
            var sf = this;
            if (amount == "") {
                safeKeyBoardHelper.setCustomValidity({
                    id: "amountInput",
                    message: "请输入购买金额",
                    maxLength: 9
                });
                return false;
            }

            if (isNaN(amount)) {
                safeKeyBoardHelper.setCustomValidity({
                    id: "amountInput",
                    message: "购买金额输入不合法"

                });
                return false;
            }

            if (parseFloat(amount) > parseFloat(totalBalance)) {
                safeKeyBoardHelper.setCustomValidity({
                    id: "amountInput",
                    message: "账户余额不足"
                });
                return false;
            }

            if (parseFloat(amount) < parseFloat(minAmount)) {
                safeKeyBoardHelper.setCustomValidity({
                    id: "amountInput",
                    message: "此产品投资起点为" + sf.financeProductData.minAmount + "元,请输入足够的金额"
                });
                return false;
            }

            if (parseFloat(amount) > parseFloat(maxAmount)) {
                safeKeyBoardHelper.setCustomValidity({
                    id: "amountInput",
                    message: "购买金额不能大于" + sf.financeProductData.maxAmount + "元."
                });
                return false;
            }

            if (parseFloat(amount) % parseFloat(unitAmount) != 0) {
                safeKeyBoardHelper.setCustomValidity({
                    id: "amountInput",
                    message: "购买金额必须为" + sf.financeProductData.unitAmount + "整数倍"
                });
                return false;
            }

            if (!this.ui.checkbox.eq(0).hasClass('on')) {
                utils.dialog.toast("请阅读并同意协议！");
                return false;
            }
            return true;

        },

        //协议
        toggleCheckbox: function () {
            var checkbox = this.ui.checkbox.eq(0);
            checkbox.toggleClass("on");
            //缓存数据
            this.formData();
        },
        openBookLink: function (e) {
            e.stopPropagation();
            var shortName = this.financeProductData.shortName;
            utils.window.open({
                title: "产品说明",
                url: "http://bank.pingan.com/licaichanpin/" + shortName + ".shtml"
            });
        },

        //缓存数据
        formData: function () {
            var data = {};
            //购买金额
            data.amountInput = this.$("#amountInput").customInput("value").replace(/,/g, '') * 1;
            //预期收益
            data.interest = this.$("#interest").text();
            //是否同意协议
            data.checkbox = this.$("#checkbox").hasClass("on");
            App.storage.set("formData", data);
        }
    });
});
