define(function(require, exports, module) {
    var indexTpl = require("text!../template/panicBuyRecords/panicBuyRecords.html");
    var panicBuyItemTpl = require("text!../template/panicBuyRecords/panicBuyItem.html");
    var panicBuyRecordsModel = require("../model/panicBuyRecords");
    var FormComponent = require("component/form");
    var PTRScroll = require("component/PTRScroll");
    var IScroll = require("vendor/iscroll");

    module.exports = FormComponent.extend({
        template : _.template(indexTpl),
        ui : {
            "startDateBtn" : "#startDate",
            "endDateBtn" : "#endDate",
            "startDateText" : "#start-date-text",
            "endDateText" : "#end-date-text"
        },
        events : {
            "tap .showMore" : "showMore",
            "datepicker:dateSelect @ui.startDateBtn" : "selectStartDate", //选择开始日期
            "datepicker:dateSelect @ui.endDateBtn" : "selectEndDate" //选择结束日期
        },
        initialize : function() {
            this.pageIndex = 1;
            this.dateFormat = "yyyyMMdd";
            this.param = this.model.attributes;
        },
        onShow : function() {
            var options = this.param;
            options.startDate = utils.date.formatTime(options.startDate).format(this.dateFormat);
            options.endDate = utils.date.formatTime(options.endDate).format(this.dateFormat);
            panicBuyRecordsModel.qryPanicBuy(options).done(_.bind(function(res) {
                this.totalPage = res.object.pageNum;
                var html = _.template(panicBuyItemTpl, res.object.remainQuotaList);
                this.$("#panicBuyList").html(html);
                this._initPTRScroll();
                if( this.totalPage == "0"){
                     $("#drawalRecords").hide();
                     $("#norecordsErrMsg").show();
                }
                //最后一页禁用上拉刷新
                if (this.pageIndex >= this.totalPage) {
                    this.scroller.disablePullUpToLoadMore();
                } else {
                    this.scroller.enablePullUpToLoadMore();
                }
            }, this)).fail(function(error) {
                utils.dialog.alert(error.message);
            });
            
        },
        showMore : function(e) {
            var el = this.$(e.currentTarget);
            var em = el.find("em");
            if (em.hasClass("iconA34")) {
                em.removeClass("iconA34").addClass("iconA33");
                el.next().slideToggle();
            } else if (em.hasClass("iconA33")) {
                em.removeClass("iconA33").addClass("iconA34");
                el.next().slideUp();
            }
            
        },
        // 准备查询（当首次进入页面 或 变更查询参数时）
        qryFirstPageData : function() {
            this.param.startDate = utils.date.formatTime($("#startDate").attr("data-initDate")).format(this.dateFormat);
            this.param.endDate = utils.date.formatTime($("#endDate").attr("data-initDate")).format(this.dateFormat);
            var param = this.param;
            param.pageIndex = 1; 
            this._qrypanicbuy(param);
        },

        //查询活动数据
        _qrypanicbuy : function(options, refresh) {
            options.startDate = utils.date.formatTime($("#startDate").attr("data-initDate")).format(this.dateFormat);
            options.endDate = utils.date.formatTime($("#endDate").attr("data-initDate")).format(this.dateFormat);
            panicBuyRecordsModel.qryPanicBuy(options).done(_.bind(function(res) {
                this.totalPage = res.object.pageNum;
                if (options.pageIndex == 1) {
                    this.$("#panicBuyList").html("");
                }
                if(this.totalPage == "0"){
                     $("#drawalRecords").hide();
                     $("#norecordsErrMsg").show();
                }else{
                    $("#drawalRecords").show();
                    $("#norecordsErrMsg").hide();
                    var html = _.template(panicBuyItemTpl, res.object.remainQuotaList);
                    this.$("#panicBuyList").append(html);
                }
                
                //最后一页禁用上拉刷新
                if (this.pageIndex >= this.totalPage) {
                    this.scroller.disablePullUpToLoadMore();
                } else {
                    this.scroller.enablePullUpToLoadMore();
                }
                if(refresh){
                    refresh();
                }else{
                    this.scroller && this.scroller.refresh();
                }
         
            }, this)).fail(function(error) {
                utils.dialog.alert(error.message);
            });
        },

        //初始化上下拉
        _initPTRScroll : function() {
            var self = this;
            if (this.scroller) {
                this.scroller.destroy();
                delete this.scroller;
            };
            
            var listHeight = $(window).height() - 120;
            var dom = this.$("#drawalRecords").css({
                "height" : listHeight,
                "position" : "relative"
            });

            //初始化iscroller
            this.scroller = new PTRScroll(dom[0], {
                "hScroll" : false,
                "hideScrollbar" : false,
                "vScrollbar" : true,
                "pullDownToRefresh" : true,
                "pullUpToLoadMore" : true,
                "checkDOMChanges" : true
            });

            //下拉刷新
            self.scroller.options.refreshContent = function(refresh) {
                self.pageIndex = 1;
                self._refreshContent(refresh, self.pageIndex);
            };

            //上拉加载
            this.scroller.options.loadMoreContent = function(refresh) {
                self.pageIndex++;
                self._loadMoreContent(refresh, self.pageIndex);
            };
        },

        //下拉请求数据
        _refreshContent : function(refresh, pageIndex) {
            //请求数据
            var options = {
                pageSize : 10,
                pageIndex : pageIndex
            };
            this._qrypanicbuy(options, refresh);
        },

        //上拉请求数据
        _loadMoreContent : function(refresh, pageIndex) {
            //请求数据
            var options = {
                pageSize : 10,
                pageIndex : pageIndex
            };
            this._qrypanicbuy(options, refresh);
        },
       // 选择开始日期
        selectStartDate: function (eve, _this, value) {
            this.dateSelect = "START";
            if (!this._validateDateSlct(value, this.ui.endDateBtn.attr("data-initDate"))) return;
            this.ui.startDateBtn.attr("data-initDate", value);
            this.ui.startDateText.text(value);
            this._validateDateThreeMotn(value, this.ui.endDateBtn.attr("data-initDate"));
        },
        // 选择结束日期
        selectEndDate: function (eve, _this, value) {
            this.dateSelect = "END";
            if (!this._validateDateSlct(this.ui.startDateBtn.attr("data-initDate"), value)) return;
            this.ui.endDateBtn.attr("data-initDate", value);
            this.ui.endDateText.text(value);
            this._validateDateThreeMotn(this.ui.startDateBtn.attr("data-initDate"), value);
        },
        _validateDateThreeMotn: function (startDate, endDate) {
            var self = this;
            var date = new Date(App.storage.get("Login_SysTime") || new Date());
            var defaultStartDate = utils.date.diffDateAdd(date,-3,'m');
            if(utils.date.diffDate(startDate, defaultStartDate) > 0){
                utils.dialog.alert("只能查询近3个月抢购记录",function(){
                    if (self.dateSelect && self.dateSelect == "START") {
                        var formatDate1 = utils.date.formatTime(defaultStartDate).format("yyyy-MM-dd");
                        self.ui.startDateBtn.attr("data-initDate", formatDate1);
                        self.ui.startDateText.text(formatDate1);
                    }
                    self.qryFirstPageData();
                });
            }else{
                self.qryFirstPageData();
            }
        },
        _validateDateSlct: function (startDate, endDate) {
            if (utils.date.compareDate(startDate, endDate) == 1) {
                utils.dialog.toast("开始日期不能大于结束日期");
                return false;
            }
            return true;
        }
    });
}); 