/**
 * 转账模块工具类
 */
define(function(require, exports, module){

    window.transferTools = module.exports = {
        /*
         * 获取转账方式
         */
        getTransferModeDesc : function (transferMode) {
            var transferModeDesc = '';
            switch (transferMode) {
            case '2':
                    transferModeDesc = '实时';
                    break;
            case '1':
                    transferModeDesc = '普通';
                    break;
            case '0':
                    transferModeDesc = '加急';
                    break;
            }
            return transferModeDesc;
        },

        /*
         * 获取转账状态
         */
        getOrderStatus : function (orderStatusId) {
            var orderStatus = '';
            switch (orderStatusId) {
            case '0':
                    orderStatus = '成功';
                    break;
            case '1':
                    orderStatus = '失败';
                    break;
            case '2':
                    orderStatus = '已受理';
                    break;
            case '3':
            case '4':
            case '5':
                    orderStatus = '等待银行答复';
                    break;
            case '6':
                    orderStatus = '退票';
                    break;
            default:
                    orderStatus = orderStatusId;
                    break;
            }
            return orderStatus;
        },

        /*
         * 获取指令类型描述
         */
        getOrderTypeDesc : function (orderType) {
            var orderTypeDesc = '';
            switch (orderType) {
            case '00':
                    orderTypeDesc = '同行转账';
                    break;
            case '01':
                    orderTypeDesc = '活期转定活通';
                    break;
            case '02':
                    orderTypeDesc = '定活通转活期';
                    break;
            case '07':
                    orderTypeDesc = '跨行转账';
                    break;
            case '14':
                    orderTypeDesc = '信用卡还款';
                    break;
            case '5':
                    orderTypeDesc = '跨行实时转账';
                    break;
            case '6':
                    orderTypeDesc = '跨行实时收款';
                    break;
            default:
                    orderTypeDesc = "未知";
                    break;
            }
            return orderTypeDesc;
        },

        /*
         * 获取转账类型
         */
        getTransferType : function (transferType) {
            var transferTypeDesc = '';
            switch (transferType) {
            case '01':
                    transferTypeDesc = '同城跨行';
                    break;
            case '02':
                    transferTypeDesc = '异地跨行';
                    break;
            case '03':
                    transferTypeDesc = '同城同行';
                    break;
            case '04':
                    transferTypeDesc = '异地同行';
                    break;
            default:
                    transferTypeDesc = "未知";
                    break;
            }
            return transferTypeDesc;
        },

        /*
         * 判断是否同行
         */
        isSameBank : function(bankCode){
            if(bankCode == "307" || bankCode == "783"){
                  return true;
            }else{
                return false;
            }
        },

        /*
         * 获取省份列表
         */
        getProvinceInfo:[
             {"key":"11","name":"北京","cityPy":"BJ"},
             {"key":"12","name":"天津","cityPy":"TJ"},
             {"key":"13","name":"河北","cityPy":"HB"},
             {"key":"14","name":"山西","cityPy":"SX"},
             {"key":"15","name":"内蒙","cityPy":"NMG"},
             {"key":"21","name":"辽宁","cityPy":"LN"},
             {"key":"22","name":"吉林","cityPy":"JL"},
             {"key":"23","name":"黑龙江","cityPy":"HLJ"},
             {"key":"31","name":"上海","cityPy":"SH"},
             {"key":"32","name":"江苏","cityPy":"JS"},
             {"key":"33","name":"浙江","cityPy":"ZJ"},
             {"key":"34","name":"安徽","cityPy":"AH"},
             {"key":"35","name":"福建","cityPy":"FJ"},
             {"key":"36","name":"江西","cityPy":"JX"},
             {"key":"37","name":"山东","cityPy":"SD"},
             {"key":"41","name":"河南","cityPy":"HN"},
             {"key":"42","name":"湖北","cityPy":"HB"},
             {"key":"43","name":"湖南","cityPy":"HN"},
             {"key":"44","name":"广东","cityPy":"GD"},
             {"key":"45","name":"广西","cityPy":"GX"},
             {"key":"46","name":"海南","cityPy":"HN"},
             {"key":"51","name":"四川","cityPy":"SC"},
             {"key":"52","name":"贵州","cityPy":"GZ"},
             {"key":"53","name":"云南","cityPy":"YN"},
             {"key":"54","name":"西藏","cityPy":"XZ"},
             {"key":"55","name":"重庆","cityPy":"CQ"},
             {"key":"61","name":"陕西","cityPy":"SX"},
             {"key":"62","name":"甘肃","cityPy":"GS"},
             {"key":"63","name":"青海","cityPy":"QH"},
             {"key":"64","name":"宁夏","cityPy":"NX"},
             {"key":"65","name":"新疆","cityPy":"XJ"}
      ],

      /**
       *对城市列表分组并排序
       */
      assCityData : function(data) {
            //省份根据首字母归类
            var myFliterList = [];
            var proList = data;
            for(var i = 0; i < proList.length; i++) {
                var newProList = [];
                var tempObj = {};

                var frist = proList[i].cityPy.substring(0,1);
                if(i == "0") {
                    newProList.push(proList[i]);
                    tempObj.Ab = frist;
                    tempObj.lists = newProList;
                    myFliterList.push(tempObj);
                }else {
                    for (var j=0; j < myFliterList.length; j++) {
                        if(frist == myFliterList[j].Ab) {
                            myFliterList[j].lists.push(proList[i]);
                            break;
                        }else{
                            if(j+1 == myFliterList.length) {
                                newProList.push(proList[i]);
                                tempObj.Ab = frist;
                                tempObj.lists = newProList;
                                myFliterList.push(tempObj);
                                break;
                            }
                        }
                    }
                }

             };
             //根据首字母排序
             myFliterList.sort(function(a,b){
                return a.Ab > b.Ab ? 1 : -1
             });
             //console.log(myFliterList);
             return myFliterList;
        },

      //是否深圳同城
      isShenZhenCity : function(cityCode){
         return cityCode=="5840";
      }

    };
});