define(function (require, exports, module) {
    var payTransferInHtml = require("text!../template/payTransferIn.html");
    var payAccView = require("../view/payAccDetails");
    var payModel = require("../model/payModel");
    var successTransferInView = require("../view/transferInResault");
    var accountModel = require("mod/common/model/accountModel");
    var safeKeyBoardHelper = require("component/customInput.helper");
    var CustomPwdOtpInput = require("component/password/customPwdOtpInput");
    var CustomPwdInput = require("component/password/customPwdInput");
    var dreamModel = require("../../dream/model/dream");
    var FUND_CODE_NANFANG = config.values.fund_code_nanfang;
    var FUND_CODE_DAHUA = config.values.fund_code_dahua;
    var TERMS = config.urls.get("terms_of_service_pinganying");
    var TERMS_NANFANG = config.urls.get("terms_of_service_pinganying_nanfang");
    var TERMS_DAHUA = config.urls.get("terms_of_service_pinganying_dahua");
    var TERMS_AUTOREPAY = config.urls.get("terms_of_autorepay_service_pinganying");

    var self = null;

    var IndexView = module.exports = ItemView.extend({
        template: _.template(payTransferInHtml),
        ui: {
            "checkbox": "#checkbox",
            "booksLink": "#booksLink a"
        },
        events: {
            "tap @ui.checkbox": "toggleCheckbox",
            "tap #pay_service_web_view": "openService_pay",
            "tap #service_web_view": "openService",
            'tap #submitTransferIn': 'transferIn',
            'customInputFocusIn #transferAmt': '_customInputFocusIn',
            "customInputFocusOut #transferAmt": "_onCustomInputFocusOutAmount",
            "customInputKeyup #transferAmt": "_transferAmtKp",
            "jsClearIconHandler": "_transferAmtKp",
            "tap #profit_autorepayService": "cardToggleCheckbox",
            "tap #service_autorepay_web_view": "openCardService_pay"
        },
        /**
         * 初始化
         */
        initialize: function (options) {
            self = this;
            self.submited = "0";
            var model = options.model;
            self.fundCode = model.get('fundCode') || FUND_CODE_DAHUA;
            self.transAmt = model.get('transferAmt');
            self.selectIcon = model.get('selectIcon');
            self.category = self.fundCode == FUND_CODE_NANFANG ? "nf" : "dh";
            categoryName = self.category == "nf" ? "平安盈（南方）" : "平安盈（大华）";
            model.set({
                'categoryName': categoryName
            });
        },
        onRender: function () {
            this._showPayDetail();
            this._indexRender();
        },
        onShow: function () {
            $("#transferAmt").customInput({
                type: "decimal",
                maxLength: 10,
                placeholder: "建议转入100元以上金额",
                className: "safeKeyBoard"
            });
            //选择付款方式
            if (self.transAmt) {//数据返写
                var inp = safeKeyBoardHelper.getSelector("transferAmt");
                inp.val(utils.string.formatMoneyNumber(self.transAmt));
                self.hasMoney = true;
                self.selectIcon ? $("#checkbox i").addClass("on") : false;
                //self._activeBtn(true);
            }
            var template = App.storage.get("ctrSelectedChannel");
            if (template && template.length > 0) {
                var htl = template.html();
                $("#payAccList").empty().append('<div class="flex1"><span class="f16">支付方式</span></div>').append(htl);
            }
            //this.$("#submitTransferIn").prop('disabled',true);//初始化禁用
        },
        toggleCheckbox: function (event) {
            var checkbox = this.ui.checkbox.children().eq(0);
            checkbox.toggleClass("on");
        },

        cardToggleCheckbox: function (event) {
            this.$(event.currentTarget).find("i").eq(0).toggleClass("on");
        },

        openCardService_pay: function (e) {
            e.stopPropagation();
            var _url = TERMS_AUTOREPAY;
            utils.window.open({
                title: "平安盈支持信用卡自动还款设置功能服务协议",
                url: _url
            });
        },


        _indexRender: function () {
            //获取页面数据源
            var promise = $.when(accountModel.asycAccountInfo(), payModel.profitSignUpQryList());
            promise.done(function (arg1, arg2) {
                var data = {};
                data.balance = arg1[0].object.balance;
                data.buyFundList = self.category == "nf" ? "nanfangList" : "dahuaList";
                _.extend(data, arg2[0].object);
                self.tempProfitData = data;

                var fundCode = self.fundCode;
                self.ctr_fund = _.findWhere(self.tempProfitData.fundList, {
                    fundCode: fundCode
                });
                //转入的产品
                self.signFlag = self.ctr_fund.signFlag;
                if (self.signFlag != "1") {//隐藏合约
                    self.$("#checkbox").show();
                    self.$("#profit_autorepayService").show();
                }
                self.$("#balance").append("<br><span>" + utils.string.formatMoneyNumber(data.balance) + "元</span>");
                self.balance = data.balance;
            });
            promise.fail(function (err) {
                utils.dialog.alert(err.message);
            });
        },
        _customInputFocusIn: function () {
            safeKeyBoardHelper.focusIn({
                id: "transferAmt"
            });
            //self._activeBtn(true);
        },
        _onCustomInputFocusOutAmount: function () {
            safeKeyBoardHelper.focusOut({
                id: "transferAmt"
            });
            var transferAmt = $("#transferAmt").customInput("value");
            var transAmount = parseFloat(transferAmt.replace(/\,/g, ""));
            var maxPaPayLimit = parseFloat(self.tempProfitData.balance.replace(/\,/g, ""));
            //余额不足
            if (transAmount > maxPaPayLimit) {
                //var tip = "活期余额不足";
                //$("#conditionTip").text(tip).show();
                self.hasMoney = false;
                //this.ui.checkbox.children().eq(0).removeClass("on");
            } else {
                if (transferAmt != "" || transferAmt.replace(/[\b(0+).,]/gi, "") != "") {
                    self.hasMoney = true;
                }
                $("#conditionTip").text("").hide();
            }
            //this._activeBtn(self.hasMoney?true:false);
        },

        /**
         * ex_huangzit
         * 2015-07-10
         * add
         * keyup事件用于判定是否输入金额
         */
        _transferAmtKp: function () {
            var transferAmt = this.$("#transferAmt").customInput("value");
            if (transferAmt && transferAmt != 0) {
                this.$("#submitTransferIn").addClass("btn_orange");
                if (this.$("#submitTransferIn").hasClass("btn_disable"))
                    this.$("#submitTransferIn").addClass("btn_orange").removeClass("btn_disable");
                self.hasMoney = true;
                // if(Number(self.balance).toFixed(2) - Number(transferAmt).toFixed(2) >= 0){
                // var tip = "活期余额不足";
                // $("#conditionTip").text(tip).hide();
                // }else{
                // $("#conditionTip").text(tip).show();
                // }
            } else {
                this.$("#submitTransferIn").addClass("btn_disable");
                if (this.$("#submitTransferIn").hasClass("btn_orange"))
                    this.$("#submitTransferIn").addClass("btn_disable").removeClass("btn_orange");
                self.hasMoney = false;
                //$("#conditionTip").text(tip).hide();
            }
        },

        _activeBtn: function (active) {//激活确认按钮
            var sumbtn = $("#submitTransferIn");
            if (active) {
                sumbtn.removeClass('btn_disable').addClass('btn_orange');
            } else {
                sumbtn.removeClass('btn_orange').addClass('btn_disable');
            }
        },
        //服务协议链接
        openService_pay: function (e) {
            e.stopPropagation();
            var _url = TERMS;
            utils.window.open({
                title: "平安盈服务协议",
                url: _url
            });
        },
        openService: function (e) {
            e.stopPropagation();
            var _url = self.category == "nf" ? TERMS_NANFANG : TERMS_DAHUA;
            utils.window.open({
                title: "平安盈快速服务协议",
                url: _url
            });
        },
        _qryPayAccList: function () {
            var transferAmt = $("#transferAmt").customInput("value");
            var selectIcon = $("#checkbox i").hasClass("on");
            //支付列表
            var amount = $("#transferAmt").customInput("value");
            App.navigate("pinganying/payIndex/payAccView", false);
            App.container.show(new payAccView({
                "model": new Model({
                    "transferAmt": transferAmt,
                    "selectIcon": selectIcon,
                    "fundCode": self.fundCode,
                    "balance": self.tempProfitData.balance,
                    "tansferAmt": amount,
                    "category": self.category
                })
            }));
        },
        _formData: function (password) {
            var formData = {};
            var amount = $("#transferAmt").customInput("value").replace(/,/g, "");
            var pwd = utils.crypto.RSAKey.encrypt(password, config.base.rsa_public_key);
            var sm2Pwd = utils.sm2.SM2Key.encrypt(password, config.base.sm2_public_key);
            var fundCode = self.fundCode;
            var fund = self.ctr_fund;
            //_.findWhere(self.tempProfitData.fundList, { fundCode: fundCode});//转入的产品
            var fundAgreement = fund.agreement;
            var module = fundAgreement == "nanfang" ? "001" : "002";
            var isFirstFlag = fund.signFlag == "0" ? "1" : "0";
            var autoFlag = "2";
            //开通自动还款 待定？

            if (isFirstFlag == "1") {
                var $box = this.$("#profit_autorepayService").children().eq(0);
                autoFlag = $box.hasClass("on") ? "1" : "0";
            }
            return {
                amt: amount,
                password: pwd,
                sm2Pwd: sm2Pwd,
                module: module,
                isFirstflag: isFirstFlag,
                autoRepay: autoFlag,
                prdCode: fundCode
            }
        },
        _validateForm: function () {
            var transferAmt = $("#transferAmt").customInput("value");
            var ckBox = this.ui.checkbox.children().eq(0);
            if (transferAmt == "" || transferAmt.replace(/[\b(0+).,]/gi, "") == "") {
                utils.dialog.toast("请输入转入金额！");
                return false;
            }

            if (Number(self.balance).toFixed(2) - transferAmt.replace(/,/g, '') < 0) {
                utils.dialog.toast("可用余额不足！");
                return false;
            }

            if (self.signFlag == "0" && !ckBox.hasClass("on")) {
                utils.dialog.toast("请阅读并同意协议！");
                return false;
            }
            return true;
        },

        /**
         *    ex_huangzit
         *    2015-07-07
         *    modify
         */
        transferIn: function (event) {
            if (this.fundCode == FUND_CODE_DAHUA) {
                utils.native.talkingDataTrackEvent("2.0平安盈转入验密（大华）");
            } else if (this.fundCode == FUND_CODE_NANFANG) {
                utils.native.talkingDataTrackEvent("2.0平安盈转入验密（南方）");
            }
            //var self = this;
            if ($(event.target).hasClass('btn_disable')) {
                return;
            }

            //防重复提交
            // if(self.submited == "1"){
            // return false;
            // }
            //校验数据
            if (self._validateForm() && self.hasMoney) {
                //用户未输入金额点击确认
                var transferAmtInp = $("#transferAmt");
                var transferAmt = transferAmtInp.customInput("value");
                if (!transferAmt) {
                    transferAmtInp.trigger('customInputFocusOut');
                    return false;
                }
                //self.submited = "1";//防重复提交
                CustomPwdInput.customPwdInput(function (pwd) {
                    payModel.profitTransferInto({
                        "url": "profitTransferInto",
                        "data": self._formData(pwd),
                        "callback": function (resp) {
                            var promise = dreamModel.qryDreamState();

                            promise.done(_.bind(function (arg1) {
                                var arg1 = arg1.object.outExists;
                                //0-不存在，1-存在
                                if (arg1 == 1) {
                                    var nowDate = resp.buyDate || "", startDate = resp.volDate || "", endDate = resp.incomeDate || "";
                                    var transferAmt = $("#transferAmt").customInput("value");

                                    if (self.fundCode == FUND_CODE_DAHUA) {
                                        utils.native.talkingDataTrackEvent("2.0平安盈转入成功（大华）");
                                    } else if (self.fundCode == FUND_CODE_NANFANG) {
                                        utils.native.talkingDataTrackEvent("2.0平安盈转入成功（南方）");
                                    }

                                    App.container.show(new successTransferInView({
                                        "model": new Model({
                                            "fundCode": self.fundCode,
                                            "transferAmt": transferAmt,
                                            "nowDate": nowDate,
                                            "startDate": startDate,
                                            "endDate": endDate
                                        })
                                    }));
                                } else {
                                    utils.native.versionInformation(function (data) {
                                        vs = data.version;
                                        if (vs.replace(/\./g, "") * 1 >= 208) {
                                            App.navigate('dream/dream/dereamOpen', true);
                                        } else {
                                            var nowDate = resp.buyDate || "", startDate = resp.volDate || "", endDate = resp.incomeDate || "";
                                            var transferAmt = $("#transferAmt").customInput("value");

                                            if (self.fundCode == FUND_CODE_DAHUA) {
                                                utils.native.talkingDataTrackEvent("2.0平安盈转入成功（大华）");
                                            } else if (self.fundCode == FUND_CODE_NANFANG) {
                                                utils.native.talkingDataTrackEvent("2.0平安盈转入成功（南方）");
                                            }

                                            App.container.show(new successTransferInView({
                                                "model": new Model({
                                                    "fundCode": self.fundCode,
                                                    "transferAmt": transferAmt,
                                                    "nowDate": nowDate,
                                                    "startDate": startDate,
                                                    "endDate": endDate
                                                })
                                            }));

                                        }
                                    });

                                }
                            }, this));

                            promise.fail(function (err) {
                                utils.dialog.toast(err.message);
                            });
                            //self.submited = "0";//防重复提交
                            // 跳转到转账成功页

                        },
                        "errorCallback": function (resp) {
                            //self.submited = "0";
                            utils.dialog.alert(resp.message);
                        }
                    });

                });
            }
        },

        //限额说明
        _limitIntroduction: function () {
            utils.window.open({
                title: "限额说明",
                url: config.urls.get("pinganying_limit_searching")
            });
        },
        _showPayDetail: function () {
            var options = {
                title: "转入"
            };
            this._showHeader(options);
        },
        _showHeader: function (options) {
            var selef = this;
            App.header.reset({
                title: options.title,
                titleContent: options.titleContent,
                titleId: options.titleId,
                titleHandler: options.titleHandler,
                leftButtonContent: "@back",
                leftButtonHandler: function () {
                    App.storage.remove("transferAmt");
                    App.storage.remove("ctrSelectedChannel");
                    App.storage.set("pinganying/payIndex/index", new Model({
                        prdCode: self.fundCode
                    }));
                    App.navigate("pinganying/payIndex/index", true);
                },
                rightButtonContent: "限额说明",
                rightButtonHandler: function () {
                    selef._limitIntroduction();
                }
            });
        }
    });
});
