define(function (require, exports, module) {
    var indexTpl = require("text!../template/payTransOut.html");
    var payModel = require("../model/payModel");
    var FormComponent = require("component/form");
    var safeKeyBoardHelper = require("component/customInput.helper");
    var FUND_CODE_NANFANG = config.values.fund_code_nanfang;
    var FUND_CODE_DAHUA = config.values.fund_code_dahua;
    var customPwdInput = require("component/password/customPwdInput");
    var TERMS = config.urls.get("terms_of_service_pinganying");
    var TERMS_NANFANG = config.urls.get("terms_of_service_pinganying_nanfang");
    var TERMS_DAHUA = config.urls.get("terms_of_service_pinganying_dahua");


    var IndexView = module.exports = FormComponent.extend({
        template: _.template(indexTpl),
        events: {
            "tap #allTransOut": "_allTransOut",
            "customInputFocusIn #transOutAmt": "_onCustomInputFocusInAmount",
            "customInputFocusOut #transOutAmt": "_onCustomInputFocusOutAmount",
            "customInputFocusIn #transferOutPwd": "_customInputFocusIn",
            "customInputFocusOut #transferOutPwd": "_customInputFocusOut",
            "tap #transOutFlag": "_toTransOutPattern",
            "tap #submitData": "_submitTransOutData",
            "tap #pay_service_web_view": "openService_pay",
            "tap #service_web_view": "openService",
            "tap #signFlag>i": "_serviceCheckBox",
            "customInputKeyup #transOutAmt": "_transOutAmtKp",
            "jsClearIconHandler": "_transOutAmtKp"
        },
        onRender: function () {
            //this._initAmountKeyboard();
            this._showPayDetail();
        },

        /**
         * 初始化
         */
        initialize: function (options) {
            this.proCode = options.proCode;
            this.transOutFlag = "0";//赎回方式
        },
        //转出首页
        _showPayDetail: function () {
            var self = this;
            //查询平安盈（大华、南方）展示数据
            if (!App.storage.get("transOutTempData")) {
                var promise = $.when(
                    payModel.profitSignUpQryList(),
                    payModel.paynfProductMoneyQry({}),
                    payModel.paydhProductMoneyQry({}),
                    payModel.qryProfitUseVol({"prdCode": self.proCode})
                );
                promise.done(function (arg1, arg2, arg3, arg4) {
                    var signList = arg1[0].object.fundList;
                    for (var i = 0; i < signList.length; i++) {
                        if (signList[i].fundCode == self.proCode) {
                            self.currentFund = signList[i];
                            self.sign_Flag = signList[i].signFlag;
                            App.storage.set("sign_Flag", self.sign_Flag);
                        }
                    }
                    var nfProductObj = arg2[0].object;//南方可取最大金额
                    var dhProductObj = arg3[0].object;//大华可取最大金额
                    var profitUseVolObj = arg4[0].object;//t+1份额查询

                    var transOutTempData = {
                        signList: self.currentFund,
                        nfList: nfProductObj,
                        dhList: dhProductObj,
                        useVol: profitUseVolObj
                    };
                    App.storage.set("transOutTempData", transOutTempData);

                    //展示数据区
                    self._showDetail(transOutTempData);

                });
                promise.fail(function (err) {
                    utils.dialog.alert(err.message);
                });
            } else {
                self._showDetail(App.storage.get("transOutTempData"));
            }
        },

        //查询快速转出当日限额额度
        _qryFastLimit: function () {
            return utils.string.formatMoneyNumber(200000);
        },

        //服务协议链接
        openService_pay: function (e) {
            e.stopPropagation();
            var _url = TERMS;
            utils.window.open({
                title: "平安盈服务协议",
                url: _url
            });
        },

        openService: function (e) {
            e.stopPropagation();
            var _url = this.proCode == FUND_CODE_NANFANG ? TERMS_NANFANG : TERMS_DAHUA;
            utils.window.open({
                title: "平安盈快速服务协议",
                url: _url
            });
        },

        //展示数据区
        _showDetail: function (options) {
            //展示可转出最大金额
            var lastMoney = 0;
            if (!App.storage.get("transOutFlag")) {
                this.transOutFlag = "0";
                if (this.proCode == FUND_CODE_NANFANG) {//南方
                    lastMoney = options.nfList.paynfDeposit;
                } else if (this.proCode == FUND_CODE_DAHUA) {//大华
                    lastMoney = options.dhList.paydhDeposit;
                }
            } else {
                this.transOutFlag = App.storage.get("transOutFlag");
                lastMoney = options.useVol.useVol;
                if (lastMoney == '' || lastMoney == null) {
                    lastMoney = 0;
                }
                if (this.transOutFlag == 0) {
                    this.$("#transOutFlag>div>span").html("预计今日到账(快速转出)");
                } else {
                    //到账时间怎么获取
                    this.$("#transOutFlag>div>span").html("预计下一至两个工作日到账(普通转出)");
                }
            }
            this.lastMoney = lastMoney;
            var placeholder = "最多可转出" + utils.string.formatMoneyNumber(lastMoney);
            this._initAmountKeyboard(placeholder);

            //展示是否已签约
            if (options.signList.signFlag == "0") {//未签约
                this.$("#signFlag").show();
            } else if (options.signList.signFlag == "1") {//已签约
                this.$("#signFlag").hide();
            }

            //快速转出
            if (this.transOutFlag == 0) {
                this.$("#fastOutLimitTip").show();
                //this.$("#fastOutLimit").html(this._qryFastLimit());
                //this.$("#normalOutProfitTip").hide();
            } else {//普通转出
                this.$("#fastOutLimitTip").hide();
                //this.$("#normalOutProfitTip").show();
            }

            //添加全部转出
            this.$("#transOutAmt").append("<span class='c_f60 m_r10' id='allTransOut'>全部转出</span>");
            if (lastMoney == 0) this.$("#allTransOut").hide();
        },

        //监听金额输入框
        _transOutAmtKp: function () {
            if (App.storage.get("sign_Flag") && App.storage.get("sign_Flag") == 0) {
                if (this.$("#transOutAmt").customInput("value") && this.$("#transOutAmt").customInput("value") != 0 && this.$("#signFlag>i").hasClass("on")) {
                    if (this.$("#submitData").hasClass("btn_disable")) this.$("#submitData").addClass("btn_orange").removeClass("btn_disable");

                    //超出限额
                    var fastLimit = this._qryFastLimit();
                    var amount = (this.$("#transOutAmt").customInput("value").replace(/,/g, "")) * 1;
                    if (this.transOutFlag == 0 && amount > fastLimit) {
                        if (!this.$("#fastOutLimitTip").hasClass("c_f60")) this.$("#fastOutLimitTip").addClass("c_f60");
                    } else {
                        if (this.$("#fastOutLimitTip").hasClass("c_f60")) this.$("#fastOutLimitTip").removeClass("c_f60");
                    }
                } else {
                    this.$("#submitData").addClass("btn_disable");
                    if (this.$("#submitData").hasClass("btn_orange")) this.$("#submitData").addClass("btn_disable").removeClass("btn_orange");
                }
            } else {
                if (this.$("#transOutAmt").customInput("value") && this.$("#transOutAmt").customInput("value") != 0) {
                    if (this.$("#submitData").hasClass("btn_disable")) this.$("#submitData").addClass("btn_orange").removeClass("btn_disable");

                    //超出限额
                    var fastLimit = this._qryFastLimit();
                    var amount = (this.$("#transOutAmt").customInput("value").replace(/,/g, "")) * 1;
                    if (this.transOutFlag == 0 && amount > fastLimit) {
                        if (!this.$("#fastOutLimitTip").hasClass("c_f60")) this.$("#fastOutLimitTip").addClass("c_f60");
                    } else {
                        if (this.$("#fastOutLimitTip").hasClass("c_f60")) this.$("#fastOutLimitTip").removeClass("c_f60");
                    }
                } else {
                    this.$("#submitData").addClass("btn_disable");
                    if (this.$("#submitData").hasClass("btn_orange")) this.$("#submitData").addClass("btn_disable").removeClass("btn_orange");
                }
            }
        },

        //单击全部转出
        _allTransOut: function () {
            var fd = this.currentFund;
            var formattedBalance = "";
            var transOutTempData = App.storage.get("transOutTempData");
            if (this.transOutFlag == 0) {//t+0
                if (this.proCode == FUND_CODE_NANFANG) {//南方
                    formattedBalance = utils.string.formatMoneyNumber(transOutTempData.nfList.paynfDeposit);
                } else if (this.proCode == FUND_CODE_DAHUA) {//大华
                    formattedBalance = utils.string.formatMoneyNumber(transOutTempData.dhList.paydhDeposit);
                }
            } else {//t+1,转出份额
                formattedBalance = utils.string.formatMoneyNumber(transOutTempData.useVol.useVol);
            }
            this.$("#transOutAmt").customInput("value", formattedBalance);

            this._transOutAmtKp();
            //if(this.$("#submitData").hasClass("btn_disable")) this.$("#submitData").addClass("btn_orange").removeClass("btn_disable");
        },

        //初始化交易金额空间
        _initAmountKeyboard: function (placeholder) {
            this.$("#transOutAmt").customInput({
                type: "decimal",
                placeholder: placeholder,
                className: "safeKeyBoard",
                maxLength: 10
            });
        },

        _onCustomInputFocusInAmount: function () {
            safeKeyBoardHelper.focusIn({ id: "transOutAmt" });
        },

        _onCustomInputFocusOutAmount: function () {
            safeKeyBoardHelper.focusOut({ id: "transOutAmt" });
        },

        _customInputFocusIn: function () {
            safeKeyBoardHelper.focusIn({id: "transferOutPwd"});
        },

        _customInputFocusOut: function () {
            safeKeyBoardHelper.focusOut({id: "transferOutPwd"});
        },

        _toTransOutPattern: function () {
            App.storage.set("transOutFlag", this.transOutFlag);
            App.navigate("pinganying/payIndex/toTransOutPettern/" + this.proCode, true);
        },

        //校验数据
        _validate: function (formData) {
            var amount = formData.amt;

            if (amount === "" || amount === 0) {
                safeKeyBoardHelper.setCustomValidity({ id: "transOutAmt", message: "请输入转出金额" });
                return false;
            }

            if (this.lastMoney == 0) {
                safeKeyBoardHelper.setCustomValidity({ id: "transOutAmt", message: "可转出余额为0元" });
                return false;
            }

            if (amount > this.lastMoney.replace(/,/g, '')) {
                safeKeyBoardHelper.setCustomValidity({ id: "transOutAmt", message: "转出金额不能大于产品余额！" });
                return false;
            }

            //超出限额
            // var fastLimit = this._qryFastLimit();
            // if(this.transOutFlag == 0 && amount > fastLimit.replace(/,/g,'')){
            // utils.dialog.toast("超出今日实时转出限额（200,000.00元）");
            // return false;
            // }

            if (App.storage.get("sign_Flag") == "0" && !this.$("#signFlag>i").hasClass("on")) {
                utils.dialog.toast("请阅读并同意协议！");
                return false;
            }
            return true;
        },

        //点击服务协议的checkBox
        _serviceCheckBox: function (e) {
            if (this.$(e.currentTarget).hasClass("on")) this.$(e.currentTarget).removeClass("on");
            else this.$(e.currentTarget).addClass("on");
            this._transOutAmtKp();
        },

        //组装快速转出参数
        _formFastData: function () {
            var data = {};
            var transOutTempData = App.storage.get("transOutTempData")
            data.transOutFlag = this.transOutFlag;
            var curFund = transOutTempData.signList;
            data.prdCode = curFund.fundCode;
            data.fundName = curFund.fundName;
            data.amt = (this.$("#transOutAmt").customInput("value").replace(/,/g, "")) * 1;
            if (this.transOutFlag == 0) {
                data.module = curFund.agreement == "nanfang" ? "001" : "002";
                data.isFirstflag = curFund.signFlag == "0" ? "1" : "0";
                data.autoRepay = curFund.signFlag == "1" ? "1" : "2";
            } else {
                data.largRedFlag = "0";//巨额赎回处理标志    0:顺延,1:取消
            }
            return data;
        },

        //提交数据
        _submitTransOutData: function (event) {
            event.stopPropagation();
            var self = this;
            var formData = this._formFastData();
            // if($(event.target).prop('disabled')){
            // return;
            // }
            if (self.proCode == FUND_CODE_DAHUA) {
                utils.native.talkingDataTrackEvent("2.0平安盈转出验密（大华）");
            } else if (self.proCode == FUND_CODE_NANFANG) {
                utils.native.talkingDataTrackEvent("2.0平安盈转出验密（南方）");
            }

            if ($(event.target).hasClass('btn_disable')) {
                return;
            }
            if (this._validate(formData)) {
                if (this.transOutFlag == "0") {//t+0
                    //调用密码控件
                    customPwdInput.customPwdInput(function (pwd) {
                        formData.password = utils.crypto.RSAKey.encrypt(pwd, config.base.rsa_public_key);
                        formData.sm2Pwd = utils.sm2.SM2Key.encrypt(pwd, config.base.sm2_public_key);
                        payModel.profitTransferExport({
                            "param": formData,
                            "callback": function (response) {
                                if (response.object.taddOne == "1") {
                                    utils.dialog.alert("快速转出金额超过今日个人每日快速转出限额、或者超过今日资金池总额限制，您可修改转出金额，或选择普通转出方式重新提交申请。");
                                    return;
                                }
                                App.storage.remove("transOutTempData");
                                var amount = parseFloat(formData.amt);
                                var tempTime = App.storage.get("Login_SysTime");//2014/04/22 11:39:14
                                App.storage.set("transferOutSuccess", {amount: amount, transOutFlag: self.transOutFlag, transTime: tempTime});//response.object.transTime
                                App.storage.remove("sign_Flag");

                                if (self.proCode == FUND_CODE_DAHUA) {
                                    utils.native.talkingDataTrackEvent("2.0平安盈转出成功（大华）");
                                } else if (self.proCode == FUND_CODE_NANFANG) {
                                    utils.native.talkingDataTrackEvent("2.0平安盈转出成功（南方）");
                                }

                                App.navigate("pinganying/payIndex/transferOutSuccess", true);
                            },
                            "errorCallback": function (response) {
                                utils.dialog.alert(response.message);
                            }
                        });
                    });
                } else {//t+1
                    //调用密码控件
                    customPwdInput.customPwdInput(function (pwd) {
                            formData.password = utils.crypto.RSAKey.encrypt(pwd, config.base.rsa_public_key);
                            formData.sm2Pwd = utils.sm2.SM2Key.encrypt(pwd, config.base.sm2_public_key)
                            payModel.profitTransferExportAddOne({
                                "param": formData,
                                "callback": function (response) {
                                    var formFastData = self._formFastData();
                                    var amount = parseFloat(formData.amt);
                                    App.storage.remove("transOutTempData");
                                    App.storage.remove("sign_Flag");
                                    var tempTime = App.storage.get("Login_SysTime");//2014/04/22 11:39:14
                                    var accountTime = response.object.clearDate;
                                    App.storage.set("transferOutSuccess", {amount: amount, transOutFlag: self.transOutFlag, transTime: tempTime, accountTime: accountTime});//response.object.transTime

                                    if (self.proCode == FUND_CODE_DAHUA) {
                                        utils.native.talkingDataTrackEvent("2.0平安盈转出成功（大华）");
                                    } else if (self.proCode == FUND_CODE_NANFANG) {
                                        utils.native.talkingDataTrackEvent("2.0平安盈转出成功（南方）");
                                    }

                                    App.navigate("pinganying/payIndex/transferOutSuccess", true);
                                },
                                "errorCallback": function (response) {
                                    utils.dialog.alert(response.message);
                                }
                            });
                        }
                    );
                }
            }
        }
    });
})
