/**
 * ex-wuyongsheng001 产品首页控制器
 */
define(function(require, exports, module) {
    var IndexView = require('../view/index');
    var FilterFundView = require('../view/filter/fund');
    var SearchFundView = require('../view/filter/search');
    var ProductsQryModel = require('../model/ProductsQryModel');

    var accountInfoSta = require("mod/common/accountInfoStatus/accountInfoStatus"); //liujun add 认证
    var smartFinancialModel = require("../../smartFinancial/model/smartFinancial"); //liujun add 智能理财
    var panicBuyIndexView = require('../view/panicBuyIndex');
    
    module.exports = Controller.extend({
        actions: {
            'index(/*type)': 'index', //产品首页随存随取，理财产品
            'filterFund': 'filterFund', //智选基金
            'searchFund': 'searchFund', //搜索基金
            'panicBuy' : 'panicBuy'  //抢购专区
        },

        authorize: function() {
            return true;
        },

        _initialize: function() {
            this._emptyData = {
                pageSize: 5,
                productList: [],
                params: {},
                billData: {}
            };

            // 2015-11-03 增加E企盈接口
            var userInfo = App.storage.get('UserInfo');
            this.billSwitch = (!!App.storage.get('isUserLoggedIn') &&
                userInfo && !!parseInt(userInfo.get('billSwitch'), 10)
            );

            // 重复请求次数
            this.qryNum = 0;
        },

        /*
         *  产品首页
         */
        index: function(type) {
            type = type || 'depositTake';
            var self = this,
                billCache;
            this._setHeaderFooter();
            // 重置初始状态
            this._initialize();

            // 2015-11-05 小票缓存用于小票详情返回列表
            billCache = App.storage.get('products/detail/billCache');
            if (billCache && 'finefinance' === type) {
                self._showIndexView(type, billCache);
                return;
            }

            //显示空白视图，修复请求server异常后，视图内容还是上个视图的Bug0
            if (this._showEmpty()) {
                this._showIndexView(type, this._emptyData);
            }

            //2015-09-06 增加精选基金单独接口
            // if ('selectFund' === type) {
            //     this.qryFundPrdInfo(type);
            //     return;
            // }
            this._qrySelectFunds();

            this._renderIndexView(type);
        },

        _renderIndexView: function(type, noNative) {
            var self = this,
                qryArray = [];

            if (IS_RUN_ON_DEVICE && !noNative) {
                qryArray = [ProductsQryModel.queryNativeProduct()];
            } else {
                qryArray = [ProductsQryModel.queryProduct({
                    customType: 2
                })];
            }

            if (this.billSwitch && 'finefinance' === type) {
                qryArray.push(ProductsQryModel.qryBillList({
                    data: {
                        pageSize: self._emptyData.pageSize,
                        pageIndex: 1
                    }
                }));
            }

            $.when.apply(0, qryArray).done(function(result, res1) {
                result || (result = self._emptyData);
                result.billData = res1 ? res1 : {};

                self._showIndexView(type, result);
            }).fail(function(error, err1) {
                if (IS_RUN_ON_DEVICE && self.qryNum < 1) {
                    self.qryNum++;
                    self._renderIndexView(type, true);
                    return;
                }
                if (error) {
                    var message = error.message ? error.message : error;
                    utils.dialog.toast(message);
                }
            });
        },

        _showEmpty: function() {
            var list = App.browseList,
                el,
                i = 0;
            if (list.length < 3) return true;

            if ('products' === list[0].split('/')[0]) {
                while (el = list[++i]) {
                    if ('products' === el.split('/')[0]) return false;
                }
            }

            return true;
        },

        //2015-09-06 增加精选基金单独接口
        qryFundPrdInfo: function(type) {
            var _this = this;
            ProductsQryModel.qryFundPrdInfo().done(function(result) {
                _this._showIndexView(type, result);
            }).fail(function(e) {
                utils.dialog.toast(e.message);
                _this._showIndexView(type, _this._emptyData);
            });
        },
        
        
         _qrySelectFunds:function(){
            ProductsQryModel.fundMaxProfit().done(function(res) {
                var list = [];
                _.each(res.object.outFundList, function(item,id){
                    if(_.indexOf([1, 2, 3, 4], item.dispOrder) != -1)
                    list.push(item);
                });
                res.object.outFundList = list;
                App.storage.set('fundMaxProfit:funds', res.object);
            }).fail(function(e) {
                utils.dialog.toast(e.message);
            });
        },
        

        _showIndexView: function(type, prdInfo) {
            App.container.show(new IndexView({
                type: type,
                prdInfo: prdInfo
            }));
        },

        /*
         *  智选基金
         */
        filterFund: function() {
            this._setHeaderFooter({
                showFooter: false,
                title: '智选基金',
                leftButtonContent: '@back',
                leftButtonHandler: function() {
                    App.navigate('products/index/index/selectFund', true);
                },
                rightButtonContent: '<i class="iconA103"></i>',
                rightButtonHandler: function() {
                    App.navigate('products/index/searchFund', true);
                }
            });

            ProductsQryModel.qryFundPrdList().done(function(result) {
                var model = result.object ? result.object : {};
                App.container.show(new FilterFundView({
                    model: new Model(model)
                }));
            }).fail(function(e) {
                App.container.show(new FilterFundView({
                    model: new Model()
                }));
            });

        },

        /*
         *  搜索基金
         */
        searchFund: function() {
            this._setHeaderFooter({
                showFooter: false,
                title: '搜索',
                leftButtonContent: '@back',
                //leftButtonHandler : function () { App.navigate('products/index/index/selectFund', true) },
                rightButtonContent: null,
                rightButtonHandler: null
            });

            App.container.show(new SearchFundView());
        },

        _setHeaderFooter: function(options) {
            var defaults = _.extend({
                showFooter: true,
                title: '产品',
                leftButtonContent: null,
                leftButtonHandler: null,
                rightButtonContent: '智能理财',
                rightButtonHandler: this._smartFinancial
            }, options || {});

            App.header.reset(defaults);
            App.footer.reset({
                visible: defaults.showFooter,
                selectedIndex: 1
            });
        },

        //智能理财liujun add 6.21
        _smartFinancial: function () {
            (function smartFinancial(){
                //查询数据，判断是否签约、是否评测
                //评测状态
                if(App.storage.get("isUserLoggedIn")){
                    var dfd = window.accountInfoStatus.getAccountInfoStatus(false,"products/index/index/depositTake");
                    dfd.done(function(status){
                        if(status){
                            var promise = $.when(
                                smartFinancialModel.qrySmartFinancialState(),
                                smartFinancialModel.riskAbilityTestQry()
                            );
                            promise.done(_.bind(function(arg1,arg2){
                                arg1 = arg1[0].object;
                                arg2 = arg2[0].object;
                                //签约状态
                                // console.log(obj1);
                                var smartStatus = arg1;
                                var riskState = arg2.otherRiskStatus;
                                if(!smartStatus || smartStatus.status == "1"){
                                    //未签约
                                    if(riskState == "2" || riskState == "3"){
                                        //未评测及过期,广告、评测->结果->签约页
                                        App.storage.set("smartFinancialRisk","1");
                                        App.storage.set("smartFinancial/smartFinancial/fromPage",3);
                                        App.navigate("smartFinancial/smartFinancial/index",true);
                                    }else if(riskState == "1"){
                                        App.storage.set("smartFinancialRisk","1");
                                        App.storage.set("smartFinancial/smartFinancial/fromPage",3);
                                        App.storage.set("smartFinancialLevel",arg2.riskLevel);
                                        App.navigate("smartFinancial/smartFinancial/evaluated",true);
                                        //是否重评+签约点击->签约页
                                    }else{}
                                }else{
                                    App.storage.set("smartFinancial/smartFinancial/fromPage",3);
                                    App.storage.set("smartFinancialLevel",arg2.riskLevel);
                                    App.navigate("smartFinancial/smartFinancial/signed",true);
                                }
                            },this));

                            promise.fail(function(err){
                                utils.dialog.toast(err.message);
                            });
                        }else{
                        }
                    });
                }else{
                    App.navigate("login/login/toaIndex?returnURL=products%2Findex%2Findex%2FdepositTake",true);
                }
            })();
        },
        
        //抢购专区  wuwenjun
        panicBuy : function(){
            this._setHeaderFooter({
                title: '抢购专区',
                leftButtonContent: '@back',
                leftButtonHandler: function() {
                    if(App.storage.get("isUserLoggedIn")){
                        App.navigate("index/indexLogined/index",true);
                    }else{
                        App.navigate("index/index/index",true);
                    }
                },
                rightButtonContent: "抢购记录",
                rightButtonHandler: function(){
                    App.navigate("panicBuy/panicBuyRecords/index",true);
                }
            });
            App.container.show(new panicBuyIndexView());
        }

    });
});
