/**
 * wuyongsheng560 小票产品购买
 */
define(function (require, exports, module) {
    var safeKeyBoardHelper = require('component/customInput.helper');
    var InputTpl = _.template(require('text!../../template/buy/billBuy.html'));
    var CustomPwdInput = require('component/password/customPwdInput');

    var ProductsQryModel = require('../../model/ProductsQryModel');
    var nFormat = utils.string.numberFormat;
    var events = {
        'tap @ui.checkbox': 'toggleCheckbox',
        'tap #submitBtn': 'submit',
        'tap #booksLink a': 'openBookLink',
        'tap #selPaymentMethod': 'selPaymentMethod'
    };
    if (IS_RUN_ON_DEVICE) {
        events['customInputKeyup  #amountInput'] = '_onCustomInputFocusSelAmount';
    } else {
        events['keyup #amountInput'] = '_onCustomInputFocusSelAmount';
    }
    module.exports = ItemView.extend({
        template: InputTpl,
        ui: {
            'checkbox': '#checkbox'
        },
        events: events,
        initialize: function (options) {
            this.rData = this.model.toJSON() || {};
            this.billErrMsg = '系统正在维护中，产品暂停购买';
            this.agreements = {
                '票据收益权转让服务协议': 'https://ssl.pingan.com/bank/xieyi/zt/piaojuxieyi.shtml',
                '受让票据收益权风险揭示书': 'https://ssl.pingan.com/bank/xieyi/zt/piaojufengxian.shtml'
            };
        },

        onShow: function () {
            // 渲染协议内容
            var booksLinkHtml = '我已阅读并同意',
                booksLink = this.$('#booksLink');
            if (booksLink.length) {
                _.each(this.agreements, function (v, k) {
                    booksLinkHtml += '<a class="c_f60" data-href="' + v + '">《' + k + '》</a> ';
                });
                booksLink.html(booksLinkHtml);
            }

            // 自定义键盘
            this.$('#amountInput').customInput({
                type: 'decimal',
                placeholder: '请输入购买金额',
                className: '',
                maxLength: '10'
            });

            // 保存支付方式
            this.payInput = this.$('#selPaymentMethod');
            var cache = App.storage.get('selPayBeforeData');
            if (cache) {
                if (cache.amountInput) {
                    this._rAmount(nFormat(cache.amountInput));
                }
                this.$('#interest').text(cache.interest); //预期收益
                //购买协议协议
                if (cache.checkbox) {
                    this.ui.checkbox.addClass('on');
                    this.$('#submitBtn').removeClass('btn_disable');
                } else {
                    this.ui.checkbox.removeClass('on');
                    this.$('#submitBtn').addClass('btn_disable');
                }
                //选择支付方式
                var payInput = this.payInput.find('p:last');
                if (cache.payMentMethod === '1') {
                    payInput.text(nFormat(cache.balance));
                } else if (cache.payMentMethod === '2') {
                    payInput.text(nFormat(cache.dhBalance));
                } else {
                    payInput.text(nFormat(cache.totalBalance) + '=' + nFormat(cache.balance) + '+' + nFormat(cache.dhBalance));
                }
                this.payInput.attr('payMethodAttr', cache.payMentMethod);
            }

        },

        submit: function (e) {
            e.preventDefault();
            if (this.$('#submitBtn').hasClass('btn_disable')) return;
            if (!this.validate()) return;
            if (this.submitFlag) return;

            var self = this;
            CustomPwdInput.customPwdInput(function (password) {
                self.submitFlag = true;
                var formData = _.pick(self.rData, [
                    'tranId', 'applyDate', 'intRate'
                ]);
                formData.password = utils.crypto.RSAKey.encrypt(password, config.base.rsa_public_key);
                formData.sm2Pwd = utils.sm2.SM2Key.encrypt(password, config.base.sm2_public_key);
                // 传给后台字段tranAmt是购买金额
                // 与E企盈（小票）列表中tranAmt（总金额） 不相同
                formData.tranAmt = self._rAmount();
                //选择支付方式
                formData.paymentType = self.payInput.attr('payMethodAttr');

                ProductsQryModel.buyBillConfirm({
                    data: formData,
                    success: function (res) {
                        //删除选择支付方式缓存信息
                        App.storage.remove('selPayBeforeData');
                        //删除购买产品信息
                        App.storage.remove('billBuyModel');

                        formData.billName = self.rData.billName;
                        App.storage.set('products/buy/finish', formData);
                        App.navigate('products/buy/finish', {
                            replace: true,
                            trigger: true
                        });

                        self.submitFlag = false;
                    },
                    error: function (err) {
                        err.message && utils.dialog.toast(err.message);
                        self.submitFlag = false;
                    }
                });
            });

        },

        _rAmount: function (value) {
            if (value === void 0) {
                return this.$('#amountInput').customInput('value').replace(/,/g, '');
            }
            this.$('#amountInput').customInput('value', value);
        },

        _onCustomInputFocusSelAmount: function () {
            var num = this._rAmount();
            this._rAmount(num);
            if (!num) num = '0';

            var interestBaseDays = this.rData.interestDays;
            var planRate = this.rData.yield;
            var interest = '';
            try {
                interest = nFormat((0.01 * planRate * num) / 365 * interestBaseDays);
            } catch (e) {
            }
            this.$('#interest').text(interest);

            var totalBalance = parseFloat(this.rData.totalBalance); //活期余额+平安盈（大华）
            var dhBalance = parseFloat(this.rData.dhBalance); //平安盈（大华）
            var accountBalance = parseFloat(this.rData.accountBalance);
            if (num <= accountBalance) {
                this.payInput.attr('payMethodAttr', '1');
                this.payInput.find('p:first').text('活期余额');
                this.payInput.find('p:last').text(nFormat(accountBalance));
            } else {
                this.payInput.attr('payMethodAttr', '3');
                this.payInput.find('p:first').text('活期余额+平安盈(大华)');
                this.payInput.find('p:last').text(nFormat(totalBalance) + '=' + nFormat(accountBalance) + '+' + nFormat(dhBalance));
            }
        },

        validate: function () {
            var amount = parseFloat(this._rAmount()),
                unitAmount = parseInt(this.rData.unitAmount, 10),
                maxAmount = parseFloat(this.rData.maxSubscribeAmt),
                minAmount = parseFloat(this.rData.minSubscribeAmt),
                billBalance = parseFloat(this.rData.balance), // 该产品剩余额度
                totalBalance = parseFloat(this.rData.totalBalance);

            if (!amount) {
                this._errorMsg('请输入有效购买金额');
                return false;
            }

            if (totalBalance < amount) {
                this._errorMsg('账户余额不足');
                return false;
            }

            if (amount < minAmount && minAmount < billBalance) {
                this._errorMsg('此产品投资起点为' + minAmount + '元');
                return false;
            }

            if (maxAmount < amount && maxAmount < billBalance) {
                this._errorMsg('购买金额不能大于' + maxAmount + '元');
                return false;
            }

            // 最后一笔金额需全额购买
            if (amount < billBalance && (minAmount <= (billBalance - amount))) {
                if (unitAmount && (amount % unitAmount)) {
                    this._errorMsg('请输入' + unitAmount + '的整数倍金额');
                    return false;
                }
            } else if (billBalance !== amount) {
                this._errorMsg('最后一笔金额' + billBalance + '元, 需购买完');
                return false;
            }

            if (!this.ui.checkbox.eq(0).hasClass('on')) {
                this._errorMsg('请阅读并同意协议！');
                return false;
            }

            return true;

        },

        _errorMsg: function (msg) {
            if (!msg) return;
            safeKeyBoardHelper.setCustomValidity({
                id: 'amountInput',
                message: msg
            });
        },

        toggleCheckbox: function (e) {
            var checkbox = this.ui.checkbox;
            var submitBtn = this.$('#submitBtn');
            checkbox.toggleClass('on');
            if (checkbox.hasClass('on')) {
                submitBtn.removeClass('btn_disable');
            } else {
                submitBtn.addClass('btn_disable');
            }
        },

        openBookLink: function (e) {
            e.preventDefault();
            var a = this.$(e.target),
                href = a.data('href');
            if (!href) return;
            utils.window.open({
                title: '产品说明',
                url: href
            });
        },

        /**
         * wuwenjun059
         * 选择支付方式
         *
         */
        selPaymentMethod: function () {
            this.formInputData();
            App.navigate('common/selPaymentMethod/selPaymentMethod', true);
        },

        /**
         * wuwenjun059
         * 缓存页面数据
         *
         */
        formInputData: function () {
            var data = {};
            data.amountInput = this.$("#amountInput").customInput("value").replace(/,/g, '') * 1; //购买金额;
            data.interest = this.$("#interest").text(); //预期收益
            data.payMentMethod = this.$("#selPaymentMethod").attr("payMethodAttr"); //支付方式
            data.balance = this.model.get("accountBalance"); //余额
            data.dhBalance = this.model.get("dhBalance"); //平安盈（大华）
            data.totalBalance = this.model.get("totalBalance"); //活期余额+平安盈（大华）
            data.checkbox = this.$("#checkbox").hasClass("on"); //是否同意协议
            data.selPayBackUrl = "products/buy/index/bill";
            App.storage.set("selPayBeforeData", data);
        }
    });
});
