/**
 * wuyongsheng560 小票详情
 */
define(function(require, exports, module) {
    var shapeRender = require('mod/common/widget/shapeRender');
    var initPTRScroll = require('mod/common/widget/initPTRScroll');
    var safeKeyBoardHelper = require('component/customInput.helper');
    var FormLayout = require('component/form');
    var accountInfoSta = require('mod/common/accountInfoStatus/accountInfoStatus');

    var Tpl = _.template(require('text!../../template/detail/billDetail.html'));
    module.exports = FormLayout.extend({
        template: Tpl,
        ui: {
            toggleWrap: '.toggleWrap'
        },
        events: {
            'tap @ui.toggleWrap .title': 'togglePanel', //产品说明面板折叠展开
            'tap #caculator': 'openCaculator', //收益率计算

            'tap .caluconTitle': 'hideCaculator',
            'customInputFocusIn #caculatorInput': '_focusIn',
            'customInputFocusOut #caculatorInput': '_focusOut',
            'customInputKeyup #caculatorInput': '_keyup',
            'jsClearIconHandler #caculatorInput': '_clearResult',

            'tap #toBuyBtn': 'toBuyProccedure' //跳转购买详情
        },

        initialize: function(options) {
            this.lastRefresh = this.model.get('lastRefresh') || Date.now();
            this.totalAmt = parseFloat(this.model.get('tranAmt'));

            this.planRate = parseFloat(this.model.get('yield')),
                this.cycleDays = parseInt(this.model.get('interestDays'), 10);

            var year = new Date().getFullYear();
            this.yearDays = utils.date.diffDate(year + '-01-01', year + 1 + '-01-01');

            // 记录计算输入框处于focus状态
            this.focusIn = false;
        },

        onShow: function() {
            var _this = this,
                gap = 75;
            setTimeout(function() {
                var ratioremarkEl = _this.$('[data-ratioremark]').eq(0);
                if (ratioremarkEl.length < 1) return;
                if (_this.highchart) _this.highchart.destroy();
                _this.highchart = shapeRender.ratioLCircle(ratioremarkEl);
            }, 300);

            this._renderCountDown();

            //初始化PTRScroll
            if (IS_RUN_ON_DEVICE) gap = 18;
            initPTRScroll.call(this, {
                gap: gap,
                pullDownToRefresh: false,
                pullUpToLoadMore: false
            });

            if (this.planRate && this.cycleDays) {
                this.$('#planRate').text(this.planRate);
                this.$('#cycleDays').text(this.cycleDays);
                this._caculator = this.$('.caculator').hide();

                this.$('#caculatorInput').customInput({
                    type: 'decimal',
                    placeholder: '请输入投资金额',
                    maxLength: 20
                });

                if (!IS_RUN_ON_DEVICE) return;
                nativeBroadcast.on('keyboard:click:left:right:cancel:keyboard:button', function() {
                    _this._rePosCaculator();
                });
            }
        },

        onClose: function() {
            if (!IS_RUN_ON_DEVICE) return;
            nativeBroadcast.off('keyboard:click:left:right:cancel:keyboard:button');
        },

        _clearResult: function(e) {
            this.$('#incomeResult').text('0.00');
        },

        _focusIn: function(e) {
            safeKeyBoardHelper.focusIn({
                id: 'caculatorInput'
            });

            var caluconMain = this.$('.caluconMain').eq(0),
                wHeight = $(window).height();
            if (caluconMain.length < 1) return;

            if (!this.focusIn) {
                this.focusIn = true;

                caluconMain.css('top', (wHeight - caluconMain.height() - 230) / 2);
            }
        },

        _focusOut: function(e) {
            safeKeyBoardHelper.focusOut({
                id: 'caculatorInput'
            });
        },

        _keyup: function() {
            var incomeResult, _this = this;
            var input = this.$('#caculatorInput').customInput('value');
            input = parseFloat(input) || 0;
            if (input && input > this.totalAmt) {
                input = this.totalAmt;
                utils.dialog.toast('该产品最大金额为: \n' + _this.totalAmt, function() {
                    _this.$('#caculatorInput input').val(input);
                });
            }

            incomeResult = input * ((100 * this.planRate * (this.cycleDays / this.yearDays)) / 10000);

            this.$('#incomeResult').text(utils.string.numberFormat(incomeResult));
        },

        _rePosCaculator: function() {
            var caluconMain = this.$('.caluconMain').eq(0);
            if (caluconMain.length < 1) return;
            var wHeight = $(window).height();
            this.focusIn = false;

            caluconMain.css('top', (wHeight - caluconMain.height()) / 2);
        },

        openCaculator: function() {
            if (this._submitFlag) return;

            if (!this._caculator) {
                utils.dialog.alert('该产品没有预期收益率或者计息天数，无法计算。');
                return;
            }
            //window.scrollTo(0, 0);
            this._caculator.show();

            this._rePosCaculator();
            $('html, body').css('overflowY', 'hidden');

        },

        hideCaculator: function() {
            if (this._caculator) {
                this.focusIn = false;
                this._caculator.hide();
            }
            $('html, body').css('overflowY', 'auto');
        },

        toBuyProccedure: function(e) {
            var self = this;
            if (!this._submitFlag) {
                this._submitFlag = true;

                accountInfoSta
                .getAccountInfoStatus(false, 'products/detail/bill')
                .done(function (accountSta) {
                    if(accountSta){
                        App.storage.set('myInvestment/commendProducts/curProObj', self.model);
                        App.navigate('myInvestment/commendProducts/riskAbilityTestQry/5', true);
                    }
                });
            }
        },

        togglePanel: function(e) {
            var _this = this,
                titleEl = $(e.currentTarget),
                panelEl = titleEl.next('.proText');
            if (titleEl.length && panelEl.length) {
                if (panelEl.is(':visible')) {
                    panelEl.slideUp(function() {
                        if (_this.scroller) {
                            _this.scroller.refresh();
                        }
                    });
                    titleEl.find('i').removeClass('on');
                } else {
                    panelEl.slideDown(function() {
                        if (_this.scroller) {
                            _this.scroller.refresh();
                            _this.scroller.scrollToElement(titleEl[0], 200);
                        }
                    });
                    titleEl.find('i').addClass('on');
                }

            }
        },

        /**
         * 渲染倒计时
         */
        _renderCountDown: function() {
            var _this = this,
                lastRefreshEllipsis = parseInt((Date.now() - _this.lastRefresh) / 1000, 10),
                countdownEl = this.$('[data-countdown]');
            if (countdownEl.length < 1) return;

            countdownEl.each(function(i, el) {
                el = $(el);
                var day = el.find('.day')[0],
                    hour = el.find('.hour')[0],
                    minute = el.find('.minute')[0],
                    second = el.find('.second')[0];
                var countdown = el.data('countdown');
                if (!countdown) return;
                //el.show();

                countdown = countdown - lastRefreshEllipsis;
                utils.date.countDown(countdown, {
                    day: day,
                    hour: hour,
                    min: minute,
                    sec: second
                });
            });
        }

    });
});
