/**
 * wuyongsheng560 基金详情视图
 */
define(function(require, exports, module) {
    var shapeRender = require('mod/common/widget/shapeRender');
    var initPTRScroll = require('mod/common/widget/initPTRScroll');

    var ProductModel = require('../../model/ProductsQryModel');
    var Tpl = _.template(require('text!../../template/detail/fundDetail.html'));
    module.exports = Layout.extend({
        className: 'fundDetail',
        template: Tpl,
        regions: {
            chartRegion: '#contentRegion'
        },
        events: {
            'tap #toggleWrap .title': 'togglePanel', //产品说明面板折叠展开
            'tap #chartBtn > a': 'refreshChartRegion', //刷新图表区域
            'tap #qryRate': 'qryRate', //立即投资
            'tap #investNow': 'investNow', //立即投资
            'tap #investThis': 'investThis' //我要定投
        },
        templateHelpers: {
            rPrdAttrName: function(name) {
                return name && name.replace(/^\s*\u57FA\u91D1/, '');
            },
            mFormat: function(money) {
                if (!money || /[^.,\d]/.test(money)) return '---';
                return utils.string.formatMoneyNumber(money);
            }
        },

        initialize: function() {
            //2015-09-14 增加2个字段判断是否能购买，定投，0-不允许 1-允许
            this.buyFlag = this.model.get('buyFlag');
            this.fixFlag = this.model.get('fixFlag');

            this.taCode = this.model.get('taCode');
            this.prdCode = this.model.get('prdCode');
            this.prdName = this.model.get('prdName');
            this.prdAttr = this.model.get('prdAttr');
            
            this.chartBtnId = 0;
            this.chartBtnIdTypes = ['7', '1', '3'];

            //非货币型基金(prdAttr != '4')，并且登陆区内显示费率
            var showRate = this.isIpoing = false,
                loggedIn = App.storage.get('isUserLoggedIn');
            if (loggedIn && this.prdAttr != '4') {
                showRate = true;
            }
            this.model.set('showRate', showRate);

            //募集期(status == 1)的基金是不能定投的，“我要定投”按钮要置灰不可点击
            if (1 == this.model.get('status'))
                this.isIpoing = true;

            this.model.set('isIpoing', this.isIpoing);
        },

        onShow: function() {
            var options, gap = 75;

            //请求接口，显示购买折扣率 定投折扣率
            if (this.model.get('showRate')) this.showFundDiscountRate();

            //七日年化收益率（七日、一个月、三个月）按钮状态
            this._changeChartBtn();

            //请求七日数据并渲染图表
            options = this._getOptions();
            this.renderChart(options);

            //如果是募集期，不允许定投
            if (!parseInt(this.fixFlag, 10) || this.isIpoing)
                this.$('#investThis').addClass('btn_disable');
            //如果 buyFlag == 0 不能购买
            if (!parseInt(this.buyFlag, 10))
                this.$('#investNow').addClass('btn_disable');

            //初始化PTRScroll
            if (IS_RUN_ON_DEVICE) gap = 18;
            initPTRScroll.call(this, {
                gap: gap,
                pullDownToRefresh: false,
                pullUpToLoadMore: false
            });

        },

        onClose: function() {
            if (this.scroller) {
                this.scroller.destroy();
                delete this.scroller;
            }
        },

        showFundDiscountRate: function() {
            var options = {},
                _this = this,
                gagio = this.$('#gagio'),
                dagio = this.$('#dagio');
            if (!gagio.length || !dagio.length || !this.prdCode || !this.taCode) return;
            options.prdCode = this.prdCode;
            options.taCode = this.taCode;

            ProductModel.qryFundDiscountRate(options).done(function(res) {
                var ro = res.object || {},
                    gagioVal, dagioVal;

                gagioVal = _this.rDiscount(ro.gagio);
                dagioVal = _this.rDiscount(ro.dagio);

                gagio.find('.phold').text(gagioVal);
                dagio.find('.phold').text(dagioVal);

            }).always(function() {
                _this.scroller && _this.scroller.refresh();
            });
        },
        /**
         *  若基金系统返回的值为1，显示“无”
         *  若基金系统返回的值为空，显示“---”
         *  若基金系统返回的值为0.8，显示“8折”
         */
        rDiscount: function(discount) {
            discount = parseFloat(discount);
            if (!discount || 1 < discount) return '---';
            if (1 === discount) return '无';
            return String(discount).split('.')[1].charAt(0) + '折';
        },

        _getOptions: function(days) {
            days = -1 * (Math.abs(days) || 3 * 30);
            var startDate = new Date(),
                options,
                qryType = this.chartBtnIdTypes[this.chartBtnId] || '7';

            options = {
                qryType: qryType,
                startDate: null,
                pageSize: 10,
                prdCode: this.prdCode
            };

            // if (qryType == '3') {
            //     days = -1 * 3 * 30;
            // }else if(qryType == '1'){
            //     days = -1 * 1 * 30;
            // }else{
            //     days = -7;
            // }
            //pageSize =  (-1 * days < 10) ? 10 : -1 * days;

            //options.pageSize = pageSize;
            options.startDate = utils.date.diffDateAdd(startDate, days, 'd')
                .format('yyyy-MM-dd');
            return options;
        },

        //七日年化收益率（七日、一个月、三个月）
        renderChart: function(options) {
            var _this = this;
            if (this.fundProfit) {
                this.showChart(this.fundProfit);
                return;
            }

            ProductModel.qryFundProfitList(options).done(function(result) {
                var list = (result.object && result.object.list) || [];
                if (list.length) _this.fundProfit = list;

                _this.showChart(list);
            }).fail(function(e) {
                if (e && e.message) utils.dialog.toast(e.message);
            });
        },

        showChart: function(list) {
            if (!Array.isArray(list) || !list.length) return [];
            var _this = this,
                arr = [],
                qryType = this.chartBtnIdTypes[this.chartBtnId] || '7';

            switch (qryType) {
                case '7':
                    arr = list.slice(0, 7);
                    break;
                case '1':
                    arr = list.slice(0, 30);
                    break;
                case '3':
                    arr = list.slice(0, 90);
                    break;
            }

            this.chartRegion.show(new shapeRender.AreaChartView({
                view: _this,
                series: _this._getSeven(arr)
            }));
        },
        
        _getSeven: function(list) {
            var seven = [],
                firstIndex = 0,
                lastIndex = list.length - 1,
                middleIndex = Math.round(lastIndex / 2),
                step = Math.round(lastIndex / 7);
            
            
            if (list.length < 8) {
                for(var i=0; i<list.length; i++){
                    list[i].prdAttr = this.prdAttr;
                }
                return list.reverse();
            }

            seven.push(list[lastIndex]);
            seven.push(list[lastIndex - step]);
            seven.push(list[middleIndex + step]);
            seven.push(list[middleIndex]);
            seven.push(list[middleIndex - step]);
            seven.push(list[firstIndex + step]);
            seven.push(list[firstIndex]);
            
            for(var i=0; i<seven.length; i++){
                seven[i].prdAttr = this.prdAttr;
            }
            return seven;
        },

        refreshChartRegion: function(e) {
            e.stopPropagation();
            e.preventDefault();
            var el = $(e.currentTarget),
                id = el.index(),
                options = this._getOptions();

            if (id != this.chartBtnId && id < this.chartBtnIdTypes.length) {
                this.chartBtnId = id;
                this._changeChartBtn();

                this.renderChart(options);
            }
        },

        _changeChartBtn: function() {
            this.$('#chartBtn > a')
                .removeClass('on')
                .eq(this.chartBtnId).addClass('on');
        },

        qryRate: function(e) {
            if (!this.prdCode) return;

            App.storage.set('products/detail/fundRate', {
                prdCode: this.prdCode,
                prdName: this.prdName || ''
            });

            App.navigate('products/detail/fundRate', true);
        },

        investNow: function(e) {
            //如果 buyFlag == 0 不能购买
            if (!parseInt(this.buyFlag, 10)) {
                utils.dialog.toast('该基金无法购买');
                return;
            }
            if (!this._investNowFlag) {
                this._investNowFlag = true;
                App.storage.set('myInvestment/commendProducts/curProObj', this.model);

                setTimeout(function() {
                    App.navigate("myInvestment/commendProducts/riskfund/0", true);
                }, 350);
            }
        },
        investThis: function(e) {
            //如果 fixFlag == 0 不能购买
            if (!parseInt(this.fixFlag, 10)) {
                utils.dialog.toast('该基金无法定投');
                return;
            }
            if (this.isIpoing) {
                utils.dialog.toast('该基金募集期无法定投');
                return;
            }
            if (!this._investThisFlag) {
                this._investThisFlag = true;
                App.storage.set('myInvestment/commendProducts/curProObj', this.model);

                setTimeout(function() {
                    App.navigate("myInvestment/commendProducts/riskfund/1", true);
                }, 350);
            }
        },

        togglePanel: function(e) {
            var _this = this,
                titleEl = $(e.currentTarget),
                panelEl = titleEl.next('.proText');
            if (titleEl.length && panelEl.length) {
                if (panelEl.is(':visible')) {
                    panelEl.slideUp(function() {
                        if (_this.scroller) {
                            _this.scroller.refresh();
                        }
                    });
                    titleEl.find('i').removeClass('on');
                } else {
                    panelEl.slideDown(function() {
                        if (_this.scroller) {
                            _this.scroller.refresh();
                            _this.scroller.scrollToElement(titleEl[0], 200);
                        }
                    });
                    titleEl.find('i').addClass('on');
                }

            }
        }
    });

});
