/**
 * wuyongsheng560 理财产品中的日添利，净值产品详情视图
 */
define(function(require, exports, module) {
    var shapeRender = require('mod/common/widget/shapeRender');
    var initPTRScroll = require('mod/common/widget/initPTRScroll');
    var caculator = require('mod/common/widget/caculator');
    var ProductModel = require('../../model/ProductsQryModel');
    var Tpl = _.template(require('text!../../template/detail/networthDetail.html'));
    module.exports = Layout.extend({
        className: 'networthDetail',
        template: Tpl,
        regions: {
            chartRegion: '#contentRegion'
        },
        events: {
            'tap .toggleWrap > .title': 'togglePanel', //产品说明面板折叠展开
            'tap #chartBtn > a': 'refreshChartRegion', //刷新图表区域

            'tap #caculator': 'showCaculator', //收益率计算
            'tap #toBuyBtn': 'toBuyProccedure', //跳转购买详情
            'tap #notice': 'prdNotice',
            'tap #faq': 'bankfaq'
        },
        templateHelpers: {
            minAmountFmt: function(minAmount) {
                minAmount = parseFloat(minAmount) || 0.00;
                if (minAmount >= 10000) {
                    return Math.floor(minAmount / 10000) + '万';
                } else {
                    return utils.string.numberFormat(minAmount, 0) + '元';
                }
            }
        },

        initialize: function() {
            // fnType 日添利时为‘1‘，净值产品时’2‘
            // 在model里根据prdCode前3位判断：
            // ’310‘为日添利 ’510‘为净值
            this.fnType = this.model.get('fnType');
            var planRate = (
                this.fnType !== '2' ? this.model.get('planRate') :
                this.model.get('planRateRemark')
            );
            caculator(this, {
                planRate : planRate,
                dayEdited: Boolean(this.fnType),
                normal: (this.fnType !== '2')
            });

            this.prdCode = this.model.get('prdCode');
            this.chartBtnId = 0;
            this.chartBtnIdTypes = ['7', '1', '3'];
        },

        onShow: function() {
            var options, gap = 75;
            //七日年化收益率（七日、一个月、三个月）按钮状态
            this._changeChartBtn();

            //请求七日数据并渲染图表
            options = this._getOptions();
            this.renderChart(options);

            //初始化PTRScroll
            if (IS_RUN_ON_DEVICE) gap = 18;
            initPTRScroll.call(this, {
                gap: gap,
                pullDownToRefresh: false,
                pullUpToLoadMore: false
            });
        },

        onClose: function() {
            if (this.scroller) {
                this.scroller.destroy();
                delete this.scroller;
            }
        },

        bankfaq: function() {
            var fnType = this.model && this.model.get('fnType');
            App.storage.set('czFaq/faqIndex/czFaq/finace', {
                'fnType': fnType
            });
            App.navigate('czFaq/faqIndex/czFaq/finace', true);
        },

        prdNotice: function() {
            if (!this.prdCode) return;
            var url = 'http://bank.pingan.com/licaichanpin/TLG' + this.prdCode + '.shtml';
            utils.window.open({
                'title': '产品公告',
                'url': url
            });
        },

        toBuyProccedure: function(e) {
            if (!this._submitFlag) {
                this._submitFlag = true;

                App.storage.set('myInvestment/commendProducts/curProObj', this.model);
                App.navigate('myInvestment/commendProducts/riskAbilityTestQry/5', true);
            }
        },

        _getOptions: function() {
            return {
                productId: this.prdCode
            };
        },

        _filterData: function (list) {
            list = list || [];
            var ft = this.fnType;
            return _.map(list, function (item) {
                var issDate, nav;
                if ('1' === ft) {
                    issDate = item.startDate;
                    nav = item.yearRate;
                } else if('2' === ft) {
                    issDate = item.navDate;
                    nav = item.netValue;
                }
                return {
                    'issDate': issDate,
                    'nav': nav
                };
            });
        },
        //七日年化收益率（七日、一个月、三个月）
        renderChart: function(options) {
            var self = this;
            if (this.prdProfit) {
                this.showChart(this.prdProfit);
                return;
            }

            ProductModel.qryFinanceHistoryYield(options).done(function(result) {
                var list = (result.object && result.object.list) || [];
                if (list.length) {
                    list = self._filterData(list);
                    self.prdProfit = list;
                }

                self.showChart(list);
            }).fail(function(e) {
                if (e && e.message) utils.dialog.toast(e.message);
            });
        },

        showChart: function(list) {
            if (!Array.isArray(list) || !list.length) return;
            var _this = this,
                arr = [],
                qryType = this.chartBtnIdTypes[this.chartBtnId] || '7';

            switch (qryType) {
                case '7': arr = list.slice(0, 7); break;
                case '1': arr = list.slice(0, 30); break;
                case '3': arr = list.slice(0, 90); break;
            }

            this.chartRegion.show(new shapeRender.AreaChartView({
                view: _this,
                series: _this._getSeven(arr)
            }));
        },

        _getSeven: function(list) {
            var seven = [],
                firstIndex = 0,
                lastIndex = list.length - 1,
                middleIndex = Math.round(lastIndex / 2),
                step = Math.round(lastIndex / 7);

            if (list.length < 8) {
                return list.reverse();
            }

            seven.push(list[lastIndex]);
            seven.push(list[lastIndex - step]);
            seven.push(list[middleIndex + step]);
            seven.push(list[middleIndex]);
            seven.push(list[middleIndex - step]);
            seven.push(list[firstIndex + step]);
            seven.push(list[firstIndex]);

            return seven;
        },

        refreshChartRegion: function(e) {
            e.stopPropagation();e.preventDefault();
            var el = $(e.currentTarget),
                id = el.index(),
                options = this._getOptions();

            if (id !== this.chartBtnId && id < this.chartBtnIdTypes.length) {
                this.chartBtnId = id;
                this._changeChartBtn();

                this.renderChart(options);
            }
        },

        _changeChartBtn: function() {
            this.$('#chartBtn > a')
                .removeClass('on')
                .eq(this.chartBtnId).addClass('on');
        },

        togglePanel: function(e) {
            var _this = this,
                titleEl = $(e.currentTarget),
                panelEl = titleEl.next('.proText');
            if (titleEl.length && panelEl.length) {
                if (panelEl.is(':visible')) {
                    panelEl.slideUp(function() {
                        if (_this.scroller) {
                            _this.scroller.refresh();
                        }
                    });
                    titleEl.find('i').removeClass('on');
                } else {
                    panelEl.slideDown(function() {
                        if (_this.scroller) {
                            _this.scroller.refresh();
                            _this.scroller.scrollToElement(titleEl[0], 200);
                        }
                    });
                    titleEl.find('i').addClass('on');
                }
            }
        },

        showCaculator: function() {
            _.isFunction(this.openCaculator) && this.openCaculator();
        }

    });

});
