/**
 * wuyongsheng560 产品首页智选基金视图
 */
define(function(require, exports, module) {
    var Tpl = _.template(require("text!../../template/filter/fund.html"));
    var FilterListView = require('./fundList');
    var ProductsQryModel = require("../../model/ProductsQryModel");
    var initPTRScroll = require("mod/common/widget/initPTRScroll");

    module.exports = Layout.extend({
        className: 'filterFund',
        template: Tpl,
        regions: {
            FundList: '#FundList'
        },
        events: {
            'tap *': 'unMask',
            //'tap [data-prdcode]' : 'toProductDetail',
            'tap #filterHeader > li': 'showFilterPanel',
            'tap #filterBody .params': 'filterParams',
            'tap #filterFundBtn': 'filterSubmit',
            'tap #indexflag > li': 'sortBySubmit'
        },
        initialize: function() {
            var fundList = this.model.get('fundList') || [];
            this.collection = new Collection(fundList);

            //初始化过滤条件
            this.qryParams = {
                fundType : 0,
                riskLevel : 0,
                indexFlag : 0,
                pageIndex : 1,
                pageSize : 10,
                totalRows : null
            };

            this.fundTypes = ['全部','混合型','货币型','股票型','债券型','保本型','QDII','其他'];
            this.riskLevels = ['全部','高风险','中高风险','中风险','中低风险','低风险','未评定'];
            this.indexFlags = ['不限','收益率从高到低','收益率从低到高'];
        },
        onShow: function() {
            var _this = this;
            initPTRScroll.call(_this, {
                pullDownToRefresh : true,
                refreshContent : function (refresh) {
                    _this._qryFirstPage(refresh);
                },
                pullUpToLoadMore: true,
                loadMoreContent: function(refresh){
                    _this._qryNextPage(refresh);
                }
            });
            //初始化过滤UI
            this._initParams();

            //初始化列表并显示第一页基金数据
            this._showFundListView();
        },

        _initParams: function () {
            var ftHtml = rlHtml = ifHtml = '';

            _.each(this.fundTypes, function (ft, id) {
                ftHtml  += '<span class="params'+
                        (id == 0 ? ' on' : '') +'" data-fundtype="'+id+'">'+ft+'</span>';
            });
            _.each(this.riskLevels, function (ft, id) {
                rlHtml  += '<span class="params'+
                        (id == 0 ? ' on' : '') +'" data-risklevel="'+id+'">'+ft+'</span>'
            });
            _.each(this.indexFlags, function (ft, id) {
                ifHtml  += '<li class="p_l10'+
                        (id == 0 ? ' on' : '') +'" data-indexflag="'+id+'">'+ft+'</li>'
            });

            this.$('#fundtype').html(ftHtml);
            this.$('#risklevel').html(rlHtml);
            this.$('#indexflag').append(ifHtml);
        },

        _showFundListView: function() {
            if (!this.fundListView) {
                this.fundListView = new FilterListView({
                    collection: this.collection
                });
                if (this.qryParams.pageSize > this.collection.size()) {
                    this.scroller.disablePullUpToLoadMore();
                }
            }
            this.FundList.show(this.fundListView);
        },

        filterSubmit: function (e) {
            e.stopPropagation(); e.preventDefault();
            this._qryFirstPage();
        },

        filterParams: function(e) {
            e.stopPropagation(); e.preventDefault();
            var span = $(e.currentTarget), data = span.data();
            span.addClass('on').siblings().removeClass('on');

            _.each(this.qryParams, function (val, key) {
                var k = key.toLowerCase();
                data[k] && (this.qryParams[key] = data[k]);
            }, this);
        },
        sortBySubmit: function (e) {
            e.stopPropagation(); e.preventDefault();
            var li = $(e.currentTarget), indexflag = li.data('indexflag');
            li.addClass('on').siblings('li').removeClass('on');

            this.qryParams.indexFlag = indexflag;
            this._qryFirstPage();
        },

        _qryFirstPage: function (callback) {
            //alert(JSON.stringify(this.qryParams, null, '\n'));
            var _this = this;
                callback = callback || function() {};

            if(this.refreshing) return;
            this.refreshing = true;

            if(this.refreshTimer) clearTimeout(this.refreshTimer);
            this.refreshTimer = setTimeout(function () {

                ProductsQryModel.qryFundPrdList(_this.qryParams)
                .done(function (res) {
                    var result = res.object, total,
                        fundList = result.fundList;

                    _this.qryParams.pageIndex = parseInt(result.pageIndex) || 1;
                    _this.qryParams.totalRows = parseInt(result.totalRows);

                    total = _this.qryParams.totalRows / _this.qryParams.pageSize;

                    if(Array.isArray(fundList) && (0 < fundList.length)){
                        _this.collection.reset(fundList);

                        if ( _this.qryParams.pageIndex < total && fundList.length == _this.qryParams.pageSize) {
                            _this.scroller.enablePullUpToLoadMore();
                        }
                    }

                }).always(function () {
                    _this.$('#filterBody').hide();
                    _this.refreshing = false;
                    callback();
                });

            }, 300);
        },
        _qryNextPage: function (callback) {
            var _this = this, totalPages,
                totalRows = parseInt(this.qryParams.totalRows);

            totalPages = totalRows ? totalRows/ this.qryParams.pageSize : 100;
            callback = callback || function() {};

            if( this.paging ) return;

            this.paging = true;
            this.qryParams.pageIndex++;
            this.lastPageIndex = this.qryParams.pageIndex;

            if(this.pageTimer) clearTimeout(this.pageTimer);
            this.pageTimer = setTimeout(function () {

                ProductsQryModel.qryFundPrdList(_this.qryParams)
                .done(function (res) {
                    var result = res.object, total,
                        fundList = result.fundList;

                    _this.qryParams.pageIndex = parseInt(result.pageIndex) || 1;
                    _this.qryParams.totalRows = parseInt(result.totalRows);

                    total = _this.qryParams.totalRows / _this.qryParams.pageSize;

                    if(Array.isArray(fundList) && (0 < fundList.length)){
                        _this.collection.add(fundList);

                        if (total <= _this.qryParams.pageIndex ||
                            _this.qryParams.pageIndex < _this.lastPageIndex) {
                            _this.scroller.disablePullUpToLoadMore();
                        }
                    }

                }).always(function () {
                    _this.paging = false;
                    callback();
                });

            }, 300);
        },

        showFilterPanel: function(e) {
            var li = $(e.currentTarget),
                id = li.index(),
                panel = this.$('#filterBody');

            panel.children('.FilterOptions').hide().eq(id).show();

            if (panel.is(':hidden')) {
                panel.show();
            } else {
                if(id == this.clickId) {
                    panel.hide();
                }
            }
            this.clickId = id;
        },

        unMask: function(e) {
            e.stopPropagation(); e.preventDefault();
            var clickEl = $(e.currentTarget);
            if (!clickEl.closest('.FilterOptions, #filterHeader').length) {
                this.$('#filterBody').hide();
            }
        }

    });
});
