/**
 * ex-wuyongsheng001 产品首页理财产品视图
 */
define(function(require, exports, module) {
    var shapeRender = require('mod/common/widget/shapeRender');
    var finefinanceTpl = _.template(require('text!../template/finefinance.html'));

    module.exports = ItemView.extend({
        className: 'finefinance',
        template: finefinanceTpl,
        templateHelpers: {
            showEmptyFlag: function() {
                var flag = (!this.financingPrdList.length &&
                    !this.pensionPrdList.length &&
                    !this.papPrdList.length &&
                    !this.goldbaoPrdList.length
                );
                if (this.isBillWhiteSwitch) {
                    return flag && !this.billPrdList.length;
                }
                return flag;
            },
            minAmount: function(minAmount) {
                if (minAmount >= 10000) {
                    return Math.floor(minAmount / 10000) + '<i class="f15 lh12">万元</i>';
                } else {
                    return utils.string.numberFormat(minAmount, 0) + '<i class="f15 lh12">元</i>';
                }
            },
            evalMarkup : function (val) {
                var monthMarkup = Number(val);
                if( -1 === monthMarkup || !val ){
                    monthMarkup = '---';
                }else{
                    monthMarkup = this.splitStr(monthMarkup.toFixed(2)) + '<i class="f15 lh12">'+ this.splitStr(monthMarkup.toFixed(2), 1) +'%</i>';
                }
                return monthMarkup;
            },
            splitStr : function(val, index) {
                if(typeof val !== "string" && typeof val !== "number") return val;
                if(typeof val === "number") val = String(val);
                index = index == null ? 0 : index;
                var strArr = val.split('.'), sStr = strArr[1] ? ('.') + strArr[1] : '.00';
                strArr.splice(1, 1, sStr);
                return strArr[index];
            }
        },
        events: {
            'tap [data-prdcode]': 'toProductDetail' //跳转产品详情页
        },

        /**
         * 提取理财产品数组， 养老产品数组
         */
        initialize: function(options) {
            var collection, productList;
            productList = options.processedResult.productList;
            // 2015-11-03 增加E企盈接口
            this.isBillWhiteSwitch = options.processedResult.params.billSwitch;
            this._billList = options.processedResult.billData.list;

            this._financingPrdList = _.where(productList, {
                type: 'finance'
            });
            this._pensionPrdList = _.where(productList, {
                type: 'pension'
            });
            this._papPrdList = _.where(productList, {
                type: 'pap'
            });
            //2015-09-24 增加黄金宝理财产品
            this._goldbaoPrdList = _.where(productList, {
                type: 'goldbao'
            });

            collection = this._financingPrdList.concat(
                this._pensionPrdList,
                this._papPrdList,
                this._goldbaoPrdList,
                this._billList
            );
            this.collection = new Collection(collection);

            this.parentView = options.parent;
            this.lastRefresh = App.storage.get('prdIndexLastRefresh') || Date.now();
            this.billLastRefresh = App.storage.get('prdBillLastRefresh') || Date.now();
        },

        serializeData: function() {
            var fcList = this._financingPrdList,
                psList = this._pensionPrdList,
                ppList = this._papPrdList,
                gbList = this._goldbaoPrdList,
                blList = this._billList;

            return {
                financingPrdList: fcList ? fcList : [],
                pensionPrdList: psList ? psList : [],
                papPrdList: ppList ? ppList : [],
                goldbaoPrdList: gbList ? gbList : [],
                isBillWhiteSwitch: this.isBillWhiteSwitch,
                billPrdList: blList ? blList : []
            };
        },

        onRender: function() {
            this._renderCountDown();

            var ratioremarkEls = this.$('[data-ratioremark]');
            if (ratioremarkEls.length) shapeRender.ratioCircle(ratioremarkEls);
        },

        toProductDetail: function(e) {
            var model,
                el = $(e.currentTarget),
                prdCode = el.data('prdcode') + '';
            if (!prdCode) return;
            model = this.collection.findWhere({
                prdCode: prdCode
            });
            if (!model) return;
            if ('bill' === model.get('type')) {
                model.set('lastRefresh', this.billLastRefresh);
            } else {
                model.set('lastRefresh', this.lastRefresh);
            }
            Marionette.triggerMethod.call(this.parentView, 'toProductDetail', model, el);
        },

        /**
         * 渲染倒计时
         */
        _renderCountDown: function() {
            var self = this,
                now = Date.now(),
                countdownEl = this.$('[data-countdown]'),
                lastRefreshEllipsis = parseInt((now - self.lastRefresh) / 1000, 10);
            if (countdownEl.length < 1) return;

            countdownEl.each(function(i, el) {
                el = $(el);
                var day = el.find('.day')[0],
                    hour = el.find('.hour')[0],
                    minute = el.find('.minute')[0],
                    second = el.find('.second')[0];
                var countdown = el.data('countdown');
                var type = el.data('type');
                if (!countdown) return;
                el.show();

                if ('bill' === type) {
                    lastRefreshEllipsis = parseInt((now - self.billLastRefresh) / 1000, 10);
                }

                countdown = countdown - lastRefreshEllipsis;
                utils.date.countDown(countdown, {
                    day: day,
                    hour: hour,
                    min: minute,
                    sec: second
                });
            });
        }

    });
});
