/**
 * ex-wuyongsheng001 产品首页精选基金视图
 */
define(function(require, exports, module){
    var selectFunds = require("text!../../template/fund/selectFunds.html");
    var selectFundIndex = _.template(require("text!../../template/fund/selectFundIndex.html"));
    var ProductsQryModel = require("mod/products/model/ProductsQryModel");   
    var initPTRScroll = require('mod/common/widget/initPTRScroll');
    
    module.exports = Layout.extend({
        className: 'selectFund',
        template: selectFundIndex,
        events: {
            'tap [data-prdcode]' : 'toProductDetail', //跳转产品详情页
            'tap #tofilterFund' : 'tofilterFund' //基金选择页
        },
        
        templateHelpers: {
            minAmount : function (minAmount) {
                if (minAmount >= 10000) {
                    return  utils.string.numberFormat(minAmount/10000, 2, '.', '')+'万';
                }else{
                    return  utils.string.numberFormat(minAmount, 2, '.', '')+'';
                }
            },
            evalMarkup : function (val) {
                var monthMarkup = Number(val);
                if( -1 === monthMarkup || !monthMarkup ){
                    monthMarkup = '---';
                }else{
                    monthMarkup = this.splitStr(((monthMarkup - 1)*100).toFixed(2)) + '<i class="f15 lh12">'+ this.splitStr(((monthMarkup - 1)*100).toFixed(2),1)+'%</i>';
                }
                return monthMarkup;
            },
            rateTpl : function (val) {
                var cls = 'c_f60';
                val = Number(val);
                if( -1 === val || !val ){
                    val = '---';
                }else{
                    if ((val - 1) < 0) cls = 'c_3eb';//近三月涨幅计算是(val - 1)才是正确的
                    val = this.splitStr(((val - 1)*100).toFixed(2)) + '<i class="f15 lh12">'+ this.splitStr(((val - 1)*100).toFixed(2), 1) +'%</i>';
                }
                return '<p class="f28 '+cls+'">'+val+'</p>';
            },
            
            splitStr : function(val, index) {
                if(typeof val !== "string" && typeof val !== "number") return val;
                if(typeof val === "number") val = String(val);
                index = index == null ? 0 : index;
                var strArr = val.split('.'), sStr = strArr[1] ? ('.') + strArr[1] : '.00';
                strArr.splice(1, 1, sStr);
                return strArr[index];
            },
            
            rPrdAttrName : function (name) {
                return name && name.replace(/^\s*\u57FA\u91D1/, '');
            },
            /**
             * 1 股票型 2 混合型 3 基金债券型 4 基金货币型 5 基金保本型 6 基金QDII 7 基金其他
             */
            rPrdAttrCls : function (prdAttr) {
                var cls = {
                    '1' : 'Stock',
                    '2' : 'Mix',
                    '3' : 'Bond',
                    '4' : 'Monetary',
                    '5' : 'Guaranteed',
                    '6' : 'QDII',
                    '7' : 'Other'
                };

                prdAttr = (prdAttr + '').trim();
                return cls[prdAttr] || 'Other';
            }
        },
        
        initialize:function () {
            this.selectFundList = this.options.model.get('list');
        },
        
        onShow: function () {
            this.tpl = selectFunds;
            App.footer.reset({
                visible:false,
                selectedIndex: 0
            });
            this.listRegion = this.$('#listRegion');
            this._renderList(this.tpl, this.selectFundList);
            if(!this.scroller) this._initSroller();
        },
        
        //初始化iScroller组件
        _initSroller: function () {
            var _this = this;
            var config =  {};
            
            var PTRConfig = {
                gap: 0,
                pullUpToLoadMore: false,
                pullDownToRefresh: true,
                refreshContent: function (refresh) {
                    _this._refresher = refresh;
                    _this._qrySelectFunds();//下拉查询精选基金
                }
            }; 
            initPTRScroll.call(this, _.extend(PTRConfig, config)); //初始化PTRScroll
        },
        
        //2015-09-06 增加精选基金单独接口
        _qrySelectFunds: function(callback) {
            var self = this;
            ProductsQryModel.qryFundPrdInfo().done(function(res) {
                
                self._renderList(self.tpl, res.productList);
                
            }).fail(function(e) {
                utils.dialog.toast(e.message);
                self._refresher && self._refresher();
            });
        },
        
        _renderList: function (tpl, list, append) {
            if (!tpl) return;
            append = !!append ? 'append' : 'html';
            var dataList = {
                parent: this,
                list: list
            };
            
            var fundList = [];
            if(!this.listArray) this.listArray = [];
            if (append === 'append') {
                fundList = _.union(fundList, dataList.list)
            } else {
                fundList = dataList.list;
            }
            
            _.map(fundList, _.bind(function(val) {
                var vv = _.clone(val);
                vv.type = 'fund';
                vv.fromPage = 'product';
                this.listArray.push(vv);
                return val;
            }, this));

            var html = _.template(tpl, dataList);
            this.listRegion[append](html);
            
            //刷新
            this._refresher && this._refresher();
        },

        
        toProductDetail: function (e) {
            e.stopPropagation();
            var model, prdCode = $(e.currentTarget).data('prdcode') + '';
            if (!prdCode) return;

            model = _.findWhere(this.listArray, {
                prdCode: prdCode
            });
            if (!model) return;
            model.fromPage = 'product';
            model.fundType = 'selectFund';
            model = new Model(model);
            //model.set('queryFundDetails', true);

            App.storage.set('products/detail/fund', model);
            App.navigate('products/detail/fund', true);
        }
    });
});