define(function (require, exports, module) {
    var ROBFunds = require("text!mod/products/template/fund/ROBFunds.html");                // 定期开放债券基金列表Regularly open bond fund
    var hundredFunds = require("text!mod/products/template/fund/hundredFunds.html");        // 百元基金列表
    var financiaFunds = require("text!mod/products/template/fund/financiaFunds.html");      // 理财型基金列表
    var guaranteedFunds = require("text!mod/products/template/fund/guaranteedFunds.html");  // 保本基金列表
    var fundIndex = _.template(require("text!mod/products/template/fund/specialFundIndex.html"));

    var ProductsQryModel = require("mod/products/model/ProductsQryModel");                  // 特色基金Model
    
    var initPTRScroll = require('mod/common/widget/initPTRScroll');


    module.exports = Layout.extend({
        template: fundIndex,
        events: {
            'tap #listType > .flex1': 'selectType',
            'tap #listRegion [data-orderno]': 'toDetail',
            'tap [data-prdcode]' : 'toProductDetail', //跳转产品详情页
        },
        
        templateHelpers: {
            minAmount : function (minAmount) {
                if (minAmount >= 10000) {
                    return  utils.string.numberFormat(minAmount/10000, 2, '.', '')+'万';
                }else{
                    return  utils.string.numberFormat(minAmount, 2, '.', '')+'';
                }
            },
            evalMarkup : function (val) {
                var monthMarkup = Number(val);
                if( -1 === monthMarkup || !monthMarkup ){
                    monthMarkup = '---';
                }else{
                    monthMarkup = this.splitStr(((monthMarkup - 1)*100).toFixed(2)) + '<i class="f15 lh12">'+ this.splitStr(((monthMarkup - 1)*100).toFixed(2),1)+'%</i>';
                }
                return monthMarkup;
            },
            rateTpl : function (val) {
                var cls = 'c_f60';
                val = Number(val);
                if( -1 === val || !val ){
                    val = '---';
                }else{
                    if ((val - 1) < 0) cls = 'c_3eb';//近三月涨幅计算是(val - 1)才是正确的
                    val = this.splitStr(((val - 1)*100).toFixed(2)) + '<i class="f15 lh12">'+ this.splitStr(((val - 1)*100).toFixed(2), 1) +'%</i>';
                }
                return '<p class="f28 '+cls+'">'+val+'</p>';
            },
            
            sevenTpl : function (val) {
                var cls = 'c_f60';
                val = Number(val);
                if( -1 === val || !val ){
                    val = '---';
                }else{
                    if (val < 0) cls = 'c_3eb';//近七日年化收益率
                    val = this.splitStr((val*100).toFixed(3)) + '<i class="f15 lh12">'+ this.splitStr((val*100).toFixed(3), 1) +'%</i>';
                }
                return '<p class="f28 '+cls+'">'+val+'</p>';
            },
            
            splitStr : function(val, index) {
                if(typeof val !== "string" && typeof val !== "number") return val;
                if(typeof val === "number") val = String(val);
                index = index == null ? 0 : index;
                var strArr = val.split('.'), sStr = strArr[1] ? ('.') + strArr[1] : '.00';
                strArr.splice(1, 1, sStr);
                return strArr[index];
            },
            
            rPrdAttrName : function (name) {
                return name && name.replace(/^\s*\u57FA\u91D1/, '');
            },
            /**
             * 1 股票型 2 混合型 3 基金债券型 4 基金货币型 5 基金保本型 6 基金QDII 7 基金其他
             */
            rPrdAttrCls : function (prdAttr) {
                var cls = {
                    '1' : 'Stock',
                    '2' : 'Mix',
                    '3' : 'Bond',
                    '4' : 'Monetary',
                    '5' : 'Guaranteed',
                    '6' : 'QDII',
                    '7' : 'Other'
                };

                prdAttr = (prdAttr + '').trim();
                return cls[prdAttr] || 'Other';
            }
        },
        
        onShow: function () {
            var _this = this;
            App.footer.reset({
                visible:false,
                selectedIndex: 0
            });
            this.listRegion = this.$('#listRegion');
            this.fundOption = this.options.model.attributes.object;
            this.pageIndex = parseInt(this.fundOption.pageIndex, 10),
            this.totalRows = parseInt(this.fundOption.totalRows, 10),
            this.pageSize  = 10;
            this.totalPage = this.totalRows ? Math.ceil(this.totalRows / this.pageSize) : 100;
            
            this.tpl =_.values(_.filter(this._initParam, function(item){ 
                if(_this.fundOption.specialType == _.keys(item)[0]) return item[_this.fundOption.specialType];
            }))[0][_this.fundOption.specialType];
            this._renderList(this.tpl, this.fundOption);
            if(!this.scroller) this._initSroller();
        },
        
        
        //初始化iScroller组件
        _initSroller: function () {
            var _this = this;
            var config =  {};
            
            var PTRConfig = {
                gap: 0,
                pullUpToLoadMore: false,
                pullDownToRefresh: true,
                refreshContent: function (refresh) {
                    _this._refresher = refresh;
                    _this._qrySpecialFunds();
                }
            }; 
            if(this.pageIndex < this.totalPage){
                config = {
                    pullUpToLoadMore: true,
                    loadMoreContent: function (refresh) {
                        _this._refresher = refresh;
                        _this._qryFundNextPage();
                    }
                }; 
            }
                
            initPTRScroll.call(this, _.extend(PTRConfig, config)); //初始化PTRScroll
        },

        _qryFundNextPage: function () {
               
            var pageIndex = this.pageIndex;
            pageIndex = pageIndex + 1;
            if (pageIndex > this.totalPage ) return;
            var options = {pageIndex: pageIndex, append:true};
            this._qrySpecialFunds(options);
        },


        //初始化
        _initParam: [
            { '201604010000000006': ROBFunds }, { '201604010000000009': hundredFunds },
            { '201604010000000007': financiaFunds }, { '201604010000000008': guaranteedFunds }
        ],
        
        //查询特色基金
        _qrySpecialFunds: function (params) {
            var fundParam = params || {};
            var specialType = this.fundOption.specialType;
            var options = _.extend({ pageIndex: 1, pageSize: this.pageSize, 'specialType': specialType , 'append':false}, fundParam);

             var isLogin = App.storage.get('isUserLoggedIn');//true 为登陆， undefined未登陆
            
            var methodArr = {'loggedIn':'fundItemFund', 'loggedOut':'fundItemFundOut'};//loggedIn:登陆区内;loggedOut:登陆区外
            var specialMethod = methodArr['loggedOut'];
            
            if(isLogin) specialMethod = methodArr['loggedIn'];//登陆区内
            
            ProductsQryModel[specialMethod](options).done(_.bind(function (res) {
                
                var resObject = res.object;
                if(specialMethod === 'fundItemFundOut'){//登陆区外
                    resObject = this._fundItemOut(res.object);
                    this.pageIndex = parseInt(resObject.pageIndex||1, 10);
                    this.totalPage = 1;//登陆区外后端totalRows返回数据有误，固定写死1
                }else{
                     this.pageIndex = parseInt(resObject.pageIndex, 10);
                }
                this.totalRows = parseInt(resObject.totalRows, 10);
                
                if (!this.totalPage)
                     this.totalPage = this.totalRows ? Math.ceil(this.totalRows / this.pageSize) : 100;
                
                //判断是否可以加载更多
                if(this.pageIndex >= this.totalPage){
                     this.scroller.disablePullUpToLoadMore();
                }else{
                    this.scroller.enablePullUpToLoadMore();
                }
                
                this._renderList(this.tpl, resObject, options.append);

            }, this)).fail(function (error) {
                utils.dialog.alert(error.message);
            }).always(_.bind(function () {
                this._refresher && this._refresher();
            }, this));
        },

         //处理登陆区外数据
        _fundItemOut:function (res) {
            if(!res) return;
            //var specialOption;
            var specialOption = App.storage.get('specialFund::specialOption');
            //(specialOption={})['dispOrder'] = '1';
            /**
             * liuxiannan 注
             * List1 对应优先级dispOrder == 1
             * List2 对应优先级dispOrder == 2
             * List3 对应优先级dispOrder == 3
             * List4 对应优先级dispOrder == 4
             */
            var outDTO;
            switch (specialOption.dispOrder) {
                case 1:
                    outDTO = res.outDTO1;
                    break;
                case 2:
                    outDTO = res.outDTO2;
                    break;
                case 3:
                    outDTO = res.outDTO3;
                    break;
                case 4:
                    outDTO = res.outDTO4;
                    break;
                default:
                    outDTO = res.outDTO1;
                    break;
            }
            return outDTO || {};
        },
        
        _renderList: function (tpl, res, append) {
            if (!tpl) return;
            var _this = this;
            append = !!append ? 'append' : 'html';
            var dataList = {
                parent: this,
                res: res
            };
            
            var fundList = [];
            if(!this.listArray) this.listArray = [];
            if (append === 'append') {
               // fundList.push(dataList.res.list);
                fundList = _.union(fundList, dataList.res.list)
            } else {
                fundList = dataList.res.list;
            }
            
            _.map(fundList, _.bind(function(val) {
                var vv = _.clone(val);
                vv.type = 'fund';
                vv.fromPage = 'product';
                this.listArray.push(vv);
                return val;
            }, this));

            var html = _.template(tpl, dataList);
            this.listRegion[append](html);
            
            //刷新
            this._refresher && this._refresher();
        },
        
        //基金详情页
        toProductDetail: function (e) {
            e.stopPropagation();
            var model, prdCode = $(e.currentTarget).data('prdcode') + '';
            if (!prdCode) return;

            model = _.findWhere(this.listArray, {
                prdCode: prdCode
            });
            
            if (!model) return;
            model.fromPage = 'product';
            model.fundType = this.fundOption.specialType;
            model = new Model(model);
            model.set('queryFundDetails', false);

            App.storage.set('products/detail/fund', model);
            App.navigate('products/detail/fund', true);
        }
    });
});
