/**
 * ex-wuyongsheng001 产品首页视图
 */
define(function(require, exports, module) {
	var initPTRScroll = require('mod/common/widget/initPTRScroll');

	var ProductsIndexTpl = _.template(require('text!../template/index.html'));
	var FundIndexView = require('./fundIndex');
	var DepositTakeView = require('./depositTake');
	var FinefinanceView = require('./finefinance');
	var SelectFundView = require('./selectFund');
	var GoldInvestmentView = require('./goldInvestment');

	var ProductsQryModel = require('../model/ProductsQryModel');
	module.exports = Layout.extend({
		template: ProductsIndexTpl,
		ui: {
			productType: '#productsType .flex1'
		},
		regions: {
			productsRegion: '#productsRegion'
		},
		events: {
			'tap @ui.productType': 'selectType', //产品首页 选择类型 tab
			'input #search_box input.search_input': 'searchFund',
			'tap #search_box input.search_input': 'beginSearch',
			'tap #search_box .iconA54': 'clearInput',
			'tap #search_box #cancel': 'cancelSearch',
			'tap #search_box #search_result li': 'toFundDetail',
			// 2016-04-08 增加 筛选
			'tap #search_box #filter': 'filterSearch',
			'tap #search_box #selectType span.params': 'filterFundType',
			'tap #search_box #selectRiskLevel span.params': 'filterRiskLevel',
			'tap #search_box #filterFundBtn': 'filterSubmit'
		},
		initialize: function(options) {
			this.ptype = options.type || 'depositTake';

			this._emptyData = {
				pageSize: 5,
				productList: [],
				params: {},
				billData: {}
			};
			this.prdInfo = _.extend({},
				this._emptyData,
				options.prdInfo
			);

			// 2015-11-05 小票缓存用于小票详情返回列表
			var pageIndex = 1;
			var billCache = App.storage.remove('products/detail/billCache');
			if (billCache && 'finefinance' === this.ptype) {
				pageIndex = billCache.billData.pageIndex;
			}
			this.prdInfo.billData.pageIndex = pageIndex;

			// 2015-11-03 增加E企盈白名单判断
			var userInfo = App.storage.get('UserInfo');
			this.prdInfo.params.billSwitch = this.billSwitch = (!!App.storage.get('isUserLoggedIn') && userInfo &&
				!!parseInt(userInfo.get('billSwitch'), 10)
			);
		},

		onShow: function() {
			//2016-03-03 增加搜索框
			this.searchBox = this.$('#search_box');
			if (this.searchBox.length) {
				this.searchBox.addClass('dsn');
			}

			this._renderRegion(this.ptype, this.prdInfo);
			// 左右滑动切换
			this._swipe();

			//liujun add 智能理财6.21pm
			if (App.storage.get('smartFinancialRisk')) {
				App.storage.remove('smartFinancialRisk');
			}
		},

		onClose: function() {
			$(document)[0].swipe.destroy();
			if (this._refreshTimer) clearTimeout(this._refreshTimer);
			if (this.scroller) {
				this.scroller.destroy();
				delete this.scroller;
			}
		},
		// wuyongsheng560 滑动事件简单封装
		_swipe: function() {
			$(document).swipe(function() {
				var lis = $('#productsType > li');
				var len = lis.size();
				var id = lis.filter('.on').index();
				if (this.direction === 'left') {
					id++;
					if (id > len - 1) {
						id = 0;
					}
					lis.eq(id).trigger('tap');
				} else if (this.direction === 'right') {
					id--;
					if (id < 0) {
						id = len - 1;
					}
					lis.eq(id).trigger('tap');
				}

			});
		},

		filterFundType: function (e) {
			if (!this.searchBox.length) return;
			this.fundFilterParams || (this.fundFilterParams = {});
			var el = this.searchBox.find(e.currentTarget);
			if (el.length) {
				el.siblings().removeClass('on');
				el.addClass('on');
				this.fundFilterParams.fundType = el.attr('fundType');
			}
		},
		filterRiskLevel: function (e) {
			if (!this.searchBox.length) return;
			this.fundFilterParams || (this.fundFilterParams = {});
			var el = this.searchBox.find(e.currentTarget);
			if (el.length) {
				el.siblings().removeClass('on');
				el.addClass('on');
				this.fundFilterParams.riskLevelName = el.attr('riskLevelName');
			}
		},
		filterSubmit: function (e) {
			if (!this.searchBox.length) return;
			if (this.filterSubmiting) return;
			e.preventDefault();e.stopPropagation();
			var self = this;
			var opsEl = this.searchBox.find('#filterOptions');
			var opts = {
				fundType : '',
				riskLevelName : ''
			};
			opts = _.extend(opts, this.fundFilterParams);

			this.filterSubmiting = true;
			ProductsQryModel.searchFund({
				data: opts
			}).done(function(res) {
				self.filterSubmiting = false;
				//search_input.attr('disabled', false).focus();
				var list = res.list,
					result = [];
					
				//list为空或者不存在    noRecorde
				if (!Array.isArray(list) || !list.length) {
					opsEl.addClass('dsn');
					$('#noRecorde').show();
					self.clearInput(null, true);
					return;
				}
				$('#noRecorde').hide();
				
				self.searchFundPage = {
					fundType: opts.fundType,
					riskLevelName: opts.riskLevelName,
					pageIndex: (res.pageIndex | 0) || 1,
					pageSize: (res.pageSize | 0) || 10,
					totalRows: (res.totalRows | 0)  || 1000
				};

				list = _.map(list, function(val) {
					var vv = _.clone(val);
					vv.type = 'fund';
					vv.fromPage = 'product';
					result.push(vv);
					return val;
				});
				self.searchFundList = result;
				self.renderSearchRes(list);

				opsEl.addClass('dsn');
			}).fail(function (err) {
				self.filterSubmiting = false;
				utils.dialog.toast(err.message || '接口错误');
				opsEl.addClass('dsn');
			});
		},
		filterSearch: function () {
			//未登陆不能进行筛选
			if(!App.storage.get('isUserLoggedIn')){
				App.navigate('login/login/toaIndex?returnURL=products%2Findex%2Findex%2FselectFund',true);
				return;
			}
			if (!this.searchBox.length) return;
			this.beginSearch(null, true);
			this.clearInput();

			//if (!this.rScroller) {
				var fopts = this.searchBox.find('#filterOptions');
				fopts.css({
					position: 'absolute',
					zIndex: 2,
					left: 0,
					backgroundColor: '#fff',
					height: this.searchBox.find('#search_result').eq(0).outerHeight(),
					top: this.searchBox.find('.search_box').eq(0).outerHeight()
				});
			//}

			fopts.removeClass('dsn');
		},

		beginSearch: function(event, noFocus) {
			var self = this;
			if(!App.storage.get('isUserLoggedIn')){
				App.navigate('login/login/toaIndex?returnURL=products%2Findex%2Findex%2FselectFund',true);
				return;
			}
			if (!this.searchBox.length) return;
			$(document)[0].swipe.destroy();
			this.searchBox.find('#cancel').removeClass('dsn');

			var gap = 0;
			var iconA54 = this.searchBox.find('.iconA54');
			var search_input = this.searchBox.find('.search_input').eq(0);
			var top = this.searchBox.find('.search_box').eq(0).outerHeight();
			var search_result = this.searchBox.find('#search_result');
			search_result.removeClass('dsn');
			if (search_input.val().trim()) {
				iconA54.removeClass('dsn');
			} else {
				iconA54.addClass('dsn');
			}

			search_input.attr('disabled', false);
			this.searchBox.find('.input_box').eq(0).removeClass('m_l15');
			if (!noFocus) search_input.focus();

			if (!this.rScroller) {
				if (IS_RUN_ON_DEVICE) gap += (top + 40);
				initPTRScroll.call(this, {
					gap: gap,
					holder: '#search_result',
					scroller: 'rScroller',
					css : { position: 'absolute', left: 0, top: top },
					pullUpToLoadMore: false,
					loadMoreContent: function(refresh) {
						self._qryFundNextPage(refresh);
					}
				});
			}
		},
		_qryFundNextPage: function (callback) {
			if (!this.searchBox.length || !this.searchFundPage) return;
			var self = this, params = {},
				keywords = this.searchFundPage.prdCodeOrpN,
				fundType = this.searchFundPage.fundType,
				riskLevelName = this.searchFundPage.riskLevelName,
				pageIndex = this.searchFundPage.pageIndex,
				totalPage = Math.ceil(this.searchFundPage.totalRows / this.searchFundPage.pageSize);
			pageIndex ++;
			if (pageIndex < 2 || totalPage < pageIndex) return;

			params.pageIndex = pageIndex;
			if (keywords) {
				params.prdCodeOrpN = keywords;
			}else{
				params.fundType = fundType;
				params.riskLevelName = riskLevelName;
			}

			ProductsQryModel.searchFund({
				silent: true,
				data: params
			}).done(function(res) {
				var pid = res.pageIndex | 0,
					list = res.list,
					result = [];
				if (!Array.isArray(list) || !list.length) return;
				if(pid === self.searchFundPage.pageIndex) return;

				self.searchFundPage.pageIndex = pid || pageIndex;

				list = _.map(list, function(val) {
					var vv = _.clone(val);
					vv.type = 'fund';
					vv.fromPage = 'product';
					result.push(vv);

					if (val.prdName && keywords) {
						val.prdName = val.prdName.replace(
							keywords,
							'<span class="f6Color">' + keywords + '</span>'
						);

					}
					return val;
				});
				self.searchFundList = self.searchFundList.concat(result);
				self.renderSearchRes(list, true);
			});
		},
		clearInput: function(event, keepInput, noRecord) {
			keepInput = Boolean(keepInput);
			if (!this.searchBox.length) return;
			!keepInput && this.searchBox.find('.search_input').eq(0).val('');
			if(!noRecord) {this.searchBox.find('.iconA54').addClass('dsn');}
			this.searchBox.find('.search_result_list').html('');
			//$('#noRecorde').hide();
			this.rScroller && this.rScroller.disablePullUpToLoadMore();
		},
		cancelSearch: function(e) {
			e.stopPropagation();e.preventDefault();
			if (!this.searchBox.length) return;
			this.clearInput();
			this.searchBox.find('.search_input').attr('disabled', true);
			this.searchBox.find('.input_box').eq(0).addClass('m_l15');
			this.searchBox.find('#filterOptions, #cancel, #search_result').addClass('dsn');

			this._swipe();
		},
		searchFund: function() {
			if (!this.searchBox.length) return;
			this.searchBox.find('#filterOptions').addClass('dsn');

			var self = this,
				search_input,
				keywords,keywords1,
				iconA54 = this.searchBox.find('.iconA54'),
				patterns = /[`~!@#\$%\^\&\*\(\)_\+\-<>\?:"\{\},\.\\\/;'\[\]]+/g;
			if (this.searchFundTimer) clearTimeout(this.searchFundTimer);

			search_input = this.searchBox.find('.search_input').eq(0);
			keywords = keywords1 = search_input.val();
			keywords = keywords.trim().replace(patterns, '');
			if (keywords) {
				iconA54.removeClass('dsn');
			} else {
				iconA54.addClass('dsn');
			}
			this.searchFundTimer = setTimeout(function() {
				if (!keywords || keywords1 !== keywords ) {
					self.clearInput(null, true);
					return;
				}
				//search_input.attr('disabled', true);
				ProductsQryModel.searchFund({
					silent: true,
					data: {
						prdCodeOrpN: keywords
					}
				}).done(function(res) {
					//search_input.attr('disabled', false).focus();
					var list = res.list,
						result = [];
					if (!Array.isArray(list) || !list.length) {
						$('#noRecorde').show();
						self.clearInput(null, true, true);
						return;
					}
					$('#noRecorde').hide();
					
					self.searchFundPage = {
						prdCodeOrpN: keywords,
						pageIndex: (res.pageIndex | 0) || 1,
						pageSize: (res.pageSize | 0) || 10,
						totalRows: (res.totalRows | 0)  || 1000
					};

					list = _.map(list, function(val) {
						var vv = _.clone(val);
						vv.type = 'fund';
						vv.fromPage = 'product';
						result.push(vv);

						if (val.prdName) {
							val.prdName = val.prdName.replace(
								keywords,
								'<span class="f6Color">' + keywords + '</span>'
							);

							return val;
						}
					});
					self.searchFundList = result;
					self.renderSearchRes(list);
				});
			}, 1000);
		},
		
		noRecord:function(){
			
		},
		
		renderSearchRes: function(list, append) {
			append = !!append ? 'append' : 'html';
			var html, searchList, totalPage, noRecordHtml;
			if (!this.searchBox.length || !list.length || !this.searchFundPage) return;
			searchList = this.searchBox.find('.search_result_list');
			//无交易记录
			if (!searchList.length){
				return;
			}
			
			html = '<%_.each(list, function(item){%>' +
					'<li data-prdcode="<%=item.prdCode%>">' +
						'<p><%=item.prdName%></p>' +
						'<p class="f12"><%=item.prdCode%></p>' +
					'</li>' +
					'<%});%>';
			html = _.template(html, {
				list: list
			});
			searchList[append](html);

			totalPage = Math.ceil(this.searchFundPage.totalRows / this.searchFundPage.pageSize);
			if (this.rScroller) {
				if (this.searchFundPage.pageIndex < totalPage) {
					this.rScroller.enablePullUpToLoadMore();
				}else{
					this.rScroller.disablePullUpToLoadMore();
				}
			}
		},
		toFundDetail: function(e) {
			e.stopPropagation();
			var model, prdCode = $(e.currentTarget).data('prdcode') + '';
			if (!prdCode) return;

			model = _.findWhere(this.searchFundList, {
				prdCode: prdCode
			});
			if (!model) return;
			model = new Model(model);
			model.set('queryFundDetails', false);

			App.storage.set('products/detail/fund', model);
			App.navigate('products/detail/fund', true);
		},

		/**
		 * 更改标题样式，渲染对应视图
		 */
		_renderRegion: function(type, prdInfo) {
			var _this = this,
				gap = 0,
				config = {},
				billData = prdInfo.billData,
				PTRConfig = {
					gap: gap,
					pullDownToRefresh: true
				};

			if (IS_RUN_ON_DEVICE) {gap = 40; PTRConfig.gap = 40;}
			if (this._refreshTimer) clearTimeout(this._refreshTimer);
			this.ui.productType.removeClass('on');
			switch (type) {
				case 'finefinance':
					utils.native.talkingDataTrackEvent("2.0产品-精选理财");
					this.ui.productType.eq(1).addClass('on');

					if (this.billSwitch && billData.pageIndex < billData.totalPage) {
						config = {
							refreshContent: function(refresh) {
								_this._refresher = refresh;
								_this._refreshContent(function(result) {
									_this.finefinance(result);
								});
							},
							pullUpToLoadMore: true,
							loadMoreContent: function(refresh) {
								_this._qryBillNextPage(refresh);
							}
						};
					} else {
						config = {
							refreshContent: function(refresh) {
								_this._refresher = refresh;
								_this._refreshContent(function(result) {
									_this.finefinance(result);
								});
							}
						};
					}
					_.extend(PTRConfig, config);
					initPTRScroll.call(_this, PTRConfig);

					this.finefinance(prdInfo);
					break;
				case 'selectFund':
					utils.native.talkingDataTrackEvent("2.0产品-智选基金");
					this.ui.productType.eq(2).addClass('on');
					
					//2016-03-03 增加搜索框
					if (this.searchBox.length) {
						this.searchBox.removeClass('dsn');
						if (IS_RUN_ON_DEVICE){
							gap += this.searchBox.outerHeight();
						}
					}

					config = {
						gap: gap,
						refreshContent: function(refresh) {
							_this._refresher = refresh;
							_this.selectFund(true);
						}
					};

					_.extend(PTRConfig, config);
					initPTRScroll.call(_this, PTRConfig);

					this.selectFund(false);
					break;
				case 'goldInvestment':
					//alert('2期黄金投资');
					this.ui.productType.eq(3).addClass('on');
					this.goldInvestment();
					break;
				case 'depositTake':
					utils.native.talkingDataTrackEvent("2.0产品-随存随取");
					this.ui.productType.eq(0).addClass('on');

					config = {
						refreshContent: function(refresh) {
							_this._refresher = refresh;
							_this._refreshContent(function(result) {
								_this.depositTake(result);
							});
						}
					};
					_.extend(PTRConfig, config);
					initPTRScroll.call(_this, PTRConfig);

					this.depositTake(prdInfo);
					break;
			}
		},
		
		//2015-11-04 增加小票翻页
		_qryBillNextPage: function(callback) {
			if (!this.billSwitch || this.ptype !== 'finefinance') return;
			var self = this,
				billData = this.prdInfo.billData,
				billDataList = billData.list || [],
				pageIndex = parseInt(billData.pageIndex, 10),
				totalRows = parseInt(billData.totalRows, 10),
				totalPage = parseInt(billData.totalPage, 10);
			if (!totalPage) {
				totalPage = totalRows ? totalRows / this._emptyData.pageSize : 100;
			}
			if (++pageIndex > totalPage) return;
			if (!Array.isArray(billDataList) || !billDataList.length) return;
			if (this.paging) return;
			this.paging = true;

			billData.pageIndex++;
			ProductsQryModel.qryBillList({
				data: {
					pageSize: this._emptyData.pageSize,
					pageIndex: billData.pageIndex
				}
			}).done(function(res) {
				if (!Array.isArray(res.list) || !res.list.length) return;
				billDataList.push.apply(billDataList, res.list);
				billData.totalRows = res.totalRows;
				billData.totalPage = res.totalPage;

				self.finefinance(self.prdInfo);
			}).always(function() {
				self.paging = false;
				callback && callback();
			});
		},

		//2015-09-06 增加精选基金单独接口
		_refreshFundContent: function(callback) {
			var self = this;
			ProductsQryModel.qryFundPrdInfo().done(function(result) {
				callback && callback(result);
			}).fail(function(e) {
				utils.dialog.toast(e.message);
				self._refresherFun();
			});
		},
		
		_refreshContent: function(callback) {
			var self = this,
				qryArray = [],
				financeTab = (this.billSwitch && self.ptype === 'finefinance');
			qryArray = [ProductsQryModel.queryProduct({
				customType: 2
			})];
			if (financeTab) {
				qryArray.push(ProductsQryModel.qryBillList({
					data: {
						pageSize: this._emptyData.pageSize,
						pageIndex: 1
					}
				}));
			}

			$.when.apply(0, qryArray).done(function(result, res1) {
				result || (result = self._emptyData);
				result.billData = res1 ? res1 : {};
				result.billData.pageIndex = 1;
				self.prdInfo = result;

				callback && callback(result);
			});
		},

		_refresherFun: function() {
			var _this = this;
			clearTimeout(_this._refreshTimer);
			_this._refreshTimer = setTimeout(function() {
				if (_this._refresher) {
					_this._refresher();
				} else {
					_this.scroller && _this.scroller.refresh();
				}
			}, 500);
		},

		/**
		 *
		 * 产品类型选择tab
		 *
		 */
		selectType: function(e) {
			var selectedType = this.$(e.currentTarget);
			if (selectedType.hasClass('on')) return;
			this.ui.productType.removeClass('on');
			selectedType.addClass('on');
			switch (selectedType.index()) {
				case 1:
					App.navigate('products/index/index/finefinance', true);
					break;
				case 2:
					App.navigate('products/index/index/selectFund', true);
					break;
				case 3:
					App.navigate('products/index/index/goldInvestment', true);
					break;
				case 0:
					App.navigate('products/index/index/depositTake', true);
					break;
			}
		},

		/**
		 * 处理产品首页，详情转跳
		 */
		onToProductDetail: function(model) {
			if (!model || !(model instanceof Model)) return;
			var type = model.get('type');
			var isLogin = App.storage.get('isUserLoggedIn');
			model.set('fromPage', 'product');
			switch (type) {
				case 'dht':
					if (!isLogin) {
						App.storage.set('dinghuotong/unlog/index', model);
						App.navigate('dinghuotong/unlog/index', true);
					} else {
						App.storage.set('dinghuotong/unlog/index', model);
						App.navigate('dinghuotong/index/login', true);
					}
					break;
				case 'paY':
					if (!isLogin) {
						App.storage.set('pinganying/payIndexLogin/index', model);
						App.navigate('pinganying/payIndexLogin/index', true);
					} else {
						App.storage.set('pinganying/payIndex/index', model);
						App.navigate('pinganying/payIndex/index', true);
					}
					break;
				case 'fund':
					//2015-09-15 需要翻多页，为提高用户体验，
					//记录当前iscroll currPageY
					if (this.scroller) {
						App.storage.set('prdIndexScrollY', this.scroller.y);
					}

					App.storage.set('products/detail/fund', model);
					App.navigate('products/detail/fund', true);
					break;
				case 'bill':
					//2015-11-04 增加小票详情
					if (!this.billSwitch) return;
					if (this.scroller) {
						App.storage.set('prdIndexScrollY', this.scroller.y);
					}
					App.storage.set('products/detail/billCache', this.prdInfo);
					App.storage.set('products/detail/bill', model);
					App.navigate('products/detail/bill', true);
					break;
				case 'goldbao':
					//2015-09-24 增加黄金宝理财产品
					App.storage.set('products/detail/goldbao', model);
					App.navigate('products/detail/goldbao', true);
					break;
				case 'finance':
				case 'pension':
				case 'pap':
					if (this.scroller) {
						App.storage.set('prdIndexScrollY', this.scroller.y);
					}
					App.storage.set('products/detail/finace', model);
					App.navigate('products/detail/finace', true);
					break;
			}
		},

		/**
		 * 随存随取
		 */
		depositTake: function(processedResult) {
			var _this = this;
			var depositTakeView = new DepositTakeView({
				parent: this,
				processedResult: processedResult
			});

			depositTakeView.on('show', function() {
				_this._refresherFun();

				// 2015-11-02 增加下拉效果
				if (!App.storage.get('prdRefreshed') && processedResult.productList.length) {
					App.storage.set('prdRefreshed', true);
					setTimeout(function() {
						_this.scroller && _this.scroller.scrollTo(0, 50, 750);
						_this._refreshContent(function(result) {
							_this.depositTake(result);
						});
					}, 500);
				}
			});
			this.productsRegion.show(depositTakeView);
		},

		/**
		 * 精选理财
		 */
		finefinance: function(processedResult) {
			var _this = this,
				billData = processedResult.billData,
				prdIndexScrollY = App.storage.remove('prdIndexScrollY'),
				financeTab = (this.billSwitch && this.ptype === 'finefinance');
			var finefinanceView = new FinefinanceView({
				parent: this,
				processedResult: processedResult
			});

			finefinanceView.on('show', function() {
				_this._refresherFun();

				if (_this.scroller) {
					if (prdIndexScrollY) {
						_this.scroller._pos(0, prdIndexScrollY);
					}

					if (financeTab) {
						if (!billData.totalPage ||
							billData.totalPage <= parseInt(billData.pageIndex, 10)
						) {
							_this.scroller.disablePullUpToLoadMore();
						} else {
							_this.scroller.enablePullUpToLoadMore();
						}
					} else {
						_this.scroller.disablePullUpToLoadMore();
					}
				}
			});
			this.productsRegion.show(finefinanceView);
		},

		/**
		 * 智选基金
		 */
		selectFund: function(refresher) {
			var _this = this;
			var fundMaxProfit = App.storage.get('fundMaxProfit:funds');
			if(refresher){
				_this._qrySelectFunds();
			}else{
				if(!fundMaxProfit){
					 _this._qrySelectFunds();
				}else{
					_this.productsRegion.show(new SelectFundView({model:new Model(fundMaxProfit)}));
				}
			}
		},
		
		_qrySelectFunds:function(){
			var _this = this;
			ProductsQryModel.fundMaxProfit().done(function(res) {
				var list = [];
				_.each(res.object.outFundList, function(item,id){
					if(_.indexOf([1, 2, 3, 4], item.dispOrder) != -1)
					list.push(item);
				});
				res.object.outFundList = list;
				App.storage.set('fundMaxProfit:funds', res.object);
				_this.productsRegion.show(new SelectFundView({model:new Model(res.object || {})}));
				_this._refresherFun();
			}).fail(function(e) {
				utils.dialog.toast(e.message);
				_this._refresherFun();
			});
		},
		
		//基金产品
		fundIndex: function(processedResult) {
			var _this = this;
			var fundIndexView = new FundIndexView({
				parent: this,
				processedResult: processedResult
			});

			//2015-09-15 基金精选30条数据，当从详情页返回列表时
			//需要翻多页，为提高用户体验，记录当前iscroll currPageY
			fundIndexView.on('show', function() {
				_this._refresherFun();

				var prdIndexScrollY = App.storage.remove('prdIndexScrollY');
				if (prdIndexScrollY && _this.scroller) {
					_this.scroller._pos(0, prdIndexScrollY);
				}
			});

			this.productsRegion.show(fundIndexView);
		},
		
		/**
		 * 黄金投资
		 */
		goldInvestment: function(processedResult) {
			var goldInvestmentView = new GoldInvestmentView({
				parent: this,
				processedResult: processedResult
			});

			this.productsRegion.show(goldInvestmentView);
		}

	});
});
