/**
 * ex-wuwenjun001 抢购专区
 */
define(function(require, exports, module) {
    var shapeRender = require('mod/common/widget/shapeRender');
    var panicBuyTpl = _.template(require('text!../template/panicBuy.html'));
    var initPTRScroll = require('mod/common/widget/initPTRScroll');
    var accountInfoSta = require("mod/common/accountInfoStatus/accountInfoStatus");
    var ProductsQryModel = require('../model/ProductsQryModel');
    
    module.exports = ItemView.extend({
        className: 'panicBuy',
        template: panicBuyTpl,
        templateHelpers: {
            showEmptyFlag: function() {
                var flag = (!this.panicBuyList.length);
                return flag;
            },
            minAmount: function(minAmount) {
                if (minAmount >= 10000) {
                    return Math.floor(minAmount / 10000) + '<i class="f15 lh12">万元</i>';
                } else {
                    return utils.string.numberFormat(minAmount, 0) + '<i class="f15 lh12">元</i>';
                }
            },
            evalMarkup : function (val) {
                var monthMarkup = Number(val);
                if( -1 === monthMarkup || !val ){
                    monthMarkup = '---';
                }else{
                    monthMarkup = this.splitStr(monthMarkup.toFixed(2)) + '<i class="f15 lh12">'+ this.splitStr(monthMarkup.toFixed(2), 1) +'%</i>';
                }
                return monthMarkup;
            },
            splitStr : function(val, index) {
                if(typeof val !== "string" && typeof val !== "number") return val;
                if(typeof val === "number") val = String(val);
                index = index == null ? 0 : index;
                var strArr = val.split('.'), sStr = strArr[1] ? ('.') + strArr[1] : '.00';
                strArr.splice(1, 1, sStr);
                return strArr[index];
            }
        },
        events: {
            'tap [data-prdcode]': 'toBuy'
        },

        /**
         * 抢购专区数据
         */
        initialize: function(options) {
            this.panicParent = options.parent;
            this._panicBuyList = options.processedResult.ruPurchasePrdInfoList;
            this.lastRefresh = App.storage.get('prdPanicBuyLastRefresh') || Date.now();
        },
        
        serializeData: function() {
            var panicBuyList = this._panicBuyList;
            return {
                panicBuyList: panicBuyList ? panicBuyList : []
            };
        },
        
        onRender: function() {
            this._renderCountDown();
            var ratioremarkEls = this.$('[data-ratioremark]');
            if (ratioremarkEls.length) shapeRender.ratioCircle(ratioremarkEls);
            //iscroll刷新
            this.panicParent._refresherPanic();
        },
        
        /**
         * 渲染倒计时
         */
        _renderCountDown: function() {
            var self = this,
                now = Date.now(),
                countdownEl = this.$('[data-countdown]'),
                lastRefreshEllipsis = parseInt((now - self.lastRefresh) / 1000, 10);
            if (countdownEl.length < 1) return;

            countdownEl.each(function(i, el) {
                el = $(el);
                var day = el.find('.day')[0],
                    hour = el.find('.hour')[0],
                    minute = el.find('.minute')[0],
                    second = el.find('.second')[0];
                var countdown = el.data('countdown');
                var type = el.data('type');
                if (!countdown) return;
                el.show();

                countdown = countdown - lastRefreshEllipsis;
                self.countDownRefresh(countdown, {
                    day: day,
                    hour: hour,
                    min: minute,
                    sec: second
                });
            });
        },
        
        /**
         * 倒计时 
         */
        countDownRefresh : function(remainSeconds, timerEls){
            var self = this;
            var f = {
                timer : null,
                remainSeconds : parseInt(remainSeconds) || 0,
                zero: function(n){
                    var n = parseInt(n, 10);
                    if(n > 0){
                        if(n <= 9){
                            n = "0" + n;
                        }
                        return String(n);
                    }else{
                        return "00";
                    }
                },
                dv: function(){
                    f.remainSeconds--;
    
                    var pms = {
                            day  : "00",
                            sec  : "00",
                            min  : "00",
                            hour : "00"
                        };
                    var remain = f.remainSeconds;
    
                    if (remain <= 0) {
                        clearTimeout(f.timer);
                        delete f;
                        return pms;
                    }
    
                    if(remain > 0){
                        var day = f.zero(Math.floor(remain/(24*3600)));
                        var hour= f.zero(Math.floor((remain-day*24*3600)/3600));
                        var min = f.zero(Math.floor((remain-day*24*3600-hour*3600)/60));
                        var sec = f.zero(Math.floor(remain-day*24*3600-hour*3600-min*60));
                        pms = {
                            day : day,
                            hour : hour,
                            min : min,
                            sec  : sec
                        }
    
                    }
    
                    return pms;
                },
                ui: function(){
                    var pms = f.dv();
                    if(timerEls.sec)   timerEls.sec.innerHTML = pms.sec;
                    if(timerEls.min)  timerEls.min.innerHTML = pms.min;
                    if(timerEls.hour)  timerEls.hour.innerHTML = pms.hour;
                    if(timerEls.day)   timerEls.day.innerHTML = pms.day;
                    if(f.remainSeconds <= 0){
                        var dataPrdCode = $(timerEls.sec).closest("div[data-prdcode]").data("prdcode");
                        var sec = this.$("div[data-prdcode = "+dataPrdCode+"] .second").text();
                        var min = this.$("div[data-prdcode = "+dataPrdCode+"] .minute").text();
                        var hour = this.$("div[data-prdcode = "+dataPrdCode+"] .hour").text();
                        var day = this.$("div[data-prdcode = "+dataPrdCode+"] .day").text();
                        var totalTime = parseInt(sec)+ parseInt(min) +parseInt(hour) +parseInt(day);
                        //倒计时是否到最后1秒00：00：00：00
                        if(totalTime <= 0){
                            clearTimeout(f.timer);
                            self.panicParent.scrollerLoadData({"silent":true});
                        }
                        return;
                    }
                    f.timer=setTimeout(f.ui, 1000);
                }
            };
            f.ui();
        },
        
        /**
         * 购买抢购产品 
         */
        toBuy : function(e){
            var self = this;
            //未达到产品开放购买时间
            if(this.$(e.currentTarget).find("[data-ratioremark = panicStart]").length > 0){
                utils.dialog.toast("即将开售，请耐心等待。");
                return;
            }else if(this.$(e.currentTarget).find("[data-ratioremark = panicEnd]").length){
                utils.dialog.toast("本期产品已售罄，我们正在准备更多产品中，敬请期待。");
                return;
            }
            var prdCode = this.$(e.currentTarget).data("prdcode");
            var panicBuySelData = _.findWhere(this._panicBuyList,{productId:prdCode.toString()});
            //缓存抢购产品信息
            App.storage.set("panicBuySelData",panicBuySelData);
            //是否在登录区内
            if(App.storage.get("isUserLoggedIn")){
                //判断用户是否符合转账条件（挂失、未身份认证、未绑定卡）
                var dfd = accountInfoSta.getAccountInfoStatus(true,"products/index/panicBuy");
                dfd.done(function (accountSta) {
                    if(accountSta){
                        App.navigate("panicBuy/buy/input",true);
                    }
                });
            }else{
                App.navigate(config.base.login_url + "?returnURL=" + "products/index/panicBuy", true);
            }
        }
    });
});
