/**
 * ex-wuyongsheng001 产品首页精选基金视图
 */
define(function(require, exports, module){
    var Tpl = _.template(require('text!../template/selectFund.html'));

    module.exports = ItemView.extend({
        className: 'selectFund',
        template: Tpl,
        events: {
            'tap .iconA224' : 'showTipsDialog', //
            'tap #selectFunds' : '_selectFunds', // 精选基金列表
            'tap .specialFund' : '_specialFund'
        },
        templateHelpers: {
            minAmount : function (minAmount) {
                if (minAmount >= 10000) {
                    return  utils.string.numberFormat(minAmount/10000, 2, '.', '')+'万';
                }else{
                    return  utils.string.numberFormat(minAmount, 2, '.', '')+'';
                }
            },
            evalMarkup : function (val) {
                var monthMarkup = Number(val);
                if( -1 === monthMarkup || !monthMarkup ){
                    monthMarkup = '---';
                }else{
                    monthMarkup = this.splitStr(((monthMarkup - 1)*100).toFixed(2)) + '<i class="f15 lh12">'+ this.splitStr(((monthMarkup - 1)*100).toFixed(2),1)+'%</i>';
                }
                return monthMarkup;
            },
            rateTpl : function (val, flag) {
                var cls = 'c_f60';
                val = Number(val);
                if( -1 === val || !val ){
                    val = '---';
                }else{
                    if ((val - 1) < 0) cls = 'c_3eb';//近三月涨幅计算是(val - 1)才是正确的
                    val = this.splitStr(((val - 1)*100).toFixed(2)) + '<i class="f15 lh12">'+ this.splitStr(((val - 1)*100).toFixed(2), 1) +'%</i>';
                }
                if(flag){
                     return val;
                }else{
                    return '<p class="f28 '+cls+'">'+val+'</p>';
                }
            },
            
            sevenTpl : function (val, flag) {
                var cls = 'c_f60';
                val = Number(val);
                if( -1 === val || !val ){
                    val = '---';
                }else{
                    if (val  < 0) cls = 'c_3eb';//近七日年化计算是(val - 1)才是正确的
                    val = this.splitStr((val*100).toFixed(3)) + '<i class="f15 lh12">'+ this.splitStr((val*100).toFixed(3), 1) +'%</i>';
                }
                if(flag){
                     return val;
                }else{
                    return '<p class="f28 '+cls+'">'+val+'</p>';
                }
            },
            
            splitStr : function(val, index) {
                if(typeof val !== "string" && typeof val !== "number") return val;
                if(typeof val === "number") val = String(val);
                index = index == null ? 0 : index;
                var strArr = val.split('.'), sStr = strArr[1] ? ('.') + strArr[1] : '.00';
                strArr.splice(1, 1, sStr);
                return strArr[index];
            },
            
            rPrdAttrName : function (name) {
                return name && name.replace(/^\s*\u57FA\u91D1/, '');
            },
            /**
             * 1 股票型 2 混合型 3 基金债券型 4 基金货币型 5 基金保本型 6 基金QDII 7 基金其他
             */
            rPrdAttrCls : function (prdAttr) {
                var cls = {
                    '1' : 'Stock',
                    '2' : 'Mix',
                    '3' : 'Bond',
                    '4' : 'Monetary',
                    '5' : 'Guaranteed',
                    '6' : 'QDII',
                    '7' : 'Other'
                };

                prdAttr = (prdAttr + '').trim();
                return cls[prdAttr] || 'Other';
            },
            
           formatData: function (options){
                options.tipShow = '七日年化收益率';
                if((options.seasonMx-1) > options.yield1Mx){
                    options.rate = this.rateTpl(options.seasonMx, true);
                    options.tipShow = '近三月涨幅';
                }else{
                    options.rate = this.sevenTpl(Number(options.yield1Mx), true);
                }
                return options;
            }
        },
        
        initialize: function(options) {
            this.model = this.options.model; 
        },
        
        //单击特色基金类型的提示
		enterTip: function(e) {
            e.stopPropagation();
			var t   = $(e.target);
            var tp   = t.position();
			var p   = t.prev().position();
            var tip = t.next();
            
            tip.find('.AssetsTips').css({"left": p.left});
            $('.AssetsTipsHold').hide();
			tip.show();
            tip.find('i.arrow').css({'left': tp.left + 6});
            
            //3秒后自动关闭提示
            if(this.clearTime) clearTimeout(this.clearTime);
            this.clearTime = setTimeout(function () {
                tip.hide();
            }, 2000);
            
		},
        
        //特色基金类型的提示
		leaveTip: function(e) {
			var tip = this.$("#specialTip");
			tip.hide();
		},
        
        //跳转到精选基金
        _selectFunds:function(){
            App.navigate('products/fund/selectFunds', true);
        },
        
        //特色基金
        _specialFund:function (e) {
            var id = $(e.target).closest('.specialFund').eq(0).attr('specialType') || '201604010000000006';
            var specialOption = _.findWhere(this.model.get('outFundList'), {typeId: id});
            App.storage.set('specialFund::specialOption', specialOption);
            App.navigate('products/fund/specialFunds/' + id, true);
        },
        
        showTipsDialog: function (event) {
            event.stopPropagation(); event.preventDefault();
            if (this.showTips) return;
            var specialID = $(event.target).attr('specialID');
            var specialOption = _.findWhere(this.model.get('outFundList'), {typeId: specialID})
            var self = this,
                str = '<div class="Mask" style="top:0;background:rgba(0,0,0,0.80);z-index:9999;">' +
                    '<div class="center">' +
                    '<div class="zgcMain ">' +
                    '<span class="f22 dsb tac">'+ specialOption.typeName +'</span>' +
                    '<p>'+ specialOption.typeDesc + '</p>' +
                    '<div class="p_10">' +
                    '<input type="button" value="知道了" class="btn_orange m_t5"/>' +
                    '</div>' +
                    '</div>' +
                    '</div>' +
                    '</div>';
            this.showTips = $(str).appendTo('body');

            self.showTips.find('input.btn_orange').on('click', function (e) {
                if(self.clearTime) return;
                self.showTips.remove();
                delete self.showTips;
            });
        }

    });
});