define(function (require, exports, module) {
	var Tpl            = require('text!./detail.html');
	var ModelMargin    = require('../../model/margin');
	var initPTRScroll  = require('mod/common/widget/initPTRScroll');
	var CustomPwdInput = require('component/password/customPwdInput');
	module.exports = ItemView.extend({
		template: Tpl,
		templateHelpers: {
			freezeDays: function (days) {
				days = parseInt(days, 10);
				if (!days) return '0天';
				if (days > 365) {
					return ~~(days / 365) + '年' + (days % 365 ? this.freezeDays(days % 365) : '');
				}
				if (days > 30) {
					return ~~(days / 30) + '个月' + (days % 30 ? this.freezeDays(days % 30) : '');
				}
				return days + '天';
			},
			freezeTypes: function (num) {
				num = parseInt(num, 10);
				switch (num) {
					case 1:
						return '活期';
					case 2:
						return '活期';
					default:
						return '活期';
				}
			}
		},

		events: {
			'tap #agreement'   : 'agreement',
			'tap #agreement a' : 'showAgreement',
			'tap #investNow'   : 'investNow'
		},

		initialize: function () {
			this.isPending = '1' === this.model.get('orderState');
			//初始化余额为0
			this.balance = 0;
		},

		onShow: function () {
			var gap = 75, that = this,
				freezeAmt = this.model.get('freezeAmt');
			if (this.isPending) {
				this.$('[data-countdown]').each(function () {
					var self = $(this);
					var seconds = self.data('countdown');
					if (!seconds) seconds = 1;
					utils.date.countDown(seconds, {
						sec: self.find('.second')[0],
						min: self.find('.minute')[0],
						hour: self.find('.hour')[0],
						day: self.find('.day')[0]
					});
				});
				var bEL = this.$('#balance');
				///*
				ModelMargin.qryBalance().done(function (res) {
					that.balance = parseFloat(res.balance) || 0;
					if (that.balance < freezeAmt) {
						bEL.show().find('span').text(that.balance);
					}
				}).fail(function (err) {
					bEL.find('span').text('---');
				});
				//*/
			}
			//初始化PTRScroll
			if (IS_RUN_ON_DEVICE) gap = 18;
			initPTRScroll.call(this, {
				gap: gap,
				pullDownToRefresh: false,
				pullUpToLoadMore: false
			});
		},

		investNow: function (e) {
			e.preventDefault();
			var self = this,
				remark = this.model.get('remark'),
				isAgree = this.model.get('isAgree'),
				freezeAmt = this.model.get('freezeAmt'),
				activityNo = this.model.get('activityNo'),
				orderNo = App.storage.get('marginOrderNo'),
				commercialNo = this.model.get('commercialNo'),
				freezeProduct = this.model.get('freezeProduct'),
				freezeTimeLimit = this.model.get('freezeTimeLimit');
			if (!this.isPending) return;
			if (!isAgree) {
				utils.dialog.toast('请同意《保证金冻结服务协议》');
				return;
			}
			if (this.balance < freezeAmt) {
				App.storage.set('transInSuccBackUrl', 'search/margin/detail');
				return App.navigate('me/transferIn/assetsTransIn', true);
			}
			var contentText = '本次冻结金额￥' + parseFloat(freezeAmt).toFixed(2);
			CustomPwdInput.customPwdInput(function (pwd) {
				var sm2Pwd = utils.sm2.SM2Key.encrypt(pwd, config.base.sm2_public_key);
				pwd = utils.crypto.RSAKey.encrypt(pwd, config.base.rsa_public_key);
				var finishCallback = function (res) {
					App.storage.set('search/margin/finish', res);
					App.navigate('search/margin/finish', {trigger: true, replace: true});
				};
				var data = {};
				if(self.model.get('prdWay') === 'orderWay'){
					data = {
						pwd     : pwd,
						sm2Pwd  : sm2Pwd,
						orderNo : orderNo
					};
					//2016-04-05 已与后台开发罗小威确认——冻结失败提示信息就用接口字段message;
					ModelMargin.confirmMarginsOrder({
						data: data
					}).done(function (res) {
						res.confirmed = true;
						finishCallback(res);
					}).fail(function (err) {
						finishCallback({remark: err.message});
					});
				}else if(self.model.get('prdWay') === 'bussWays'){
					data = {
						pwd: pwd,
						sm2Pwd: sm2Pwd,
						activityNo: activityNo,
						commercialNo:commercialNo,
						remark: remark,
						freezeProduct: freezeProduct,
						freezeTimeLimit: freezeTimeLimit,
						freezeAmt: freezeAmt
					};
					ModelMargin.createMarginsOrder({
						data: data
					}).done(function (res) {
						res.confirmed = true;
						finishCallback(res);
					}).fail(function (err) {
						finishCallback({remark: err.message});
					});
				}
			}, { contentText: contentText });
		},

		agreement: function (e) {
			if (!this.isPending) return;
			var iconA46 = $(e.currentTarget).find('.iconA46');
			var btn = this.$('#investNow');
			iconA46.eq(0).toggleClass('on').toggleClass('off');
			if (iconA46.hasClass('on')) {
				this.model.set('isAgree', true);
				btn.removeClass('btn_disable');
			} else {
				this.model.set('isAgree', false);
				btn.addClass('btn_disable');
			}
		},

		showAgreement: function (e) {
			e.stopPropagation();e.preventDefault();
			utils.window.open({
				title: '《橙子保证金服务协议》',
				url: 'http://ssl.pingan.com/bank/xieyi/wy/chengbaozhengjin.shtml'
			});
		}
	});
});