define(function(require, exports, module) {
    var Tpl = require('text!./index.html');
    var TplOrderLists = require('text!././orderLists.html');
    var TplBusLists = require('text!././busLists.html');

    var ModelMargin = require('../../model/margin');
    var initPTRScroll = require('mod/common/widget/initPTRScroll');
    var bindCardTip = require('component/bindCardTip');
    module.exports = ItemView.extend({
        template: Tpl,
        events: {
            'tap .activityItem': '_activityItem',
            'tap #listType > .flex1': 'selectType',
            'tap #listRegion [data-orderno]': 'toDetail'
        },

        onShow: function() {
            var options = this.options;

            this.listRegion = this.$('#listRegion');
            this.listTypes = this.$('#listType > .flex1').removeClass('on');
            if (!this.listRegion.length) throw new Error('cannt find #listRegion selector.');

            if ('orderLists' in options) {
                this.listTypes.eq(0).addClass('on');
                this._renderList(TplOrderLists, options.orderLists);
            }else{
                this.listTypes.eq(1).addClass('on');
                var commercialList = _.clone(options.commercialList);
                var bussMargin = this._removeDuplicate(commercialList);
                //从商家入口进去，做个‘bussWays’标识
                _.each(commercialList, function (item) {
                    item.prdWay = 'bussWays';
                    item.orderState = '1';
                    item.businessName = item.activityName;
                    item.sysDate = item.currentDate;
                });
                this._renderList(TplBusLists, commercialList, false, bussMargin);
            }

            //初始化PTRScroll
            initPTRScroll.call(this, {
                gap: 0,
                scroller: 'iscroll',
                pullDownToRefresh: false,
                pullUpToLoadMore: false
            });

            //打个保证金已访问标致
            App.storage.set('search::margin::hasVisited', true);
        },

        toDetail: function(e) {


            var target = this.$(e.currentTarget);
            var orderno = target.attr('data-orderno');
            if (!orderno) return;

            // this._ajustState();

            //激活未绑卡情况下提示取绑卡
            var UserInfo  = App.storage.get('UserInfo'),
                bindState = UserInfo.get('bindState'),
                cardState = UserInfo.get('cardState'),
                activeState  = UserInfo.get('activeState'),
                bindCardFlag = UserInfo.get('bindCardFlag');
            //审核中的提示
            if (cardState === '3') {
                utils.dialog.toast('您的卡正在审核中，请耐心等待。');
                return;
            }

            if (
                bindCardTip.newBindFlag() ||
                (
                    bindCardFlag === '1' && bindState === '0' &&
                    cardState === '1' && activeState === '1'
                )
            ) {
                bindCardTip.activeSwitch();
                return;
            }

            App.storage.set('formBussWays', '1');//进入详情的方式：1.从‘我的订单’， 2.‘支持商家’

            App.storage.set('marginOrderNo', orderno);
            App.navigate('search/margin/detail', true);
        },

        selectType: function(e) {
            var self = this,
                selected = this.$(e.currentTarget);
            if (selected.hasClass('on')) return;

            this.listTypes.removeClass('on');
            selected.addClass('on');
            switch (selected.index()) {
                case 0:
                    ModelMargin.qryMarginsOrderList()
                        .done(function(re) {
                            self._renderList(TplOrderLists, re.orderLists);

                            App.navigate('search/margin/index', { trigger: false });
                        }).fail(function(err) {
                            utils.dialog.toast(err.message || '订单接口异常！');
                        });
                    break;
                case 1:
                    ModelMargin.qryMarginsCommercialList()
                        .done(function(re) {
                            var commercialList = _.clone(re.commercialList);
                            var bussMargin = self._removeDuplicate(commercialList);
                            //从商家入口进去，做个‘bussWays’标识
                            _.each(commercialList, function (item) {
                                item.prdWay = 'bussWays';
                                item.orderState = '1';
                                item.businessName = item.activityName;
                                item.sysDate = item.currentDate;
                            });
                            self._renderList(TplBusLists, commercialList, false, bussMargin);
                            App.navigate('search/margin/indexBus', { trigger: false });
                        }).fail(function(err) {
                            utils.dialog.toast(err.message || '商家接口异常！');
                        });
                    break;
            }


        },

        //去重复(由于用户返回)
        _removeDuplicate: function (options) {
            var bussType = [], i = 0;
            for(i; i<options.length; i++){
                var option = _.pick(options[i], 'commercialName', 'commercialNo', 'commercialDesc', 'orderNumber');
                if(_.findWhere(bussType, option)) continue;
                bussType.push(option);
            }
            return _.sortBy(bussType, 'orderNumber');
        },

        _renderList: function(tpl, list, append, bussMargin) {
            if (!tpl) return;
            append = !!append ? 'append' : 'html';
            var html = '';
            var dataList = {
                list: list || [],
                bussMargin: bussMargin || []
            };
            if (append === 'append') {
                this.listArray.push(dataList.list);
            } else {
                this.listArray = dataList.list;
            }

            html = _.template(tpl, dataList);
            this.listRegion[append](html);

            if(this.iscroll){this.iscroll.refresh();}

            this.listRegion.find('[data-countdown]').each(function() {
                var self = $(this);
                var seconds = self.data('countdown');
                if (!seconds) seconds = 1;
                utils.date.countDown(seconds, {
                    sec: self.find('.second')[0],
                    min: self.find('.minute')[0],
                    hour: self.find('.hour')[0],
                    day: self.find('.day')[0]
                });
            });
        },

        _activityItem: function (e) {

            //this._ajustState();

             //激活未绑卡情况下提示取绑卡
            var UserInfo = App.storage.get('UserInfo'),
                bindState = UserInfo.get('bindState'),
                cardState = UserInfo.get('cardState'),
                activeState = UserInfo.get('activeState'),
                bindCardFlag = UserInfo.get('bindCardFlag');
            //审核中的提示
            if (cardState === '3') {
                utils.dialog.toast('您的卡正在审核中，请耐心等待。');
                return;
            }

            if (
                bindCardTip.newBindFlag() ||
                (
                    bindCardFlag === '1' && bindState === '0' &&
                    cardState === '1' && activeState === '1'
                )
            ) {
                bindCardTip.activeSwitch();
                return;
            }

            var activityNo = $(e.target).closest(".activityItem").attr('activityNo');
            var activityItem = _.findWhere(this.listArray, {activityNo: activityNo});
            App.storage.set('bussWays::activityItem', activityItem);
            App.navigate('search/margin/activityItem', true);
        }
    });

});
