define(function(require, exports, module){
    var IndexTpl = require("text!../template/payIndex.html");
    var payYieldCharts = require("../view/payYieldCharts");
    var payModel = require("../model/payModel");
    var FormComponent  = require("component/form");
    var FUND_CODE_NANFANG = config.values.fund_code_nanfang;
    var FUND_CODE_DAHUA   = config.values.fund_code_dahua;
    
    var IndexView = module.exports = FormComponent.extend({
        template : _.template(IndexTpl),
        events:{
        	"tap #sevenYield" : "_periodYearYield",
        	"tap #oneMonthYield" : "_periodYearYield",
        	"tap #threeMonthYield" : "_periodYearYield",
        	"tap #dhTab" : "_changeTab",
        	"tap #nfTab" : "_changeTab",
        	"tap #productInstructions" : "_showProInstructions",
        	"tap #yieldInstructions" : "_showProInstructions",
        	"tap #moneyInstructions" : "_showProInstructions",
        	"tap #holdAssetsLi":"_toAssetsDetails",
        	"tap #totalYieldsLi":"_toYieldDetails",
        	"tap #payTransOut":"_toTransOut",
        	"tap #payTransIn" : "_toTransIn",
        	"click .pay-entrust-revoke" : "_payEntrustRevoke"  //平安盈委托撤销    
        },
        
        regions:{
        	contentRegion :"#contentRegion"
        },
        
        onRender:function(){
        	this._showPayDetail();
        },
        
        //展示平安盈首页
        _showPayDetail:function(){
        	
        	//首页传过来的数据
        	var indexModel = App.storage.get("pinganying/payIndexLogin/index");
        	var proCode = FUND_CODE_DAHUA;
        	if(indexModel){
	        	proCode = indexModel.attributes.prdCode;
        	}
        	var options = {qryType:"7", prdCode:proCode};//初始化数据
        	
        	//初始化七日年化率和万份收益
        	this._paySevenYield(options);
        	
        	//初始化七日年化率(七日、一月、三月)
        	this._payYearYield(options);
        	
        	//查询个人信息
        	this._userYieldInfo(options);
        	
        	//可撤销委托
        	this._fundCancelCommision(options);
        	
        },
        
        //展示七日年化收益率和份分收益(大华、南方)
        _paySevenYield:function(options){
        	var self = this;
        	payModel.paySevenYeildQry({
        		url:"qryPaYingInfo",
        		data:options,
        		callback:function(res){
        			var prdList = res.prdList;
        			self.$("#wfProfit").html(prdList[0].incomeUnit);
        			self.$("#profitYield").html(prdList[0].sevenIncomeRate);
        		},
        		errorCallback:function(res){
        			utils.dialog.alert(response.message);
        		}
        	});
        },
        
        //七日年化收益率（南方-大华：七日、一个月、三个月）
        _payYearYield:function(options){
        	var self = this;
        	payModel.payYearYield({
        		url:"qryPaYingIncomeList",
        		data:options,
        		callback:function(res){
        			res.servenIncomeList = self._averageSevenPoint(res.servenIncomeList);
        			self._showYieldChart(self, res);
        		},
        		errorCallback:function(res){
        			utils.dialog.alert(response.message);
        		}
        	});
        },
        
        //取根据查询月份取七日、一月、三月的年华收益率,取一个数组中的七个点
        _averageSevenPoint:function(dataArray){
        	var sevenPoints = [];
        	if(dataArray.length < 8 && dataArray.length > 0){
        		return dataArray.reverse();
        	}else if (dataArray.length >= 8){
        		var firstIndex = 0
        		var lastIndex = dataArray.length - 1;
        		var middleIndex = parseInt(lastIndex/2);
        		var averageModel = Math.ceil((lastIndex - firstIndex)/7);
        		sevenPoints.push(dataArray[lastIndex]);
        		sevenPoints.push(dataArray[lastIndex - averageModel]);
        		sevenPoints.push(dataArray[middleIndex + averageModel]);
        		sevenPoints.push(dataArray[middleIndex]);
        		sevenPoints.push(dataArray[middleIndex - averageModel]);
        		sevenPoints.push(dataArray[firstIndex + averageModel]);
        		sevenPoints.push(dataArray[firstIndex]);
	        	return sevenPoints;
        	}
        },
        
        //展示highcharts数据
        _showYieldChart:function(_this, options){
        	_this.contentRegion.show(new payYieldCharts({
                view:_this,
                data:options,
                model:new Model(options)
        	}));
        },
        
        //用户已登陆的收益、账号信息（大华-南方：昨日收益、持有资产、累积收益）
        _userYieldInfo:function(options){
        	var self = this;
        	var url ="";
        	var yesterdayIncome ="";
        	var payDeposit = "";
        	var payTotalincome = "";
        	if(options.prdCode == FUND_CODE_DAHUA){
        		url = "paydhProductMoneyQry";
        		payDeposit = "paydhDeposit";
        		yesterdayIncome = "yesterdaydhIncome";
        		payTotalincome = "paydhTotalincome";
        	}else{
        		url = "paynfProductMoneyQry";
        		payDeposit = "paynfDeposit";
        		yesterdayIncome = "yesterdaynfIncome";
        		payTotalincome = "paynfTotalincome";
        	}
        	payModel.userYieldInfo({
        		url:url,
        		data:options,
        		callback:function(res){
        			if(options.prdCode == FUND_CODE_DAHUA){
		        		self.$("#yesProfit").html(res.yesterdaydhIncome);
        				self.$("#totalAssets").html(res.paydhDeposit);
        				self.$("#totalYields").html(res.paydhTotalincome);
		        	}else{
		        		self.$("#yesProfit").html(res.yesterdaynfIncome);
        				self.$("#totalAssets").html(res.paynfDeposit);
        				self.$("#totalYields").html(res.paynfTotalincome);
		        	}
        		},
        		errorCallback:function(res){
    				self.$("#yesProfit").html("--");
        			self.$("#totalAssets").html("--");
        			self.$("#totalYields").html("--");
        			utils.dialog.alert(response.message);
        		}
        	});
        },
        
        //平安盈编号
        _queryProCode:function(e){
        	var proCode = FUND_CODE_DAHUA;
        	if(this.$("#dhTab").hasClass("on")){
        		proCode = FUND_CODE_DAHUA;
        	}else{
        		proCode = FUND_CODE_NANFANG;
        	}
        	return proCode;
        },
        
        //七日、一月、三月年化收益率(大华、南方), e:事件源
        _periodYearYield:function(e){
        	var options = {};
        	//南方、大华标识
        	if(this.$(e.currentTarget).attr("id") == "sevenYield"){
        		options.qryType = '7';	
        	}else if(this.$(e.currentTarget).attr("id") == "oneMonthYield"){
        		options.qryType = '1';
        	}else{
        		options.qryType = '3';
        	}
        	this.$(e.currentTarget).addClass("on").siblings().removeClass("on");
        	//大华、南方标识
        	options.prdCode = this._queryProCode();
        	this._payYearYield(options);
        },
        
        //大华、南方页签 e:事件源
        _changeTab:function(e){
        	var options = {};
        	
        	if(this.$(e.currentTarget).attr("id") == "dhTab"){
        		options.prdCode = FUND_CODE_DAHUA;
        	}else if(this.$(e.currentTarget).attr("id") == "nfTab"){
        		options.prdCode = FUND_CODE_NANFANG;
        	}
        	
        	this.$(e.currentTarget).addClass("on").siblings().removeClass("on");
        	this.$("#sevenYield").addClass("on").siblings().removeClass("on");
        	
        	//昨日万份收益、昨日年华收益率
        	this._paySevenYield(options);
        		
        	this._userYieldInfo(options);//查询用户持有资产、昨日收益、累计收益
        	this._fundCancelCommision(options);//查询可撤销列表
        	
        	options.qryType = "7"; //初始化年化率 7:为七日年化率、1:一月年化率、3:三月年化率
        	this._payYearYield(options);
        },
        
        //产品介绍、收益到账说明、资金到账说明 e:事件源
        _showProInstructions:function(e){
        	
        	if(this.$(e.currentTarget).find("i").hasClass("on")){
        		//隐藏
        		this.$(e.currentTarget).find("i").removeClass("on");
        		this.$(e.currentTarget).siblings().hide();
        	}else{
        		//展示
        		this.$(e.currentTarget).find("i").addClass("on");
        		this.$(e.currentTarget).siblings().show();
        	}
        },
        //可撤销查询
        _fundCancelCommision:function(options){
        	var self = this;
        	payModel.queryFundCancelCommision({
        		url:"queryFundCancelCommision",
        		data:options,
        		callback:function(res){
        			var fundCancelCommisionList = res.transferRecordList;
					if(fundCancelCommisionList.length != 0){
						self.$("#cancelComment>p").first().siblings().remove();
	        			var showCancelCommisionHtml = "";
	        			for (var i=0; i < fundCancelCommisionList.length; i++) {
						  var cancelAmt = fundCancelCommisionList[i].fundShare;
						  showCancelCommisionHtml += 
	                			"<p class='f28 c_000 h38'><span>"+ cancelAmt +"</span>" + 
	                				"<a class='UndoBtn f12 pay-entrust-revoke' entrust-seqNo='"+fundCancelCommisionList[i].seqNo+"' entrust-fundShare='"+fundCancelCommisionList[i].fundShare+"' entrust-date='"+fundCancelCommisionList[i].applyDate +"' style='margin-left:0px;'>撤销</a>" +
	                			"</p>";
						}
						self.$("#cancelComment").height(45 * fundCancelCommisionList.length);
						self.$("#cancelComment").append(showCancelCommisionHtml);
					}else{
						self.$("#cancelComment").hide();
					}
        		},
        		errorCallback:function(res){
        			utils.dialog.alert(res.message);
        		}
        	});
        },
        
	    //平安盈委托撤销
        _payEntrustRevoke:function(e){
        	var self = this;
            if(utils.string.interceptLoss()) return ;
        	var target = e.currentTarget;
            var options = {
                assoSerial: this.$(target).attr("entrust-seqNo"),
                yebFlag   : 1
            };
                          
            utils.dialog.dialogConfirm({
            	message:"点击确定则将转出款撤销至持有资产", 
            	title:"您确定撤销转出吗？",
            	params: options,
            	callback: _.bind(self._payEntrustSubmit, self)
            });
        },
        
        //提交撤销
        _payEntrustSubmit:function(options){
        	var self = this;
        	var proCode = this._queryProCode();
            payModel.entrustCommision4PAY(options).done(_.bind(function(res){
            	//刷新数据
            	this.$("#cancelComment>p").first().siblings().remove();
            	var param = {prdCode:proCode, pageSize:50};
	        	self._fundCancelCommision(param);
                utils.dialog.toast("撤销成功");
            },this)).fail(function(error){
                utils.dialog.alert(error.message);
            });
        },
     
        //跳转到资产详情页面
        _toAssetsDetails:function(){
        	var prdCode = this._queryProCode();
        	App.navigate("pinganying/payIndex/assetsDetails/"+ prdCode, true);
        },
        //跳转到收益详情页面
        _toYieldDetails:function(){
        	var proCode = this._queryProCode();
        	App.navigate("pinganying/payIndex/yieldDetails/"+ proCode, true);
        },
        
        //平安盈转出
        _toTransOut:function(){
        	if(App.storage.get("transOutTempData")){
        		App.storage.remove("transOutTempData");
        	}
        	var proCode = this._queryProCode();
        	App.navigate("pinganying/payIndex/payTransOut/"+ proCode, true);
        },
        
        //平安盈转入
        _toTransIn : function() {
            var proCode = this._queryProCode();
            App.navigate("pinganying/payIndex/payTransferIn/"+proCode, true);
        }
        
    });
})
