define(function (require, exports, module) {
    var Bank2stockVerifyTpl = require("text!../template/bank2StockVerify.html");
    var stockModel = require("../model/stockModel");
    var accountModel = require("mod/common/model/accountModel");
    var safeKeyBoardHelper = require("component/customInput.helper");
    var CustomPwdInput = require("component/password/customPwdInput");

    var Bank2stockVerifyView = module.exports = ItemView.extend({
        template: _.template(Bank2stockVerifyTpl),
        events: {
            "tap #submit_b2s": "submitB2s",
            "customInputFocusIn #b2sAmount": "customInputFocusInAmount",
            "customInputFocusOut #b2sAmount": "customInputFocusOutAmount"
        },
        onShow: function () {
            this.showSafeKeyBoardAmount();
            this.requestBalance();
        },

        showSafeKeyBoardAmount: function () {
            this.$("#b2sAmount").customInput({
                type: "decimal",
                placeholder: "请输入转入金额",
                maxLength: 12,
                className: "safeKeyBoard"
            });
        },

        customInputFocusInAmount: function () {
            safeKeyBoardHelper.focusIn({
                id: "b2sAmount"
            });
            // var el=safeKeyBoardHelper.getSelector("b2sAmount");
            // el.addClass("focusBlue");
        },
        customInputFocusOutAmount: function () {
            safeKeyBoardHelper.focusOut({
                id: "b2sAmount"
            });
            // var el=safeKeyBoardHelper.getSelector("b2sAmount");
            // el.removeClass("focusBlue");
        },

        /**
         * 获取活余额
         */
        requestBalance: function () {
            var self = this;
            accountModel.asycAccountInfo({
                silent: true,
                cache: false,
                callback: function (response) {
                    var balance = response.object.balance;
                    var html = '';
                    var balanceHTML = utils.string.moneyFormatHTML({
                        bigFontClass: "f21",
                        smallFontClass: "f16",
                        money: balance
                    });
                    html += '<span class="f16">￥</span>';
                    html += balanceHTML;
                    self.$("#balance").html(html).attr({"data-balance": balance});
                },
                errorCallback: function (response) {
                    utils.dialog.alert(response.message);
                    self.$("#balance").html(response.message);//.removeAttr("data-balance");
                }
            });
        },

        _verifyData: function () {
            var transferAmt = $("#b2sAmount").customInput("value").replace(/,/g, "");
            var balance = $("#balance").attr("data-balance") ? $("#balance").attr("data-balance").replace(/,/g, "") : 0;
            if (transferAmt == "") {
                safeKeyBoardHelper.setCustomValidity({ id: "b2sAmount", message: "请输入转入金额"});
                return false;
            }
            if (parseFloat(transferAmt) > parseFloat(balance)) {
                safeKeyBoardHelper.setCustomValidity({ id: "b2sAmount", message: "余额不足" });
                return false;
            }
            return true;
        },

        _submit: function (pwd) {
            var password = utils.crypto.RSAKey.encrypt(pwd, config.base.rsa_public_key);
            var sm2Pwd = utils.sm2.SM2Key.encrypt(pwd, config.base.sm2_public_key);
            var transferAmt = $("#b2sAmount").customInput("value").replace(/,/g, "");
            var balance = $("#balance").attr("data-balance") ? $("#balance").attr("data-balance").replace(/,/g, "") : 0;
            utils.native.talkingDataTrackEvent("2.0发现-证券三方存管-银转证-录入转账信息");
            stockModel.bankToSecurities({
                "url": "bankToSecurities",
                "data": {
                    "stkCode": this.model.get("stkCode"),
                    "curCode": this.model.get("curCodeText"),
                    "tranAmount": transferAmt,
                    "stkAcct": this.model.get("stkAcct"),
                    "bankPwd": password,
                    "sm2Pwd": sm2Pwd
                },
                "callback": function (res) {
                    //App.storage.remove("bank2stock_stockAccList");
                    App.storage.set("bank2stock_verify_data", res.object);
                    App.navigate('stock/stock/bank2StockSuccess', true);
                },
                "errorCallback": function (res) {
                    utils.dialog.alert(res.message);
                }
            });
        },

        submitB2s: function (e) {
            var self = this;
            if (this._verifyData()) {
                CustomPwdInput.customPwdInput(function (pwd) {
                    self._submit(pwd)
                });
            }
        }

    });
});