define(function (require, exports, module) {
    var PrespecifiedVerifyTpl = require("text!../template/prespecifiedVerify.html");
    var FormComponent = require("component/form");
    var stockModel = require('../model/stockModel');
    var safeKeyBoardHelper = require("component/customInput.helper");

    var PrespecifiedVerifyView = module.exports = FormComponent.extend({
        template: _.template(PrespecifiedVerifyTpl),
        events: {
            "tap #pactCheck": "pactCheck",
            "tap #servicePact": "openService",
            "tap #submit_psv": "submitStock",
            "customInputFocusIn #czpwd": "customInputFocusInCz",
            "customInputFocusOut #czpwd": "customInputFocusOutCz",
            "customInputFocusIn #zqpwd": "customInputFocusInZq",
            "customInputFocusOut #zqpwd": "customInputFocusOutZq"
        },
        onShow: function () {
            this.showSafeKeyBoardCz();
            this.showSafeKeyBoardZq();
        },

        showSafeKeyBoardCz: function () {
            this.$("#czpwd").customInput({
                type: "password-number",
                placeholder: "输入橙子交易密码",
                maxLength: 6,
                className: "safeKeyBoard"
            });
        },
        showSafeKeyBoardZq: function () {
            this.$("#zqpwd").customInput({
                type: "password-number",
                placeholder: "输入证券资金账户密码",
                maxLength: 6,
                className: "safeKeyBoard"
            });
        },

        customInputFocusInCz: function () {
            safeKeyBoardHelper.focusIn({
                id: "czpwd"
            });
            // var el=safeKeyBoardHelper.getSelector("czpwd");
            // el.addClass("focusBlue");
        },
        customInputFocusOutCz: function () {
            safeKeyBoardHelper.focusOut({
                id: "czpwd"
            });
            // var el=safeKeyBoardHelper.getSelector("czpwd");
            // el.removeClass("focusBlue");
        },
        customInputFocusInZq: function () {
            safeKeyBoardHelper.focusIn({
                id: "zqpwd"
            });
            // var el=safeKeyBoardHelper.getSelector("zqpwd");
            // el.addClass("focusBlue");
        },
        customInputFocusOutZq: function () {
            safeKeyBoardHelper.focusOut({
                id: "zqpwd"
            });
            // var el=safeKeyBoardHelper.getSelector("zqpwd");
            // el.removeClass("focusBlue");
        },

        submitStock: function (e) {
            utils.native.talkingDataTrackEvent("2.0发现-证券三方存管-预指定确认-校验密码");
            var self = this;
            if ($(e.currentTarget).hasClass("btn_disable")) return;
            if (this._verifyData() && !this.submitFlag) {
                this.submitFlag = true;
                var czPwd = this.$("#czpwd").customInput("value");
                var zqPwd = this.$("#zqpwd").customInput("value");
                stockModel.instructionConfirm({
                    "url": "instructionConfirm",
                    "data": {
                        "invName": this.model.get("custName"),
                        "idType": this.model.get("idType"),
                        "invIdCode": this.model.get("idCode"),
                        "secCompCode": this.model.get("stkCode"),
                        "capAcct": this.model.get("stkAcct"),
                        //"cardId"    : App.storage.get("UserInfo").get("accNumber"),
                        "stkAcctPwd": utils.crypto.RSAKey.encrypt(zqPwd, config.base.bkey),
                        "bankPwd": utils.crypto.RSAKey.encrypt(czPwd, config.base.rsa_public_key),
                        "sm2Pwd": utils.sm2.SM2Key.encrypt(czPwd, config.base.sm2_public_key)
                    },
                    "callback": function (res) {
                        App.storage.remove("prespecifiedInfoItem");
                        App.navigate('stock/stock/prespecifiedSuccess', true);
                    },
                    "errorCallback": function (res) {
                        utils.dialog.alert(res.message);
                        self.submitFlag = false;
                    }
                });
            }
        },

        _verifyData: function () {
            var czPwd = this.$("#czpwd").customInput("value");
            var zqPwd = this.$("#zqpwd").customInput("value");
            var ckBox = this.$("#pactCheck").children().eq(0);

            if (czPwd == "") {
                safeKeyBoardHelper.setCustomValidity({ id: "czpwd", message: "请输入橙子交易密码！" });
                return false;
            }
            if (zqPwd == "") {
                safeKeyBoardHelper.setCustomValidity({ id: "czpwd", message: "请输入证券资金账户密码！" });
                return false;
            }
            if (!ckBox.hasClass("on")) {
                utils.dialog.toast("请阅读并同意协议");
                return false;
            }
            return true;
        },

        /**
         * 打开服务协议
         */
        openService: function (e) {
            e.stopPropagation();
            utils.window.open({
                title: "《服务协议》",
                url: "https://ssl.pingan.com/bank/xieyi/zt/yuzhiding.html"
            });
        },

        /**
         * 同意或不同意协议
         */
        pactCheck: function (e) {
            var ckBox = this.$("#pactCheck").children().eq(0);
            if (ckBox && ckBox.hasClass('on')) {
                this.$("#submit_psv").prop('disabled', true).removeClass('btn_orange').addClass('btn_disable');
            } else {
                this.$("#submit_psv").prop('disabled', false).removeClass('btn_disable').addClass('btn_orange');
            }
            ckBox.toggleClass("on");
        }

    });
});