define(function(require, exports, module){
    var Stock2BankVerifyTpl = require("text!../template/stock2BankVerify.html");
    var FormComponent       = require("component/form");
    var stockModel          = require('../model/stockModel');
    var accountModel        = require("mod/common/model/accountModel");
    var safeKeyBoardHelper  = require("component/customInput.helper");
    var CustomPwdInput      = require("component/password/customPwdInput");

    var Stock2BankVerifyView = module.exports = ItemView.extend({
        template : _.template(Stock2BankVerifyTpl),
        events:{
            "tap #submit_b2s"                : "submitB2s",
            "tap #showBalance"               : "showStockBalance",
            "tap #hideBalance"               : "hideStockBalance",
            "customInputFocusIn #s2bAmount"  : "customInputFocusInAmount",
            "customInputFocusOut #s2bAmount" : "customInputFocusOutAmount"
        },
        onShow: function(){
            this.showSafeKeyBoardAmount();
            //this.requestBalance();
        },

        showSafeKeyBoardAmount:function(){
            this.$("#s2bAmount").customInput({
               type: "decimal",
               placeholder: "请输入转出金额",
               maxLength: 12,
               className:"safeKeyBoard"
            });
        },

        customInputFocusInAmount:function(){
            safeKeyBoardHelper.focusIn({
                id:"s2bAmount"
            });
            // var el=safeKeyBoardHelper.getSelector("s2bAmount");
            // el.addClass("focusBlue");
        },
        customInputFocusOutAmount:function(){
            safeKeyBoardHelper.focusOut({
                id:"s2bAmount"
            });
            // var el=safeKeyBoardHelper.getSelector("s2bAmount");
            // el.removeClass("focusBlue");
        },

        /**
         * 隐藏证券可用余额
         */
         hideStockBalance: function(){
            utils.dialog.confirm("您确定要隐藏证券资金账户可用余额吗？",function(ok){
                console.log(ok);
                if(ok){
                    $("#stockBalance").html("");
                    $("#hideBalance").hide();
                    $("#showBalance").show();
                }
            });
         },

        /**
         * 获取证券可用余额
         */
        showStockBalance: function(){
            utils.native.talkingDataTrackEvent("2.0发现-证券三方存管-证转银-输入证券密码");
            var self=this;
            CustomPwdInput.customPwdInput(function(pwd){
                utils.native.talkingDataTrackEvent("2.0发现-证券三方存管-证转银-查看证券余额");
                stockModel.qrySecuritiMoney({
                    "url" : "qrySecuritiMoney",
                    "data": {
                        //"cardNo"     : App.storage.get("UserInfo").get("accNumber"),
                        "stkCode"    : self.model.get("stkCode"),
                        "range"      : "1",
                        "curCode"    : self.model.get("curCodeText"),
                        "stkAcct"    : self.model.get("stkAcct"),
                        "stkAcctPwd" : utils.crypto.RSAKey.encrypt(pwd,config.base.bkey)
                    },
                    callback:function(response){
                        //availBalance 可用余额
                        //actCashAvailLimit 实际取现可用额度
                        //manageAcctBalance 管理账户余额

                        var balance=response.object.rMBAvailBal;
                        var html='';
                        var balanceHTML=utils.string.moneyFormatHTML({
                            bigFontClass:"f20",
                            smallFontClass:"f16",
                            money:balance
                        });
                        html+='<span class="f16">￥</span>';
                        html+=balanceHTML;
                        self.$("#stockBalance").html(html).attr({"data-actCashAvailLimit": balance});
                        self.$("#hideBalance").show();
                        self.$("#showBalance").hide();
                    },
                    errorCallback: function(response){
                        utils.dialog.alert(response.message);
                    }
                });
            },{"titleText":"请输入证券资金账号密码"});
        },

        /**
         * 获取活期余额
         */
        requestBalance: function(){
            var self=this;
            accountModel.asycAccountInfo({
                silent:true,
                cache:false,
                callback:function(response){
                    var balance=response.object.balance;
                    var html='';
                    var balanceHTML=utils.string.moneyFormatHTML({
                        bigFontClass:"f20",
                        smallFontClass:"f16",
                        money:balance
                    });
                    html+='<span class="f16">￥</span>';
                    html+=balanceHTML;
                    self.$("#balance").html(html).attr({"data-balance": balance});
                },
                errorCallback: function(response){
                    utils.dialog.alert(response.message);
                    self.$("#balance").html(response.message);//.removeAttr("data-balance");
                }
            });
        },

        _verifyData: function(){
            var transferAmt = $("#s2bAmount").customInput("value").replace(/,/g, "");
            //var balance     = $("#balance").attr("data-balance")?$("#balance").attr("data-balance").replace(/,/g, ""):0;
            if(transferAmt == ""){
               safeKeyBoardHelper.setCustomValidity({ id:"s2bAmount", message:"请输入转出金额"});
               return false;
           }
           // if(parseFloat(transferAmt)>parseFloat(balance)){
               // safeKeyBoardHelper.setCustomValidity({ id:"s2bAmount", message:"余额不足" });
               // return false;
           // }
           return true;
        },

        _submit: function(pwd){
            var password    = utils.crypto.RSAKey.encrypt(pwd,config.base.bkey);
            var transferAmt = $("#s2bAmount").customInput("value").replace(/,/g, "");
            //var balance     = $("#balance").attr("data-balance")?$("#balance").attr("data-balance").replace(/,/g, ""):0;
            stockModel.securitiesToBank({
                "url" : "securitiesToBank",
                "data": {
                    //"cardId"          : App.storage.get("UserInfo").get("accNumber"),
                    "stkAcct"    : this.model.get("stkAcct"),
                    "ccyCode"    : this.model.get("curCodeText"),
                    "tranAmount" : transferAmt,
                    "stkCode"    : this.model.get("stkCode"),
                    "stkAcctPwd" : password
                },
                "callback": function(res){
                    //App.storage.remove("stock2bank_stockAccList");
                    App.storage.set("stock2bank_verify_data",res.object);
                    App.navigate('stock/stock/stock2BankSuccess', true);
                },
                "errorCallback": function(res){
                    utils.dialog.alert(res.message);
                }
            });
        },

        submitB2s: function(e){
            var self = this;
            if(this._verifyData()){
                CustomPwdInput.customPwdInput(function(pwd){self._submit(pwd);},{"titleText":"请输入证券资金账号密码"});
            }
        }

    });
});