define(function (require, exports, module) {
	var temp = require("text!../../template/newActive/bindCardAuth.html");
	var OtpView = require("component/otp/OtpView");
	var FormComponent = require("component/form");
	var IdentityModel = require("../../model/identityModel");
	var safeKeyBoardHelper = require("component/customInput.helper");

	module.exports = FormComponent.extend({
		template: _.template(temp),
		events: {
			'tap #bankInfo': '_tobankInfo',
			'input #mobile': '_setFullFill',
			'tap #nextStepBtn': '_toSubmit',
			'tap #unionPayLink': '_toUionPay',
			'input #otp_passWord': '_setFullFill',
			'customInputKeyup #transPwd': '_setFullFill',
			'jsClearIconHandler #transPwd': '_setFullFill',
			'customInputFocusIn #transPwd': '_customInputPwdFocusIn',
			'customInputFocusOut #transPwd': '_customInputPwdFocusOut',
		},

		initialize: function (options) {
			this.model = options.model;
			this.submitFlag = false;
		},

		onRender: function () {
			this.bankFlag = this.model.attributes.bankFlag; //0:本行， 1：他行
			var bankCode = this.model.attributes.bankCode;
			this.otpFlag = this.model.attributes.otpFlag; //本行是否发送OPT
			if (this.bankFlag === '0') this._showSafeKeyBoard();
			this.bankCodeArr = ["308", "306", "305", "304"]; //招行308、广发306、华夏304、民生305

			//他行：如果是这四家银行走老流程，不发OTP，不展示手机号；其他的走新流程，输入手机号和OTP
			//本行：根据后台返回是否发送OTP标识， 1:发送， 0:不发送
			if ((this.bankFlag == 0 && this.otpFlag == 1)
				|| (this.bankFlag == 1 && this.bankCodeArr.indexOf(bankCode) == -1)) {
				this._showOTP();
			}

			//他行无卡BIN情况
			var bankOption = App.storage.get("verifyIdentity/bankOption");
			if (bankOption) {
				this.$('#bankInfo').html(bankOption.recBankName);
				this.model.set('bankCode', bankOption.recBankId);
				this.model.set('bankName', bankOption.recBankName);
				if (this.bankCodeArr.indexOf(bankOption.recBankId) != -1) {
					this.$('#transPwd, #transOtp, #mobileLi').hide();
				}
			}

			this._setFullFill(null, true);
		},


		//input事件控制提交按钮是否disabled
		_setFullFill: function (event, flag) {
			var mobileVal = this.$("#mobile").val();
			if (mobileVal) mobileVal = mobileVal.replace(/\s/g, "");
			var mobile = this.model.attributes.mobile ? this.model.attributes.mobile : mobileVal;
			var bankCode = this.model.attributes.bankCode;
			var bankName = this.model.attributes.bankName;
			var code = this.$('#otp_passWord').val();
			var self = this;
			var btnFun = function (btnFlag) {
				if (btnFlag) {
					self.enabledBtn();
				} else {
					self.disabledBtn();
				}
			}

			if (flag) {
				btnFun(this.bankCodeArr.indexOf(bankCode) != -1 && bankCode && bankName);
				return;
			}

			//本行高级网银手机号和橙子手机号不匹配需验证OTP， 本行需要验证借记卡密码
			if (this.bankFlag === '0') {
				var transPwd = this.$("#transPwd").customInput('value');
				if (this.otpFlag === '1') {
					btnFun(code && transPwd);
				} else {
					btnFun(transPwd);
				}
			} else { //他行（除了四家银行：招行308、广发306、华夏304、民生305）需验证OTP
				if (this.bankCodeArr.indexOf(bankCode) == -1) {//非四家银行
					btnFun(bankCode && bankName && code && mobile);
				} else {
					btnFun(bankCode && bankName);
				}
			}
		},

		disabledBtn: function () {
			if (this.$('#nextStepBtn').hasClass("btn_orange")) this.$('#nextStepBtn').removeClass('btn_orange');
			this.$('#nextStepBtn').addClass("btn_disable");
		},

		enabledBtn: function () {
			if (this.$('#nextStepBtn').hasClass("btn_disable")) this.$('#nextStepBtn').removeClass('btn_disable');
			this.$('#nextStepBtn').addClass("btn_orange");
		},

		_validMobile: function (mobile) {
			if (!mobile) {
				utils.dialog.toast("请输入手机号。");
				return false;
			}
			if (mobile && !utils.validate.phone(mobile)) {
				utils.dialog.toast("你输入的手机号不符合规范。");
				return false;
			}
			return true;
		},

		//OTP展示
		_showOTP: function () {
			var options = {
				isOtpSended: true,
				isNeedSendOtpValidate: false,
				isQryOtpPhoneNo: false, //不调用接口查询手机号码
				otpEnable: null,
				isMobilePhoneByUser: true, //手机号码是用户输入的
				resendBtnHandler: _.debounce(_.bind(this.resendBtnHandler, this), 300),  //点击“立即获取”按钮调用方法
				isOutLogin: true
			};

			this.otpView = new OtpView();
			this.otpView.initOtp(options);
			this.$("#transOtp").empty();
			var $el = $(this.otpView.$el[0]);
			this.$("#transOtp").append($el);
			$el.find('div[class="f16"]').width(64);
		},

		_showSafeKeyBoard: function () {
			this.$("#transPwd").customInput({ type: "password-number", placeholder: "交易密码", className: "safeKeyBoard", maxLength: "6" });
		},

		_customInputPwdFocusIn: function () {
			safeKeyBoardHelper.focusIn({ id: "transPwd" });
		},

		_customInputPwdFocusOut: function () {
			safeKeyBoardHelper.focusOut({ id: "transPwd" });
		},

		resendBtnHandler: function () {
			var self = this;
			var mobileVal = this.$("#mobile").val();
			if (mobileVal) mobileVal = mobileVal.replace(/\s/g, "");
			var mobile = this.model.attributes.mobile ? this.model.attributes.mobile : mobileVal;
			if (self._validMobile(mobile)) {
				if (self.submitFlag) return;
				if (this.bankFlag == 0 && this.otpFlag == 1) {
					this.cat = config.values.bindCard; //高级网银手机号和橙子手机号不相等时，需要发OTP
				} else {
					this.cat = config.values.union_pay; //绑定他行卡，需要发OTP
				}

				var url = config.urls.get('sendByPhoneNo') + "/" + this.cat;
				self.otpView.sendSmsOTP(url, {
					mobileNo: mobile,
					successFunction: _.bind(self.successFunction, self),
					errorFunction: _.bind(self.errorFunction, self)
				}, self);
			}
		},

		successFunction: function () {
			this.$('#transPwd').addClass('m_t30');
		},

		errorFunction: function () {

		},

		_toSubmit: function () {
			var options = this._formData();
			if (this.$('#nextStepBtn').hasClass("btn_disable")
				|| !this._validateForm(options)
				|| this.submitFlag) return;

			this.submitFlag = true;
			//缓存页面数据
			App.storage.set("toPostUnionPay_formData", options);

			/**
			 * 他行绑定卡：1.判断四家银行（招行308、广发306、华夏304、民生305）则走老流程，其他的走新流程，
			 *            2.其他银行的走新的银联鉴权
			 * 本行绑定卡：bindDebitCard
			 */

			if (this.bankFlag == 0) {
				utils.native.talkingDataTrackEvent('2.0注册-绑卡-我行银联鉴权验证');

				this._bindDebitCard(_.pick(options, ['password', 'code', 'cat', 'sm2Pwd']));
			} else if (this.bankFlag == 1 && this.bankCodeArr.indexOf(options.bankCode) != -1) {
				App.navigate('verifyAccount/main/toFastAuthSubmitView', true); //调生成订单接口，该接口返回订单信息给前端
			} else {
				utils.native.talkingDataTrackEvent('2.0注册-绑卡-他行卡绑定');

				this._unionSendBack(options);
			}
		},

		/**
		 * 功能：银联鉴权新改造
		 * author:ex_huangzit
		 * time: 2015-09-30
		 */
		_unionSendBack: function (options) {
			var self = this;
			IdentityModel.unionSendBack({
				"url": "unionSendBack",
				"data": options,
				"callback": function (response) {
					//清除银行信息缓存
					App.storage.remove("verifyIdentity/openBankList");
					self.submitFlag = false;

					//跳到成功页面
					App.navigate("verifyAccount/bindCard/bindCardSuccess", true);
				},
				"errorCallback": function (response) {
					utils.native.talkingDataTrackEvent('2.0注册-绑卡-绑定失败提示');

					self.submitFlag = false;
					//失败
					utils.dialog.alert("您绑定的银行卡因为“" + response.message + "”的原因，绑定卡失败。");
				}
			});
		},

		/**
		 * 功能：绑定本行卡
		 * author:ex_huangzit
		 * time: 2015-09-30
		 */
		_bindDebitCard: function (options) {
			var self = this;
			IdentityModel.bindSameBankCard({
				"url": "bindSameBankCard",
				"data": options,
				"callback": function (response) {
					self.submitFlag = false;

					//跳到成功页面
					App.navigate("verifyAccount/bindCard/bindCardSuccess", true);
				},
				"errorCallback": function (response) {
					utils.native.talkingDataTrackEvent('2.0注册-绑卡-绑定失败提示');

					self.submitFlag = false;
					//失败
					utils.dialog.alert(response.message);
				}
			});
		},


		/**
		 * 功能：校验数据
		 * author:ex_huangzit
		 * time: 2015-08-19
		 */
		_validateForm: function (formData) {

			//他行卡，如果没有银行卡信息, 提交时需要校验该信息
			if (!formData.bankCode || !formData.bankName) {
				utils.dialog.toast("请选择借记卡开户行。");
				return false;
			}

			if ((this.bankFlag == 1 && this.bankCodeArr.indexOf(formData.bankCode) == -1)
				|| (this.bankFlag == 0 && this.otpFlag == 1)) {

				//校验手机号
				if (!formData.mobileNo) {
					utils.dialog.toast("请输入手机号。");
					return false;
				}
				if (!utils.validate.phone(formData.mobileNo)) {
					utils.dialog.toast("你输入的手机号不符合规范。");
					return false;
				}
				//手机动态码：1.他行
				if (!formData.code) {
					utils.dialog.toast("请输入手机动态码。");
					return false;
				}
			}

			//本行验证密码
			if (this.bankFlag == 0) {
				if (formData.password === "") {
					utils.dialog.toast("请输入交易密码。");
					return false;
				}
			}
			return true;
		},

		_formData: function () {
			var cardNo = this.model.attributes.cardNo;
			var bankCode = this.model.attributes.bankCode;
			var bankName = this.model.attributes.bankName;
			var mobileNo = this.model.attributes.mobile;

			if (!bankCode || !bankName) {
				var bankOption = App.storage.get("verifyIdentity/bankOption");
				bankCode = bankOption.bankCode;
				bankName = bankOption.bankName;
			}

			if (!mobileNo) {
				var mobileVal = this.$("#mobile").val();
				mobileNo = mobileVal ? mobileVal.replace(/\s/g, "") : mobileVal;
			}

			var options = { cardNo: cardNo, bankCode: bankCode, bankName: bankName, mobileNo: mobileNo, cat: this.cat, bankFlag: this.bankFlag };

			//本行卡：1.手机验证码，密码，2.他行卡：手机验证码（除了四家银行以外）
			if ((this.bankFlag == 0 && this.otpFlag && this.otpFlag == 1) || (this.bankFlag == 1 && this.bankCodeArr.indexOf(bankCode) == -1)) {
				var code = this.$('#otp_passWord').val();
				options.code = code;
			}

			if (this.bankFlag == 0) {
				var tranPwdOrg = $("#transPwd").customInput("value");  //交易密码
				var tranPwd = utils.crypto.RSAKey.encrypt(tranPwdOrg, config.base.rsa_public_key);
				options.password = tranPwd;
				options.sm2Pwd = utils.sm2.SM2Key.encrypt(tranPwdOrg, config.base.sm2_public_key);
			}
			return options;
		},

		//跳转到选择借记卡银行
		_tobankInfo: function () {
			App.navigate('verifyAccount/bindCard/toBankInfo', true);
		},

		//银联
		_toUionPay: function(){
			utils.window.open({
				title : "银联在线",
				url : "https://www.95516.com/portal/open/init.do?entry=open"
			});
		}
	});
});