define(function (require, exports, module) {
	var temp = require("text!../../template/newActive/inputBindCard.html");
	var FormComponent = require("component/form");
	var faceRecognition = require("component/faceRecognition");
	var bankListModel = require("mod/me/model/transferModel");
	var identityModel = require("mod/verifyAccount/model/identityModel");

	module.exports = FormComponent.extend({
		template: _.template(temp),
		events: {
			'tap #nextStepBtn'  : '_toSubmit',
			'input #bankCardNo' : '_setFullFill',
			'tap #checkbox'		: '_clickPayment',
			'tap #userPayment'	: '_clickUserPayment'
		},

		initialize: function () {
			this.submitFlag = false;
		},

		onRender: function () {
			//卡BIN
			if (!this.bankBinList) this._qryBankBinSel();
		},

		_setFullFill: function () {
			var cardNo = this.$("#bankCardNo").val().trim();
			if (cardNo && this.$("#checkbox").hasClass('on')) {
				if (this.$('#nextStepBtn').hasClass("btn_disable")) this.$('#nextStepBtn').removeClass('btn_disable');
				this.$('#nextStepBtn').addClass("btn_orange");
			} else {
				if (this.$('#nextStepBtn').hasClass("btn_orange")) this.$('#nextStepBtn').removeClass('btn_orange');
				this.$('#nextStepBtn').addClass("btn_disable");
			}
		},

		_toSubmit: function () {
			//校验数据
			var options = this._formData();
			if (!this._validateForm(options)) return;
			if (!this.submitFlag) {
				this.submitFlag = true;
				this.validateDebitCard(options);
			}
		},

		/**
		 * 信用卡号校验
		 * 入参：1、卡号
		 *     2、卡类型（不传参则支持全部类型）
		 * 支持的卡类型：mastercard, visa, amex, dinersclub, enroute, discover, jcb, unknown
		 * 返回：
		 *     Boolean [false/true]
		 */
		_creditcard: function (value, params) {
			var value = value.replace(/\s/g, ''),
				validTypes = 0x0000,
				types = {
					mastercard: 0x0001,
					visa: 0x0002,
					amex: 0x0004,
					dinersclub: 0x0008,
					enroute: 0x0010,
					discover: 0x0020,
					jcb: 0x0040,
					unknown: 0x0080
				};

			if (/[^0-9\-]+/.test(value)) {
				return false;
			}
			value = value.replace(/\D/g, "");

			if (!params) {
				validTypes = 0x0001 | 0x0002 | 0x0004 | 0x0008 | 0x0010 | 0x0020 | 0x0040 | 0x0080;
			} else {
				for (var i = 0; i < parmas.length; i++) {
					validTypes |= types[params[i]];
				}
			}

			if (validTypes & 0x0001 && /^(5[12345])/.test(value)) { //mastercard
				return value.length === 16;
			}
			if (validTypes & 0x0002 && /^(4)/.test(value)) { //visa
				return value.length === 16;
			}
			if (validTypes & 0x0004 && /^(3[47])/.test(value)) { //amex
				return value.length === 15;
			}
			if (validTypes & 0x0008 && /^(3(0[012345]|[68]))/.test(value)) { //dinersclub
				return value.length === 14;
			}
			if (validTypes & 0x0010 && /^(2(014|149))/.test(value)) { //enroute
				return value.length === 15;
			}
			if (validTypes & 0x0020 && /^(6011)/.test(value)) { //discover
				return value.length === 16;
			}
			if (validTypes & 0x0040 && /^(3)/.test(value)) { //jcb
				return value.length === 16;
			}
			if (validTypes & 0x0040 && /^(2131|1800)/.test(value)) { //jcb
				return value.length === 15;
			}
			// if (validTypes & 0x0080) { //unknown
			//     return true;
			// }
			return false;
		},

		/**
		* 银行卡合法性检查
		* 入参：
		*     value-卡号
		* 返回：
		*     Boolean-false/true
		*/

		_bankcard: function (value) {
			var cardValue = value.replace(/\s/g, ''),
				isValid = true,
				rFormat = /^[\d]{13,19}$/;
			if (!rFormat.test(cardValue)) {
				isValid = false;
			} else {
				var arr = cardValue.split('').reverse(),
					i = arr.length,
					temp,
					sum = 0;
				while (i--) {
					if (i % 2 === 0) {
						sum += +arr[i];
					} else {
						temp = +arr[i] * 2;
						sum += temp % 10;
						if (temp > 9) sum += 1;
					}
				}
				if (sum % 10 !== 0) {
					isValid = false;
				}
			}
			return isValid; //|| "请输入有效的银行卡号";
		},


		/**
		 * 功能：校验数据
		 * author:ex_huangzit
		 * time: 2015-12-16
		 */
		_validateForm: function (formData) {
			//校验卡号
			var cardNo = formData.cardNo;
			var checkFlag = this.$("#checkbox").hasClass('on');
			if (cardNo === "") {
				utils.dialog.toast("请输入你的借记卡卡号！");
				return false;
			} else if (!(/^\d+$/).test(cardNo)) {
				utils.dialog.toast("请输入正确的银行卡号！");
				return false;
			} else if (!(/^\d{13,19}$/).test(cardNo)) {
				utils.dialog.toast("输入卡号位数有误！");
				return false;
			// } else if (this._creditcard(cardNo)) {
			//     utils.dialog.toast("不支持该类型的卡号！");
			//     return false;
			// } else if(!this._bankcard(cardNo)){
			//     utils.dialog.toast("请输入有效的银行卡号！");
			//     return false;
			}
			//校验协议
			if(!checkFlag){
				utils.dialog.toast("请勾选用户协议");
				return false;
			}
			return true;
		},

		/**
		 * 功能：获取提交数据
		 * author:ex_huangzit
		 * time: 2015-12-16
		 */
		_formData: function () {
			var cardNo = $.trim(this.$("#bankCardNo").val().replace(/\s/g, ""));
			var options = { cardNo: cardNo };
			//匹配卡Bin
			if (this.bankBinList) {
				for (var i = 0; i < this.bankBinList.length; i++) {
					if (cardNo.substring(0, 6) == this.bankBinList[i].cardBin) {
						options.bankCode = this.bankBinList[i].bankCode;
						options.bankName = this.bankBinList[i].bankName;
						break;
					} else {
						options.bankCode = '';
						options.bankName = '';
					}
				}
			}
			return options;
		},

		//判断接口跳转：1.本行绑卡，2.他行绑卡（首张卡直接跳到绑卡界面，非首张跳转到人脸识别）
		validateDebitCard: function (options) {
			utils.native.talkingDataTrackEvent("2.0账户与安全-银行卡管理-新增绑卡-人脸识别");
			var self = this;
			identityModel.validateDebitCard({
				"url": "validateDebitCard",
				"data": options,
				"callback": function (response) {
					self.submitFlag = false;
					var bankFlag = response.object.bankFlag;
					var otpFlag  = response.object.otpFlag;
					var mobile   = response.object.mobile || '';
					var faceFlag = response.object.faceFlag || '1'; //当bankFlag返回1时，faceFlag:0为需要人脸识别，1为不需要人脸识别
					if (bankFlag === '0') {
						options.bankCode = '307';
						options.bankName = '平安银行';
					}

					var data = { cardNo: options.cardNo, bankCode: options.bankCode, bankName: options.bankName, mobile: mobile, bankFlag: bankFlag, otpFlag: otpFlag };

					//缓存页面数据
					App.storage.set("newActive/bankInfo", data);

					//他行非首次绑卡需人脸识别
					if (faceFlag === '0') {
						utils.dialog.confirm("即将进入人脸识别验证。", function (ok) {
							if (ok) {
							   faceRecognition(function(err, isSamePerson){
									if(err){
										utils.dialog.alert('人脸识别接口异常，请稍后再试！');
										return;
									}
									//是否是同一个人：true为同一人，false为不为同一人
									if(isSamePerson){
										utils.native.talkingDataTrackEvent("2.0账户与安全-银行卡管理-新增绑卡-人脸识别通过");
										App.navigate('verifyAccount/bindCard/bindCardAuth', true);
									}else{
										utils.native.talkingDataTrackEvent("2.0账户与安全-银行卡管理-新增绑卡-人脸识别失败");
										utils.dialog.alert('识别未通过，请调整面部姿态重新再试');
									}
								},{sceneNum: 'B001'});
							}
						});
					} else {
						App.navigate('verifyAccount/bindCard/bindCardAuth', true);
					}
				},
				"errorCallback": function (response) {
					self.submitFlag = false;
					utils.dialog.toast(response.message);
				}
			});
		},

		/**
		 * 功能：卡Bin匹配银行
		 * author:ex_huangzit
		 * time:2015-08-31
		 */
		_qryBankBinSel: function () {
			var self = this;
			bankListModel.qryBankBinInfo({
				"url": "qryBankBinInfo",
				"data": {},
				"callback": function (response) {
					self.bankBinList = response.object.bankBinList;
				},
				"errorCallback": function (response) {
					utils.dialog.toast(response.message);
				}
			});
		},

		_clickPayment:function(){
			if(this.$("#checkbox").hasClass('on')){
				this.$("#checkbox").removeClass('on');
			}else{
				this.$("#checkbox").addClass('on');
			}
			this._setFullFill();
		},

		//用户协议
		_clickUserPayment:function(){
			var userPayMentUrl = 'https://ssl.pingan.com/bank/xieyi/zt/daishou.html';
			utils.window.open({"title": "用户协议","url": userPayMentUrl});
		}
	});
});