define(function(require, exports, module) {
    var temp = require("text!../../template/verifyIdentity/byCreditCard.html");
    var FormComponent = require("component/form");
    var IdentityModel = require("../../model/identityModel");
    var safeKeyBoardHelper=require("component/customInput.helper");
    var accountModel = require("mod/common/model/accountModel");

    module.exports = FormComponent.extend({

        template: _.template(temp),

        ui: {
            cardNo: "input#inputCardNo"
        },

        events: {
            'tap #btnSubmit': 'toSubmit',
            "customInputFocusIn #js-pwd-input":"_customInputFocusIn",
            "customInputFocusOut #js-pwd-input":"_customInputFocusOut"
        },

        onRender: function(){
            this._showSafeKeyBoard();
        },

        _customInputFocusIn:function(){
            safeKeyBoardHelper.focusIn({
                id:"js-pwd-input"
            });
            var el=safeKeyBoardHelper.getSelector("js-pwd-input");
            el.addClass("focusBlue");
        },
        _customInputFocusOut:function(){
            safeKeyBoardHelper.focusOut({
                id:"js-pwd-input"
            });
            var el=safeKeyBoardHelper.getSelector("js-pwd-input");
            el.removeClass("focusBlue");
        },
        _showSafeKeyBoard:function(){
            this.$("#js-pwd-input").customInput({
               type: "password-number",
               placeholder: "输入你的查询密码",
               maxLength: 6,
               className:"safeKeyBoard"
            });
        },

        toSubmit: function(){
            if (this.validateForm()) {
                if (!this.submitFlag) {
                    this._doSubmit();
                    this.submitFlag=true;
                }
            }
        },

        validateForm: function(){
            var cardNo = this.ui.cardNo.val().replace(/\s/g, '');
            var pwd = $("#js-pwd-input").customInput("value");
            if (cardNo === "") {
                this.inputCardNo.setCustomValidity("输入你的平安信用卡卡号！");
                return false;
            } else if (!(/^\d{16}$/).test(cardNo)) {
                this.inputCardNo.setCustomValidity("卡号输入有误！");
                return false;
            }
            if(pwd===""){
                safeKeyBoardHelper.setCustomValidity({
                    id:"js-pwd-input",
                    message:"请输入查询密码"
                });
                return false;
            }
            return true;
        },

        _doSubmit: function(){
            var that = this;
            var formData = this.formData();
            //万里通积分提示
           // var wltPrompt = "<br/>恭喜您获得奖励积分，积分将在T+1日入账。请前往转账记录-万里通积分查询。";

            IdentityModel.creditCardActivation(formData, function(err, resp){
                that.submitFlag = false;
                if(err) return utils.dialog.alert(err.message || err);

                App.storage.get("UserInfo").set("cardState", "1");
                App.storage.get("UserInfo").set("activeState", "1");
                 App.storage.get('UserInfo').set('verifyMode', '4')
                
                utils.dialog.alert("认证成功！", function () {
                    App.navigate('index/indexLogined/index', true);
                });
    
                //是否送万里通积分
                // accountModel.getWLTCheckRule({
                //     data : {"ruleId":config.values.wltJiHuo},
                //     callback : function(res){
                //         //0是送积分1不送积分
                //         if(res.object.wanlitongRule && res.object.wanlitongRule == 0){
                //             utils.dialog.toast('认证成功！'+wltPrompt, function () {
                //                 App.navigate('search/search/index', true);
                //             });
                //         }else{
                //             utils.dialog.toast('认证成功！', function () {
                //                 App.navigate('search/search/index', true);
                //             });
                //         }
                //     },
                //     errorCallback : function(res){
                //         //utils.dialog.alert(res.message);
                //     }
                // });
            });
        },

        formData: function(){
            var cardNo = this.ui.cardNo.val().replace(/\s/g, '');
            var pwd = $("#js-pwd-input").customInput("value");
            var passwd = utils.crypto.RSAKey.encrypt(pwd, config.base.cardKey);
            return {
                card: cardNo,
                passwd: passwd
            };
        }

    });
});