define(function (require, exports, module) {

    var date = module.exports;

    /*
     * 根据日期获取星期
     */
    date.getWeek=function(date){
        var day = new Date(date.replace(/-/g, "/")).getDay();
        var weekName = "";
        switch(day){
            case 0:
                weekName = "周日";
                break;
            case 1:
                weekName = "周一";
                break;
            case 2:
                weekName = "周二";
                break;
            case 3:
                weekName = "周三";
                break;
            case 4:
                weekName = "周四";
                break;
            case 5:
                weekName = "周五";
                break;
            case 6:
                weekName = "周六";
                break;
        }
        return weekName;

    };


    /**
     * @author EX-LIYANPING001
     * 功能描述      ：给Date对象扩展格式化方法
     */
    Date.prototype.format = function(format){
        var o = {
            "M+" : this.getMonth()+1, //month
            "d+" : this.getDate(), //day
            "h+" : this.getHours(), //hour
            "m+" : this.getMinutes(), //minute
            "s+" : this.getSeconds(), //second
            "q+" : Math.floor((this.getMonth()+3)/3), //quarter
            "S" : this.getMilliseconds() //millisecond
        };

        if(/(y+)/.test(format)){
            format=format.replace(RegExp.$1,(this.getFullYear()+"").substr(4- RegExp.$1.length));
        }

        for(var k in o){
           if(new RegExp("("+ k +")").test(format)){
               format = format.replace(RegExp.$1,RegExp.$1.length==1? o[k] :("00"+ o[k]).substr((""+ o[k]).length));
           }
        }

        return format;
   }

    /**
     * @author EX-LIYANPING001
     * 功能描述      ：时间推移的方法
     *    @param {string} date 当前时间   形式为  这些方式  "2012.3.4 23:22:33" "2012.3.4" new Date()
     *    @param {string} num 推移的次数
     *    @param {string} unit  单位   只能为("y"或者"m"或者"d")
     */
   date.diffDateAdd = function(date,num,unit){
        if(!date || num == undefined || !unit){
            return "";
        }
        var d = this.formatTime(date);
        var unit = {
        'y' : 1000*60*60*24*365,
        'm' : 1000*60*60*24*30,
        'd' : 1000*60*60*24
        }[unit];
        return new Date(d.getTime()+num*unit);
   },

   /**
    * @description 格式化为标准时间
    * @param  : date
    * @return : Date格式化类型
    */
   date.formatTime = function(date){
        if(typeof date == "string"){
            if(date.length == 8){
                var arr = [date.substr(0,4),date.substr(4,2),date.substr(6,2)];
            }else if(date.length == 14){
                var arr = [date.substr(0,4),date.substr(4,2),date.substr(6,2),date.substr(8,2),date.substr(10,2),date.substr(12,2)];
            }else{
                var arr = date.split(/[^0-9]+/);
            }
            date = new Date(arr[0],arr[1]-1,arr[2],arr[3]||0,arr[4]||0,arr[5]||0);
        }
        return date;
   },

    /**
     * @description 比较两个时间的大小,
     * t1 时间参数   形式为  这些方式  "2012.3.4 23:22:33" "2012.3.4" new Date()
     * t2 时间参数   形式为  这些方式  "2012.3.4 23:22:33" "2012.3.4" new Date()
     * @return: 返回-1 0 1
     *    t1>t2 返回1
     *    t1=t2 返回0
     *    t1<t2  返回-1
     */
    date.compareDate = function(t1,t2) {
        if(!t1 || !t2){
            return "";
        }
        t1 = this.formatTime(t1);
        t2 = this.formatTime(t2);
        var result = t1.getTime()-t2.getTime();
        return result == 0 ? 0: result>0 ? 1: -1;
    },

    /**
     * @description 返回2个时间间隔的天数
     * t1 时间参数   形式为  这些方式  "2012.3.4 23:22:33" "2012.3.4" new Date()
     * t2 时间参数   形式为  这些方式  "2012.3.4 23:22:33" "2012.3.4" new Date()
     * @returns 返回2个时间之间的天数,如果t1>t2返回负数，t1==t2返回0，t1<t2返回正数
     */
    date.diffDate = function(t1,t2){
        if(!t1 || !t2){
            return false;
        }
        t1 = this.formatTime(t1);
        t2 = this.formatTime(t2);
        return parseInt((t2.getTime()-t1.getTime())/(1000*60*60*24));
    }

    /**
     * 倒计时
     * utils.date.countDown(
     *         36000                //剩余秒
     *     ,{
     *         sec: $("sec")[0],    //秒占位
     *         min: $("min")[0],    //分占位
     *         hour: $("hour")[0]   //时占位
     *     }
     * );
     */
    date.countDown = function(remainSeconds, timerEls){
        var f = {
            timer : null,
            remainSeconds : parseInt(remainSeconds) || 0,
            zero: function(n){
                var n = parseInt(n, 10);
                if(n > 0){
                    if(n <= 9){
                        n = "0" + n;
                    }
                    return String(n);
                }else{
                    return "00";
                }
            },
            dv: function(){
                f.remainSeconds--;

                var pms = {
                        day  : "00",
                        sec  : "00",
                        min  : "00",
                        hour : "00"
                    };
                var remain = f.remainSeconds;

                if (remain <= 0) {
                    clearTimeout(f.timer);
                    delete f;
                    return pms;
                }

                if(remain > 0){
                    var day = f.zero(Math.floor(remain/(24*3600)));
                    var hour= f.zero(Math.floor((remain-day*24*3600)/3600));
                    var min = f.zero(Math.floor((remain-day*24*3600-hour*3600)/60));
                    var sec = f.zero(Math.floor(remain-day*24*3600-hour*3600-min*60));
                    pms = {
                        day : day,
                        hour : hour,
                        min : min,
                        sec  : sec
                    }

                }

                return pms;
            },
            ui: function(){
                var pms = f.dv();
                if(timerEls.sec)   timerEls.sec.innerHTML = pms.sec;
                if(timerEls.min)  timerEls.min.innerHTML = pms.min;
                if(timerEls.hour)  timerEls.hour.innerHTML = pms.hour;
                if(timerEls.day)   timerEls.day.innerHTML = pms.day;
                f.timer=setTimeout(f.ui, 1000);
            }
        };
        f.ui();
    };

});