define(function(require, exports, module) {

	require("vendor/sha1");

	var native = exports;

	var execute = native.execute = function(service, action, args) {
		var dfd = $.Deferred();
		if (ENABLE_PHONEGAP)
			cordova.exec(dfd.resolve, dfd.reject, service, action, args || []);
		return dfd;
	};

	/**
	 * 地理定位
	 */
	native.getlocation = function(callback) {
		execute("LocationManagerPlugin", "location", []).done(callback);
	};

	native.getEnvironment = function(callback) {
		execute("ToolsPlugin", "getEnvironment", []).done(callback);
	};
	native.getApp = function(options) {
		execute("CommonPlugin", "openUri", options);
	};

	native.exitApp = function() {
		if (IS_RUN_ON_ANDROID)
			execute("ToolsPlugin", "systemExit", []);
		if (IS_RUN_ON_IDevice)
			execute("ToolsPlugin", "exitApp", []);
	};

	/* LayoutPlugin
	 ---------------------------------------------- */

	native.resetHeader = function(options) {
		function createComponent(position, content) {
			if (!content)
				return {};

			if (content == "@back")
				return {
					position : position,
					type : "img",
					value : "back"
				};
			if (content == "@menu")
				return {
					position : position,
					type : "img",
					value : "menu"
				};
			if (content == "@share")
				return {
					position : position,
					type : "img",
					value : "share"
				};
			if (content == "@exit")
				return {
					position : position,
					type : "txt",
					value : "退出"
				};
			if (content == "@logo")
				return {
					position : position,
					type : "img",
					value : "logo"
				};
			if (content == "@more")
				return {
					position : position,
					type : "img",
					value : "more"
				};

		    if (content == "@messageCenter")
                return {
                    position : position,
                    type : "img",
                    value : "messageCenter"
                };

            if(content == "@customerCenter"){
               return {
                    position : position,
                    type : "txt",
                    value : "客服中心"
                };
            }

			if (position == "background")
				return {
					position : position,
					type : "img",
					value : content
				};

            if (content == "@add")
				return {
					position : position,
					type : "img",
					value : "add"
				};

			return {
				position : position,
				type : "txt",
				value : content
			};
		}

		var title = createComponent("middle", options.title);
		var leftButton = createComponent("left", options.leftButtonContent);
		var rightButton = createComponent("right", options.rightButtonContent);
		var background = createComponent("background", options.background || "#ffffff");
		execute("LayoutPlugin", "setTopLayout", [leftButton, title, rightButton, background]);
	};

	native.resetFooter = function(options) {
		// options: { visible: boolean, selectedIndex: number, trigger: boolean }
		execute("LayoutPlugin", "setBottomLayout", [options]);
	};

	/* SlidingMenuPlugin
	 ---------------------------------------------- */

	native.toggleSideMenu = function() {
		execute("SlidingMenuPlugin", "setSlidingMenuToggle", []);
	};

	native.setSideMenuDisabled = function(isDisabled) {
		execute("SlidingMenuPlugin", "setSlidingMenuDisable", [isDisabled]);
	};

	/* HttpPlugin
	 ---------------------------------------------- */

	native.HTTPRequest = function(options) {
		var deferred = $.Deferred();
		execute("HttpPlugin", "request", [options]).then(function(rawData) {
			var data = $.parseJSON(rawData);
			var JSONResponse, statusCode = parseInt(data.statusCode);
			if (statusCode >= 200 && statusCode < 300 || statusCode === 304) {
				if (options.isDownloadImg)
					return deferred.resolve(data.response);
				try {
					JSONResponse = $.parseJSON(data.response);
				} catch(e) {
					return deferred.reject("parseerror");
				}
				return deferred.resolve("success", JSONResponse);
			}
			deferred.reject({
				message : "error"
			});
		}, function(rawData) {
			// 因为一些原因，这个回调可能是同步的,强制加个defer,使行为统一
			_.defer(function() {
				deferred.reject($.parseJSON(rawData).statusText);
			});
		});

		return deferred;
	};

	/**
	 * 更新个缓存接口
	 */
	native.HTTPRequestCache = function(options) {
		var deferred = $.Deferred();

		execute("HttpPlugin", "requestWithCache", [options]).then(function(rawData) {
			try {
				var JSONResponse = $.parseJSON(rawData);
				deferred.resolve(JSONResponse);
			} catch(e) {
				deferred.reject("parseerror");
			}
		}, function(rawData) {
			// 因为一些原因，这个回调可能是同步的,强制加个defer,使行为统一
			_.defer(function() {
				deferred.reject($.parseJSON(rawData).statusText);
			});
		});

		return deferred;
	};

	native.pawsFinish = function() {
		execute("ToolsPlugin", "pawaComplete", []);
	};

	native.isLogin = function(isLogin) {
		var options = {};
		options.isLogin = isLogin;
		execute("Tools", "isLogin", [options.isLogin]);
	};

	native.datepicker = function(options, callback) {
		var promise = execute("DatePicker", "datePicker", [options]);
		if (callback)
			promise.done(callback);
	};

	/* DialogPlugin
	 ---------------------------------------------- */

	native.dialogAlert = function(options, callback) {
		var promise = execute("DialogPlugin", "alert", [options]);
		if (callback)
			promise.done(function(arg) {
				callback($.parseJSON(arg));
			});
	};

	native.dialogConfirm = function(options, callback) {
		var promise = execute("DialogPlugin", "confirm", [options]);
		if (callback)
			promise.done(function(arg) {
				callback($.parseJSON(arg));
			});
	};

	native.dialogSpinner = function(opts) {
		var options = opts.options || [];
		var selectedIndex = opts.selectedIndex;
		var title = opts.title || "";
		var callback = opts.callback ||
		function() {
		};

		if (!_.isNumber(selectedIndex))
			selectedIndex = 0;
		if (selectedIndex < 0 || selectedIndex >= options.length)
			selectedIndex = 0;

		execute("DialogPlugin", "spinner", [{
			title : title,
			selectedIndex : selectedIndex,
			options : options
		}]).done(function(idx) {
			opts.callback && opts.callback($.parseJSON(idx));
		});
	};

	native.showMask = function(options) {
		execute("HeadFootMaskPlugin", "showMask", [options]);
	};

	native.openWindow = function(options) {
		execute("WindowPlugin", "open", [options]);
	};

	native.closeWindow = function(options) {
		execute("WindowPlugin", "close", [options]);
	};

	native.shareUserData = function() {
		execute("SharePlugin", "share", []);
	};

	/* GalleryPlugin
	 ---------------------------------------------- */

	native.gallery = {};

	native.gallery.show = function(options, callback) {
		var source = options.source;
		var highIndex = options.highIndex;
		if (highIndex == null || source[highIndex] == null)
			highIndex = 0;

		execute("GalleryPlugin", "show", [{
			highIndex : highIndex,
			source : source
		}]).done(function () {
			callback();
		});
	};

	native.versionInformation = function(callback) {
        var versionInfo = App.storage.get("versionInformation");
        if (versionInfo) {
            callback(versionInfo);
            return;
        }
        execute("ToolsPlugin", "versionInformation", []).done(function (data) {
            data = $.parseJSON(data);
            data.canUpgrade = data.version != data.latestVersion;
            callback(data);
            App.storage.set("versionInformation", data);
        });

	};

	native.upgrade = function() {
		execute("ToolsPlugin", "upgrade", [])
	};

	native.getTokenID = function(callback) {
		execute("DeviceToken", "getToken", []).done(function(data) {
			callback(data);
		}).fail(function() {
			callback();
		});
	};

	native.getDeviceID = function(callback) {
		execute("DevicePlugin", "getDeviceId", []).done(function(data) {
			callback(data);
		}).fail(function() {
			console.log("Get DeviceID Error!");
		});
	};

	/*IOS下自己加密生成一个DeviceID*/
	native.getIDeviceID = function() {
		var deviceId = localStorage.getItem("deviceId");
		var device = window.device;
		if (!deviceId) {
			deviceId = 'AUUID_' + hex_sha1(device.uuid);
			localStorage.setItem("deviceId", deviceId);
		}
		return deviceId;
	};

	native.getDeviceInfo = function() {
		var dfd = $.Deferred();
		execute("ToolsPlugin", "getDeviceInfo").always(function(info) {
			info = JSON.parse(info || '{}');
			if (IS_RUN_ON_IDEVICE) {
				if (!info.deviceId) {
					info.deviceId = native.getIDeviceID();
				}
			}
			dfd.resolve(info);
		});
		return dfd;
	};

	/* soft keyboard
	 ---------------------------------------------------- */
	native.showSafeKeyboard = function(option) {
		var keyboardTypeEnum = {
			"decimal" : 1,
			"password-decimal" : 1,
			"password-number" : 0,
			"password-ascii" : 2
		};

		option.inputType = keyboardTypeEnum[option.inputType];

		// 0: number, 1: decimal, 2:ascii
		execute("SafeKeyboardPlugin", "showSafeKeyboard", [option]);
	};

	native.hideSafeKeyboard = function() {
		execute("SafeKeyboardPlugin", "hideSafeKeyboard", []);
	};

	native.showDecimalKeyboard = function() {
		execute("SafeKeyboardPlugin", "showDecimalKeyboard", []);
	};

	/*Talking Data Plugin
	 ----------------------------------------------------------------------*/

	native.talkingDataCollectUser = function(option) {
		execute("TalkingDataPlugin", "collectUser", [option]);
	};

	native.talkingDataClearUser = function() {
		execute("TalkingDataPlugin", "clearUser", []);
	};

	native.talkingDataTrackEvent = function(option) {
		option+=App.storage.get("UserInfo") && App.storage.get("UserInfo").get("ecifNo")?"-"+App.storage.get("UserInfo").get("ecifNo"):"";
		execute("TalkingDataPlugin", "trackEvent", [option]);
	};

	/* Any Door Plugin
	 ----------------------------------------------------------------------*/
	native.anydoor = {};

	native.anydoor.show = function() {
		return execute("AnyDoorPlugin", "show", [true]);
	};
	native.anydoor.hide = function() {
		return execute("AnyDoorPlugin", "show", [false]);
	};

	native.anydoor.initialize = function() {
		return execute("AnyDoorPlugin", "init");
	};

	native.anydoor.setLoginInfo = function(data) {
		// * mamc_sso_once_token 登录凭证     -- loginTicket
		// * userId 普通账号／一账通账号
		// * userType 账号类型，若没有传“”   -- userType
		// url 交换token的访问服务端的地址
		// toaPatyNum 一账通登录后才有，普通账号传“”  -- toaPartyNo
		// toaClientNo 一账通登录后才有，普通账号传“”   -- toaClientNo
		// * mobileNo 手机号    -- toaMobileNo
		return execute("AnyDoorPlugin", "setLoginInfo", [data]);
	};

	native.anydoor.cleanLoginInfo = function(data) {
		return execute("AnyDoorPlugin", "cleanLoginInfo", [data]);
	};

	//进入客服中心
	native.anydoor.intoCustomerService = function(){
	    return execute("AnyDoorPlugin", "openCustomerServiceCenter");
	};

	//进入消息中心
	native.anydoor.intoMessageCenter = function(){
	    return execute("AnyDoorPlugin", "openMessageCenter");
	};

	/* Configuration Plugin
	 ----------------------------------------------------------------------*/
	native.readConfigAsXMLDoc = function() {
		/*
		 return $.Deferred().resolve($.parseXML('\
		 <Application>\
		 <bannerList>\
		 <banner title="banner 1" img="http://10.6.160.161/image/fonz1.png" url="http://www.baidu.com" />\
		 <banner title="banner 2" img="http://10.6.160.161/image/fonz2.png" url="#path1" />\
		 <banner title="banner 3" img="http://10.6.160.161/image/fonz3.png" url="http://www.baidu.com" />\
		 </bannerList>\
		 </Application>'));
		 */
		return execute("ToolsPlugin", "getConfigInfo").then(function(xml) {
			return $.parseXML(xml || "<Application />");
		});
	};

	native.SharePlugin = function(data) {
		return execute("SharePlugin", "share", [data]);
	};
	//产品分享
	native.shareProduct = function(data) {
		return execute("SharePlugin", "shareProduct", [data]);
	};

	native.saveUserName = function(str) {
		execute("ToolsPlugin", "saveUserName", [str]);
	};

	native.getUserName = function(callback) {
		var promise = execute("ToolsPlugin", "getUserName", []);
		promise.done(function(arg) {
			callback(arg);
		});
	};

	/*
	 * OCR身份识别
	 ----------------------------------------------------------------------*/
	native.idCardScan = function(callback) {
		execute("IDCardScanPlugin", "show", []).done(function(data) {
			callback(data);
		}).fail(function(data) {
			callback();
		});
	};

	/*
	 * 人脸识别
	 ----------------------------------------------------------------------*/
	native.livenessDetection = function(cardId, callback) {
		//2015-12-18 wuyongsheng560 人脸识别壳有调整，
		//新流程里不需要cardId(咨询壳dev徐海鹏)
		var arg0 = Array.prototype.slice.call(arguments)[0];
		if (typeof arg0 === 'function') {
			callback = arg0;
			cardId = '';
		}

		execute("LivenessDetectionPlugin", "show", [cardId]).done(function(data) {
			try{
				data = JSON.parse(data);
			}catch(e){};

			callback(data);
		}).fail(function(data) {
			callback();
		});
	};

	/*
	 * 获取图片缓存
	 ----------------------------------------------------------------------*/
	native.getIDCardImage = function(callback) {
		execute("ToolsPlugin", "getIDCardImage", []).done(function(data) {
			callback(data);
		}).fail(function(data) {
			callback();
		});
	};

	/*
	 * 获取试点城市
	 ----------------------------------------------------------------------*/
	native.location = function(callback) {
		execute("LocationManagerPlugin", "location", []).done(function(data) {
			callback(data);
		}).fail(function(data) {
			callback();
		});
	};

	/*
	 * 获取 webview 高度
	 ----------------------------------------------------------------------*/
	native.getWebviewHeight = function(callback) {
		execute("ToolsPlugin", "getWebviewHeight", []).done(function(data) {
			callback(data);
		}).fail(function(data) {
			callback();
		});
	};

	/*
	 * 手势密码设置
	 ------------------------------------------------------------------------*/
	native.showGestureLoginSetupView = function(options) {
		execute("PAGestureLoginPlugin", "showGestureLoginSetupView", []).done(function(data) {
			options.callback && options.callback();
		}).fail(function() {
			options.errorCallback && options.errorCallback();
		});
	};

	/*
	 * 保存用户信息方法
	 ------------------------------------------------------------------------*/
	native.saveGestureLoginData = function(options) {
		execute("PAGestureLoginPlugin", "saveGestureLoginData", [options]);
	};

	/*
	 * 用户登录后引导用户设置手势密码弹框
	 ------------------------------------------------------------------------*/
	native.showGestureAlert = function() {
		execute("PAGestureLoginPlugin", "showGestureAlert", []);
	};

	/*
	 * 关闭手势密码
	 ------------------------------------------------------------------------*/
	native.closeGestureLogin = function() {
		execute("PAGestureLoginPlugin", "closeGestureLogin", []);
	};

	/*
	 * 关闭手势密码页面
	 ------------------------------------------------------------------------*/
	native.closeGestureView = function() {
		execute("PAGestureLoginPlugin", "closeGestureView", []);
	};

	//梦想宣传页
	native.dreamIndex = function() {
		execute("GalleryPlugin", "dreamIndex", []);
	};

	//车贷
	native.carLoan = function (callback) {
		execute("ToaFPlugin", "toaFCarLoan", []);
		App.storage.set("isToaf", "isToaf");
	};
	//房贷
	native.houseLoan = function (callback) {
		execute("ToaFPlugin", "toaFHouseLoan", []);
		App.storage.set("isToaf", "isToaf");
	};
	//一账通登录
	native.setToaFLoginInfo = function (data) {
		execute("ToaFPlugin", "setToaFLoginInfo", [data.object]).done(function (res) {
			if (res) {
				var data = JSON.parse(res);
				var login = data.toaBankLoginStatus || "0";
				if (login == "1") {
					App.storage.set("isToaFLoginIn", "isUserLoggedIn");
				}
			}
		});
	};
	//保持一账通会话
	native.setToaFHearBeat = function (callback) {
		execute("ToaFPlugin", "setToaFHearBeat", []);
	};

	//退出一账通
	native.setToaFLogout = function (callback) {
		execute("ToaFPlugin", "setToaFLogout", []);
	}
});
