define(function (require, exports, module) {

    var string = module.exports;

    // format a number, using the _.str.numberFormat(),
    // but this version accept string type, and the default value of dec is 2.
    // [_.str.numberFormat](https://github.com/epeli/underscore.string)
    // numberFormat(number, [dec=2, dsep=".", tsep=","])
    string.numberFormat = function(number, dec, dsep, tsep){
        number = parseFloat(number);
        dec = dec == null ? 2 : dec;

        if (isNaN(number) || number == null) return '';

        number = number.toFixed(~~dec);
        tsep = typeof tsep == 'string' ? tsep : ',';

        var parts = number.split('.'), fnums = parts[0],
            decimals = parts[1] ? (dsep || '.') + parts[1] : '';

        return fnums.replace(/(\d)(?=(?:\d{3})+$)/g, '$1' + tsep) + decimals;
    };

    string.translateToChinese = function(number){
        number = number.toString();
        number = number.replace(/(?:^\s+|\s+$)/g, "");
        number = number.replace(/^[-+]/, "");
        if(!number || isNaN(number)) return "";

        number = "0" + number;
        number = number.indexOf(".") < 0 ? number + ".00" : number + "00";
        number = number.replace(/^(?:0(?!\.))*(\d+\.\d\d)\d*$/, "$1");
        number = number.replace(".", "");
        number = number.replace(/0*(\d+)$/, "$1");

        if(!/^\d+$/.test(number)) return "";
        if(number.length > 17) return "";
        if(/^0+$/.test(number)) return "零元";

        var chineseNum = ["零","壹","贰","叁","肆","伍","陆","柒","捌","玖","拾"];
        var chineseUnit = ["分","角","元","拾","佰","仟","万","拾","佰","仟","亿","拾","佰","仟","万","拾","佰","仟"];

        var result = "";
        for (var i = 0; i < number.length; i++){
            result += chineseNum[number.charAt(i)] + chineseUnit[number.length - i - 1];
        }

        result = result
            .replace(/(?:零[分角拾佰仟])+/g, "零")
            .replace(/零+([元万亿])/g, "$1零")
            .replace(/元/, "元零")
            .replace(/亿零*万/, "亿")
            .replace(/([万亿])零*元/, "$1元")
            .replace(/零+/g, "零")
            .replace(/零*$/, "")
            .replace(/^元零+/, "")
            .replace(/元$/, "元整");

        return result;
    };

    string.moneyFormat=function(options){
        if(options){
            var domValue=$("#"+options.domID)[0];
            var showSpan=$("#"+options.showSpanID)[0];
            switch(options.funcName){
                case 'inputEvent':
                    formatMoneyOpt._setText({obj:domValue});
                    showSpan.innerHTML=string.translateToChinese(domValue.value);
                    break;
                case 'blurEvent':
                    domValue.value=string.formatMoneyNumber(domValue.value);
                    break;
                case 'focusEvent':
                    if(domValue.value==''||domValue.value=='0.00'){
                        domValue.value='';
                        showSpan.innerHTML='';
                        }
                    else {
                        domValue.value=formatMoneyOpt._removeMoneyNumberComma(domValue.value);
                    }
                    break;
                default:
                    return;
            }
        }else{
            alert("options对象为空");
        }
    };
    string.formatMoneyNumber =function(moneyNum) {
                if(typeof(moneyNum=="number")){
                    moneyNum=moneyNum+"";
                }
                var moneyNum = moneyNum.replace(/,/g,"");
                var result = isNaN((1 * moneyNum).toFixed(2)) ? (new Number(0).toFixed(2)) : (1 * moneyNum).toFixed(2);
                return /\./.test(result) ? result.replace(/(\d{1,3})(?=(\d{3})+\.)/g, "$1,") : result.replace(/(\d{1,3})(?=(\d{3})+\b)/g, "$1,");
   };
    var formatMoneyOpt={
         _setText:function(options){
            if(options && options.obj){
                var obj=options.obj;
                //保证必须为数字或者小数点
                obj.value=obj.value.replace(/[^\d.]/g,"");
                //保证第一个数字必须为数字
                obj.value=obj.value.replace(/^\./g,"");
                //保证小数点只出现一次
                obj.value=obj.value.replace(/\.{2,}/g,".");
                //将多余的小数点替换删除
                obj.value=obj.value.replace(/\./,"$#$").replace(/\./g,"").replace("$#$",".");
                //保证小数点后只能有两位数字
                obj.value=obj.value.replace(/\.\d{2,}$/,obj.value.substr(obj.value.indexOf("."),3));
            }else{
                alert("options对象为空");
            }
        },
        _removeMoneyNumberComma:function(moneyNum) {
                moneyNum = (moneyNum+'').replace(/,/g, "");
                return isNaN((1 * moneyNum).toFixed(2)) ? (new Number(0).toFixed(2)) : (1 * moneyNum).toFixed(2);
        }
    };

    /*
     * 移除金额逗号分隔符
     *
     * 入参：
     *      money：金额
     *
     * 返回：
     *      移除逗号后的金额
     */
    string.removeMoneyComma = function(money) {
        return money.remove(/,/, "");
    };

    /*
     * 对手机号码进行掩码处理
     *
     * 入参：
     *      Phone：手机号码
     *
     * 返回：
     *      进行掩码处理后的手机号
     */
    string.dealThePhone = function(phone) {
        if(phone) {
            var phone = phone.replace(/\s/g,"");
            return phone.substr(0, 3) + "****" + phone.substr(phone.length-4, 4);
        }
    };

    /*
     * 对Email地址进行掩码处理
     *
     * 入参：
     *      email：Email地址
     *
     * 返回：
     *      进行掩码处理后的Email地址
     */
    string.dealTheEmail = function(email) {
        if(email) {
            var email = email.replace(/\s/g,"");
            var name  = email.split("@")[0];
            var url   = email.split("@")[1];
            if(name.length>2){
                return name.substr(0, 2) + "****@" + url;
            }else{
                return name.substr(0, 1) + "****@" + url;
            }
        }
    };

    /*
     * 对银行账号进行掩码处理
     *
     * 入参：
     *      accNo：银行账号
     *
     * 返回：
     *      accNo : 进行掩码处理后的账号
     */
    string.dealTheAccNo = function(accNo) {
        try {
            var accNo = accNo.replace(/\s/g,"");
            var numLength = accNo.length;
            if(numLength < 8) {
                return accNo;
            }
            return accNo.substr(0, 4) + "****" + accNo.substr(accNo.length-4, 4);
        } catch(err) {
            return accNo;
        }
    };

    /*
     * 格式化银行账号（每隔4位加一个空格）
     *
     * 入参：
     *      accNo：银行账号
     *
     * 返回：
     *      formatAcc : 格式化后的账号
     */
    string.formatAccount = function(accNo){
        var formatAcc = "";
        if(!accNo || $.trim(accNo)===""){
            return formatAcc;
        }
        var accNo = $.trim(accNo.replace(/\s/g, ""));
        var accLength = accNo.length;
        var accArray = [];
        // 获取需要的空格数
        var spaceCount = (accLength % 4 == 0) ? parseInt(accLength/4)-1 : parseInt(accLength/4);
        for(var i=0; i<spaceCount; i++){
            // 每4位数添加进数组
            var fourNumbers = accNo.substr(i * 4, 4);
            accArray.push(fourNumbers);
        }
        // 添加最后的几位数（1~4位）
        accArray.push(accNo.substring(spaceCount * 4, accLength));

        // 组装成格式化账号
        formatAcc = accArray.join(" ");

        return formatAcc;
    };

    /*
     * 移除银行账号空格
     *
     * 入参：
     *      accNo：银行账号
     *
     * 返回：
     *      去掉所有空格后的账号
     */
    string.removeAccSpace = function(accNo){
        return accNo.replace(/\s/g, "");
    };

    /**
     * @author    EX-ZHENGZONGYI001
     * @description   货币MAP集合
     * @example    　　["01", "人民币", "rmb"],["23", "欧元", "eur"]
     */
    var currencyMap = [
        ["01", "人民币", "rmb"],
        ["01", "人民币", "cny"],
        ["23", "欧元", "eur"],
        ["28", "加拿大元", "cad"],
        ["13", "港币", "hkd"],
        ["27", "日元", "jpy"],
        ["15", "瑞士法郎", "chf"],
        ["14", "美元", "usd"],
        ["18", "新加坡元", "sgd"],
        ["29", "澳大利亚元", "aud"],
        ["12", "英镑", "gbp"],
        [undefined, "澳门元", "mop"]
    ];

    /**
     * @author    EX-ZHENGZONGYI001
     * @description  货币MAP集合
     * @example    　["156", "人民币"],["250", "马克"]
     */
    var currencyMap2 = [
        ["156", "人民币"],
        ["250", "马克"],
        ["256", "法郎"],
        ["344", "港元"],
        ["392", "日元"],
        ["826", "英镑"],
        ["840", "美元"],
        ["954", "欧元"]
    ];

    /**
     * @author    EX-ZHENGZONGYI001
     * @description   根据货币代码或货币简写获取货币名称
     * @example    getCurrencyName("01") --> "人民币"
     * @example    getCurrencyName("rmb") --> "人民币"
     * @example    getCurrencyName("0123") --> "人民币,欧元"
     * @param : options : {
     *    @param {string} 　　  code               货币代码或货币简写
     *    @param {non-false} isUserMap2 默认false,当isUserMap2为ture时方法使用currencyMap2数组
     * }
     * @return {string} 　   result     返回货币名称
     */
    string.getCurrencyName = function(options){
        function _getName(value, map, key){
            for(var len = map.length; len--;){
                if(map[len][key] === value) return map[len][1];
            }
        }

        if(options){
            code = options.code || "";
            code = code.toString().toLowerCase();
            if(code === "") return "";
            if(code.length < 2) return "";
            if(options.isUserMap2) return _getName(code, currencyMap2, 0);
            if(!/\d+/.test(code)) return _getName(code, currencyMap, 2) || "";
            if(code.length === 2) return _getName(code, currencyMap, 0) || "";
            var ret = [], val;
            for(var i = 0, len = code.length; i < len; i += 2){
                if(val = this.getCurrencyName({'code':code.substr(i, 2),'isUserMap2':false})) ret.push(val);
            }
            return ret.join();
        }else{
           wrapView.FlipPrompt.alert({'title':"温馨提示" , 'content':"options对象为空"});
        }
    };
    string.moneyFormatHTML=function(options){
        var html='';
        var moneyInt=string.formatMoneyNumber(options.money).split(".")[0];
        var moneyFloat=string.formatMoneyNumber(options.money).split(".")[1];
        // <span class="f21"><%=payDepositInt%>.</span><span class="f16"><%=payDepositFloat%></span>
        html+='<span class="'+options.bigFontClass+'">'+moneyInt+'.</span>';
        html+='<span class="'+options.smallFontClass+'">'+moneyFloat+'</span>';
        return html;
    };
    string._maskPhoneNumber = function(phone){
        // 紧急联系人电话只显示尾4位，其他脱敏显示
        var phone = phone.replace(/\s/g,"");
       	var phoneLength = phone.length;
        if(!_.isString(phone)) return "";
        if(phoneLength <= 10){
	        return $.trim(phone).replace(/^.+(.{4})$/, "****$1");
        }else{
            return phone.substr(0, 3) + "****" + phone.substr(phone.length-4, 4);
        }
    };
    string._dealTheName = function(name){
        // 紧急联系人姓名
        // 2位，显示名，姓脱敏显示
        // 3位，显示首尾，中间脱敏显示
        // 4位及以上，显示首尾，中间脱敏显示；为奇数，中间脱敏以*代替；为偶数，中间脱敏以**代替
        if(!_.isString(name) || !(name = $.trim(name)))
            return "";

        var words = name.split(name.indexOf(" ") === -1 ? "" : " ");
        var length = words.length;

        switch(length){
            case 1: return name;
            case 2: return "*" + words[1]
            case 3: return words[0] + "*" + words[2];
            default: return words[0] + (length % 2 ? "*" : "**") + words[length - 1];
        }
    };
    string._dealTheAddress = function(address){
        // 家庭住址，省、市、县、区显示街道及详细地址掩码
        if(!_.isString(address)) return "";
        str = $.trim(address);
        length = str.length;
        if(length > 4 ){
	        if(str.indexOf("县") > 0){
	        	address = str.substr(0,(str.indexOf("县")+1))+"****";
	        	return address;
	        }
	        else if(str.indexOf("区") > 0){
	        	address = str.substr(0,(str.indexOf("区")+1))+"****";
	        	return address;
	        }else{
	        	if(str.indexOf("市") > 0){
	        		address = str.substr(0,(str.indexOf("市")+1))+"****";
		        	return address;
	        	}else if(str.indexOf("省") > 0){
	        		address = str.substr(0,(str.indexOf("省")+1))+"****";
		        	return address;
	        	}else{
	        		address = "****" + str.substr(length-3);
	        		return address;
	        	}
	        }
        }else{
        	return str;
        }
    };

     /**
     * 挂失拦截提示  add hzt 2015-06-09
     */
    string.interceptLoss = function () {
        var lossStatus = App.storage.get("cradLossStatus");
        if (lossStatus) {
            utils.dialog.alert("您的平安橙子账户已冻结，请先解除冻结后再使用此功能。");
            return true;
        }
        return false;
    };

    /**
    * 字符截断  wuyongsheng560 2015-07-27
    * length，新字符串长度，truncation，新字符串的结尾的字段,返回新字符串
    */
    string.truncate = function(str, length, truncation) {
        if(typeof str !== "string") return str;
        length = length || 30;
        truncation = typeof truncation === "string" ?  truncation : "...";
        return str.length > length ? str.slice(0, length - truncation.length) + truncation : str;
    };
    
    /**
     * 手机号格式化（3 4 4）：186 1988 0525
     */
    string.formatMobile = function(mobile){
        return mobile.replace(/(\d{3})(\d{4})(\d{4})/,"$1 $2 $3");
    };
    
});