/**
 * ex-penglu001
 *
 * 功能描述：提供各种验证方法的工具类
 */
define(function(require, exports, module){

    var validate = module.exports = {

        /**
         * @description 邮箱规则验证
         * @param {Object} str 邮箱
         * @return  boolean
         */
        email : function(str){
            str = str.replace(/\u2006/g, '');
            //var regEmail = /^([a-zA-Z0-9]+[_|\_|\.|\-]?)*[a-zA-Z0-9]+@([a-zA-Z0-9]+[_|\_|\.|\-]?)*[a-zA-Z0-9]+\.[a-zA-Z]{2,3}$/;
            //var regEmail = /^\w+((-\w+)|(\.\w+))*\@[A-Za-z0-9]+((\.|-)[A-Za-z0-9]+)*\.[A-Za-z0-9]+$/;
            var regEmail = /^[a-zA-Z0-9]+[_\.\-]?[a-zA-Z0-9]+@[a-zA-Z0-9]+[_\.\-]?[a-zA-Z0-9]+\.[a-zA-Z]{2,3}$/;
            return regEmail.test(str);
        },

        /**
         * @description 手机规则验证
         * @param {Object} str
         * @return  boolean
         */
        phone : function(str) {
            str = str.replace(/\s/g,"");
            var regPhone = /^((\(\d{2,3}\))|(\d{3}\-))?1[3-8]\d{9}$/;
            return regPhone.test(str);
        },

        /**
         * @description 交易密码规则验证
         * @param {Object} str 交易密码
         * @return  boolean
         */
        password : function(str) {
            var regPwd = /^\d{6}$/;
            return regPwd.test(str);
        },

        /**
         * @description    邮件编码验证
         * @param {Object} str 邮件编码
         * @return  boolean
         */
        zipCode : function(str){
            var regCode = /^[0-9]{6}$/;
            return regCode.test(str);
        },

        /**
         * @description    区号验证
         * @param {Object} str 邮件编码
         * @return  boolean
         */
        areaCode : function(str){
            var ergAreaCode = /^\d{3,4}$/;
            return ergAreaCode.test(str);
        },

        /**
         * @description    电话编码验证
         * @param {Object} str 邮件编码
         * @return  boolean
         */
        telephoneCode : function(str){
            var telephoneCode = /^\d{7,8}$/;
            return telephoneCode.test(str);
        },

        /**
         * @description    电话编码验证
         * @param {Object} str 邮件编码
         * @return  boolean
         */
        telephone : function(str){
            var telephone = /^\d{7,12}$/;
            return telephone.test(str);
        },

        /**
         * @description    特殊字符验证
         * @param {Object} str
         * @return  boolean
         */
        specialCharacter : function(str){
            var specialCharacter = /^[^$:&#：%‘“'"<>/]*$/;
            return specialCharacter.test(str);
        }
    };

});
