/**
 * wuyongsheng560 滑动事件简单封装
 * $('#test').swipe([options, ], callback);
 */
(function(factory) {
    'use strict';
    if (typeof define === 'function' && define.amd) {
        define(['jquery'], factory);
    } else if (typeof exports !== 'undefined') {
        module.exports = factory(require('jquery'));
    } else {
        factory(jQuery);
    }

}(function($) {
    'use strict';

    var Swipe = window.Swipe || {};

    Swipe = (function() {
        function Swipe(element, settings, callback) {
            var _this = this;
            _this.$el = $(element);
            if(_this.$el.size() < 1) return;
            if($.isFunction(settings)){
                callback = settings;
                settings = {};
            }
            callback = $.isFunction(callback) ? callback : function () {};

            _this.defaults = {
                onInit: null,
                rtl: false,
                swipe: true,
                touchThreshold: 5, //屏幕 5等分
                vertical: false
            };

            _this.direction = 'left';  //滑动 方向 left,  right
            _this.touchObject = {};
            _this._winWidth = $(window).width();

            _this.options = $.extend({}, _this.defaults, settings);

            _this.originalSettings = _this.options;

            _this.swipeHandler = $.proxy(_this.swipeHandler, _this);
            _this._swipeCallback = $.proxy(callback, _this);

            _this.init();

        }

        return Swipe;
    }());

    Swipe.prototype.destroy = function() {

        var _this = this;
        _this.touchObject = {};
        _this.$el.off('.swipe');

    };

    Swipe.prototype.init = function() {

        var _this = this;

        _this.$el.on('touchstart.swipe mousedown.swipe', {
            action: 'start'
        }, _this.swipeHandler);
        _this.$el.on('touchmove.swipe mousemove.swipe', {
            action: 'move'
        }, _this.swipeHandler);
        _this.$el.on('touchend.swipe mouseup.swipe', {
            action: 'end'
        }, _this.swipeHandler);
        _this.$el.on('touchcancel.swipe mouseleave.swipe', {
            action: 'end'
        }, _this.swipeHandler);

        if (_this.options.onInit !== null) {
            _this.options.onInit.call(this, _this);
        }

    };

    Swipe.prototype.swipeDirection = function() {

        var xDist, yDist, r, swipeAngle, rtl = this.options.rtl === false;

        xDist = this.touchObject.startX - this.touchObject.curX;
        yDist = this.touchObject.startY - this.touchObject.curY;
        r = Math.atan2(yDist, xDist);

        swipeAngle = Math.round(r * 180 / Math.PI);

        if (swipeAngle >= -45 && swipeAngle <= 45) {
            return (rtl ? 'left' : 'right');
        }
        if ((swipeAngle >= -180) && (swipeAngle <= -135)) {
            return (rtl ? 'right' : 'left');
        }
        if ((swipeAngle >= 135) && (swipeAngle <= 180)) {
            return (rtl ? 'right' : 'left');
        }


        if ((swipeAngle < 135) && (swipeAngle > 45)) {
            return (rtl ? 'up' : 'down');
        }
        if ((swipeAngle > -135) && (swipeAngle < -45)) {
            return (rtl ? 'down' : 'up');
        }
    };

    Swipe.prototype.swipeStart = function(event) {

        var _this = this,
            touches;

        if (_this.touchObject.fingerCount !== 1 ) {
            _this.touchObject = {};
            return false;
        }

        if (event.originalEvent !== undefined && event.originalEvent.touches !== undefined) {
            touches = event.originalEvent.touches[0];
        }

        _this.touchObject.startX = _this.touchObject.curX = touches !== undefined ? touches.pageX : event.clientX;
        _this.touchObject.startY = _this.touchObject.curY = touches !== undefined ? touches.pageY : event.clientY;

        _this.dragging = true;

    };

    Swipe.prototype.swipeMove = function(event) {

        var _this = this, swipeDirection, positionOffset, touches;

        touches = event.originalEvent !== undefined ? event.originalEvent.touches : null;

        if (!_this.dragging || touches && touches.length !== 1) {
            return false;
        }

        _this.touchObject.curX = touches !== undefined ? touches[0].pageX : event.clientX;
        _this.touchObject.curY = touches !== undefined ? touches[0].pageY : event.clientY;

        _this.touchObject.swipeLenX = Math.round(Math.sqrt( Math.pow(_this.touchObject.curX - _this.touchObject.startX, 2)));
        _this.touchObject.swipeLenY = Math.round(Math.sqrt( Math.pow(_this.touchObject.curY - _this.touchObject.startY, 2)));


        if (event.originalEvent !== undefined && (_this.touchObject.swipeLenX > 4 || _this.touchObject.swipeLenY > 4)) {
            event.preventDefault();
        }

        positionOffset = (_this.options.rtl === false ? 1 : -1) * (_this.touchObject.curX > _this.touchObject.startX ? 1 : -1);

        _this._swipeLeft = _this.touchObject.swipeLenX * positionOffset;
        _this._swipeDonw = _this.touchObject.swipeLenY * positionOffset;

    };

    Swipe.prototype.swipeEnd = function(event) {

        var _this = this, swipeDirection;

        _this.dragging = false;

        if (_this.touchObject.curX === undefined || _this.touchObject.curY === undefined) {
            return false;
        }

        swipeDirection = _this.swipeDirection();

        if (_this.touchObject.swipeLenX >= _this.touchObject.minSwipe || _this.touchObject.swipeLenY >= _this.touchObject.minSwipe) {
            _this.direction = swipeDirection;
        }else{
            _this.direction = null;
        }

        _this._swipeCallback();
        _this.touchObject = {};

    };

    Swipe.prototype.swipeHandler = function(event) {

        var _this = this;

        if ((_this.options.swipe === false) || ('ontouchend' in document && _this.options.swipe === false)) {
           return;
        }

        _this.touchObject.fingerCount = event.originalEvent && event.originalEvent.touches !== undefined ?
            event.originalEvent.touches.length : 1;

        _this.touchObject.minSwipe = _this._winWidth / _this.options
            .touchThreshold;

        switch (event.data.action) {

            case 'start':
                _this.swipeStart(event);
                break;

            case 'move':
                _this.swipeMove(event);
                break;

            case 'end':
                _this.swipeEnd(event);
                break;

        }

    };

    $.fn.swipe = function(options, callback) {
        var _this = this;
        return _this.each(function(index, element) {

            element.swipe = new Swipe(element, options, callback);

        });
    };

    return Swipe;
}));